@@ -26,14 +26,15 @@ describe('Gerbera Items', () => {
   });
   afterEach((done) => {
     $("body").on('transitionend', function(event){
-      fixture.cleanup();
       $('#editModal').remove();
       $('.modal-backdrop').remove();
-      done();
     });
     fixture.cleanup();
     done();
   });
+  beforeAll(() => {
+    spyOn(GerberaApp, 'writeLocalStorage').and.callFake(() => {});
+  });
 
   describe('initialize()', () => {
    beforeEach(() => {
@@ -66,6 +67,7 @@ describe('Gerbera Items', () => {
       };
       spyOn(GerberaApp, 'getType').and.returnValue('db');
       GerberaApp.serverConfig = {};
+      GerberaApp.pageInfo.viewItems = 25;
 
       await Items.initialize();
       Items.treeItemSelected(data);
@@ -94,6 +96,7 @@ describe('Gerbera Items', () => {
     beforeEach(() => {
       GerberaApp.serverConfig = {};
       spyOn(GerberaApp, 'getType').and.returnValue('db');
+      spyOn(GerberaApp, 'gridMode').and.returnValue(0);
       $('#tree').tree({
         data: treeDataJson,
         config: {
@@ -129,7 +132,7 @@ describe('Gerbera Items', () => {
     it('sets pager click to the callback method', () => {
       itemsResponse.success = true;
       spyOn(Items, 'retrieveItemsForPage');
-      spyOn(GerberaApp, 'viewItems').and.returnValue(25);
+      spyOn(GerberaApp, 'viewItems').and.returnValue(10);
 
       Items.loadItems(itemsResponse);
       $($('#datagrid nav.grb-pager > ul > li').get(1)).find('a').click();
@@ -364,16 +367,17 @@ describe('Gerbera Items', () => {
       editModal.editmodal('loadItem', itemData);
 
       Items.saveItem();
-
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
-        sid: 'SESSION_ID',
+      var data = {
         req_type: 'edit_save',
         object_id: '39479',
         title: 'Test.mp4',
         description: 'A%20description',
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
       editModal.remove();
     });
 
@@ -385,15 +389,16 @@ describe('Gerbera Items', () => {
       editModal.editmodal('loadItem', itemData);
 
       Items.saveItem();
-
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
-        sid: 'SESSION_ID',
+      var data = {
         req_type: 'edit_save',
         object_id: '1471',
         title: 'container%20title',
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
       editModal.remove();
     });
 
@@ -405,10 +410,7 @@ describe('Gerbera Items', () => {
       editModal.editmodal('loadItem', itemData);
 
       Items.saveItem();
-
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
-        sid: 'SESSION_ID',
+      var data = {
         req_type: 'edit_save',
         object_id: '1469',
         title: 'title',
@@ -417,7 +419,11 @@ describe('Gerbera Items', () => {
         'mime-type': 'video%2Fts',
         protocol: 'http-get',
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
       editModal.remove();
     });
   });
@@ -566,10 +572,7 @@ describe('Gerbera Items', () => {
       editModal.editmodal('addNewItem', {type: 'item', item: item});
 
       await Items.addObject();
-
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
-        sid: 'SESSION_ID',
+      var data = {
         req_type: 'add_object',
         parent_id: '9999',
         obj_type: 'item',
@@ -578,7 +581,11 @@ describe('Gerbera Items', () => {
         title: '',
         description: '',
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
     });
 
     it('allows creation of object under root parent = 0 (database)', async () => {
@@ -588,44 +595,43 @@ describe('Gerbera Items', () => {
       editModal.editmodal('addNewItem', {type: 'container', item: parentId});
 
       await Items.addObject();
-
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
-        sid: 'SESSION_ID',
+      var data = {
         req_type: 'add_object',
         parent_id: '0',
         obj_type: 'container',
         class: 'object.container',
         title: '',
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
     });
 
     it('calls the server with the `container` details', async () => {
       editModal.editmodal('addNewItem', {type: 'container', item: item});
 
       await Items.addObject();
-
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
-        sid: 'SESSION_ID',
+      var data = {
         req_type: 'add_object',
         parent_id: '9999',
         obj_type: 'container',
         class: 'object.container',
         title: '',
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
     });
 
     it('calls the server with the `external_url` details', async () => {
       editModal.editmodal('addNewItem', {type: 'external_url', item: item});
 
       await Items.addObject();
-
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
-        sid: 'SESSION_ID',
+      var data = {
         req_type: 'add_object',
         parent_id: '9999',
         obj_type: 'external_url',
@@ -636,7 +642,11 @@ describe('Gerbera Items', () => {
         'mime-type': '',
         protocol: 'http-get',
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
     });
 
     it('when successful adds a GERBERA.Updates UI timer to check for updates later', async () => {
@@ -664,15 +674,16 @@ describe('Gerbera Items', () => {
       spyOn(Auth, 'getSessionId').and.returnValue('SESSION_ID');
 
       await Items.retrieveGerberaItems('db', 0, 0, 25);
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
+      var data = {
         req_type: 'db',
-        sid: 'SESSION_ID',
         parent_id: 0,
         start: 0,
         count: 25,
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
     });
   });
   describe('retrieveItemsForPage()', () => {
@@ -705,15 +716,16 @@ describe('Gerbera Items', () => {
       spyOn(GerberaApp, 'getType').and.returnValue('db');
 
       await Items.retrieveItemsForPage(event);
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
+      var data = {
         req_type: 'items',
-        sid: 'SESSION_ID',
         parent_id: 1235,
         start: 0,
         count: 25,
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
       expect(GerberaApp.currentPage()).toBe(1);
     });
 
@@ -730,16 +742,16 @@ describe('Gerbera Items', () => {
       spyOn(GerberaApp, 'getType').and.returnValue('db');
 
       await Items.retrieveItemsForPage(event);
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
+      var data = {
         req_type: 'items',
-        sid: 'SESSION_ID',
         parent_id: 1235,
         start: 100,
         count: 25,
         updates: 'check'
-      });
-
+      };
+      data[Auth.SID] = 'SESSION_ID';
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
       expect(GerberaApp.currentPage()).toBe(5);
     });
   });
@@ -771,16 +783,17 @@ describe('Gerbera Items', () => {
       Items.setPage(1);
 
       await Items.nextPage(event);
-
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
+      var data = {
         req_type: 'items',
-        sid: 'SESSION_ID',
         parent_id: 1235,
         start: 25,
-        count: 50,
+        count: 25,
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
       expect(GerberaApp.currentPage()).toBe(2);
     });
   });
@@ -812,15 +825,16 @@ describe('Gerbera Items', () => {
       Items.setPage(2);
 
       await Items.previousPage(event);
-      expect(ajaxSpy.calls.count()).toBe(1);
-      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual({
+      var data = {
         req_type: 'items',
-        sid: 'SESSION_ID',
         parent_id: 1235,
         start: 0,
-        count: 50,
+        count: 25,
         updates: 'check'
-      });
+      };
+      data[Auth.SID] = 'SESSION_ID';
+      expect(ajaxSpy.calls.count()).toBe(1);
+      expect(ajaxSpy.calls.mostRecent().args[0].data).toEqual(data);
       expect(GerberaApp.currentPage()).toBe(1);
     });
   });
