@@ -1,7 +1,9 @@
 #!/usr/bin/env bash
-
 set -Eeuo pipefail
 
+ROOT_DIR=`dirname $0`/../../
+ROOT_DIR=`realpath ${ROOT_DIR}`/
+
 function install-gcc {
   echo "::group::Installing GCC"
   # bionic defaults to gcc-7
@@ -17,9 +19,9 @@ function install-gcc {
 
 function install-cmake() {
   echo "::group::Installing CMake"
-  if [[ "$lsb_codename" == "bionic" ]]; then
+  if [[ "$lsb_codename" == "bionic" || "$lsb_codename" == "focal" ]]; then
     sudo apt-get install apt-transport-https ca-certificates gnupg software-properties-common wget -y
-    wget -O - https://apt.kitware.com/keys/kitware-archive-latest.asc 2>/dev/null | gpg --dearmor - | sudo tee /etc/apt/trusted.gpg.d/kitware.gpg >/dev/null
+    curl https://apt.kitware.com/keys/kitware-archive-latest.asc | gpg --dearmor - | sudo tee /etc/apt/trusted.gpg.d/kitware.gpg >/dev/null
     sudo apt-add-repository "deb https://apt.kitware.com/ubuntu/ ${lsb_codename} main"
     sudo apt-get update -y
   fi
@@ -29,22 +31,62 @@ function install-cmake() {
 
 function install-fmt {
   echo "::group::Installing fmt"
-  #if [[ "$lsb_codename" == "bionic" || "$lsb_codename" == "buster" || "$lsb_codename" == "hirsute" ]]; then
-    sudo bash scripts/install-fmt.sh static
-  #else
-  #   sudo apt-get install libfmt-dev -y
-  #fi
+  sudo bash ${ROOT_DIR}scripts/install-fmt.sh static
   echo "::endgroup::"
 }
 
 function install-spdlog() {
   echo "::group::Installing spdlog"
+  sudo bash ${ROOT_DIR}scripts/install-spdlog.sh static
+  echo "::endgroup::"
+}
 
-  #if [[ "$lsb_codename" == "bionic" || "$lsb_codename" == "buster" || "$lsb_codename" == "hirsute" ]]; then
-    sudo bash scripts/install-spdlog.sh
-  #else
-  #  sudo apt-get install libspdlog-dev -y
-  #fi
+function install-googletest() {
+  echo "::group::Installing googletest"
+  sudo bash ${ROOT_DIR}scripts/install-googletest.sh
+  echo "::endgroup::"
+}
+
+function install-pupnp() {
+  echo "::group::Installing libupnp"
+  sudo bash ${ROOT_DIR}scripts/install-pupnp.sh
+  echo "::endgroup::"
+}
+
+function install-taglib() {
+  echo "::group::Installing taglib"
+  sudo bash ${ROOT_DIR}scripts/install-taglib.sh
+  echo "::endgroup::"
+}
+
+function install-ffmpegthumbnailer() {
+  echo "::group::Installing ffmpegthumbnailer"
+  sudo bash ${ROOT_DIR}scripts/install-ffmpegthumbnailer.sh
+  echo "::endgroup::"
+}
+
+function install-pugixml() {
+  echo "::group::Installing pugixml"
+  sudo bash ${ROOT_DIR}scripts/install-pugixml.sh
+  echo "::endgroup::"
+}
+
+function install-duktape() {
+  echo "::group::Installing duktape"
+  sudo bash ${ROOT_DIR}scripts/install-duktape.sh
+  echo "::endgroup::"
+}
+
+function install-libexiv2() {
+  echo "::group::Installing libexiv2"
+  sudo bash ${ROOT_DIR}scripts/install-libexiv2.sh static
+  echo "::endgroup::"
+}
+
+function install-matroska() {
+  echo "::group::Installing matroska"
+  sudo bash ${ROOT_DIR}scripts/install-ebml.sh
+  sudo bash ${ROOT_DIR}scripts/install-matroska.sh
   echo "::endgroup::"
 }
 
@@ -58,31 +100,59 @@ function upload_to_artifactory() {
   curl -H "X-JFrog-Art-Api:$ART_API_KEY" -XPUT  -T "$deb_name" -uian@gerbera.io:"${ART_API_KEY}" "$bintray_url"
 }
 
+# Fix time issues
+ln -snf /usr/share/zoneinfo/$TZ /etc/localtime && echo $TZ > /etc/timezone
+
+# Pre reqs
 export DEBIAN_FRONTEND=noninteractive
+apt-get update -y
+apt-get install -y lsb-release sudo wget curl git ca-certificates
+
 lsb_codename=$(lsb_release -c --short)
 lsb_distro=$(lsb_release -i --short)
 lsb_rel=$(lsb_release -r --short)
 
 install-gcc
 install-cmake
+my_sys=${lsb_codename}
+if [ $# -gt 0 ]; then
+  my_sys=$1
+fi
 
-echo "Running $0 $1"
+echo "Running $0 ${my_sys}"
 
-libduktape="libduktape205"
-if [[ "$lsb_codename" == "bionic" ]]; then
-  libduktape="libduktape202"
-elif [ "$lsb_codename" == "buster" ]; then
-  libduktape="libduktape203"
-elif [ "$lsb_codename" == "sid" -o "$1" == "debian:testing" -o "$1" == "debian:unstable" ]; then
-  libduktape="libduktape206"
+if [[ "${my_sys}" == "HEAD" ]]; then
+  libexiv2="libexpat1-dev"
+  libduktape=""
+  libmatroska=""
+  libpugixml=""
+  ffmpegthumbnailer="ffmpeg libavfilter-dev libavcodec-dev libavutil-dev libavdevice-dev libavresample-dev"
+  BuildType="Debug"
+  DoTests="ON"
+else
+  libexiv2="libexiv2-dev"
+  libpugixml="libpugixml-dev"
+  libmatroska="libebml-dev libmatroska-dev"
+  libduktape="libduktape205"
+  ffmpegthumbnailer="libffmpegthumbnailer-dev"
+  BuildType="Release"
+  DoTests="OFF"
+  if [[ "$lsb_codename" == "bionic" ]]; then
+    libduktape="libduktape202"
+  elif [ "$lsb_codename" == "buster" ]; then
+    libduktape="libduktape203"
+  elif [ "$lsb_codename" == "sid" -o "${my_sys}" == "debian:testing" -o "${my_sys}" == "debian:unstable" ]; then
+    libduktape="libduktape206"
+  fi
+  libduktape="duktape-dev ${libduktape}"
+  echo "Selecting $libduktape for $lsb_distro $lsb_codename"
 fi
-echo "Selecting $libduktape for $lsb_distro $lsb_codename"
 
 libmysqlclient="libmysqlclient-dev"
-if [ "$lsb_distro" == "Debian" ]; then
+if [ "$lsb_distro" == "Debian" -o "$lsb_distro" == "Raspbian" ]; then
   libmysqlclient="libmariadb-dev-compat"
 fi
-if [[ "$lsb_codename" == "hirsute" ]]; then
+if [[ "$lsb_codename" == "hirsute" || "$lsb_codename" == "impish" ]]; then
   libmysqlclient="libmysql++-dev"
 fi
 
@@ -94,22 +164,21 @@ if [[ ! -d build-deb ]]; then
   sudo apt-get install -y \
       dpkg-dev \
       systemd \
+      build-essential shtool \
       wget autoconf libtool pkg-config \
       cmake \
       bsdmainutils \
-      duktape-dev \
       libavformat-dev \
       libcurl4-openssl-dev \
-      "${libduktape}" \
-      libebml-dev \
+      ${libduktape} \
+      ${libmatroska} \
+      ${libexiv2} \
       libexif-dev \
-      libffmpegthumbnailer-dev \
+      ${ffmpegthumbnailer} \
       libmagic-dev \
-      libmatroska-dev \
       "${libmysqlclient}" \
-      libpugixml-dev \
+      "${libpugixml}" \
       libsqlite3-dev \
-      libtag1-dev \
       uuid-dev
   sudo apt-get clean
   echo "::endgroup::"
@@ -121,12 +190,19 @@ if [[ "$lsb_codename" == "bionic" ]]; then
   sudo update-alternatives --set cpp /usr/bin/cpp-8
 fi
 
+if [[ "${my_sys}" == "HEAD" ]]; then
+  install-googletest
+  install-libexiv2
+  install-pugixml
+  install-duktape
+  install-matroska
+  install-ffmpegthumbnailer
+fi
+
 install-fmt
 install-spdlog
-
-echo "::group::Installing libupnp"
-sudo bash scripts/install-pupnp.sh
-echo "::endgroup::"
+install-pupnp
+install-taglib
 
 cd build-deb
 
@@ -144,8 +220,8 @@ fi
 deb_arch=$(dpkg --print-architecture)
 deb_name="gerbera_${deb_version}_${deb_arch}.deb"
 
-if [[ ! -f $deb_name ]]; then
-  cmake ../ \
+if [[ (! -f ${deb_name}) || "${my_sys}" == "HEAD" ]]; then
+  cmake ${ROOT_DIR} -DWITH_TESTS=${DoTests} \
     -DWITH_MAGIC=ON \
     -DWITH_MYSQL=ON \
     -DWITH_CURL=ON \
@@ -154,22 +230,29 @@ if [[ ! -f $deb_name ]]; then
     -DWITH_AVCODEC=ON \
     -DWITH_FFMPEGTHUMBNAILER=ON \
     -DWITH_EXIF=ON \
+    -DWITH_EXIV2=ON \
     -DWITH_LASTFM=OFF \
     -DWITH_SYSTEMD=ON \
     -DWITH_DEBUG=ON \
     -DSTATIC_LIBUPNP=ON \
-    -DCMAKE_BUILD_TYPE=Release \
+    -DCMAKE_BUILD_TYPE=${BuildType} \
     -DCMAKE_INSTALL_PREFIX=/usr
   make "-j$(nproc)"
 
-  cpack -G DEB -D CPACK_DEBIAN_PACKAGE_VERSION="$deb_version" -D CPACK_DEBIAN_PACKAGE_ARCHITECTURE="$deb_arch"
+  if [[ "${my_sys}" != "HEAD" ]]; then
+    cpack -G DEB -D CPACK_DEBIAN_PACKAGE_VERSION="$deb_version" -D CPACK_DEBIAN_PACKAGE_ARCHITECTURE="$deb_arch"
+  fi
 else
   printf "Deb already built!\n"
 fi
 
-if [[ "${ART_API_KEY:-}" ]]; then
-  # Tags only for main repo
-  [[ $is_tag == 1 ]] && upload_to_artifactory debian
-  # Git builds go to git
-  upload_to_artifactory debian-git
+if [[ "${my_sys}" != "HEAD" ]]; then
+  if [[ "${ART_API_KEY:-}" ]]; then
+    # Tags only for main repo
+    [[ $is_tag == 1 ]] && upload_to_artifactory debian
+    # Git builds go to git
+    upload_to_artifactory debian-git
+  fi
+else
+  ctest --output-on-failure
 fi
