@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     cds_objects.h - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -32,12 +32,9 @@
 #ifndef __CDS_OBJECTS_H__
 #define __CDS_OBJECTS_H__
 
-#include <filesystem>
 #include <map>
 #include <memory>
-#include <string>
 #include <vector>
-namespace fs = std::filesystem;
 
 #include "cds_resource.h"
 #include "common.h"
@@ -103,13 +100,13 @@ protected:
     std::chrono::seconds utime {};
 
     /// \brief File size on disk (in bytes).
-    off_t sizeOnDisk {};
+    std::uintmax_t sizeOnDisk {};
 
     /// \brief virtual object flag
     bool virt {};
 
     /// \brief type of the object: item, container, etc.
-    unsigned int objectType;
+    unsigned int objectType {};
 
     /// \brief field which can hold various flags for the object
     unsigned int objectFlags { OBJECT_FLAG_RESTRICTED };
@@ -117,7 +114,7 @@ protected:
     /// \brief flag that allows to sort objects within a container
     int sortPriority {};
 
-    std::map<std::string, std::string> metadata;
+    std::vector<std::pair<std::string, std::string>> metaData;
     std::map<std::string, std::string> auxdata;
     std::vector<std::shared_ptr<CdsResource>> resources;
 
@@ -155,7 +152,6 @@ public:
 
     /// \brief Retrieve the objects parent ID.
     int getParentID() const { return parentID; }
-    std::shared_ptr<CdsObject> getParent() const { return parent; }
 
     /// \brief Set the restricted flag.
     void setRestricted(bool restricted) { changeFlag(OBJECT_FLAG_RESTRICTED, restricted); }
@@ -175,7 +171,7 @@ public:
     /// \brief Set the physical location of the media (usually an absolute path)
     void setLocation(const fs::path& location) { this->location = location; }
     /// \brief Retrieve media location.
-    fs::path getLocation() const { return location; }
+    const fs::path& getLocation() const { return location; }
 
     /// \brief Set modification time of the media file.
     void setMTime(std::chrono::seconds mtime) { this->mtime = mtime; }
@@ -188,9 +184,9 @@ public:
     std::chrono::seconds getUTime() const { return utime; }
 
     /// \brief Set file size.
-    void setSizeOnDisk(off_t sizeOnDisk) { this->sizeOnDisk = sizeOnDisk; }
+    void setSizeOnDisk(std::uintmax_t sizeOnDisk) { this->sizeOnDisk = sizeOnDisk; }
     /// \brief Retrieve the file size (in bytes).
-    off_t getSizeOnDisk() const { return sizeOnDisk; }
+    std::uintmax_t getSizeOnDisk() const { return sizeOnDisk; }
 
     /// \brief Set the virtual flag.
     void setVirtual(bool virt) { this->virt = virt; }
@@ -235,30 +231,63 @@ public:
     void clearFlag(unsigned int mask) { objectFlags &= ~mask; }
 
     /// \brief Query single metadata value.
-    std::string getMetadata(const metadata_fields_t key) const
+    std::string getMetaData(const metadata_fields_t key) const
     {
-        return getValueOrDefault(metadata, MetadataHandler::getMetaFieldName(key));
+        auto field = MetadataHandler::getMetaFieldName(key);
+        auto it = std::find_if(metaData.begin(), metaData.end(), [=](auto&& md) { return md.first == field; });
+        return it != metaData.end() ? it->second : std::string();
+    }
+    /// \brief Query single metadata value.
+    std::string getMetaData(const std::string& field) const
+    {
+        auto it = std::find_if(metaData.begin(), metaData.end(), [=](auto&& md) { return md.first == field; });
+        return it != metaData.end() ? it->second : std::string();
+    }
+    std::map<std::string, std::vector<std::string>> getMetaGroups() const
+    {
+        std::map<std::string, std::vector<std::string>> metaGroups;
+        for (auto&& [mkey, mvalue] : metaData) {
+            if (metaGroups.find(mkey) == metaGroups.end()) {
+                metaGroups[mkey] = {};
+            }
+            metaGroups[mkey].push_back(mvalue);
+        }
+        return metaGroups;
     }
 
     /// \brief Query entire metadata dictionary.
-    std::map<std::string, std::string> getMetadata() const { return metadata; }
+    const std::vector<std::pair<std::string, std::string>>& getMetaData() const { return metaData; }
+    void clearMetaData() { metaData.clear(); }
 
     /// \brief Set entire metadata dictionary.
-    void setMetadata(const std::map<std::string, std::string>& metadata)
+    void setMetaData(const std::vector<std::pair<std::string, std::string>>& metaData)
     {
-        this->metadata = metadata;
+        this->metaData = metaData;
     }
 
-    /// \brief Set a single metadata value.
-    void setMetadata(const metadata_fields_t key, const std::string& value)
+    /// \brief Set entire metadata dictionary by moving
+    void setMetaData(std::vector<std::pair<std::string, std::string>>&& metaData)
     {
-        metadata[MetadataHandler::getMetaFieldName(key)] = value;
+        this->metaData = std::move(metaData);
+    }
+
+    /// \brief Add a single metadata value.
+    void addMetaData(const metadata_fields_t key, const std::string& value)
+    {
+        metaData.emplace_back(MetadataHandler::getMetaFieldName(key), value);
+    }
+    /// \brief Add a single metadata value.
+    void addMetaData(const std::string& key, const std::string& value)
+    {
+        metaData.emplace_back(key, value);
     }
 
     /// \brief Removes metadata with the given key
-    void removeMetadata(const metadata_fields_t key)
+    void removeMetaData(const metadata_fields_t key)
     {
-        metadata.erase(MetadataHandler::getMetaFieldName(key));
+        auto&& field = MetadataHandler::getMetaFieldName(key);
+        while (std::find_if(metaData.begin(), metaData.end(), [=](auto&& md) { return md.first == field; }) != metaData.end())
+            metaData.erase(std::remove_if(metaData.begin(), metaData.end(), [=](auto&& md) { return md.first == field; }));
     }
 
     /// \brief Query single auxdata value.
@@ -268,7 +297,7 @@ public:
     }
 
     /// \brief Query entire auxdata dictionary.
-    std::map<std::string, std::string> getAuxData() const { return auxdata; }
+    const std::map<std::string, std::string>& getAuxData() const { return auxdata; }
 
     /// \brief Set a single auxdata value.
     void setAuxData(const std::string& key, const std::string& value)
@@ -282,14 +311,8 @@ public:
         this->auxdata = auxdata;
     }
 
-    /// \brief Removes auxdata with the given key
-    void removeAuxData(const std::string& key)
-    {
-        auxdata.erase(key);
-    }
-
     /// \brief Get number of resource tags
-    size_t getResourceCount() const { return resources.size(); }
+    std::size_t getResourceCount() const { return resources.size(); }
 
     /// \brief Query resources
     const std::vector<std::shared_ptr<CdsResource>>& getResources() const
@@ -303,6 +326,12 @@ public:
         resources = res;
     }
 
+    /// \brief Set resources by move
+    void setResources(std::vector<std::shared_ptr<CdsResource>>&& res)
+    {
+        resources = std::move(res);
+    }
+
     /// \brief Search resources for given handler id
     bool hasResource(int id) const
     {
@@ -319,16 +348,16 @@ public:
     }
 
     /// \brief Query resource tag with the given index
-    std::shared_ptr<CdsResource> getResource(size_t index) const
+    std::shared_ptr<CdsResource> getResource(std::size_t index) const
     {
         return resources.at(index);
     }
 
     /// \brief Add resource tag
-    void addResource(std::shared_ptr<CdsResource> resource)
+    void addResource(const std::shared_ptr<CdsResource>& resource)
     {
         resource->setResId(resources.size());
-        resources.push_back(move(resource));
+        resources.push_back(resource);
     }
 
     /// \brief Copies all object properties to another object.
@@ -353,7 +382,7 @@ public:
 
     static std::shared_ptr<CdsObject> createObject(unsigned int objectType);
 
-    static std::string_view mapObjectType(unsigned int objectType);
+    static std::string_view mapObjectType(unsigned int type);
 };
 
 /// \brief An Item in the content directory.
@@ -387,7 +416,11 @@ public:
     std::string getMimeType() const { return mimeType; }
 
     /// \brief Sets the upnp:originalTrackNumber property
-    void setTrackNumber(int trackNumber) { this->trackNumber = trackNumber; }
+    void setTrackNumber(int trackNumber)
+    {
+        if (trackNumber >= 0)
+            this->trackNumber = trackNumber;
+    }
 
     int getTrackNumber() const { return trackNumber; }
 
@@ -433,16 +466,14 @@ public:
     /// \param URL full url to the item: http://somewhere.com/something.mpg
     void setURL(const std::string& URL) { this->location = URL; }
 
-    /// \brief Get the URL of the item.
-    std::string getURL() const { return location; }
     /// \brief Copies all object properties to another object.
     /// \param obj target object (clone)
-    //void copyTo(std::shared_ptr<CdsObject> obj) override;
+    // void copyTo(std::shared_ptr<CdsObject> obj) override;
 
     /// \brief Checks if current object is equal to obj.
     ///
     /// See description for CdsObject::equals() for details.
-    //int equals(std::shared_ptr<CdsObject> obj, bool exactly=false) override;
+    // int equals(std::shared_ptr<CdsObject> obj, bool exactly=false) override;
 
     /// \brief Checks if the minimum required parameters for the object have been set and are valid.
     void validate() const override;
@@ -463,6 +494,12 @@ protected:
 public:
     /// \brief Constructor, initializes default values for the flags and sets the object type.
     CdsContainer();
+    explicit CdsContainer(const std::string& title, const std::string& upnpClass = UPNP_CLASS_CONTAINER)
+    {
+        this->title = title;
+        this->upnpClass = upnpClass;
+    }
+
     bool isContainer() const override { return true; }
 
     /// \brief Set the searchable flag.
@@ -497,9 +534,10 @@ public:
     ///
     /// See description for CdsObject::equals() for details.
     bool equals(const std::shared_ptr<CdsObject>& obj, bool exactly = false) const override;
-
-    /// \brief Checks if the minimum required parameters for the object have been set and are valid.
-    void validate() const override;
+    /*
+        /// \brief Checks if the minimum required parameters for the object have been set and are valid.
+        void validate() const override;
+    */
 };
 
 #endif // __CDS_OBJECTS_H__
