@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     common.h - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -31,8 +31,6 @@
 #ifndef __COMMON_H__
 #define __COMMON_H__
 
-#include <cerrno>
-
 #include "exceptions.h"
 #include "upnp_common.h"
 #include "util/logger.h"
@@ -57,7 +55,6 @@ static constexpr bool IS_FORBIDDEN_CDS_ID(int id) { return id <= CDS_ID_FS_ROOT;
 #define URL_UI_PARAM_SEPARATOR '?'
 #define SERVER_VIRTUAL_DIR "content"
 #define CONTENT_MEDIA_HANDLER "media"
-#define CONTENT_SERVE_HANDLER "serve"
 #define CONTENT_ONLINE_HANDLER "online"
 #define CONTENT_UI_HANDLER "interface"
 #define DEVICE_DESCRIPTION_PATH "description.xml"
@@ -69,14 +66,13 @@ static constexpr bool IS_FORBIDDEN_CDS_ID(int id) { return id <= CDS_ID_FS_ROOT;
 #define VIRTUAL_CONTAINER_ESCAPE '\\'
 
 // MIME TYPES FOR WEB UI
-#define MIMETYPE_XML "text/xml"
 #define MIMETYPE_TEXT "text/plain"
 #define MIMETYPE_JSON "application/json" // RFC 4627
 // default mime types for items in the cds
 #define MIMETYPE_DEFAULT "application/octet-stream"
 
 // default protocol
-#define PROTOCOL "http-get"
+static constexpr auto PROTOCOL = std::string_view("http-get");
 
 // device description defaults
 #define DESC_MANUFACTURER_URL "http://gerbera.io/"
@@ -124,12 +120,6 @@ static constexpr auto CFG_DEFAULT_UPDATE_AT_START = std::chrono::seconds(10);
 #define INVALID_OBJECT_ID_2 (-666)
 #define CHECK_SOCKET (-666)
 
-// database
-#define LOC_DIR_PREFIX 'D'
-#define LOC_FILE_PREFIX 'F'
-#define LOC_VIRT_PREFIX 'V'
-#define LOC_ILLEGAL_PREFIX 'X'
-
 #define XML_XMLNS_XSI "http://www.w3.org/2001/XMLSchema-instance"
 #define XML_XMLNS "http://mediatomb.cc/config/"
 
