@@ -1,11 +1,11 @@
 /*GRB*
 
     Gerbera - https://gerbera.io/
-    
+
     config.h - this file is part of Gerbera.
-    
-    Copyright (C) 2020-2021 Gerbera Contributors
-    
+
+    Copyright (C) 2020-2022 Gerbera Contributors
+
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -24,11 +24,10 @@
 #ifndef __CONFIG_H__
 #define __CONFIG_H__
 
-#include <filesystem>
 #include <map>
-#include <memory>
 #include <vector>
-namespace fs = std::filesystem;
+
+#include "util/grb_fs.h"
 
 // forward declarations
 class AutoscanDirectory;
@@ -59,7 +58,6 @@ enum config_option_t {
     CFG_SERVER_HOME,
     CFG_SERVER_TMPDIR,
     CFG_SERVER_WEBROOT,
-    CFG_SERVER_SERVEDIR,
     CFG_SERVER_ALIVE_INTERVAL,
     CFG_SERVER_HIDE_PC_DIRECTORY,
     CFG_SERVER_BOOKMARK_FILE,
@@ -67,6 +65,9 @@ enum config_option_t {
     CFG_SERVER_UI_ENABLED,
     CFG_SERVER_UI_POLL_INTERVAL,
     CFG_SERVER_UI_POLL_WHEN_IDLE,
+    CFG_SERVER_UI_ENABLE_NUMBERING,
+    CFG_SERVER_UI_ENABLE_THUMBNAIL,
+    CFG_SERVER_UI_ENABLE_VIDEO,
     CFG_SERVER_UI_ACCOUNTS_ENABLED,
     CFG_SERVER_UI_ACCOUNT_LIST,
     CFG_SERVER_UI_SESSION_TIMEOUT,
@@ -97,8 +98,10 @@ enum config_option_t {
     CFG_SERVER_STORAGE_MYSQL_INIT_SQL_FILE,
     CFG_SERVER_STORAGE_MYSQL_UPGRADE_FILE,
 #endif
-#if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
+#ifdef HAVE_FFMPEGTHUMBNAILER
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED,
+    CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_VIDEO_ENABLED,
+    CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_ENABLED,
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE,
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE,
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY,
@@ -140,7 +143,7 @@ enum config_option_t {
     CFG_IMPORT_SCRIPTING_STRUCTURED_LAYOUT_GENREBOX,
     CFG_IMPORT_SCRIPTING_STRUCTURED_LAYOUT_TRACKBOX,
     CFG_IMPORT_SCRIPTING_STRUCTURED_LAYOUT_DIVCHAR,
-#endif // JS
+#endif // HAVE_JS
     CFG_IMPORT_SCRIPTING_VIRTUAL_LAYOUT_TYPE,
     CFG_IMPORT_SCRIPTING_IMPORT_GENRE_MAP,
 #ifdef HAVE_MAGIC
@@ -155,18 +158,23 @@ enum config_option_t {
     CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_CASE_SENSITIVE,
     CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST,
     CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST,
+    CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNATRANSFER_LIST,
     CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST,
     CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
+    CFG_IMPORT_MAPPINGS_IGNORED_EXTENSIONS,
 #ifdef HAVE_LIBEXIF
     CFG_IMPORT_LIBOPTS_EXIF_AUXDATA_TAGS_LIST,
+    CFG_IMPORT_LIBOPTS_EXIF_METADATA_TAGS_LIST,
     CFG_IMPORT_LIBOPTS_EXIF_CHARSET,
 #endif
 #ifdef HAVE_EXIV2
     CFG_IMPORT_LIBOPTS_EXIV2_AUXDATA_TAGS_LIST,
+    CFG_IMPORT_LIBOPTS_EXIV2_METADATA_TAGS_LIST,
     CFG_IMPORT_LIBOPTS_EXIV2_CHARSET,
 #endif
 #if defined(HAVE_TAGLIB)
     CFG_IMPORT_LIBOPTS_ID3_AUXDATA_TAGS_LIST,
+    CFG_IMPORT_LIBOPTS_ID3_METADATA_TAGS_LIST,
     CFG_IMPORT_LIBOPTS_ID3_CHARSET,
 #endif
     CFG_TRANSCODING_TRANSCODING_ENABLED,
@@ -174,13 +182,7 @@ enum config_option_t {
 #ifdef HAVE_CURL
     CFG_EXTERNAL_TRANSCODING_CURL_BUFFER_SIZE,
     CFG_EXTERNAL_TRANSCODING_CURL_FILL_SIZE,
-#endif //HAVE_CURL
-#ifdef SOPCAST
-    CFG_ONLINE_CONTENT_SOPCAST_ENABLED,
-    CFG_ONLINE_CONTENT_SOPCAST_REFRESH,
-    CFG_ONLINE_CONTENT_SOPCAST_UPDATE_AT_START,
-    CFG_ONLINE_CONTENT_SOPCAST_PURGE_AFTER,
-#endif
+#endif // HAVE_CURL
 #ifdef ATRAILERS
     CFG_ONLINE_CONTENT_ATRAILERS_ENABLED,
     CFG_ONLINE_CONTENT_ATRAILERS_REFRESH,
@@ -190,6 +192,7 @@ enum config_option_t {
 #endif
 #if defined(HAVE_FFMPEG)
     CFG_IMPORT_LIBOPTS_FFMPEG_AUXDATA_TAGS_LIST,
+    CFG_IMPORT_LIBOPTS_FFMPEG_METADATA_TAGS_LIST,
     CFG_IMPORT_LIBOPTS_FFMPEG_CHARSET,
 #endif
     CFG_CLIENTS_LIST,
@@ -216,6 +219,11 @@ enum config_option_t {
     CFG_VIRTUAL_URL,
     CFG_IMPORT_SYSTEM_DIRECTORIES,
     CFG_IMPORT_VISIBLE_DIRECTORIES,
+    CFG_UPNP_MULTI_VALUES_ENABLED,
+    CFG_UPNP_SEARCH_SEPARATOR,
+    CFG_UPNP_SEARCH_FILENAME,
+    CFG_UPNP_SEARCH_ITEM_SEGMENTS,
+    CFG_UPNP_SEARCH_CONTAINER_FLAG,
     CFG_UPNP_ALBUM_PROPERTIES,
     CFG_UPNP_ARTIST_PROPERTIES,
     CFG_UPNP_GENRE_PROPERTIES,
@@ -226,11 +234,9 @@ enum config_option_t {
     CFG_UPNP_GENRE_NAMESPACES,
     CFG_UPNP_PLAYLIST_NAMESPACES,
     CFG_UPNP_TITLE_NAMESPACES,
+    CFG_UPNP_CAPTION_COUNT,
     CFG_THREAD_SCOPE_SYSTEM,
     CFG_IMPORT_READABLE_NAMES,
-#ifdef SOPCAST
-    CFG_IMPORT_SOPCAST_MIMETYE_LIST,
-#endif
     CFG_SERVER_DYNAMIC_CONTENT_LIST_ENABLED,
     CFG_SERVER_DYNAMIC_CONTENT_LIST,
     CFG_IMPORT_RESOURCES_ORDER,
@@ -261,6 +267,7 @@ enum config_option_t {
     ATTR_IMPORT_RESOURCES_NAME,
     ATTR_IMPORT_RESOURCES_EXT,
     ATTR_IMPORT_LIBOPTS_AUXDATA_DATA,
+    ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
     ATTR_IMPORT_LIBOPTS_AUXDATA_TAG,
     ATTR_TRANSCODING_MIMETYPE_PROF_MAP,
     ATTR_TRANSCODING_MIMETYPE_PROF_MAP_TRANSCODE,
@@ -277,6 +284,7 @@ enum config_option_t {
     ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_MODE,
     ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC,
     ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL,
+    ATTR_TRANSCODING_PROFILES_PROFLE_DLNA,
     ATTR_TRANSCODING_PROFILES_PROFLE_SAMPFREQ,
     ATTR_TRANSCODING_PROFILES_PROFLE_NRCHAN,
     ATTR_TRANSCODING_PROFILES_PROFLE_HIDEORIG,
@@ -286,6 +294,10 @@ enum config_option_t {
     ATTR_TRANSCODING_PROFILES_PROFLE_AGENT,
     ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND,
     ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ARGS,
+    ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON,
+    ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON_KEY,
+    ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON_NAME,
+    ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON_VALUE,
     ATTR_TRANSCODING_PROFILES_PROFLE_BUFFER,
     ATTR_TRANSCODING_PROFILES_PROFLE_BUFFER_SIZE,
     ATTR_TRANSCODING_PROFILES_PROFLE_BUFFER_CHUNK,
@@ -321,6 +333,7 @@ enum config_option_t {
     ATTR_UPNP_NAMESPACE_PROPERTY,
     ATTR_UPNP_NAMESPACE_KEY,
     ATTR_UPNP_NAMESPACE_URI,
+    ATTR_CLIENTS_UPNP_CAPTION_COUNT,
     ATTR_IMPORT_RESOURCES_HANDLER,
 
     ATTR_DYNAMIC_CONTAINER,
@@ -334,7 +347,7 @@ enum config_option_t {
 class Config {
 public:
     virtual ~Config() = default;
-    virtual void updateConfigFromDatabase(std::shared_ptr<Database> database) = 0;
+    virtual void updateConfigFromDatabase(const std::shared_ptr<Database>& database) = 0;
     virtual std::string getOrigValue(const std::string& item) const = 0;
     virtual void setOrigValue(const std::string& item, const std::string& value) = 0;
     virtual void setOrigValue(const std::string& item, bool value) = 0;
@@ -344,13 +357,10 @@ public:
     /// \brief Returns the path of the config file that was used to launch the server.
     virtual fs::path getConfigFilename() const = 0;
 
-    /// \brief Returns the path of the directory holding gerbera data files (sql,web,js)
-    virtual fs::path getDataDir() const = 0;
-
     /// \brief add a config option
     /// \param option option type to add.
     /// \param option option to add.
-    virtual void addOption(config_option_t option, std::shared_ptr<ConfigOption> optionValue) = 0;
+    virtual void addOption(config_option_t option, const std::shared_ptr<ConfigOption>& optionValue) = 0;
 
     /// \brief returns a config option of type std::string
     /// \param option option to retrieve.
