@@ -4,7 +4,7 @@
 
     config_setup.h - this file is part of Gerbera.
 
-    Copyright (C) 2020-2021 Gerbera Contributors
+    Copyright (C) 2020-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -53,7 +53,7 @@
 #define DEFAULT_POLL_WHEN_IDLE_VALUE NO
 #define DEFAULT_POLL_INTERVAL 2
 #define DEFAULT_ACCOUNTS_EN_VALUE NO
-#define DEFAULT_ALIVE_INTERVAL 1800 // seconds
+#define DEFAULT_ALIVE_INTERVAL 180 // seconds
 #define DEFAULT_BOOKMARK_FILE "gerbera.html"
 #define DEFAULT_IGNORE_UNKNOWN_EXTENSIONS NO
 #define DEFAULT_CASE_SENSITIVE_EXTENSION_MAPPINGS NO
@@ -70,11 +70,6 @@
 #define DEFAULT_HIDE_PC_DIRECTORY NO
 #define DEFAULT_CLIENTS_EN_VALUE NO
 
-#ifdef SOPCAST
-#define DEFAULT_SOPCAST_ENABLED NO
-#define DEFAULT_SOPCAST_UPDATE_AT_START NO
-#endif
-
 #ifdef ATRAILERS
 #define DEFAULT_ATRAILERS_ENABLED NO
 #define DEFAULT_ATRAILERS_UPDATE_AT_START NO
@@ -96,7 +91,7 @@
 #define DEFAULT_MYSQL_USER "gerbera"
 #define DEFAULT_MYSQL_ENABLED NO
 
-#else //HAVE_MYSQL
+#else // HAVE_MYSQL
 #define DEFAULT_MYSQL_ENABLED NO
 #endif
 
@@ -130,7 +125,7 @@
 #define DEFAULT_MARK_PLAYED_ITEMS_STRING "*"
 
 /// \brief default values for CFG_IMPORT_SYSTEM_DIRECTORIES
-static std::vector<std::string> excludes_fullpath {
+static const std::vector<std::string> excludesFullpath {
     "/bin",
     "/boot",
     "/dev",
@@ -149,7 +144,7 @@ static std::vector<std::string> excludes_fullpath {
 };
 
 /// \brief default values for CFG_IMPORT_RESOURCES_FANART_FILE_LIST
-static std::vector<std::string> defaultFanArtFile {
+static const std::vector<std::string> defaultFanArtFile {
     // "%title%.jpg",
     // "%filename%.jpg",
     // "folder.jpg",
@@ -160,7 +155,7 @@ static std::vector<std::string> defaultFanArtFile {
 };
 
 /// \brief default values for CFG_IMPORT_RESOURCES_CONTAINERART_FILE_LIST
-static std::vector<std::string> defaultContainerArtFile {
+static const std::vector<std::string> defaultContainerArtFile {
     // "folder.jpg",
     // "poster.jpg",
     // "cover.jpg",
@@ -168,20 +163,20 @@ static std::vector<std::string> defaultContainerArtFile {
 };
 
 /// \brief default values for CFG_IMPORT_RESOURCES_SUBTITLE_FILE_LIST
-static std::vector<std::string> defaultSubtitleFile {
+static const std::vector<std::string> defaultSubtitleFile {
     // "%title%.srt",
     // "%filename%.srt"
 };
 
 /// \brief default values for CFG_IMPORT_RESOURCES_RESOURCE_FILE_LIST
-static std::vector<std::string> defaultResourceFile {
+static const std::vector<std::string> defaultResourceFile {
     // "%filename%.srt",
     // "cover.jpg",
     // "%album%.jpg",
 };
 
 /// \brief default values for CFG_SERVER_UI_ITEMS_PER_PAGE_DROPDOWN
-static std::vector<std::string> defaultItemsPerPage {
+static const std::vector<std::string> defaultItemsPerPage {
     "10",
     "25",
     "50",
@@ -189,51 +184,77 @@ static std::vector<std::string> defaultItemsPerPage {
 };
 
 /// \brief default values for CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST
-static std::map<std::string, std::string> mt_ct_defaults {
-    { "audio/mpeg", CONTENT_TYPE_MP3 },
+static const std::map<std::string, std::string> mtCtDefaults {
     { "application/ogg", CONTENT_TYPE_OGG },
-    { "audio/ogg", CONTENT_TYPE_OGG },
-    { "audio/x-flac", CONTENT_TYPE_FLAC },
+    { "audio/L16", CONTENT_TYPE_PCM },
     { "audio/flac", CONTENT_TYPE_FLAC },
-    { "audio/x-ms-wma", CONTENT_TYPE_WMA },
-    { "audio/x-wavpack", CONTENT_TYPE_WAVPACK },
-    { "image/jpeg", CONTENT_TYPE_JPG },
+    { "audio/mp4", CONTENT_TYPE_MP4 },
+    { "audio/mpeg", CONTENT_TYPE_MP3 },
+    { "audio/ogg", CONTENT_TYPE_OGG },
+    { "audio/x-dsd", CONTENT_TYPE_DSD },
+    { "audio/x-flac", CONTENT_TYPE_FLAC },
+    { "audio/x-matroska", CONTENT_TYPE_MKA },
     { "audio/x-mpegurl", CONTENT_TYPE_PLAYLIST },
+    { "audio/x-ms-wma", CONTENT_TYPE_WMA },
     { "audio/x-scpls", CONTENT_TYPE_PLAYLIST },
     { "audio/x-wav", CONTENT_TYPE_PCM },
-    { "audio/L16", CONTENT_TYPE_PCM },
-    { "video/x-msvideo", CONTENT_TYPE_AVI },
+    { "audio/x-wavpack", CONTENT_TYPE_WAVPACK },
+    { "image/jpeg", CONTENT_TYPE_JPG },
+    { "image/png", CONTENT_TYPE_PNG },
+    { "video/mkv", CONTENT_TYPE_MKV },
     { "video/mp4", CONTENT_TYPE_MP4 },
-    { "audio/mp4", CONTENT_TYPE_MP4 },
+    { "video/mpeg", CONTENT_TYPE_MPEG },
     { "video/x-matroska", CONTENT_TYPE_MKV },
-    { "audio/x-matroska", CONTENT_TYPE_MKA },
-    { "audio/x-dsd", CONTENT_TYPE_DSD },
+    { "video/x-mkv", CONTENT_TYPE_MKV },
+    { "video/x-ms-asf", CONTENT_TYPE_ASF },
+    { MIME_TYPE_ASX_PLAYLIST, CONTENT_TYPE_PLAYLIST },
+    { "video/x-msvideo", CONTENT_TYPE_AVI },
 };
 
 /// \brief default values for CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST
-static std::map<std::string, std::string> ct_dlna_defaults {
-    { CONTENT_TYPE_MP4, UPNP_DLNA_PROFILE_AVC_MP4_EU },
-    { CONTENT_TYPE_MKV, UPNP_DLNA_PROFILE_MKV },
-    { CONTENT_TYPE_AVI, UPNP_DLNA_PROFILE_AVI },
-    { CONTENT_TYPE_MPEG, UPNP_DLNA_PROFILE_MPEG_PS_PAL },
-    { CONTENT_TYPE_MP3, UPNP_DLNA_PROFILE_MP3 },
-    { CONTENT_TYPE_PCM, UPNP_DLNA_PROFILE_LPCM },
+static const std::map<std::string, std::string> ctDlnaDefaults {
+    { CONTENT_TYPE_ASF, "VC_ASF_AP_L2_WMA" },
+    { CONTENT_TYPE_AVI, "AVI" },
+    { CONTENT_TYPE_DSD, "DSF" },
+    { CONTENT_TYPE_FLAC, "FLAC" },
+    { CONTENT_TYPE_JPG, "JPEG_LRG" },
+    { CONTENT_TYPE_MKA, "MKV" },
+    { CONTENT_TYPE_MKV, "MKV" },
+    { CONTENT_TYPE_MP3, "MP3" },
+    { CONTENT_TYPE_MP4, "AVC_MP4_EU" },
+    { CONTENT_TYPE_MPEG, "MPEG_PS_PAL" },
+    { CONTENT_TYPE_OGG, "OGG" },
+    { CONTENT_TYPE_PCM, "LPCM" },
+    { CONTENT_TYPE_PNG, "PNG_LRG" },
+    { CONTENT_TYPE_WMA, "WMAFULL" },
 };
 
 /// \brief default values for CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST
-static std::map<std::string, std::string> mt_upnp_defaults {
-    { "audio/*", UPNP_CLASS_MUSIC_TRACK },
-    { "video/*", UPNP_CLASS_VIDEO_ITEM },
-    { "image/*", UPNP_CLASS_IMAGE_ITEM },
+static const std::map<std::string, std::string> mtUpnpDefaults {
     { "application/ogg", UPNP_CLASS_MUSIC_TRACK },
+    { "audio/*", UPNP_CLASS_MUSIC_TRACK },
+    { "image/*", UPNP_CLASS_IMAGE_ITEM },
+    { "video/*", UPNP_CLASS_VIDEO_ITEM },
+};
+
+/// \brief default values for CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNATRANSFER_LIST
+static const std::map<std::string, std::string> mtTransferDefaults {
+    { "application/ogg", UPNP_DLNA_TRANSFER_MODE_STREAMING },
+    { "audio/*", UPNP_DLNA_TRANSFER_MODE_STREAMING },
+    { "image/*", UPNP_DLNA_TRANSFER_MODE_INTERACTIVE },
+    { "video/*", UPNP_DLNA_TRANSFER_MODE_STREAMING },
+    { "text/*", UPNP_DLNA_TRANSFER_MODE_BACKGROUND },
+    { "application/x-srt", UPNP_DLNA_TRANSFER_MODE_BACKGROUND },
+    { "srt", UPNP_DLNA_TRANSFER_MODE_BACKGROUND },
 };
 
 /// \brief default values for CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST
-static std::map<std::string, std::string> ext_mt_defaults {
+static const std::map<std::string, std::string> extMtDefaults {
     { "asf", "video/x-ms-asf" },
-    { "asx", "video/x-ms-asf" },
-    { "dff", "audio/x-dsd" },
-    { "dsf", "audio/x-dsd" },
+    { "asx", MIME_TYPE_ASX_PLAYLIST }, // tweak to handle asx as playlist
+    { "dff", "audio/x-dff" },
+    { "dsd", "audio/x-dsd" },
+    { "dsf", "audio/x-dsf" },
     { "flv", "video/x-flv" },
     { "m2ts", "video/mp2t" }, // LibMagic fails to identify MPEG2 Transport Streams
     { "m3u", "audio/x-mpegurl" },
@@ -261,25 +282,27 @@ static std::map<std::string, std::string> ext_mt_defaults {
     { "wvx", "video/x-ms-wvx" },
 };
 
-#ifdef SOPCAST
-/// \brief default values for CFG_IMPORT_SOPCAST_MIMETYE_LIST
-static std::map<std::string, std::string> sc_mt_defaults {
-    { "wmv", "video/sopcast-x-ms-wmv" },
-    { "mp3", "audio/sopcast-mpeg" },
-    { "wma", "audio/sopcast-x-ms-wma" },
-    { "*", "application/sopcast-stream" }, // default value
+/// \brief default values for CFG_IMPORT_MAPPINGS_IGNORED_EXTENSIONS
+static const std::vector<std::string> ignoreDefaults {
+    "part",
+    "tmp",
 };
-#endif
 
 /// \brief default values for ATTR_TRANSCODING_MIMETYPE_PROF_MAP
-static std::map<std::string, std::string> tr_mt_defaults {
+static const std::map<std::string, std::string> trMtDefaults {
     { "video/x-flv", "vlcmpeg" },
     { "application/ogg", "vlcmpeg" },
     { "audio/ogg", "ogg2mp3" },
 };
 
+/// \brief default values for CFG_UPNP_SEARCH_SEGMENTS
+static const std::vector<std::string> upnpSearchSegmentDefaults {
+    "M_ARTIST",
+    "M_TITLE",
+};
+
 /// \brief default values for CFG_UPNP_ALBUM_PROPERTIES
-static std::map<std::string, std::string> upnp_album_prop_defaults {
+static const std::map<std::string, std::string> upnpAlbumPropDefaults {
     { "dc:creator", "M_ALBUMARTIST" },
     { "upnp:artist", "M_ALBUMARTIST" },
     { "upnp:albumArtist", "M_ALBUMARTIST" },
@@ -294,22 +317,32 @@ static std::map<std::string, std::string> upnp_album_prop_defaults {
 };
 
 /// \brief default values for CFG_UPNP_ARTIST_PROPERTIES
-static std::map<std::string, std::string> upnp_artist_prop_defaults {
+static const std::map<std::string, std::string> upnpArtistPropDefaults {
     { "upnp:artist", "M_ALBUMARTIST" },
     { "upnp:albumArtist", "M_ALBUMARTIST" },
     { "upnp:genre", "M_GENRE" },
 };
 
 /// \brief default values for CFG_UPNP_GENRE_PROPERTIES
-static std::map<std::string, std::string> upnp_genre_prop_defaults {
+static const std::map<std::string, std::string> upnpGenrePropDefaults {
     { "upnp:genre", "M_GENRE" },
 };
 
 /// \brief default values for CFG_UPNP_PLAYLIST_PROPERTIES
-static std::map<std::string, std::string> upnp_playlist_prop_defaults {
+static const std::map<std::string, std::string> upnpPlaylistPropDefaults {
     { "dc:date", "M_UPNP_DATE" },
 };
 
+/// \brief default values for CFG_IMPORT_LIBOPTS_ID3_METADATA_TAGS_LIST
+static const std::map<std::string, std::string> id3SpecialPropertyMap {
+    { "PERFORMER", "upnp:artist@role[Performer]" },
+};
+
+/// \brief default values for CFG_IMPORT_LIBOPTS_FFMPEG_METADATA_TAGS_LIST
+static const std::map<std::string, std::string> ffmpegSpecialPropertyMap {
+    { "performer", "upnp:artist@role[Performer]" },
+};
+
 /// \brief configure all known options
 const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions = {
     std::make_shared<ConfigIntSetup>(CFG_SERVER_PORT,
@@ -363,9 +396,6 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         DEFAULT_TMPDIR),
     std::make_shared<ConfigPathSetup>(CFG_SERVER_WEBROOT,
         "/server/webroot", "config-server.html#webroot"),
-    std::make_shared<ConfigPathSetup>(CFG_SERVER_SERVEDIR,
-        "/server/servedir", "config-server.html#servedir",
-        ""),
     std::make_shared<ConfigIntSetup>(CFG_SERVER_ALIVE_INTERVAL,
         "/server/alive", "config-server.html#alive",
         DEFAULT_ALIVE_INTERVAL, ALIVE_INTERVAL_MIN, ConfigIntSetup::CheckMinValue),
@@ -435,7 +465,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         DEFAULT_SQLITE_SYNC, ConfigIntSetup::CheckSqlLiteSyncValue),
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_STORAGE_SQLITE_RESTORE,
         "/server/storage/sqlite3/on-error", "config-server.html#storage",
-        DEFAULT_SQLITE_RESTORE, ConfigBoolSetup::CheckSqlLiteRestoreValue),
+        DEFAULT_SQLITE_RESTORE, StringCheckFunction(ConfigBoolSetup::CheckSqlLiteRestoreValue)),
 #ifdef SQLITE_BACKUP_ENABLED
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_STORAGE_SQLITE_BACKUP_ENABLED,
         "/server/storage/sqlite3/backup/attribute::enabled", "config-server.html#storage",
@@ -465,6 +495,15 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_UI_POLL_WHEN_IDLE,
         "/server/ui/attribute::poll-when-idle", "config-server.html#ui",
         DEFAULT_POLL_WHEN_IDLE_VALUE),
+    std::make_shared<ConfigBoolSetup>(CFG_SERVER_UI_ENABLE_NUMBERING,
+        "/server/ui/attribute::show-numbering", "config-server.html#ui",
+        YES),
+    std::make_shared<ConfigBoolSetup>(CFG_SERVER_UI_ENABLE_THUMBNAIL,
+        "/server/ui/attribute::show-thumbnail", "config-server.html#ui",
+        YES),
+    std::make_shared<ConfigBoolSetup>(CFG_SERVER_UI_ENABLE_VIDEO,
+        "/server/ui/attribute::show-video", "config-server.html#ui",
+        NO),
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_UI_ACCOUNTS_ENABLED,
         "/server/ui/accounts/attribute::enabled", "config-server.html#ui",
         DEFAULT_ACCOUNTS_EN_VALUE),
@@ -480,7 +519,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigArraySetup>(CFG_SERVER_UI_ITEMS_PER_PAGE_DROPDOWN,
         "/server/ui/items-per-page", "config-server.html#ui",
         ATTR_SERVER_UI_ITEMS_PER_PAGE_DROPDOWN_OPTION, ConfigArraySetup::InitItemsPerPage, true,
-        std::move(defaultItemsPerPage)),
+        defaultItemsPerPage),
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_UI_SHOW_TOOLTIPS,
         "/server/ui/attribute::show-tooltips", "config-server.html#ui",
         DEFAULT_UI_SHOW_TOOLTIPS_VALUE),
@@ -519,7 +558,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST,
         "/import/mappings/extension-mimetype", "config-import.html#extension-mimetype",
         ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO,
-        false, false, true, std::move(ext_mt_defaults)),
+        false, false, true, extMtDefaults),
     std::make_shared<ConfigBoolSetup>(CFG_IMPORT_MAPPINGS_IGNORE_UNKNOWN_EXTENSIONS,
         "/import/mappings/extension-mimetype/attribute::ignore-unknown", "config-import.html#extension-mimetype",
         DEFAULT_IGNORE_UNKNOWN_EXTENSIONS),
@@ -529,15 +568,23 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST,
         "/import/mappings/mimetype-upnpclass", "config-import.html#mimetype-upnpclass",
         ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO,
-        false, false, true, std::move(mt_upnp_defaults)),
+        false, false, true, mtUpnpDefaults),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNATRANSFER_LIST,
+        "/import/mappings/mimetype-dlnatransfermode", "config-import.html#mimetype-dlnatransfermode",
+        ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO,
+        false, false, true, mtTransferDefaults),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST,
         "/import/mappings/mimetype-contenttype", "config-import.html#mimetype-contenttype",
         ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_TREAT, ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_MIMETYPE, ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_AS,
-        false, false, true, std::move(mt_ct_defaults)),
+        false, false, true, mtCtDefaults),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
         "/import/mappings/contenttype-dlnaprofile", "config-import.html#contenttype-dlnaprofile",
         ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO,
-        false, false, true, std::move(ct_dlna_defaults)),
+        false, false, true, ctDlnaDefaults),
+    std::make_shared<ConfigArraySetup>(CFG_IMPORT_MAPPINGS_IGNORED_EXTENSIONS,
+        "/import/mappings/ignore-extensions", "config-import.html#ignore-extensions",
+        ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME,
+        false, false, ignoreDefaults),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LAYOUT_MAPPING,
         "/import/layout", "config-import.html#layout",
         ATTR_IMPORT_LAYOUT_MAPPING_PATH, ATTR_IMPORT_LAYOUT_MAPPING_FROM, ATTR_IMPORT_LAYOUT_MAPPING_TO),
@@ -597,7 +644,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigStringSetup>(CFG_IMPORT_SCRIPTING_STRUCTURED_LAYOUT_DIVCHAR,
         "/import/scripting/virtual-layout/structured-layout/attribute::div-char", "config-import.html#scripting",
         ""),
-#endif // JS
+#endif // HAVE_JS
 
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_SCRIPTING_IMPORT_GENRE_MAP,
         "/import/scripting/virtual-layout/genre-map", "config-import.html#layout",
@@ -634,7 +681,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_FANART_FILE_LIST,
         "/import/resources/fanart", "config-import.html#resources",
         ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME,
-        false, false, std::move(defaultFanArtFile)),
+        false, false, defaultFanArtFile),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_RESOURCES_FANART_DIR_LIST,
         "/import/resources/fanart", "config-import.html#resources",
         ATTR_IMPORT_RESOURCES_ADD_DIR, ATTR_IMPORT_RESOURCES_NAME, ATTR_IMPORT_RESOURCES_EXT),
@@ -642,7 +689,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_CONTAINERART_FILE_LIST,
         "/import/resources/container", "config-import.html#container",
         ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME,
-        false, false, std::move(defaultContainerArtFile)),
+        false, false, defaultContainerArtFile),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_RESOURCES_CONTAINERART_DIR_LIST,
         "/import/resources/container", "config-import.html#container",
         ATTR_IMPORT_RESOURCES_ADD_DIR, ATTR_IMPORT_RESOURCES_NAME, ATTR_IMPORT_RESOURCES_EXT),
@@ -659,14 +706,14 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_SUBTITLE_FILE_LIST,
         "/import/resources/subtitle", "config-import.html#resources",
         ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME,
-        false, false, std::move(defaultSubtitleFile)),
+        false, false, defaultSubtitleFile),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_RESOURCES_SUBTITLE_DIR_LIST,
         "/import/resources/subtitle", "config-import.html#resources",
         ATTR_IMPORT_RESOURCES_ADD_DIR, ATTR_IMPORT_RESOURCES_NAME, ATTR_IMPORT_RESOURCES_EXT),
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_RESOURCE_FILE_LIST,
         "/import/resources/resource", "config-import.html#resources",
         ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME,
-        false, false, std::move(defaultResourceFile)),
+        false, false, defaultResourceFile),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_RESOURCES_RESOURCE_DIR_LIST,
         "/import/resources/resource", "config-import.html#resources",
         ATTR_IMPORT_RESOURCES_ADD_DIR, ATTR_IMPORT_RESOURCES_NAME, ATTR_IMPORT_RESOURCES_EXT),
@@ -678,7 +725,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_SYSTEM_DIRECTORIES,
         "/import/system-directories", "config-import.html#system-directories",
         ATTR_IMPORT_SYSTEM_DIR_ADD_PATH, ATTR_IMPORT_RESOURCES_NAME, true, true,
-        std::move(excludes_fullpath)),
+        excludesFullpath),
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_VISIBLE_DIRECTORIES,
         "/import/visible-directories", "config-import.html#visible-directories",
         ATTR_IMPORT_SYSTEM_DIR_ADD_PATH, ATTR_IMPORT_RESOURCES_NAME),
@@ -687,6 +734,12 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED,
         "/server/extended-runtime-options/ffmpegthumbnailer/attribute::enabled", "config-extended.html#ffmpegthumbnailer",
         DEFAULT_FFMPEGTHUMBNAILER_ENABLED),
+    std::make_shared<ConfigBoolSetup>(CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_VIDEO_ENABLED,
+        "/server/extended-runtime-options/ffmpegthumbnailer/attribute::video-enabled", "config-extended.html#ffmpegthumbnailer",
+        YES),
+    std::make_shared<ConfigBoolSetup>(CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_ENABLED,
+        "/server/extended-runtime-options/ffmpegthumbnailer/attribute::image-enabled", "config-extended.html#ffmpegthumbnailer",
+        YES),
     std::make_shared<ConfigIntSetup>(CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE,
         "/server/extended-runtime-options/ffmpegthumbnailer/thumbnail-size", "config-extended.html#ffmpegthumbnailer",
         DEFAULT_FFMPEGTHUMBNAILER_THUMBSIZE, 1, ConfigIntSetup::CheckMinValue),
@@ -715,7 +768,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         DEFAULT_MARK_PLAYED_ITEMS_ENABLED),
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING_MODE_PREPEND,
         "/server/extended-runtime-options/mark-played-items/string/attribute::mode", "config-extended.html#extended-runtime-options",
-        DEFAULT_MARK_PLAYED_ITEMS_STRING_MODE, ConfigBoolSetup::CheckMarkPlayedValue),
+        DEFAULT_MARK_PLAYED_ITEMS_STRING_MODE, StringCheckFunction(ConfigBoolSetup::CheckMarkPlayedValue)),
     std::make_shared<ConfigStringSetup>(CFG_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_STRING,
         "/server/extended-runtime-options/mark-played-items/string", "config-extended.html#extended-runtime-options",
         false, DEFAULT_MARK_PLAYED_ITEMS_STRING, true),
@@ -736,24 +789,6 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "/server/extended-runtime-options/lastfm/password", "config-extended.html#lastfm",
         false, DEFAULT_LASTFM_PASSWORD, true),
 #endif
-#ifdef SOPCAST
-    std::make_shared<ConfigBoolSetup>(CFG_ONLINE_CONTENT_SOPCAST_ENABLED,
-        "/import/online-content/SopCast/attribute::enabled", "config-online.html#sopcast",
-        DEFAULT_SOPCAST_ENABLED),
-    std::make_shared<ConfigIntSetup>(CFG_ONLINE_CONTENT_SOPCAST_REFRESH,
-        "/import/online-content/SopCast/attribute::refresh", "config-online.html#sopcast",
-        0),
-    std::make_shared<ConfigBoolSetup>(CFG_ONLINE_CONTENT_SOPCAST_UPDATE_AT_START,
-        "/import/online-content/SopCast/attribute::update-at-start", "config-online.html#sopcast",
-        DEFAULT_SOPCAST_UPDATE_AT_START),
-    std::make_shared<ConfigIntSetup>(CFG_ONLINE_CONTENT_SOPCAST_PURGE_AFTER,
-        "/import/online-content/SopCast/attribute::purge-after", "config-online.html#sopcast",
-        0),
-    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_SOPCAST_MIMETYE_LIST,
-        "/import/online-content/SopCast/mimetype-mappings", "config-online.html#sopcast",
-        ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO,
-        false, false, false, std::move(sc_mt_defaults)),
-#endif
 #ifdef ATRAILERS
     std::make_shared<ConfigBoolSetup>(CFG_ONLINE_CONTENT_ATRAILERS_ENABLED,
         "/import/online-content/AppleTrailers/attribute::enabled", "config-online.html#appletrailers",
@@ -776,7 +811,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
 #ifdef HAVE_INOTIFY
     std::make_shared<ConfigBoolSetup>(CFG_IMPORT_AUTOSCAN_USE_INOTIFY,
         "/import/autoscan/attribute::use-inotify", "config-import.html#autoscan",
-        "auto", ConfigBoolSetup::CheckInotifyValue),
+        "auto", StringCheckFunction(ConfigBoolSetup::CheckInotifyValue)),
     std::make_shared<ConfigAutoscanSetup>(CFG_IMPORT_AUTOSCAN_INOTIFY_LIST,
         "/import/autoscan", "config-import.html#autoscan",
         ScanMode::INotify),
@@ -815,35 +850,51 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigIntSetup>(CFG_EXTERNAL_TRANSCODING_CURL_FILL_SIZE,
         "/transcoding/attribute::fetch-buffer-fill-size", "config-transcode.html#transcoding",
         DEFAULT_CURL_INITIAL_FILL_SIZE, 0, ConfigIntSetup::CheckMinValue),
-#endif //HAVE_CURL
+#endif // HAVE_CURL
 #ifdef HAVE_LIBEXIF
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_LIBOPTS_EXIF_AUXDATA_TAGS_LIST,
-        "/import/library-options/libexif/auxdata", "config-import.html#auxdata",
+        "/import/library-options/libexif/auxdata", "config-import.html#libexif",
         ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LIBOPTS_EXIF_METADATA_TAGS_LIST,
+        "/import/library-options/libexif/metadata", "config-import.html#libexif",
+        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
+        false, true, false),
     std::make_shared<ConfigStringSetup>(CFG_IMPORT_LIBOPTS_EXIF_CHARSET,
         "/import/library-options/libexif/attribute::charset", "config-import.html#charset",
         ""),
 #endif
 #ifdef HAVE_EXIV2
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_LIBOPTS_EXIV2_AUXDATA_TAGS_LIST,
-        "/import/library-options/exiv2/auxdata", "config-import.html#library-options",
+        "/import/library-options/exiv2/auxdata", "config-import.html#exiv2",
         ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LIBOPTS_EXIV2_METADATA_TAGS_LIST,
+        "/import/library-options/exiv2/metadata", "config-import.html#exiv2",
+        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
+        false, true, false),
     std::make_shared<ConfigStringSetup>(CFG_IMPORT_LIBOPTS_EXIV2_CHARSET,
         "/import/library-options/exiv2/attribute::charset", "config-import.html#charset",
         ""),
 #endif
 #ifdef HAVE_TAGLIB
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_LIBOPTS_ID3_AUXDATA_TAGS_LIST,
-        "/import/library-options/id3/auxdata", "config-import.html#id2",
+        "/import/library-options/id3/auxdata", "config-import.html#id3",
         ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LIBOPTS_ID3_METADATA_TAGS_LIST,
+        "/import/library-options/id3/metadata", "config-import.html#id3",
+        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
+        false, true, false, id3SpecialPropertyMap),
     std::make_shared<ConfigStringSetup>(CFG_IMPORT_LIBOPTS_ID3_CHARSET,
         "/import/library-options/id3/attribute::charset", "config-import.html#charset",
         ""),
 #endif
 #ifdef HAVE_FFMPEG
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_LIBOPTS_FFMPEG_AUXDATA_TAGS_LIST,
-        "/import/library-options/ffmpeg/auxdata", "config-import.html#id5",
+        "/import/library-options/ffmpeg/auxdata", "config-import.html#ffmpeg",
         ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LIBOPTS_FFMPEG_METADATA_TAGS_LIST,
+        "/import/library-options/ffmpeg/metadata", "config-import.html#ffmpeg",
+        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG, ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
+        false, true, false, ffmpegSpecialPropertyMap),
     std::make_shared<ConfigStringSetup>(CFG_IMPORT_LIBOPTS_FFMPEG_CHARSET,
         "/import/library-options/ffmpeg/attribute::charset", "config-import.html#charset",
         ""),
@@ -875,6 +926,9 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS,
         "attribute::client-flags", "config-transcode.html#profiles",
         ""),
+    std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_DLNA,
+        "attribute::dlna-profile", "config-transcode.html#profiles",
+        ""),
     std::make_shared<ConfigBoolSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_ENABLED,
         "attribute::enabled", "config-transcode.html#profiles"),
     std::make_shared<ConfigBoolSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL,
@@ -908,7 +962,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigDictionarySetup>(ATTR_TRANSCODING_MIMETYPE_PROF_MAP,
         "/transcoding/mimetype-profile-mappings", "config-transcode.html#profiles",
         ATTR_TRANSCODING_MIMETYPE_PROF_MAP_TRANSCODE, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_MIMETYPE, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_USING,
-        false, false, false, std::move(tr_mt_defaults)),
+        false, false, false, trMtDefaults),
     std::make_shared<ConfigSetup>(ATTR_TRANSCODING_PROFILES_PROFLE,
         "/transcoding/profiles/profile", "config-server.html#ui",
         ""),
@@ -924,6 +978,10 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ARGS,
         "attribute::arguments", "config-transcode.html#profiles",
         true, "", true),
+    std::make_shared<ConfigDictionarySetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON,
+        "agent", "config-transcode.html#profiles",
+        ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON_KEY, ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON_NAME, ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON_VALUE,
+        false, false, false),
     std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_RES,
         "resolution", "config-transcode.html#profiles",
         false),
@@ -1006,6 +1064,9 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigStringSetup>(ATTR_IMPORT_LIBOPTS_AUXDATA_TAG,
         "attribute::tag", "config-import.html#auxdata",
         ""),
+    std::make_shared<ConfigStringSetup>(ATTR_IMPORT_LIBOPTS_AUXDATA_KEY,
+        "attribute::key", "config-import.html#auxdata",
+        ""),
     std::make_shared<ConfigStringSetup>(ATTR_SERVER_UI_ACCOUNT_LIST_PASSWORD,
         "attribute::password", "config-server.html#ui",
         ""),
@@ -1013,22 +1074,41 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "attribute::user", "config-server.html#ui",
         ""),
 
+    std::make_shared<ConfigBoolSetup>(CFG_UPNP_MULTI_VALUES_ENABLED,
+        "/server/upnp/attribute::multi-value", "config-server.html#upnp",
+        NO),
+    std::make_shared<ConfigBoolSetup>(CFG_UPNP_SEARCH_CONTAINER_FLAG,
+        "/server/upnp/attribute::searchable-container-flag", "config-server.html#upnp",
+        NO),
+    std::make_shared<ConfigStringSetup>(CFG_UPNP_SEARCH_SEPARATOR,
+        "/server/upnp/attribute::search-result-separator", "config-server.html#upnp",
+        " - "),
+    std::make_shared<ConfigBoolSetup>(CFG_UPNP_SEARCH_FILENAME,
+        "/server/upnp/attribute::search-filename", "config-server.html#upnp",
+        NO),
+    std::make_shared<ConfigIntSetup>(CFG_UPNP_CAPTION_COUNT,
+        "/server/upnp/attribute::caption-info-count", "config-server.html#upnp",
+        1, 0, ConfigIntSetup::CheckMinValue),
+    std::make_shared<ConfigArraySetup>(CFG_UPNP_SEARCH_ITEM_SEGMENTS,
+        "/server/upnp/search-item-result", "config-server.html#upnpf",
+        ATTR_IMPORT_LIBOPTS_AUXDATA_DATA, ATTR_IMPORT_LIBOPTS_AUXDATA_TAG,
+        false, false, upnpSearchSegmentDefaults),
     std::make_shared<ConfigDictionarySetup>(CFG_UPNP_ALBUM_PROPERTIES,
         "/server/upnp/album-properties", "config-server.html#upnp",
         ATTR_UPNP_PROPERTIES_PROPERTY, ATTR_UPNP_PROPERTIES_UPNPTAG, ATTR_UPNP_PROPERTIES_METADATA,
-        false, false, true, std::move(upnp_album_prop_defaults)),
+        false, false, true, upnpAlbumPropDefaults),
     std::make_shared<ConfigDictionarySetup>(CFG_UPNP_ARTIST_PROPERTIES,
         "/server/upnp/artist-properties", "config-server.html#upnp",
         ATTR_UPNP_PROPERTIES_PROPERTY, ATTR_UPNP_PROPERTIES_UPNPTAG, ATTR_UPNP_PROPERTIES_METADATA,
-        false, false, true, std::move(upnp_artist_prop_defaults)),
+        false, false, true, upnpArtistPropDefaults),
     std::make_shared<ConfigDictionarySetup>(CFG_UPNP_GENRE_PROPERTIES,
         "/server/upnp/genre-properties", "config-server.html#upnp",
         ATTR_UPNP_PROPERTIES_PROPERTY, ATTR_UPNP_PROPERTIES_UPNPTAG, ATTR_UPNP_PROPERTIES_METADATA,
-        false, false, true, std::move(upnp_genre_prop_defaults)),
+        false, false, true, upnpGenrePropDefaults),
     std::make_shared<ConfigDictionarySetup>(CFG_UPNP_PLAYLIST_PROPERTIES,
         "/server/upnp/playlist-properties", "config-server.html#upnp",
         ATTR_UPNP_PROPERTIES_PROPERTY, ATTR_UPNP_PROPERTIES_UPNPTAG, ATTR_UPNP_PROPERTIES_METADATA,
-        false, false, true, std::move(upnp_playlist_prop_defaults)),
+        false, false, true, upnpPlaylistPropDefaults),
     std::make_shared<ConfigDictionarySetup>(CFG_UPNP_TITLE_PROPERTIES,
         "/server/upnp/title-properties", "config-server.html#upnp",
         ATTR_UPNP_PROPERTIES_PROPERTY, ATTR_UPNP_PROPERTIES_UPNPTAG, ATTR_UPNP_PROPERTIES_METADATA,
@@ -1083,9 +1163,18 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigStringSetup>(ATTR_DYNAMIC_CONTAINER_SORT,
         "attribute::sort", "config-server.html#sort",
         ""),
+    std::make_shared<ConfigIntSetup>(ATTR_CLIENTS_UPNP_CAPTION_COUNT,
+        "attribute::caption-info-count", "config-clients.html#caption-info-count",
+        1, 0, ConfigIntSetup::CheckMinValue),
 
     // simpleOptions
 
+    std::make_shared<ConfigSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON_KEY,
+        "environ", ""),
+    std::make_shared<ConfigSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON_NAME,
+        "name", ""),
+    std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_ENVIRON_VALUE,
+        "value", ""),
     std::make_shared<ConfigSetup>(ATTR_SERVER_UI_ITEMS_PER_PAGE_DROPDOWN_OPTION,
         "option", ""),
     std::make_shared<ConfigSetup>(ATTR_SERVER_EXTOPTS_MARK_PLAYED_ITEMS_CONTENT,
@@ -1185,15 +1274,19 @@ const std::map<config_option_t, std::vector<config_option_t>> ConfigDefinition::
     { ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_MIMETYPE, { CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST } },
     { ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_TREAT, { CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST } },
     { ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_AS, { CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST } },
-    { ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, { CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
-#ifdef SOPCAST
-                                              CFG_IMPORT_SOPCAST_MIMETYE_LIST
-#endif
+    { ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, {
+                                              CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST,
+                                              CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST,
+                                              CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST,
+                                              CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNATRANSFER_LIST,
+                                              CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
                                           } },
-    { ATTR_IMPORT_MAPPINGS_MIMETYPE_TO, { CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
-#ifdef SOPCAST
-                                            CFG_IMPORT_SOPCAST_MIMETYE_LIST
-#endif
+    { ATTR_IMPORT_MAPPINGS_MIMETYPE_TO, {
+                                            CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST,
+                                            CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST,
+                                            CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST,
+                                            CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNATRANSFER_LIST,
+                                            CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
                                         } },
 
     { ATTR_IMPORT_RESOURCES_NAME, { CFG_IMPORT_RESOURCES_FANART_FILE_LIST, CFG_IMPORT_RESOURCES_CONTAINERART_FILE_LIST, CFG_IMPORT_RESOURCES_RESOURCE_FILE_LIST, CFG_IMPORT_RESOURCES_SUBTITLE_FILE_LIST, //
@@ -1249,7 +1342,7 @@ const std::map<config_option_t, config_option_t> ConfigDefinition::dependencyMap
 
 const char* ConfigDefinition::mapConfigOption(config_option_t option)
 {
-    auto co = std::find_if(complexOptions.begin(), complexOptions.end(), [&](auto&& c) { return c->option == option; });
+    auto co = std::find_if(complexOptions.begin(), complexOptions.end(), [=](auto&& c) { return c->option == option; });
     if (co != complexOptions.end()) {
         return (*co)->xpath;
     }
@@ -1263,7 +1356,7 @@ bool ConfigDefinition::isDependent(config_option_t option)
 
 std::shared_ptr<ConfigSetup> ConfigDefinition::findConfigSetup(config_option_t option, bool save)
 {
-    auto co = std::find_if(complexOptions.begin(), complexOptions.end(), [&](auto&& s) { return s->option == option; });
+    auto co = std::find_if(complexOptions.begin(), complexOptions.end(), [=](auto&& s) { return s->option == option; });
     if (co != complexOptions.end()) {
         log_debug("Config: option found: '{}'", (*co)->xpath);
         return *co;
@@ -1303,7 +1396,7 @@ std::shared_ptr<ConfigSetup> ConfigDefinition::findConfigSetupByPath(const std::
         co = std::find_if(complexOptions.begin(), complexOptions.end(),
             [&](auto&& s) {
                 auto uPath = s->getUniquePath();
-                size_t len = std::min(uPath.length(), key.length());
+                auto len = std::min(uPath.length(), key.length());
                 return key.substr(0, len) == uPath.substr(0, len);
             });
         return (co != complexOptions.end()) ? *co : nullptr;
