@@ -4,7 +4,7 @@
 
     config_definition.h - this file is part of Gerbera.
 
-    Copyright (C) 2020-2021 Gerbera Contributors
+    Copyright (C) 2020-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,6 +29,7 @@
 
 #include "common.h"
 #include "config.h"
+#include "util/tools.h"
 
 class ConfigSetup;
 
@@ -77,14 +78,14 @@ public:
     static std::string ensureAttribute(config_option_t option, bool check = true)
     {
         auto attr = std::string(mapConfigOption(option));
-        if (attr.substr(0, ATTRIBUTE.size()) != ATTRIBUTE && check)
-            attr.insert(0, ATTRIBUTE);
+        if (!startswith(attr, ATTRIBUTE) && check)
+            return fmt::format("{}{}", ATTRIBUTE, attr);
         return attr;
     }
     static std::string removeAttribute(config_option_t option)
     {
         auto attr = std::string(mapConfigOption(option));
-        if (attr.size() > ATTRIBUTE.size() && attr.substr(0, ATTRIBUTE.size()) == ATTRIBUTE)
+        if (attr.size() > ATTRIBUTE.size() && startswith(attr, ATTRIBUTE))
             attr = attr.substr(ATTRIBUTE.size());
         return attr;
     }
