@@ -4,7 +4,7 @@
 
     config_generator.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2021 Gerbera Contributors
+    Copyright (C) 2016-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -26,7 +26,6 @@
 #include "config_generator.h"
 
 #include <sstream>
-#include <string>
 
 #include "config/config_definition.h"
 #include "config/config_setup.h"
@@ -59,7 +58,7 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::string& tag
         for (auto&& part : split) {
             nodeKey += "/" + part;
             if (generated.find(nodeKey) == generated.end()) {
-                if (part.substr(0, ConfigDefinition::ATTRIBUTE.size()) == ConfigDefinition::ATTRIBUTE) {
+                if (startswith(part, ConfigDefinition::ATTRIBUTE)) {
                     attribute = part.substr(ConfigDefinition::ATTRIBUTE.size()); // last attribute gets the value
                 } else {
                     auto newNode = generated[parent]->append_child(part.c_str());
@@ -100,7 +99,7 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(config_option_t option
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::shared_ptr<pugi::xml_node>& parent, config_option_t option, const std::string& value)
 {
     auto cs = std::string(ConfigDefinition::mapConfigOption(option));
-    if (cs.substr(0, ConfigDefinition::ATTRIBUTE.size()) == ConfigDefinition::ATTRIBUTE) {
+    if (startswith(cs, ConfigDefinition::ATTRIBUTE)) {
         cs = ConfigDefinition::removeAttribute(option);
         parent->append_attribute(cs.c_str()) = value.c_str();
     } else {
@@ -164,7 +163,7 @@ std::string ConfigGenerator::generate(const fs::path& userHome, const fs::path&
 
     auto docinfo = config->append_child(pugi::node_comment);
     docinfo.set_value(R"(
-     See http://gerbera.io or read the docs for more
+     See https://gerbera.io or read the docs for more
      information on creating and using config.xml configuration files.
     )");
 
@@ -324,6 +323,7 @@ void ConfigGenerator::generateMappings()
 
     setDictionary(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST);
     setDictionary(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
+    setDictionary(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNATRANSFER_LIST);
     setDictionary(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST);
 }
 
@@ -341,7 +341,7 @@ void ConfigGenerator::generateOnlineContent()
 
 void ConfigGenerator::generateTranscoding()
 {
-    auto transcoding = setValue(CFG_TRANSCODING_TRANSCODING_ENABLED);
+    setValue(CFG_TRANSCODING_TRANSCODING_ENABLED);
     setDictionary(ATTR_TRANSCODING_MIMETYPE_PROF_MAP);
 
     const auto profileTag = ConfigDefinition::mapConfigOption(ATTR_TRANSCODING_PROFILES_PROFLE);
