@@ -4,7 +4,7 @@
 
     config_generator.h - this file is part of Gerbera.
 
-    Copyright (C) 2016-2021 Gerbera Contributors
+    Copyright (C) 2016-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -26,13 +26,10 @@
 #ifndef GERBERA_CONFIG_GENERATOR_H
 #define GERBERA_CONFIG_GENERATOR_H
 
-#include <filesystem>
 #include <pugixml.hpp>
 
 #include "config/config_manager.h"
 
-namespace fs = std::filesystem;
-
 class ConfigGenerator {
 public:
     std::string generate(const fs::path& userHome, const fs::path& configDir, const fs::path& dataDir, const fs::path& magicFile);
@@ -40,6 +37,7 @@ public:
     void generateServer(const fs::path& userHome, const fs::path& configDir, const fs::path& dataDir);
     void generateUi();
     void generateExtendedRuntime();
+    void generateDynamics();
     void generateDatabase();
     void generateImport(const fs::path& prefixDir, const fs::path& magicFile);
     void generateMappings();
@@ -49,7 +47,7 @@ public:
 
     std::shared_ptr<pugi::xml_node> init();
 
-    std::shared_ptr<pugi::xml_node> getNode(const std::string& tag);
+    std::shared_ptr<pugi::xml_node> getNode(const std::string& tag) const;
 
 protected:
     std::map<std::string, std::shared_ptr<pugi::xml_node>> generated;
@@ -62,7 +60,7 @@ protected:
     std::shared_ptr<pugi::xml_node> setValue(config_option_t option, const std::string& key, const std::string& value);
     std::shared_ptr<pugi::xml_node> setValue(config_option_t option, config_option_t dict, config_option_t attr, const std::string& value);
 
-    static std::shared_ptr<pugi::xml_node> setValue(std::shared_ptr<pugi::xml_node>& parent, config_option_t option, const std::string& value);
+    static std::shared_ptr<pugi::xml_node> setValue(const std::shared_ptr<pugi::xml_node>& parent, config_option_t option, const std::string& value);
 };
 
-#endif //GERBERA_CONFIG_GENERATOR_H
+#endif // GERBERA_CONFIG_GENERATOR_H
