@@ -31,30 +31,19 @@
 
 #include "config_manager.h" // API
 
-#include <array>
-#include <cstdio>
 #include <filesystem>
-#include <iostream>
 #include <numeric>
 #include <sstream>
-#include <sys/stat.h>
 
 #if defined(HAVE_NL_LANGINFO) && defined(HAVE_SETLOCALE)
-#include <clocale>
 #include <langinfo.h>
 #endif
 
-#ifdef HAVE_CURL
-#include <curl/curl.h>
-#endif
-
 #include "client_config.h"
 #include "config_definition.h"
 #include "config_options.h"
 #include "config_setup.h"
-#include "content/autoscan.h"
 #include "database/database.h"
-#include "metadata/metadata_handler.h"
 #include "transcoding/transcoding.h"
 #include "util/string_converter.h"
 #include "util/tools.h"
@@ -72,7 +61,6 @@ ConfigManager::ConfigManager(fs::path filename,
     , ip(std::move(ip))
     , interface(std::move(interface))
     , port(port)
-    , xmlDoc(std::make_unique<pugi::xml_document>())
 {
     ConfigManager::debug = debug;
 
@@ -95,11 +83,6 @@ ConfigManager::ConfigManager(fs::path filename,
     }
 }
 
-ConfigManager::~ConfigManager()
-{
-    log_debug("ConfigManager destroyed");
-}
-
 std::shared_ptr<Config> ConfigManager::getSelf()
 {
     return shared_from_this();
@@ -114,7 +97,7 @@ std::shared_ptr<ConfigOption> ConfigManager::setOption(const pugi::xml_node& roo
     return co->getValue();
 }
 
-void ConfigManager::addOption(config_option_t option, std::shared_ptr<ConfigOption> optionValue)
+void ConfigManager::addOption(config_option_t option, const std::shared_ptr<ConfigOption>& optionValue)
 {
     options.at(option) = optionValue;
 }
@@ -123,7 +106,6 @@ void ConfigManager::load(const fs::path& userHome)
 {
     std::map<std::string, std::string> args;
     auto self = getSelf();
-    std::shared_ptr<ConfigSetup> co;
 
     log_info("Loading configuration from: {}", filename.c_str());
     pugi::xml_parse_result result = xmlDoc->load_file(filename.c_str());
@@ -149,7 +131,7 @@ void ConfigManager::load(const fs::path& userHome)
 
     // now go through the mandatory parameters,
     // if something is missing we will not start the server
-    co = ConfigDefinition::findConfigSetup(CFG_SERVER_HOME);
+    auto co = ConfigDefinition::findConfigSetup(CFG_SERVER_HOME);
     // respect command line if available; ignore xml value
     {
         std::string temp = !userHome.empty() ? userHome.string() : co->getXmlContent(root);
@@ -160,8 +142,8 @@ void ConfigManager::load(const fs::path& userHome)
     }
 
     // checking database driver options
-    bool mysql_en = false;
-    bool sqlite3_en = false;
+    bool mysqlEn = false;
+    bool sqlite3En = false;
 
     co = ConfigDefinition::findConfigSetup(CFG_SERVER_STORAGE);
     co->getXmlElement(root); // fails if missing
@@ -169,26 +151,26 @@ void ConfigManager::load(const fs::path& userHome)
 
     co = ConfigDefinition::findConfigSetup(CFG_SERVER_STORAGE_MYSQL);
     if (co->hasXmlElement(root)) {
-        mysql_en = setOption(root, CFG_SERVER_STORAGE_MYSQL_ENABLED)->getBoolOption();
+        mysqlEn = setOption(root, CFG_SERVER_STORAGE_MYSQL_ENABLED)->getBoolOption();
     }
 
     co = ConfigDefinition::findConfigSetup(CFG_SERVER_STORAGE_SQLITE);
     if (co->hasXmlElement(root)) {
-        sqlite3_en = setOption(root, CFG_SERVER_STORAGE_SQLITE_ENABLED)->getBoolOption();
+        sqlite3En = setOption(root, CFG_SERVER_STORAGE_SQLITE_ENABLED)->getBoolOption();
     }
 
-    if (sqlite3_en && mysql_en)
+    if (sqlite3En && mysqlEn)
         throw_std_runtime_error("You enabled both, sqlite3 and mysql but "
                                 "only one database driver may be active at a time");
 
-    if (!sqlite3_en && !mysql_en)
+    if (!sqlite3En && !mysqlEn)
         throw_std_runtime_error("You disabled both sqlite3 and mysql but "
                                 "one database driver must be active");
 
     std::string dbDriver;
 
 #ifdef HAVE_MYSQL
-    if (mysql_en) {
+    if (mysqlEn) {
         // read mysql options
         setOption(root, CFG_SERVER_STORAGE_MYSQL_HOST);
         setOption(root, CFG_SERVER_STORAGE_MYSQL_DATABASE);
@@ -206,14 +188,14 @@ void ConfigManager::load(const fs::path& userHome)
         dbDriver = "mysql";
     }
 #else
-    if (mysql_en) {
+    if (mysqlEn) {
         throw_std_runtime_error("You enabled MySQL database in configuration, "
                                 "however this version of Gerbera was compiled "
                                 "without MySQL support!");
     }
 #endif // HAVE_MYSQL
 
-    if (sqlite3_en) {
+    if (sqlite3En) {
         // read sqlite options
         setOption(root, CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
         setOption(root, CFG_SERVER_STORAGE_SQLITE_SYNCHRONOUS);
@@ -234,17 +216,17 @@ void ConfigManager::load(const fs::path& userHome)
     co->makeOption(dbDriver, self);
 
     // now go through the optional settings and fix them if anything is missing
-    auto def_ipp = setOption(root, CFG_SERVER_UI_DEFAULT_ITEMS_PER_PAGE)->getIntOption();
+    auto defIpp = setOption(root, CFG_SERVER_UI_DEFAULT_ITEMS_PER_PAGE)->getIntOption();
 
-    // now get the option list for the drop down menu
-    auto menu_opts = setOption(root, CFG_SERVER_UI_ITEMS_PER_PAGE_DROPDOWN)->getArrayOption();
-    if (std::find(menu_opts.begin(), menu_opts.end(), fmt::to_string(def_ipp)) == menu_opts.end())
+    // now get the option list for the drop-down menu
+    auto menuOpts = setOption(root, CFG_SERVER_UI_ITEMS_PER_PAGE_DROPDOWN)->getArrayOption();
+    if (std::find(menuOpts.begin(), menuOpts.end(), fmt::to_string(defIpp)) == menuOpts.end())
         throw_std_runtime_error("Error in config file: at least one <option> "
                                 "under <items-per-page> must match the "
                                 "<items-per-page default=\"\" /> attribute");
 
-    bool cl_en = setOption(root, CFG_CLIENTS_LIST_ENABLED)->getBoolOption();
-    args["isEnabled"] = cl_en ? "true" : "false";
+    bool clEn = setOption(root, CFG_CLIENTS_LIST_ENABLED)->getBoolOption();
+    args["isEnabled"] = clEn ? "true" : "false";
     setOption(root, CFG_CLIENTS_LIST, &args);
     args.clear();
 
@@ -258,14 +240,14 @@ void ConfigManager::load(const fs::path& userHome)
 #if defined(HAVE_NL_LANGINFO) && defined(HAVE_SETLOCALE)
     if (setlocale(LC_ALL, "")) {
         defaultCharSet = nl_langinfo(CODESET);
-        log_debug("received {} from nl_langinfo", defaultCharSet.c_str());
+        log_debug("received {} from nl_langinfo", defaultCharSet);
     }
 #endif
     // check if the one we take as default is actually available
     co = ConfigDefinition::findConfigSetup(CFG_IMPORT_FILESYSTEM_CHARSET);
     try {
         auto conv = std::make_unique<StringConverter>(defaultCharSet, DEFAULT_INTERNAL_CHARSET);
-    } catch (const std::runtime_error& e) {
+    } catch (const std::runtime_error&) {
         defaultCharSet = DEFAULT_FALLBACK_CHARSET;
     }
     co->setDefaultValue(defaultCharSet);
@@ -276,7 +258,7 @@ void ConfigManager::load(const fs::path& userHome)
     } catch (const std::runtime_error& e) {
         throw_std_runtime_error("Error in config file: unsupported filesystem-charset specified: {}\n{}", charset, e.what());
     }
-    log_debug("Setting filesystem import charset to {}", charset.c_str());
+    log_debug("Setting filesystem import charset to {}", charset);
     co->makeOption(charset, self);
 
     co = ConfigDefinition::findConfigSetup(CFG_IMPORT_METADATA_CHARSET);
@@ -287,7 +269,7 @@ void ConfigManager::load(const fs::path& userHome)
     } catch (const std::runtime_error& e) {
         throw_std_runtime_error("Error in config file: unsupported metadata-charset specified: {}\n{}", charset, e.what());
     }
-    log_debug("Setting metadata import charset to {}", charset.c_str());
+    log_debug("Setting metadata import charset to {}", charset);
     co->makeOption(charset, self);
 
     // read playlist options
@@ -299,7 +281,7 @@ void ConfigManager::load(const fs::path& userHome)
     } catch (const std::runtime_error& e) {
         throw_std_runtime_error("Error in config file: unsupported playlist-charset specified: {}\n{}", charset, e.what());
     }
-    log_debug("Setting playlist charset to {}", charset.c_str());
+    log_debug("Setting playlist charset to {}", charset);
     co->makeOption(charset, self);
 
     // read network options
@@ -320,7 +302,7 @@ void ConfigManager::load(const fs::path& userHome)
             throw_std_runtime_error("Error in config file: \"append-to\" attribute "
                                     "value in <presentationURL> tag is set to \"{}\""
                                     "but no URL is specified",
-                temp.c_str());
+                temp);
         }
     }
 #ifdef HAVE_JS
@@ -363,7 +345,6 @@ void ConfigManager::load(const fs::path& userHome)
     co->setDefaultValue(dataDir / DEFAULT_JS_DIR / DEFAULT_IMPORT_SCRIPT);
     co->makeOption(root, self, &args);
     args.clear();
-    auto script_path = co->getValue()->getOption();
 #endif
 
     co = ConfigDefinition::findConfigSetup(CFG_SERVER_PORT);
@@ -385,27 +366,28 @@ void ConfigManager::load(const fs::path& userHome)
     args.clear();
 
     // read transcoding options
-    auto tr_en = setOption(root, CFG_TRANSCODING_TRANSCODING_ENABLED)->getBoolOption();
-    args["isEnabled"] = tr_en ? "true" : "false";
+    auto trEn = setOption(root, CFG_TRANSCODING_TRANSCODING_ENABLED)->getBoolOption();
+    args["isEnabled"] = trEn ? "true" : "false";
     setOption(root, CFG_TRANSCODING_PROFILE_LIST, &args);
     args.clear();
 
 #ifdef HAVE_CURL
-    if (tr_en) {
+    if (trEn) {
         setOption(root, CFG_EXTERNAL_TRANSCODING_CURL_BUFFER_SIZE);
         setOption(root, CFG_EXTERNAL_TRANSCODING_CURL_FILL_SIZE);
     }
-#endif //HAVE_CURL
+#endif // HAVE_CURL
 
     // read import options
     args["trim"] = "false";
     setOption(root, CFG_IMPORT_LIBOPTS_ENTRY_SEP, &args);
+    setOption(root, CFG_UPNP_SEARCH_SEPARATOR, &args);
     setOption(root, CFG_IMPORT_LIBOPTS_ENTRY_LEGACY_SEP, &args);
     args.clear();
 
 #if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
-    auto ffmp_en = setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED)->getBoolOption();
-    if (ffmp_en) {
+    auto ffmpEn = setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED)->getBoolOption();
+    if (ffmpEn) {
         setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE);
         setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE);
         setOption(root, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY);
@@ -423,8 +405,8 @@ void ConfigManager::load(const fs::path& userHome)
     }
 
 #if defined(HAVE_LASTFMLIB)
-    auto lfm_en = setOption(root, CFG_SERVER_EXTOPTS_LASTFM_ENABLED)->getBoolOption();
-    if (lfm_en) {
+    auto lfmEn = setOption(root, CFG_SERVER_EXTOPTS_LASTFM_ENABLED)->getBoolOption();
+    if (lfmEn) {
         setOption(root, CFG_SERVER_EXTOPTS_LASTFM_USERNAME);
         setOption(root, CFG_SERVER_EXTOPTS_LASTFM_PASSWORD);
     }
@@ -439,35 +421,26 @@ void ConfigManager::load(const fs::path& userHome)
 #endif
 
 #ifdef HAVE_INOTIFY
-    auto config_timed_list = getAutoscanListOption(CFG_IMPORT_AUTOSCAN_TIMED_LIST);
-    auto config_inotify_list = getAutoscanListOption(CFG_IMPORT_AUTOSCAN_INOTIFY_LIST);
+    auto configTimedList = getAutoscanListOption(CFG_IMPORT_AUTOSCAN_TIMED_LIST);
+    auto configInotifyList = getAutoscanListOption(CFG_IMPORT_AUTOSCAN_INOTIFY_LIST);
 
-    for (size_t i = 0; i < config_inotify_list->size(); i++) {
-        auto i_dir = config_inotify_list->get(i);
-        for (size_t j = 0; j < config_timed_list->size(); j++) {
-            auto t_dir = config_timed_list->get(j);
-            if (i_dir->getLocation() == t_dir->getLocation())
+    for (std::size_t i = 0; i < configInotifyList->size(); i++) {
+        auto iDir = configInotifyList->get(i);
+        for (std::size_t j = 0; j < configTimedList->size(); j++) {
+            auto tDir = configTimedList->get(j);
+            if (iDir->getLocation() == tDir->getLocation())
                 throw_std_runtime_error("Error in config file: same path used in both inotify and timed scan modes");
         }
     }
 #endif
 
     // read online content options
-#ifdef SOPCAST
-    int sopcast_refresh = setOption(root, CFG_ONLINE_CONTENT_SOPCAST_REFRESH)->getIntOption();
-    int sopcast_purge = setOption(root, CFG_ONLINE_CONTENT_SOPCAST_PURGE_AFTER)->getIntOption();
-
-    if (sopcast_refresh >= sopcast_purge) {
-        if (sopcast_purge != 0)
-            throw_std_runtime_error("Error in config file: SopCast purge-after value must be greater than refresh interval");
-    }
-#endif
 
 #ifdef ATRAILERS
-    int atrailers_refresh = setOption(root, CFG_ONLINE_CONTENT_ATRAILERS_REFRESH)->getIntOption();
+    int atrailersRefresh = setOption(root, CFG_ONLINE_CONTENT_ATRAILERS_REFRESH)->getIntOption();
 
     co = ConfigDefinition::findConfigSetup(CFG_ONLINE_CONTENT_ATRAILERS_PURGE_AFTER);
-    co->makeOption(fmt::to_string(atrailers_refresh), self);
+    co->makeOption(fmt::to_string(atrailersRefresh), self);
 #endif
 
     // read options that do not have special requirement and that are not yet loaded
@@ -481,13 +454,13 @@ void ConfigManager::load(const fs::path& userHome)
 
     std::ostringstream buf;
     xmlDoc->print(buf, "  ");
-    log_debug("Config file dump after validation: {}", buf.str().c_str());
+    log_debug("Config file dump after validation: {}", buf.str());
 
     // now the XML is no longer needed we can destroy it
     xmlDoc = nullptr;
 }
 
-void ConfigManager::updateConfigFromDatabase(std::shared_ptr<Database> database)
+void ConfigManager::updateConfigFromDatabase(const std::shared_ptr<Database>& database)
 {
     auto values = database->getConfigValues();
     auto self = getSelf();
