@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     config_manager.h - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -33,12 +33,10 @@
 #ifndef __CONFIG_MANAGER_H__
 #define __CONFIG_MANAGER_H__
 
-#include <filesystem>
 #include <map>
 #include <memory>
 #include <netinet/in.h>
 #include <pugixml.hpp>
-namespace fs = std::filesystem;
 
 #include "common.h"
 #include "config.h"
@@ -64,21 +62,17 @@ public:
         fs::path dataDir, fs::path magicFile,
         std::string ip, std::string interface, in_port_t port,
         bool debug);
-    ~ConfigManager() override;
-
-    ConfigManager(const ConfigManager&) = delete;
-    ConfigManager& operator=(const ConfigManager&) = delete;
 
     /// \brief Returns the name of the config file that was used to launch the server.
     fs::path getConfigFilename() const override { return filename; }
 
     void load(const fs::path& userHome);
-    void updateConfigFromDatabase(std::shared_ptr<Database> database) override;
+    void updateConfigFromDatabase(const std::shared_ptr<Database>& database) override;
 
     /// \brief add a config option
     /// \param option option type to add.
     /// \param option option to add.
-    void addOption(config_option_t option, std::shared_ptr<ConfigOption> optionValue) override;
+    void addOption(config_option_t option, const std::shared_ptr<ConfigOption>& optionValue) override;
 
     /// \brief returns a config option of type std::string
     /// \param option option to retrieve.
@@ -135,7 +129,6 @@ public:
     void setOrigValue(const std::string& item, int value) override;
 
     static bool isDebugLogging() { return debug; }
-    fs::path getDataDir() const override { return dataDir; }
 
 protected:
     fs::path filename;
@@ -147,7 +140,7 @@ protected:
     static bool debug;
     std::map<std::string, std::string> origValues;
 
-    std::unique_ptr<pugi::xml_document> xmlDoc;
+    std::unique_ptr<pugi::xml_document> xmlDoc { std::make_unique<pugi::xml_document>() };
 
     std::vector<std::shared_ptr<ConfigOption>> options { CFG_MAX };
 
