@@ -34,7 +34,6 @@
 #define __CONFIG_OPTIONS_H__
 
 #include <map>
-#include <string>
 #include <vector>
 
 #include "transcoding/transcoding.h"
@@ -43,9 +42,12 @@
 class AutoscanList;
 class ClientConfigList;
 class DirectoryConfigList;
+class DynamicContentList;
 
 class ConfigOption {
 public:
+    virtual ~ConfigOption() = default;
+
     virtual std::string getOption() const
     {
         throw std::runtime_error("Wrong option type string");
@@ -91,7 +93,10 @@ public:
         throw std::runtime_error("Wrong option type directory list");
     }
 
-    virtual ~ConfigOption() = default;
+    virtual std::shared_ptr<DynamicContentList> getDynamicContentListOption() const
+    {
+        throw std::runtime_error("Wrong option type dynamic content list");
+    }
 };
 
 class Option : public ConfigOption {
@@ -139,7 +144,7 @@ public:
         : option(std::move(option))
     {
         this->origSize = this->option.size();
-        size_t i = 0;
+        std::size_t i = 0;
         for (auto&& [key, val] : this->option) {
             this->indexMap[i] = key;
             i++;
@@ -148,56 +153,55 @@ public:
 
     std::map<std::string, std::string> getDictionaryOption(bool forEdit = false) const override;
 
-    std::string getKey(size_t index)
+    std::string getKey(std::size_t index)
     {
         return indexMap[index];
     }
 
-    size_t getEditSize() const;
+    std::size_t getEditSize() const;
 
-    void setKey(size_t keyIndex, const std::string& newKey);
+    void setKey(std::size_t keyIndex, const std::string& newKey);
 
-    void setValue(size_t keyIndex, const std::string& value);
+    void setValue(std::size_t keyIndex, const std::string& value);
 
 private:
     std::map<std::string, std::string> option;
-    size_t origSize;
-    std::map<size_t, std::string> indexMap;
+    std::size_t origSize;
+    std::map<std::size_t, std::string> indexMap;
 };
 
 class ArrayOption : public ConfigOption {
 public:
     explicit ArrayOption(std::vector<std::string> option)
         : option(std::move(option))
-        , origSize()
     {
         this->origSize = this->option.size();
-        for (size_t i = 0; i < this->origSize; i++) {
+        for (std::size_t i = 0; i < this->origSize; i++) {
             this->indexMap[i] = i;
         }
     }
 
     std::vector<std::string> getArrayOption(bool forEdit = false) const override;
 
-    size_t getIndex(size_t index)
+    std::size_t getIndex(std::size_t index)
     {
         return index < indexMap.size() ? indexMap[index] : indexMap.size();
     }
 
-    size_t getEditSize() const;
+    std::size_t getEditSize() const;
 
-    void setItem(size_t index, const std::string& value);
+    void setItem(std::size_t index, const std::string& value);
 
 private:
     std::vector<std::string> option;
-    size_t origSize;
-    std::map<size_t, size_t> indexMap;
+    std::size_t origSize {};
+    std::map<std::size_t, std::size_t> indexMap;
 };
 
 class AutoscanListOption : public ConfigOption {
 public:
-    explicit AutoscanListOption(std::shared_ptr<AutoscanList> option)
-        : option(std::move(option))
+    explicit AutoscanListOption(const std::shared_ptr<AutoscanList>& option)
+        : option(option)
     {
     }
 
@@ -209,7 +213,7 @@ private:
 
 class ClientConfigListOption : public ConfigOption {
 public:
-    explicit ClientConfigListOption(std::shared_ptr<ClientConfigList> option)
+    explicit ClientConfigListOption(const std::shared_ptr<ClientConfigList>& option)
         : option(std::move(option))
     {
     }
@@ -221,8 +225,8 @@ private:
 
 class DirectoryTweakOption : public ConfigOption {
 public:
-    explicit DirectoryTweakOption(std::shared_ptr<DirectoryConfigList> option)
-        : option(std::move(option))
+    explicit DirectoryTweakOption(const std::shared_ptr<DirectoryConfigList>& option)
+        : option(option)
     {
     }
     std::shared_ptr<DirectoryConfigList> getDirectoryTweakOption() const override { return option; }
@@ -233,10 +237,11 @@ protected:
 
 class TranscodingProfileListOption : public ConfigOption {
 public:
-    explicit TranscodingProfileListOption(std::shared_ptr<TranscodingProfileList> option)
-        : option(std::move(option))
+    explicit TranscodingProfileListOption(const std::shared_ptr<TranscodingProfileList>& option)
+        : option(option)
     {
     }
+
     std::shared_ptr<TranscodingProfileList> getTranscodingProfileListOption() const override
     {
         return option;
@@ -251,4 +256,20 @@ protected:
     std::shared_ptr<TranscodingProfileList> option;
 };
 
-#endif // __CONFIG_MANAGER_H__
+class DynamicContentListOption : public ConfigOption {
+public:
+    explicit DynamicContentListOption(const std::shared_ptr<DynamicContentList>& option)
+        : option(option)
+    {
+    }
+
+    std::shared_ptr<DynamicContentList> getDynamicContentListOption() const override
+    {
+        return option;
+    }
+
+protected:
+    std::shared_ptr<DynamicContentList> option;
+};
+
+#endif // __CONFIG_OPTIONS_H__
