@@ -3,7 +3,7 @@
     Gerbera - https://gerbera.io/
 
     config_setup.h - this file is part of Gerbera.
-    Copyright (C) 2020-2021 Gerbera Contributors
+    Copyright (C) 2020-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -26,7 +26,6 @@
 #ifndef __CONFIG_SETUP_H__
 #define __CONFIG_SETUP_H__
 
-#include <filesystem>
 #include <map>
 #include <memory>
 #include <pugixml.hpp>
@@ -43,15 +42,15 @@ class DirectoryTweak;
 class DynamicContent;
 enum class ScanMode;
 
-#define ITEM_PATH_ROOT -1
-#define ITEM_PATH_NEW -2
-#define ITEM_PATH_PREFIX -3
+#define ITEM_PATH_ROOT (-1)
+#define ITEM_PATH_NEW (-2)
+#define ITEM_PATH_PREFIX (-3)
 
-using StringCheckFunction = bool (*)(std::string& value);
-using ArrayInitFunction = bool (*)(const pugi::xml_node& value, std::vector<std::string>& result, const char* node_name);
-using DictionaryInitFunction = bool (*)(const pugi::xml_node& value, std::map<std::string, std::string>& result);
-using IntCheckFunction = bool (*)(int value);
-using IntMinFunction = bool (*)(int value, int minValue);
+using StringCheckFunction = std::function<bool(std::string& value)>;
+using ArrayInitFunction = std::function<bool(const pugi::xml_node& value, std::vector<std::string>& result, const char* node_name)>;
+using DictionaryInitFunction = std::function<bool(const pugi::xml_node& value, std::map<std::string, std::string>& result)>;
+using IntCheckFunction = std::function<bool(int value)>;
+using IntMinFunction = std::function<bool(int value, int minValue)>;
 
 using ConfigOptionIterator = EnumIterator<config_option_t, config_option_t::CFG_MIN, config_option_t::CFG_MAX>;
 
@@ -77,11 +76,11 @@ protected:
     std::string cpath;
     bool required = false;
     bool useDefault = false;
-    StringCheckFunction rawCheck;
+    StringCheckFunction rawCheck {};
     std::string defaultValue;
     const char* help;
 
-    static size_t extractIndex(const std::string& item);
+    static std::size_t extractIndex(const std::string& item);
 
     void setOption(const std::shared_ptr<Config>& config)
     {
@@ -89,13 +88,10 @@ protected:
     }
     static std::string buildCpath(const char* xpath)
     {
-        std::string cPath(xpath);
-        if (cPath[0] != '/') {
-            cPath = cPath.insert(0, "/");
-        }
-        cPath = cPath.insert(0, ROOT_NAME);
-        cPath = cPath.insert(0, "/");
-        return cPath;
+        auto cPath = std::string_view(xpath);
+        if (!cPath.empty() && cPath.front() != '/')
+            return fmt::format("/{}/{}", ROOT_NAME, cPath);
+        return fmt::format("/{}{}", ROOT_NAME, cPath);
     }
 
 public:
@@ -122,7 +118,7 @@ public:
     ConfigSetup(config_option_t option, const char* xpath, const char* help, StringCheckFunction check, const char* defaultValue = "", bool required = false)
         : cpath(buildCpath(xpath))
         , required(required)
-        , rawCheck(check)
+        , rawCheck(std::move(check))
         , defaultValue(defaultValue)
         , help(help)
         , option(option)
@@ -188,7 +184,7 @@ public:
     }
 
     ConfigStringSetup(config_option_t option, const char* xpath, const char* help, const char* defaultValue, StringCheckFunction check = nullptr, bool notEmpty = false, bool required = false)
-        : ConfigSetup(option, xpath, help, check, defaultValue, required)
+        : ConfigSetup(option, xpath, help, std::move(check), defaultValue, required)
         , notEmpty(notEmpty)
     {
     }
@@ -244,7 +240,7 @@ public:
     En getXmlContent(const pugi::xml_node& root)
     {
         std::string optValue = ConfigSetup::getXmlContent(root, true);
-        log_debug("Config: option: '{}' value: '{}'", xpath, optValue.c_str());
+        log_debug("Config: option: '{}' value: '{}'", xpath, optValue);
         if (notEmpty && optValue.empty()) {
             throw_std_runtime_error("Error in config file: Invalid {}/{} empty value '{}'", root.path(), xpath, optValue);
         }
@@ -288,7 +284,7 @@ public:
     static fs::path Home;
 
     ConfigPathSetup(config_option_t option, const char* xpath, const char* help, const char* defaultValue = "", bool isFile = false, bool mustExist = true, bool notEmpty = false)
-        : ConfigSetup(option, xpath, help, nullptr, defaultValue)
+        : ConfigSetup(option, xpath, help, false, defaultValue)
         , isFile(isFile)
         , mustExist(mustExist)
         , notEmpty(notEmpty)
@@ -331,7 +327,7 @@ public:
 
     ConfigIntSetup(config_option_t option, const char* xpath, const char* help, IntCheckFunction check)
         : ConfigSetup(option, xpath, help)
-        , valueCheck(check)
+        , valueCheck(std::move(check))
 
     {
         this->defaultValue = fmt::to_string(0);
@@ -339,7 +335,7 @@ public:
 
     ConfigIntSetup(config_option_t option, const char* xpath, const char* help, int defaultValue, IntCheckFunction check)
         : ConfigSetup(option, xpath, help)
-        , valueCheck(check)
+        , valueCheck(std::move(check))
 
     {
         this->defaultValue = fmt::to_string(defaultValue);
@@ -347,7 +343,7 @@ public:
 
     ConfigIntSetup(config_option_t option, const char* xpath, const char* help, int defaultValue, int minValue, IntMinFunction check)
         : ConfigSetup(option, xpath, help)
-        , minCheck(check)
+        , minCheck(std::move(check))
         , minValue(minValue)
     {
         this->defaultValue = fmt::to_string(defaultValue);
@@ -355,14 +351,14 @@ public:
 
     ConfigIntSetup(config_option_t option, const char* xpath, const char* help, const char* defaultValue, IntCheckFunction check = nullptr)
         : ConfigSetup(option, xpath, help)
-        , valueCheck(check)
+        , valueCheck(std::move(check))
 
     {
         this->defaultValue = defaultValue;
     }
 
     ConfigIntSetup(config_option_t option, const char* xpath, const char* help, const char* defaultValue, StringCheckFunction check)
-        : ConfigSetup(option, xpath, help, check, defaultValue)
+        : ConfigSetup(option, xpath, help, std::move(check), defaultValue)
 
     {
     }
@@ -395,19 +391,16 @@ public:
 };
 
 class ConfigBoolSetup : public ConfigSetup {
-public:
-    ConfigBoolSetup(config_option_t option, const char* xpath, const char* help)
-        : ConfigSetup(option, xpath, help)
-    {
-    }
+    using ConfigSetup::ConfigSetup;
 
+public:
     ConfigBoolSetup(config_option_t option, const char* xpath, const char* help, const char* defaultValue, StringCheckFunction check = nullptr)
-        : ConfigSetup(option, xpath, help, check, defaultValue)
+        : ConfigSetup(option, xpath, help, std::move(check), defaultValue)
     {
     }
 
     ConfigBoolSetup(config_option_t option, const char* xpath, const char* help, bool defaultValue, StringCheckFunction check = nullptr)
-        : ConfigSetup(option, xpath, help, check)
+        : ConfigSetup(option, xpath, help, std::move(check))
     {
         this->defaultValue = defaultValue ? YES : NO;
     }
@@ -430,7 +423,7 @@ public:
 
     std::shared_ptr<ConfigOption> newOption(bool optValue);
 
-    std::string getCurrentValue() const override { return optionValue ? (optionValue->getBoolOption() ? "true" : "false") : ""; }
+    std::string getCurrentValue() const override { return optionValue ? fmt::to_string(optionValue->getBoolOption()) : ""; }
 
     static bool CheckSqlLiteRestoreValue(std::string& value);
 
@@ -461,7 +454,7 @@ protected:
     /// This function will create an array like that: ["data", "otherdata"]
     bool createOptionFromNode(const pugi::xml_node& element, std::vector<std::string>& result) const;
 
-    bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<ArrayOption>& value, const std::string& optValue, const std::string& status = "") const;
+    bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<ArrayOption>& value, const std::string& optValue, const std::string& status = "") const;
 
 public:
     config_option_t nodeOption;
@@ -471,7 +464,7 @@ public:
         ArrayInitFunction init = nullptr, bool notEmpty = false, std::vector<std::string> defaultEntries = {})
         : ConfigSetup(option, xpath, help)
         , notEmpty(notEmpty)
-        , initArray(init)
+        , initArray(std::move(init))
         , defaultEntries(std::move(defaultEntries))
         , nodeOption(nodeOption)
     {
@@ -504,9 +497,9 @@ public:
 
     std::string getCurrentValue() const override { return {}; }
 
-    static bool InitPlayedItemsMark(const pugi::xml_node& value, std::vector<std::string>& result, const char* node_name);
+    static bool InitPlayedItemsMark(const pugi::xml_node& value, std::vector<std::string>& result, const char* nodeName);
 
-    static bool InitItemsPerPage(const pugi::xml_node& value, std::vector<std::string>& result, const char* node_name);
+    static bool InitItemsPerPage(const pugi::xml_node& value, std::vector<std::string>& result, const char* nodeName);
 };
 
 class ConfigDictionarySetup : public ConfigSetup {
@@ -534,7 +527,7 @@ protected:
     /// key:value paris: "1":"2", "3":"4"
     bool createOptionFromNode(const pugi::xml_node& optValue, std::map<std::string, std::string>& result) const;
 
-    bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<DictionaryOption>& value, const std::string& optKey, const std::string& optValue, const std::string& status = "") const;
+    bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<DictionaryOption>& value, const std::string& optKey, const std::string& optValue, const std::string& status = "") const;
 
 public:
     config_option_t nodeOption {};
@@ -546,7 +539,7 @@ public:
         : ConfigSetup(option, xpath, help, required && defaultEntries.empty())
         , notEmpty(notEmpty)
         , itemNotEmpty(itemNotEmpty)
-        , initDict(init)
+        , initDict(std::move(init))
         , defaultEntries(std::move(defaultEntries))
     {
     }
@@ -589,7 +582,7 @@ protected:
     /// \param scanmode add only directories with the specified scanmode to the array
     bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<AutoscanList>& result);
 
-    bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<AutoscanDirectory>& entry, std::string& optValue, const std::string& status = "") const;
+    bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<AutoscanDirectory>& entry, std::string& optValue, const std::string& status = "") const;
 
 public:
     ConfigAutoscanSetup(config_option_t option, const char* xpath, const char* help, ScanMode scanmode)
@@ -614,6 +607,8 @@ public:
 };
 
 class ConfigTranscodingSetup : public ConfigSetup {
+    using ConfigSetup::ConfigSetup;
+
 protected:
     bool isEnabled = false;
 
@@ -623,11 +618,6 @@ protected:
     static bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<TranscodingProfileList>& result);
 
 public:
-    ConfigTranscodingSetup(config_option_t option, const char* xpath, const char* help)
-        : ConfigSetup(option, xpath, help)
-    {
-    }
-
     std::string getTypeString() const override { return "List"; }
 
     void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
@@ -642,6 +632,8 @@ public:
 };
 
 class ConfigClientSetup : public ConfigSetup {
+    using ConfigSetup::ConfigSetup;
+
 protected:
     bool isEnabled = false;
 
@@ -649,14 +641,9 @@ protected:
     /// \param element starting element of the nodeset.
     static bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<ClientConfigList>& result);
 
-    bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<ClientConfig>& entry, std::string& optValue, const std::string& status = "") const;
+    bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<ClientConfig>& entry, std::string& optValue, const std::string& status = "") const;
 
 public:
-    ConfigClientSetup(config_option_t option, const char* xpath, const char* help)
-        : ConfigSetup(option, xpath, help)
-    {
-    }
-
     std::string getTypeString() const override { return "List"; }
 
     void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
@@ -671,19 +658,16 @@ public:
 };
 
 class ConfigDirectorySetup : public ConfigSetup {
+    using ConfigSetup::ConfigSetup;
+
 protected:
     /// \brief Creates an array of DirectoryTweak objects from a XML nodeset.
     /// \param element starting element of the nodeset.
     static bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<DirectoryConfigList>& result);
 
-    bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<DirectoryTweak>& entry, std::string& optValue, const std::string& status = "") const;
+    bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<DirectoryTweak>& entry, std::string& optValue, const std::string& status = "") const;
 
 public:
-    ConfigDirectorySetup(config_option_t option, const char* xpath, const char* help)
-        : ConfigSetup(option, xpath, help)
-    {
-    }
-
     std::string getTypeString() const override { return "List"; }
 
     void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
@@ -699,19 +683,16 @@ public:
 
 /// \brief Setup of dynamic content reader
 class ConfigDynamicContentSetup : public ConfigSetup {
+    using ConfigSetup::ConfigSetup;
+
 protected:
     /// \brief Creates an array of DynamicContent objects from a XML nodeset.
     /// \param element starting element of the nodeset.
     static bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<DynamicContentList>& result);
 
-    bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<DynamicContent>& entry, std::string& optValue, const std::string& status = "") const;
+    bool updateItem(std::size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<DynamicContent>& entry, std::string& optValue, const std::string& status = "") const;
 
 public:
-    ConfigDynamicContentSetup(config_option_t option, const char* xpath, const char* help)
-        : ConfigSetup(option, xpath, help)
-    {
-    }
-
     std::string getTypeString() const override { return "List"; }
 
     void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
