@@ -33,9 +33,7 @@
 #ifndef __AUTOSCAN_H__
 #define __AUTOSCAN_H__
 
-#include <filesystem>
 #include <mutex>
-namespace fs = std::filesystem;
 
 #include "util/timer.h"
 
@@ -55,7 +53,7 @@ enum class ScanMode {
 /// \brief Provides information about one autoscan directory.
 class AutoscanDirectory {
 public:
-    AutoscanDirectory();
+    AutoscanDirectory() = default;
 
     /// \brief Creates a new AutoscanDirectory object.
     /// \param location autoscan path
@@ -124,7 +122,7 @@ public:
     /// the last modification time of the starting point but we may not
     /// overwrite it until we are done.
     /// The time will be only set if it is higher than the previous value!
-    void setCurrentLMT(const fs::path& location, std::chrono::seconds lmt);
+    void setCurrentLMT(const fs::path& loc, std::chrono::seconds lmt);
     std::chrono::seconds getPreviousLMT() const;
     std::chrono::seconds getPreviousLMT(const fs::path& loc, const std::shared_ptr<CdsContainer>& parent) const;
     bool updateLMT();
@@ -134,35 +132,35 @@ public:
         last_mod_previous_scan = {};
         last_mod_current_scan = {};
     }
-    int getActiveScanCount() const { return activeScanCount; }
+    unsigned int getActiveScanCount() const { return activeScanCount; }
 
     /// \brief copies all properties to another object
     void copyTo(const std::shared_ptr<AutoscanDirectory>& copy) const;
 
     /// \brief Get the timer notify parameter associated with this directory.
-    std::shared_ptr<Timer::Parameter> getTimerParameter();
+    std::shared_ptr<Timer::Parameter> getTimerParameter() const;
 
     /* helpers for autoscan stuff */
-    static std::string_view mapScanmode(ScanMode scanmode);
+    static const char* mapScanmode(ScanMode scanmode);
     static ScanMode remapScanmode(const std::string& scanmode);
 
 protected:
     fs::path location;
-    ScanMode mode;
-    bool isOrig { false };
-    bool recursive;
-    bool hidden;
-    bool persistent_flag;
+    ScanMode mode {};
+    bool isOrig {};
+    bool recursive {};
+    bool hidden {};
+    bool persistent_flag {};
     std::chrono::seconds interval {};
-    int taskCount { 0 };
+    int taskCount {};
     int scanID { INVALID_SCAN_ID };
     int objectID { INVALID_OBJECT_ID };
     int databaseID { INVALID_OBJECT_ID };
     std::chrono::seconds last_mod_previous_scan {};
     std::chrono::seconds last_mod_current_scan {};
-    std::shared_ptr<Timer::Parameter> timer_parameter;
+    std::shared_ptr<Timer::Parameter> timer_parameter { std::make_shared<Timer::Parameter>(Timer::Parameter::IDAutoscan, INVALID_SCAN_ID) };
     std::map<fs::path, std::chrono::seconds> lastModified;
-    unsigned int activeScanCount { 0 };
+    unsigned int activeScanCount {};
 };
 
 #endif
