@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     autoscan_inotify.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -32,23 +32,23 @@
 #ifdef HAVE_INOTIFY
 #include "autoscan_inotify.h" // API
 
-#include <cassert>
+#include <sstream>
 
 #include "content_manager.h"
 #include "database/database.h"
 
 #define INOTIFY_MAX_USER_WATCHES_FILE "/proc/sys/fs/inotify/max_user_watches"
 
-AutoscanInotify::AutoscanInotify(std::shared_ptr<ContentManager> content)
+AutoscanInotify::AutoscanInotify(const std::shared_ptr<ContentManager>& content)
     : config(content->getContext()->getConfig())
     , database(content->getContext()->getDatabase())
-    , content(std::move(content))
+    , content(content)
 {
     std::error_code ec;
     if (isRegularFile(INOTIFY_MAX_USER_WATCHES_FILE, ec)) {
         try {
-            [[maybe_unused]] int max_watches = std::stoi(trimString(readTextFile(INOTIFY_MAX_USER_WATCHES_FILE)));
-            log_debug("Max watches on the system: {}", max_watches);
+            [[maybe_unused]] int maxWatches = std::stoi(trimString(GrbFile(INOTIFY_MAX_USER_WATCHES_FILE).readTextFile()));
+            log_debug("Max watches on the system: {}", maxWatches);
         } catch (const std::runtime_error& ex) {
             log_error("Could not determine maximum number of inotify user watches: {}", ex.what());
         }
@@ -94,7 +94,7 @@ void AutoscanInotify::threadProc()
 
             //  remove old dirs
             while (!unmonitorQueue.empty()) {
-                auto adir = unmonitorQueue.front();
+                auto adir = std::move(unmonitorQueue.front());
                 unmonitorQueue.pop();
 
                 lock.unlock();
@@ -120,7 +120,7 @@ void AutoscanInotify::threadProc()
 
             // monitor new dir
             while (!monitorQueue.empty()) {
-                auto adir = monitorQueue.front();
+                auto adir = std::move(monitorQueue.front());
                 monitorQueue.pop();
 
                 lock.unlock();
@@ -160,12 +160,12 @@ void AutoscanInotify::threadProc()
                 int wd = event->wd;
                 int mask = event->mask;
                 std::string name = event->name;
-                log_debug("inotify event: {} 0x{:x} {}", wd, mask, name.c_str());
+                log_debug("inotify event: {} 0x{:x} {}", wd, mask, name);
 
                 std::shared_ptr<Wd> wdObj;
                 try {
                     wdObj = watches.at(wd);
-                } catch (const std::out_of_range& ex) {
+                } catch (const std::out_of_range&) {
                     inotify->removeWatch(wd);
                     continue;
                 }
@@ -196,26 +196,23 @@ void AutoscanInotify::threadProc()
                         recheckNonexistingMonitors(wd, wdObj);
                     }
 
-                    if (adir && adir->getRecursive()) {
-                        // dir created
-                        if (mask & IN_CREATE) {
-                            if (adir->getHidden() || name.at(0) != '.') {
-                                log_debug("Detected new dir, adding to inotify: {}", path.c_str());
-                                auto dirEnt = fs::directory_entry(path, ec);
-                                if (!ec) {
-                                    monitorUnmonitorRecursive(dirEnt, false, adir, false, config->getBoolOption(CFG_IMPORT_FOLLOW_SYMLINKS));
-                                } else {
-                                    log_error("Failed to read {}: {}", path.c_str(), ec.message());
-                                }
+                    if (adir && adir->getRecursive() && (mask & IN_CREATE)) {
+                        if (adir->getHidden() || name.at(0) != '.') {
+                            log_debug("Detected new dir, adding to inotify: {}", path.c_str());
+                            auto dirEnt = fs::directory_entry(path, ec);
+                            if (!ec) {
+                                monitorUnmonitorRecursive(dirEnt, false, adir, false, config->getBoolOption(CFG_IMPORT_FOLLOW_SYMLINKS));
                             } else {
-                                log_debug("Detected new dir, irgnoring because it's hidden: {}", path.c_str());
+                                log_error("Failed to read {}: {}", path.c_str(), ec.message());
                             }
+                        } else {
+                            log_debug("Detected new dir, irgnoring because it's hidden: {}", path.c_str());
                         }
                     }
                 }
 
                 // changed
-                if (adir && mask & (IN_DELETE | IN_DELETE_SELF | IN_MOVE_SELF | IN_CLOSE_WRITE | IN_MOVED_FROM | IN_MOVED_TO | IN_UNMOUNT | IN_CREATE)) {
+                if (adir && (mask & (IN_DELETE | IN_DELETE_SELF | IN_MOVE_SELF | IN_CLOSE_WRITE | IN_MOVED_FROM | IN_MOVED_TO | IN_UNMOUNT | IN_CREATE))) {
                     // not new
                     if (!(mask & (IN_MOVED_TO | IN_CREATE))) {
                         log_debug("deleting {}", path.c_str());
@@ -225,11 +222,9 @@ void AutoscanInotify::threadProc()
                             if (mask & IN_MOVE_SELF)
                                 inotify->removeWatch(wd);
                             auto watch = getStartPoint(wdObj);
-                            if (watch) {
-                                if (adir->persistent()) {
-                                    monitorNonexisting(path, watch->getAutoscanDirectory());
-                                    content->handlePeristentAutoscanRemove(adir);
-                                }
+                            if (watch && adir->persistent()) {
+                                monitorNonexisting(path, watch->getAutoscanDirectory());
+                                content->handlePeristentAutoscanRemove(adir);
                             }
                         }
 
@@ -297,8 +292,7 @@ int AutoscanInotify::watchPathForMoves(const fs::path& path, int wd)
 
     fs::path watchPath;
     for (auto it = path.begin(); it != std::prev(path.end()); ++it) {
-        auto&& p = *it;
-        watchPath /= p;
+        watchPath /= *it;
         log_debug("adding move watch: {}", watchPath.c_str());
         parentWd = addMoveWatch(watchPath, wd, parentWd);
     }
@@ -312,10 +306,10 @@ int AutoscanInotify::addMoveWatch(const fs::path& path, int removeWd, int parent
     if (wd >= 0) {
         std::shared_ptr<Wd> wdObj;
         try {
-            //find
+            // find
             wdObj = watches.at(wd);
 
-            //alreadyThere
+            // alreadyThere
             int parentWdSet = wdObj->getParentWd();
             if (parentWdSet >= 0) {
                 if (parentWd != parentWdSet) {
@@ -324,7 +318,7 @@ int AutoscanInotify::addMoveWatch(const fs::path& path, int removeWd, int parent
                 }
             } else
                 wdObj->setParentWd(parentWd);
-        } catch (const std::out_of_range& ex) {
+        } catch (const std::out_of_range&) {
             // add new wstch
             wdObj = std::make_shared<Wd>(path, wd, parentWd);
             watches.emplace(wd, wdObj);
@@ -346,13 +340,13 @@ void AutoscanInotify::monitorNonexisting(const fs::path& path, const std::shared
 void AutoscanInotify::recheckNonexistingMonitor(int curWd, const std::vector<std::string>& pathAr, const std::shared_ptr<AutoscanDirectory>& adir)
 {
     bool first = true;
-    for (size_t i = pathAr.size() + 1; i > 0;) {
+    for (std::size_t i = pathAr.size() + 1; i > 0;) {
         i--;
         std::ostringstream buf;
         if (i == 0)
             buf << DIR_SEPARATOR;
         else {
-            for (size_t j = 0; j < i; j++) {
+            for (std::size_t j = 0; j < i; j++) {
                 buf << DIR_SEPARATOR << pathAr.at(j);
                 //                log_debug("adding: {}", pathAr->get(j)->data);
             }
@@ -381,8 +375,7 @@ void AutoscanInotify::checkMoveWatches(int wd, const std::shared_ptr<Wd>& wdObj)
 {
     auto&& wdWatches = wdObj->getWdWatches();
     for (auto it = wdWatches->begin(); it != wdWatches->end(); /*++it*/) {
-        auto& watchToCheck = *it;
-        if (watchToCheck->getType() == WatchType::Move) {
+        if ((*it)->getType() == WatchType::Move) {
             if (wdWatches->size() == 1) {
                 inotify->removeWatch(wd);
                 ++it;
@@ -390,7 +383,7 @@ void AutoscanInotify::checkMoveWatches(int wd, const std::shared_ptr<Wd>& wdObj)
                 it = wdWatches->erase(it);
             }
 
-            auto watchMv = std::static_pointer_cast<WatchMove>(watchToCheck);
+            auto watchMv = std::static_pointer_cast<WatchMove>(*it);
             int removeWd = watchMv->getRemoveWd();
             try {
                 auto wdToRemove = watches.at(removeWd);
@@ -413,7 +406,7 @@ void AutoscanInotify::checkMoveWatches(int wd, const std::shared_ptr<Wd>& wdObj)
                     if (objectID != INVALID_OBJECT_ID)
                         content->removeObject(adir, objectID, false);
                 }
-            } catch (const std::out_of_range& ex) {
+            } catch (const std::out_of_range&) {
             } // Not found in map
         } else
             ++it;
@@ -437,24 +430,20 @@ void AutoscanInotify::recheckNonexistingMonitors(int wd, const std::shared_ptr<W
 void AutoscanInotify::removeNonexistingMonitor(int wd, const std::shared_ptr<Wd>& wdObj, const std::vector<std::string>& pathAr)
 {
     auto&& wdWatches = wdObj->getWdWatches();
-    for (auto it = wdWatches->begin(); it != wdWatches->end(); /*++it*/) {
-        auto& watch = *it;
-        if (watch->getType() == WatchType::Autoscan) {
-            auto watchAs = std::static_pointer_cast<WatchAutoscan>(watch);
-            if (watchAs->getNonexistingPathArray() == pathAr) {
-                if (wdWatches->size() == 1) {
-                    // should be done automatically, because removeWatch triggers an IGNORED event
-                    //watches.remove(wd);
-
-                    inotify->removeWatch(wd);
-                    ++it;
-                } else {
-                    it = wdWatches->erase(it);
-                }
-                return;
+    auto it = std::find_if(wdWatches->begin(), wdWatches->end(),
+        [&](auto&& watch) {
+            if (watch->getType() == WatchType::Autoscan) {
+                auto watchAs = std::static_pointer_cast<WatchAutoscan>(watch);
+                return watchAs->getNonexistingPathArray() == pathAr;
             }
-        } else
-            ++it;
+            return false; });
+    if (it != wdWatches->end()) {
+        if (wdWatches->size() == 1) {
+            // removeWatch triggers an IN_IGNORED event so watches.erase(wd) is called in threadProc
+            inotify->removeWatch(wd);
+        } else {
+            wdWatches->erase(it);
+        }
     }
 }
 
@@ -522,7 +511,7 @@ int AutoscanInotify::monitorDirectory(const fs::path& path, const std::shared_pt
 
             // should we check for already existing "nonexisting" watches?
             // ...
-        } catch (const std::out_of_range& ex) {
+        } catch (const std::out_of_range&) {
             wdObj = std::make_shared<Wd>(path, wd, parentWd);
             watches.emplace(wd, wdObj);
         }
@@ -570,7 +559,7 @@ void AutoscanInotify::unmonitorDirectory(const fs::path& path, const std::shared
     } else {
         if (wdObj->getWdWatches()->size() == 1) {
             // should be done automatically, because removeWatch triggers an IGNORED event
-            //watches.remove(wd);
+            // watches.remove(wd);
 
             inotify->removeWatch(wd);
         } else {
@@ -585,10 +574,8 @@ std::shared_ptr<AutoscanInotify::WatchAutoscan> AutoscanInotify::getAppropriateA
     for (auto&& watch : *wdWatches) {
         if (watch->getType() == WatchType::Autoscan) {
             auto watchAs = std::static_pointer_cast<WatchAutoscan>(watch);
-            if (watchAs->getNonexistingPathArray().empty()) {
-                if (watchAs->getAutoscanDirectory()->getLocation() == adir->getLocation()) {
-                    return watchAs;
-                }
+            if (watchAs->getNonexistingPathArray().empty() && watchAs->getAutoscanDirectory()->getLocation() == adir->getLocation()) {
+                return watchAs;
             }
         }
     }
@@ -605,9 +592,9 @@ std::shared_ptr<AutoscanInotify::WatchAutoscan> AutoscanInotify::getAppropriateA
             auto watchAs = std::static_pointer_cast<WatchAutoscan>(watch);
             if (watchAs->getNonexistingPathArray().empty()) {
                 fs::path testLocation = watchAs->getAutoscanDirectory()->getLocation();
-                if (startswith(path.string(), testLocation.string())) {
+                if (testLocation <= path) {
                     if (!pathBestMatch.empty()) {
-                        if (pathBestMatch.string().length() < testLocation.string().length()) {
+                        if (pathBestMatch < testLocation) {
                             pathBestMatch = testLocation;
                             bestMatch = watchAs;
                         }
@@ -630,7 +617,7 @@ void AutoscanInotify::removeWatchMoves(int wd)
         std::shared_ptr<Wd> wdObj;
         try {
             wdObj = watches.at(checkWd);
-        } catch (const std::out_of_range& ex) {
+        } catch (const std::out_of_range&) {
             break;
         }
 
@@ -642,18 +629,17 @@ void AutoscanInotify::removeWatchMoves(int wd)
             first = false;
         } else {
             for (auto it = wdWatches->begin(); it != wdWatches->end(); /*++it*/) {
-                auto& watch = *it;
-                if (watch->getType() == WatchType::Move) {
-                    auto watchMv = std::static_pointer_cast<WatchMove>(watch);
+                if ((*it)->getType() == WatchType::Move) {
+                    auto watchMv = std::static_pointer_cast<WatchMove>(*it);
                     if (watchMv->getRemoveWd() == wd) {
                         log_debug("removing watch move");
-                        if (wdWatches->size() == 1) {
-                            inotify->removeWatch(checkWd);
-                            ++it;
-                        } else
+                        if (wdWatches->size() > 1) {
                             it = wdWatches->erase(it);
-                    } else
-                        ++it;
+                            continue;
+                        }
+                        inotify->removeWatch(checkWd);
+                    }
+                    ++it;
                 }
             }
         }
@@ -664,18 +650,16 @@ void AutoscanInotify::removeWatchMoves(int wd)
 bool AutoscanInotify::removeFromWdObj(const std::shared_ptr<Wd>& wdObj, const std::shared_ptr<Watch>& toRemove)
 {
     auto&& wdWatches = wdObj->getWdWatches();
-    for (auto it = wdWatches->begin(); it != wdWatches->end(); /*++it*/) {
-        auto& watch = *it;
-        if (watch == toRemove) {
-            if (wdWatches->size() == 1) {
-                inotify->removeWatch(wdObj->getWd());
-                ++it;
-            } else
-                it = wdWatches->erase(it);
-            return true;
+    auto it = std::find(wdWatches->begin(), wdWatches->end(), toRemove);
+    if (it != wdWatches->end()) {
+        if (wdWatches->size() == 1) {
+            inotify->removeWatch(wdObj->getWd());
+        } else {
+            wdWatches->erase(it);
         }
-        ++it;
+        return true;
     }
+
     return false;
 }
 
@@ -698,7 +682,7 @@ void AutoscanInotify::addDescendant(int startPointWd, int addWd, const std::shar
     std::shared_ptr<Wd> wdObj;
     try {
         wdObj = watches.at(startPointWd);
-    } catch (const std::out_of_range& ex) {
+    } catch (const std::out_of_range&) {
         return;
     }
     if (!wdObj)
@@ -718,7 +702,7 @@ void AutoscanInotify::removeDescendants(int wd)
     std::shared_ptr<Wd> wdObj;
     try {
         wdObj = watches.at(wd);
-    } catch (const std::out_of_range& ex) {
+    } catch (const std::out_of_range&) {
         return;
     }
 
