@@ -4,7 +4,7 @@
 
     autoscan_list.cc - this file is part of Gerbera.
 
-    Copyright (C) 2021 Gerbera Contributors
+    Copyright (C) 2021-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -35,20 +35,20 @@ AutoscanList::AutoscanList(std::shared_ptr<Database> database)
 void AutoscanList::updateLMinDB()
 {
     AutoLock lock(mutex);
-    for (size_t i = 0; i < list.size(); i++) {
+    for (std::size_t i = 0; i < list.size(); i++) {
         log_debug("i: {}", i);
         auto ad = list[i];
         database->updateAutoscanDirectory(ad);
     }
 }
 
-int AutoscanList::add(const std::shared_ptr<AutoscanDirectory>& dir, size_t index)
+int AutoscanList::add(const std::shared_ptr<AutoscanDirectory>& dir, std::size_t index)
 {
     AutoLock lock(mutex);
     return _add(dir, index);
 }
 
-int AutoscanList::_add(const std::shared_ptr<AutoscanDirectory>& dir, size_t index)
+int AutoscanList::_add(const std::shared_ptr<AutoscanDirectory>& dir, std::size_t index)
 {
     if (std::any_of(list.begin(), list.end(), [loc = dir->getLocation()](auto&& item) { return loc == item->getLocation(); })) {
         throw_std_runtime_error("Attempted to add same autoscan path twice");
@@ -76,22 +76,22 @@ void AutoscanList::addList(const std::shared_ptr<AutoscanList>& list)
     }
 }
 
-size_t AutoscanList::getEditSize() const
+std::size_t AutoscanList::getEditSize() const
 {
     if (indexMap.empty()) {
         return 0;
     }
-    return (*std::max_element(indexMap.begin(), indexMap.end(), [&](auto a, auto b) { return (a.first < b.first); })).first + 1;
+    return std::max_element(indexMap.begin(), indexMap.end(), [](auto a, auto b) { return (a.first < b.first); })->first + 1;
 }
 
-std::vector<std::shared_ptr<AutoscanDirectory>> AutoscanList::getArrayCopy()
+std::vector<std::shared_ptr<AutoscanDirectory>> AutoscanList::getArrayCopy() const
 {
     AutoLock lock(mutex);
 
     return list;
 }
 
-std::shared_ptr<AutoscanDirectory> AutoscanList::get(size_t id, bool edit)
+std::shared_ptr<AutoscanDirectory> AutoscanList::get(std::size_t id, bool edit) const
 {
     AutoLock lock(mutex);
     if (!edit) {
@@ -101,12 +101,12 @@ std::shared_ptr<AutoscanDirectory> AutoscanList::get(size_t id, bool edit)
         return list[id];
     }
     if (indexMap.find(id) != indexMap.end()) {
-        return indexMap[id];
+        return indexMap.at(id);
     }
     return nullptr;
 }
 
-std::shared_ptr<AutoscanDirectory> AutoscanList::getByObjectID(int objectID)
+std::shared_ptr<AutoscanDirectory> AutoscanList::getByObjectID(int objectID) const
 {
     AutoLock lock(mutex);
 
@@ -114,7 +114,7 @@ std::shared_ptr<AutoscanDirectory> AutoscanList::getByObjectID(int objectID)
     return it != list.end() ? *it : nullptr;
 }
 
-std::shared_ptr<AutoscanDirectory> AutoscanList::get(const fs::path& location)
+std::shared_ptr<AutoscanDirectory> AutoscanList::get(const fs::path& location) const
 {
     AutoLock lock(mutex);
 
@@ -122,7 +122,7 @@ std::shared_ptr<AutoscanDirectory> AutoscanList::get(const fs::path& location)
     return it != list.end() ? *it : nullptr;
 }
 
-void AutoscanList::remove(size_t id, bool edit)
+void AutoscanList::remove(std::size_t id, bool edit)
 {
     AutoLock lock(mutex);
 
@@ -157,12 +157,12 @@ std::shared_ptr<AutoscanList> AutoscanList::removeIfSubdir(const fs::path& paren
 {
     AutoLock lock(mutex);
 
-    auto rm_id_list = std::make_shared<AutoscanList>(database);
+    auto rmIdList = std::make_shared<AutoscanList>(database);
 
     for (auto it = list.begin(); it != list.end(); /*++it*/) {
-        auto& dir = *it;
+        auto dir = *it;
 
-        if (startswith(dir->getLocation(), parent)) {
+        if (parent <= dir->getLocation()) {
             if (dir->persistent() && !persistent) {
                 ++it;
                 continue;
@@ -171,20 +171,21 @@ std::shared_ptr<AutoscanList> AutoscanList::removeIfSubdir(const fs::path& paren
             auto copy = std::make_shared<AutoscanDirectory>();
             dir->copyTo(copy);
             copy->setScanID(dir->getScanID());
-            rm_id_list->add(copy);
+            rmIdList->add(copy);
 
             dir->setScanID(INVALID_SCAN_ID);
             it = list.erase(it);
-        } else
-            ++it;
+            continue;
+        }
+        ++it;
     }
 
-    return rm_id_list;
+    return rmIdList;
 }
 
 void AutoscanList::notifyAll(Timer::Subscriber* sub)
 {
-    if (sub == nullptr)
+    if (!sub)
         return;
     AutoLock lock(mutex);
 
