@@ -4,7 +4,7 @@
 
     autoscan_list.h - this file is part of Gerbera.
 
-    Copyright (C) 2021 Gerbera Contributors
+    Copyright (C) 2021-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -35,7 +35,6 @@ class AutoscanDirectory;
 class AutoscanList {
 public:
     explicit AutoscanList(std::shared_ptr<Database> database);
-    virtual ~AutoscanList() = default;
 
     /// \brief Adds a new AutoscanDirectory to the list.
     ///
@@ -44,22 +43,22 @@ public:
     ///
     /// \param dir AutoscanDirectory to add to the list.
     /// \return scanID of the newly added AutoscanDirectory
-    int add(const std::shared_ptr<AutoscanDirectory>& dir, size_t index = std::numeric_limits<std::size_t>::max());
+    int add(const std::shared_ptr<AutoscanDirectory>& dir, std::size_t index = std::numeric_limits<std::size_t>::max());
 
     [[maybe_unused]] void addList(const std::shared_ptr<AutoscanList>& list);
 
-    std::shared_ptr<AutoscanDirectory> get(size_t id, bool edit = false);
+    std::shared_ptr<AutoscanDirectory> get(std::size_t id, bool edit = false) const;
 
-    std::shared_ptr<AutoscanDirectory> get(const fs::path& location);
+    std::shared_ptr<AutoscanDirectory> get(const fs::path& location) const;
 
-    std::shared_ptr<AutoscanDirectory> getByObjectID(int objectID);
+    std::shared_ptr<AutoscanDirectory> getByObjectID(int objectID) const;
 
-    size_t getEditSize() const;
+    std::size_t getEditSize() const;
 
-    size_t size() const { return list.size(); }
+    std::size_t size() const { return list.size(); }
 
     /// \brief removes the AutoscanDirectory given by its scan ID
-    void remove(size_t id, bool edit = false);
+    void remove(std::size_t id, bool edit = false);
 
     /// \brief removes the AutoscanDirectory if it is a subdirectory of a given location.
     /// \param parent parent directory.
@@ -76,19 +75,19 @@ public:
     void updateLMinDB();
 
     /// \brief returns a copy of the autoscan list in the form of an array
-    std::vector<std::shared_ptr<AutoscanDirectory>> getArrayCopy();
+    std::vector<std::shared_ptr<AutoscanDirectory>> getArrayCopy() const;
 
 protected:
-    size_t origSize { 0 };
-    std::map<size_t, std::shared_ptr<AutoscanDirectory>> indexMap;
+    std::size_t origSize {};
+    std::map<std::size_t, std::shared_ptr<AutoscanDirectory>> indexMap;
 
     std::shared_ptr<Database> database;
 
-    std::recursive_mutex mutex;
-    using AutoLock = std::lock_guard<std::recursive_mutex>;
+    mutable std::recursive_mutex mutex;
+    using AutoLock = std::scoped_lock<std::recursive_mutex>;
 
     std::vector<std::shared_ptr<AutoscanDirectory>> list;
-    int _add(const std::shared_ptr<AutoscanDirectory>& dir, size_t index);
+    int _add(const std::shared_ptr<AutoscanDirectory>& dir, std::size_t index);
 };
 
 #endif //__AUTOSCAN_LIST_H__
