@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     atrailers_content_handler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -102,7 +102,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     if (temp.empty()) {
         log_warning("Failed to retrieve Trailer ID for \"{}\", "
                     "skipping...\n",
-            item->getTitle().c_str());
+            item->getTitle());
         return nullptr;
     }
 
@@ -113,7 +113,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     if (!preview) {
         log_warning("Failed to retrieve Trailer location for \"{}\", "
                     "skipping...\n",
-            item->getTitle().c_str());
+            item->getTitle());
         return nullptr;
     }
 
@@ -123,41 +123,33 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     } else {
         log_error("Could not get location for Trailers item {}, "
                   "skipping.\n",
-            item->getTitle().c_str());
+            item->getTitle());
         return nullptr;
     }
 
     item->setClass("object.item.videoItem");
 
-    temp = info.child("rating").text().as_string();
-    if (!temp.empty())
-        item->setMetadata(M_RATING, temp);
-
-    temp = info.child("studio").text().as_string();
-    if (!temp.empty())
-        item->setMetadata(M_PRODUCER, temp);
-
-    temp = info.child("director").text().as_string();
-    if (!temp.empty())
-        item->setMetadata(M_DIRECTOR, temp);
+    auto propertyMap = std::array {
+        std::pair("rating", M_RATING),
+        std::pair("studio", M_PRODUCER),
+        std::pair("director", M_DIRECTOR),
+        std::pair("releasedate", M_DATE),
+        /// \todo cut out a small part for the usual description
+        std::pair("description", M_LONGDESCRIPTION),
+    };
+    for (auto&& [key, tag] : propertyMap) {
+        temp = info.child(key).text().as_string();
+        if (!temp.empty()) {
+            item->addMetaData(tag, temp);
+        }
+    }
 
     temp = info.child("postdate").text().as_string();
     if (!temp.empty())
         item->setAuxData(ATRAILERS_AUXDATA_POST_DATE, temp);
 
-    temp = info.child("releasedate").text().as_string();
-    if (!temp.empty())
-        item->setMetadata(M_DATE, temp);
-
-    temp = info.child("description").text().as_string();
-    if (!temp.empty()) {
-        /// \todo cut out a small part for the usual description
-        item->setMetadata(M_LONGDESCRIPTION, temp);
-    }
-
     auto cast = trailer.child("cast");
     if (cast) {
-        std::string actors;
         for (auto&& actor : cast.children()) {
             if (actor.type() != pugi::node_element)
                 return nullptr;
@@ -166,20 +158,13 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
 
             temp = actor.text().as_string();
             if (!temp.empty()) {
-                if (!actors.empty())
-                    actors.append(", ");
-
-                actors.append(temp);
+                item->addMetaData(M_ARTIST, temp);
             }
         }
-
-        if (!actors.empty())
-            item->setMetadata(M_GENRE, temp);
     }
 
     auto genre = trailer.child("genre");
     if (genre) {
-        std::string genres;
         for (auto&& gn : genre.children()) {
             if (gn.type() != pugi::node_element)
                 return nullptr;
@@ -188,15 +173,9 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
 
             temp = gn.text().as_string();
             if (!temp.empty()) {
-                if (!genres.empty())
-                    genres.append(", ");
-
-                genres.append(temp);
+                item->addMetaData(M_GENRE, temp);
             }
         }
-
-        if (!genres.empty())
-            item->setMetadata(M_GENRE, temp);
     }
 
     /*
@@ -210,12 +189,12 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     }
     */
 
-    item->setAuxData(ONLINE_SERVICE_LAST_UPDATE, fmt::to_string(std::chrono::system_clock::to_time_t(std::chrono::system_clock::now())));
+    item->setAuxData(ONLINE_SERVICE_LAST_UPDATE, fmt::to_string(currentTime().count()));
 
     item->setFlag(OBJECT_FLAG_ONLINE_SERVICE);
     try {
         item->validate();
-        return std::move(item);
+        return item;
     } catch (const std::runtime_error& ex) {
         log_warning("Failed to validate newly created Trailer item: {}",
             ex.what());
@@ -223,4 +202,4 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     }
 }
 
-#endif //ATRAILERS
+#endif // ATRAILERS
