@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     lastfm_scrobbler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -41,12 +41,6 @@ LastFm::LastFm(const std::shared_ptr<Context>& context)
 {
 }
 
-LastFm::~LastFm()
-{
-    if (currentTrackId != -1 && scrobbler)
-        scrobbler->finishedPlaying();
-}
-
 void LastFm::run()
 {
     if (!config->getBoolOption(CFG_SERVER_EXTOPTS_LASTFM_ENABLED))
@@ -76,13 +70,11 @@ void LastFm::startedPlaying(const std::shared_ptr<CdsItem>& item)
 
     currentTrackId = item->getID();
 
-    log_debug("Artist:\t{}",
-        item->getMetadata(M_ARTIST).c_str());
-    log_debug("Title:\t{}",
-        item->getMetadata(M_TITLE).c_str());
+    std::string artist = item->getMetaData(M_ARTIST);
+    std::string title = item->getMetaData(M_TITLE);
 
-    std::string artist = item->getMetadata(M_ARTIST);
-    std::string title = item->getMetadata(M_TITLE);
+    log_debug("Artist:\t{}", artist);
+    log_debug("Title:\t{}", title);
 
     if (artist.empty() || title.empty()) {
         scrobbler->finishedPlaying();
@@ -92,11 +84,11 @@ void LastFm::startedPlaying(const std::shared_ptr<CdsItem>& item)
 
     auto info = SubmissionInfo(artist, title);
 
-    std::string album = item->getMetadata(M_ALBUM);
+    std::string album = item->getMetaData(M_ALBUM);
     if (!album.empty())
         info.setAlbum(album);
 
-    std::string trackNr = item->getMetadata(M_TRACKNUMBER);
+    std::string trackNr = item->getMetaData(M_TRACKNUMBER);
     if (!trackNr.empty())
         info.setTrackNr(std::stoi(trackNr));
 
@@ -109,4 +101,4 @@ void LastFm::startedPlaying(const std::shared_ptr<CdsItem>& item)
     scrobbler->startedPlaying(info);
 }
 
-#endif //HAVE_LASTFMLIB
+#endif // HAVE_LASTFMLIB
