@@ -35,9 +35,19 @@
 #include "content/content_manager.h"
 #include "content/layout/layout.h"
 
+TaskProcessor::TaskProcessor(std::shared_ptr<Config> config)
+    : config(std::move(config))
+{
+}
+
 void TaskProcessor::run()
 {
-    threadRunner = std::make_unique<StdThreadRunner>("TaskProcessorThread", TaskProcessor::staticThreadProc, this, config);
+    threadRunner = std::make_unique<StdThreadRunner>(
+        "TaskProcessorThread", [](void* arg) {
+            auto inst = static_cast<TaskProcessor*>(arg);
+            inst->threadProc();
+        },
+        this, config);
 
     // wait for thread to become ready
     threadRunner->waitForReady();
@@ -54,13 +64,6 @@ void TaskProcessor::shutdown()
     threadRunner->join();
 }
 
-void* TaskProcessor::staticThreadProc(void* arg)
-{
-    auto inst = static_cast<TaskProcessor*>(arg);
-    inst->threadProc();
-    return nullptr;
-}
-
 void TaskProcessor::threadProc()
 {
     StdThreadRunner::waitFor("TaskProcessor", [this] { return threadRunner != nullptr; });
@@ -76,7 +79,7 @@ void TaskProcessor::threadProc()
 
         task = nullptr;
         if (!taskQueue.empty()) {
-            task = taskQueue.front();
+            task = std::move(taskQueue.front());
             taskQueue.pop_front();
         }
 
@@ -93,7 +96,7 @@ void TaskProcessor::threadProc()
         try {
             if (task->isValid())
                 task->run();
-        } catch (const ServerShutdownException& se) {
+        } catch (const ServerShutdownException&) {
             shutdownFlag = true;
         } catch (const std::runtime_error& e) {
             log_error("Exception caught: {}", e.what());
@@ -105,32 +108,28 @@ void TaskProcessor::threadProc()
     }
 }
 
-void TaskProcessor::addTask(const std::shared_ptr<GenericTask>& task)
+void TaskProcessor::addTask(std::shared_ptr<GenericTask> task)
 {
     auto lock = threadRunner->lockGuard();
 
     task->setID(taskID++);
 
-    taskQueue.push_back(task);
+    taskQueue.push_back(std::move(task));
     threadRunner->notify();
 }
 
-std::shared_ptr<GenericTask> TaskProcessor::getCurrentTask()
+std::shared_ptr<GenericTask> TaskProcessor::getCurrentTask() const
 {
-    std::shared_ptr<GenericTask> task;
     auto lock = threadRunner->lockGuard();
-    task = currentTask;
-    return task;
+    return currentTask;
 }
 
 void TaskProcessor::invalidateTask(unsigned int taskID)
 {
     auto lock = threadRunner->lockGuard();
     auto tc = getCurrentTask();
-    if (tc) {
-        if ((tc->getID() == taskID) || (tc->getParentID() == taskID)) {
-            tc->invalidate();
-        }
+    if (tc && (tc->getID() == taskID || tc->getParentID() == taskID)) {
+        tc->invalidate();
     }
 
     for (auto&& tq : taskQueue) {
@@ -160,19 +159,19 @@ std::deque<std::shared_ptr<GenericTask>> TaskProcessor::getTasklist()
 }
 
 TPFetchOnlineContentTask::TPFetchOnlineContentTask(std::shared_ptr<ContentManager> content,
-    std::shared_ptr<TaskProcessor> task_processor,
+    std::shared_ptr<TaskProcessor> taskProcessor,
     std::shared_ptr<Timer> timer,
     std::shared_ptr<OnlineService> service,
     std::shared_ptr<Layout> layout,
     bool cancellable,
-    bool unscheduled_refresh)
+    bool unscheduledRefresh)
     : GenericTask(TaskProcessorTask)
     , content(std::move(content))
-    , task_processor(std::move(task_processor))
+    , task_processor(std::move(taskProcessor))
     , timer(std::move(timer))
     , service(std::move(service))
     , layout(std::move(layout))
-    , unscheduled_refresh(unscheduled_refresh)
+    , unscheduled_refresh(unscheduledRefresh)
 {
     this->cancellable = cancellable;
     this->taskType = FetchOnlineContent;
@@ -186,10 +185,9 @@ void TPFetchOnlineContentTask::run()
     }
 
     try {
-        //cm->_fetchOnlineContent(service, getParentID(), unscheduled_refresh);
+        // cm->_fetchOnlineContent(service, getParentID(), unscheduled_refresh);
         if (service->refreshServiceData(layout) && (isValid())) {
-            log_debug("Scheduling another task for online service: {}",
-                service->getServiceName().c_str());
+            log_debug("Scheduling another task for online service: {}", service->getServiceName());
 
             if ((service->getRefreshInterval() > std::chrono::seconds::zero()) || unscheduled_refresh) {
                 auto t = std::make_shared<TPFetchOnlineContentTask>(
@@ -203,13 +201,11 @@ void TPFetchOnlineContentTask::run()
         log_error("{}", ex.what());
     }
     service->decTaskCount();
-    if (service->getTaskCount() == 0) {
-        if ((service->getRefreshInterval() > std::chrono::seconds::zero()) && !unscheduled_refresh) {
-            timer->addTimerSubscriber(
-                content.get(),
-                service->getRefreshInterval(),
-                service->getTimerParameter(), true);
-        }
+    if ((service->getTaskCount() == 0) && (service->getRefreshInterval() > std::chrono::seconds::zero()) && !unscheduled_refresh) {
+        timer->addTimerSubscriber(
+            content.get(),
+            service->getRefreshInterval(),
+            service->getTimerParameter(), true);
     }
 }
 #endif // ONLINE_SERVICES
