@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     script.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -54,7 +54,7 @@
 #include "content/onlineservice/atrailers_content_handler.h"
 #endif
 
-static constexpr auto js_global_functions = std::array {
+static constexpr auto jsGlobalFunctions = std::array {
     duk_function_list_entry { "print", js_print, DUK_VARARGS },
     duk_function_list_entry { "addCdsObject", js_addCdsObject, 3 },
     duk_function_list_entry { "addContainerTree", js_addContainerTree, 1 },
@@ -68,14 +68,15 @@ static constexpr auto js_global_functions = std::array {
 
 std::string Script::getProperty(const std::string& name) const
 {
+    std::string ret;
     if (!duk_is_object_coercible(ctx, -1))
-        return {};
+        return ret;
     duk_get_prop_string(ctx, -1, name.c_str());
     if (duk_is_null_or_undefined(ctx, -1) || !duk_to_string(ctx, -1)) {
         duk_pop(ctx);
-        return {};
+        return ret;
     }
-    auto ret = duk_get_string(ctx, -1);
+    ret = duk_get_string(ctx, -1);
     duk_pop(ctx);
     return ret;
 }
@@ -108,11 +109,38 @@ int Script::getIntProperty(const std::string& name, int def) const
     return ret;
 }
 
+std::vector<std::string> Script::getArrayProperty(const std::string& name) const
+{
+    std::vector<std::string> result;
+    if (!duk_is_object_coercible(ctx, -1))
+        return result;
+    duk_get_prop_string(ctx, -1, name.c_str());
+    if (duk_is_null_or_undefined(ctx, -1) || !duk_is_array(ctx, -1)) {
+        duk_pop(ctx);
+        return result;
+    }
+    duk_enum(ctx, -1, 0);
+    while (duk_next(ctx, -1, 1 /* get_value */)) {
+        duk_get_string(ctx, -1);
+        if (duk_is_null_or_undefined(ctx, -1)) {
+            duk_pop_2(ctx);
+            continue;
+        }
+        // [key = duk_to_string(ctx, -2)]
+        auto val = std::string(duk_to_string(ctx, -1));
+        result.push_back(std::move(val));
+        duk_pop_2(ctx); /* pop_key */
+    }
+    duk_pop(ctx); // duk_enum
+    duk_pop(ctx); // property
+    return result;
+}
+
 std::vector<std::string> Script::getPropertyNames() const
 {
     std::vector<std::string> keys;
     duk_enum(ctx, -1, 0);
-    while (duk_next(ctx, -1 /*enum_idx*/, 0 /*get_value*/)) {
+    while (duk_next(ctx, -1, 0 /*get_key*/)) {
         /* [ ... enum key ] */
         auto sym = std::string(duk_get_string(ctx, -1));
         keys.push_back(std::move(sym));
@@ -136,14 +164,18 @@ void Script::setIntProperty(const std::string& name, int value)
 
 /* **************** */
 
-Script::Script(std::shared_ptr<ContentManager> content,
-    const std::shared_ptr<ScriptingRuntime>& runtime, const std::string& name)
+Script::Script(const std::shared_ptr<ContentManager>& content,
+    const std::shared_ptr<ScriptingRuntime>& runtime, const std::string& name,
+    std::string objName, std::unique_ptr<StringConverter> sc)
     : config(content->getContext()->getConfig())
     , database(content->getContext()->getDatabase())
-    , content(std::move(content))
+    , content(content)
     , runtime(runtime)
     , name(name)
+    , objectName(std::move(objName))
+    , sc(std::move(sc))
 {
+    entrySeparator = config->getOption(CFG_IMPORT_LIBOPTS_ENTRY_SEP);
     /* create a context and associate it with the JS run time */
     ScriptingRuntime::AutoLock lock(runtime->getMutex());
     ctx = runtime->createContext(name);
@@ -180,15 +212,10 @@ Script::Script(std::shared_ptr<ContentManager> content,
 #else
     duk_push_int(ctx, -1);
     duk_put_global_string(ctx, "ONLINE_SERVICE_APPLE_TRAILERS");
-#endif //ATRAILERS
+#endif // ATRAILERS
 
-#ifdef SOPCAST
-    duk_push_int(ctx, int(OS_SopCast));
-    duk_put_global_string(ctx, "ONLINE_SERVICE_SOPCAST");
-#else
     duk_push_int(ctx, -1);
     duk_put_global_string(ctx, "ONLINE_SERVICE_SOPCAST");
-#endif //SOPCAST
 
 #else // ONLINE SERVICES
     duk_push_int(ctx, 0);
@@ -199,13 +226,13 @@ Script::Script(std::shared_ptr<ContentManager> content,
     duk_put_global_string(ctx, "ONLINE_SERVICE_APPLE_TRAILERS");
     duk_push_int(ctx, -1);
     duk_put_global_string(ctx, "ONLINE_SERVICE_SOPCAST");
-#endif //ONLINE_SERVICES
+#endif // ONLINE_SERVICES
 
     for (auto&& [field, sym] : mt_keys) {
         duk_push_string(ctx, sym);
-        for (auto&& [f, s] : mt_names) {
+        for (auto [f, s] : mt_names) {
             if (f == field) {
-                duk_put_global_string(ctx, s);
+                duk_put_global_string(ctx, s.data());
             }
         }
     }
@@ -246,11 +273,11 @@ Script::Script(std::shared_ptr<ContentManager> content,
 
     for (auto&& acs : ConfigDefinition::getConfigSetupList<ConfigArraySetup>()) {
         auto array = acs->getValue()->getArrayOption(true);
-        auto duk_array = duk_push_array(ctx);
-        for (size_t i = 0; i < array.size(); i++) {
-            auto entry = array[i];
+        auto dukArray = duk_push_array(ctx);
+        for (duk_uarridx_t i = 0; i < array.size(); i++) {
+            auto&& entry = array[i];
             duk_push_string(ctx, entry.c_str());
-            duk_put_prop_index(ctx, duk_array, i);
+            duk_put_prop_index(ctx, dukArray, i);
         }
         duk_put_prop_string(ctx, -2, acs->getItemPath(-1).c_str());
     }
@@ -259,13 +286,13 @@ Script::Script(std::shared_ptr<ContentManager> content,
     std::string autoscanItemPath;
     for (auto&& ascs : ConfigDefinition::getConfigSetupList<ConfigAutoscanSetup>()) {
         auto autoscan = ascs->getValue()->getAutoscanListOption();
-        for (size_t i = 0; i < autoscan->size(); i++) {
+        for (std::size_t i = 0; i < autoscan->size(); i++) {
             auto&& entry = autoscan->get(i);
             auto&& adir = this->content->getAutoscanDirectory(entry->getLocation());
 
             duk_push_object(ctx);
             setProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_LOCATION), adir->getLocation());
-            setProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_MODE), AutoscanDirectory::mapScanmode(adir->getScanMode()).data());
+            setProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_MODE), AutoscanDirectory::mapScanmode(adir->getScanMode()));
             setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_INTERVAL), adir->getInterval().count());
             setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_RECURSIVE), adir->getRecursive());
             setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_HIDDENFILES), adir->getHidden());
@@ -281,29 +308,27 @@ Script::Script(std::shared_ptr<ContentManager> content,
 
     duk_put_global_string(ctx, "config");
 
-    defineFunctions(js_global_functions.data());
+    defineFunctions(jsGlobalFunctions.data());
 
-    std::string common_scr_path = config->getOption(CFG_IMPORT_SCRIPTING_COMMON_SCRIPT);
+    std::string commonScrPath = config->getOption(CFG_IMPORT_SCRIPTING_COMMON_SCRIPT);
 
-    if (common_scr_path.empty()) {
+    if (commonScrPath.empty()) {
         log_js("Common script disabled in configuration");
     } else {
         try {
-            _load(common_scr_path);
+            _load(commonScrPath);
             _execute();
         } catch (const std::runtime_error& e) {
-            log_js("Unable to load {}: {}", common_scr_path.c_str(),
-                e.what());
+            log_js("Unable to load {}: {}", commonScrPath, e.what());
         }
     }
-    std::string custom_scr_path = config->getOption(CFG_IMPORT_SCRIPTING_CUSTOM_SCRIPT);
-    if (!custom_scr_path.empty()) {
+    std::string customScrPath = config->getOption(CFG_IMPORT_SCRIPTING_CUSTOM_SCRIPT);
+    if (!customScrPath.empty()) {
         try {
-            _load(custom_scr_path);
+            _load(customScrPath);
             _execute();
         } catch (const std::runtime_error& e) {
-            log_js("Unable to load {}: {}", custom_scr_path.c_str(),
-                e.what());
+            log_js("Unable to load {}: {}", customScrPath, e.what());
         }
     }
 }
@@ -326,7 +351,7 @@ Script* Script::getContextScript(duk_context* ctx)
     return self;
 }
 
-void Script::defineFunction(const std::string& name, duk_c_function function, uint32_t numParams)
+void Script::defineFunction(const std::string& name, duk_c_function function, std::uint32_t numParams)
 {
     duk_push_c_function(ctx, function, numParams);
     duk_put_global_string(ctx, name.c_str());
@@ -339,9 +364,9 @@ void Script::defineFunctions(const duk_function_list_entry* functions)
     duk_pop(ctx);
 }
 
-void Script::_load(const std::string& scriptPath)
+void Script::_load(const fs::path& scriptPath)
 {
-    std::string scriptText = readTextFile(scriptPath);
+    std::string scriptText = GrbFile(scriptPath).readTextFile();
 
     if (scriptText.empty())
         throw_std_runtime_error("empty script");
@@ -360,7 +385,7 @@ void Script::_load(const std::string& scriptPath)
     }
 }
 
-void Script::load(const std::string& scriptPath)
+void Script::load(const fs::path& scriptPath)
 {
     ScriptingRuntime::AutoLock lock(runtime->getMutex());
     duk_push_thread_stash(ctx, ctx);
@@ -378,21 +403,44 @@ void Script::_execute()
     duk_pop(ctx);
 }
 
-void Script::execute()
+#define OBJECT_SCRIPT_PATH "object_script_path"
+#define OBJECT_AUTOSCAN_ID "object_autoscan_id"
+
+void Script::cleanup()
 {
+    duk_push_global_object(ctx);
+    duk_del_prop_string(ctx, -1, objectName.c_str());
+    duk_del_prop_string(ctx, -1, OBJECT_SCRIPT_PATH);
+    duk_del_prop_string(ctx, -1, OBJECT_AUTOSCAN_ID);
+}
+
+void Script::execute(const std::shared_ptr<CdsObject>& obj, const std::string& scriptPath)
+{
+    cdsObject2dukObject(obj);
+    duk_put_global_string(ctx, objectName.c_str());
+
+    duk_push_string(ctx, scriptPath.c_str());
+    duk_put_global_string(ctx, OBJECT_SCRIPT_PATH);
+
+    auto autoScan = content->getAutoscanDirectory(scriptPath);
+    if (autoScan && !scriptPath.empty()) {
+        duk_push_sprintf(ctx, "%d", autoScan->getScanID());
+        duk_put_global_string(ctx, OBJECT_AUTOSCAN_ID);
+    }
+
     ScriptingRuntime::AutoLock lock(runtime->getMutex());
     duk_push_thread_stash(ctx, ctx);
     duk_get_prop_string(ctx, -1, "script");
     duk_remove(ctx, -2);
+
     _execute();
+    cleanup();
+    duk_pop(ctx);
 }
 
 std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<CdsObject>& pcd)
 {
     std::string val;
-    int b;
-    int i;
-    std::unique_ptr<StringConverter> sc = (this->whoami() == S_PLAYLIST) ? StringConverter::p2i(config) : StringConverter::i2i(config);
 
     int objType = getIntProperty("objectType", -1);
     if (objType == -1) {
@@ -405,20 +453,20 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
     // CdsObject
     obj->setVirtual(true); // JS creates only virtual objects
 
-    i = getIntProperty("id", INVALID_OBJECT_ID);
-    if (i != INVALID_OBJECT_ID)
-        obj->setID(i);
-    i = getIntProperty("refID", INVALID_OBJECT_ID);
-    if (i != INVALID_OBJECT_ID)
-        obj->setRefID(i);
-    i = getIntProperty("parentID", INVALID_OBJECT_ID);
-    if (i != INVALID_OBJECT_ID) {
-        obj->setParentID(i);
+    int id = getIntProperty("id", INVALID_OBJECT_ID);
+    if (id != INVALID_OBJECT_ID)
+        obj->setID(id);
+    id = getIntProperty("refID", INVALID_OBJECT_ID);
+    if (id != INVALID_OBJECT_ID)
+        obj->setRefID(id);
+    id = getIntProperty("parentID", INVALID_OBJECT_ID);
+    if (id != INVALID_OBJECT_ID) {
+        obj->setParentID(id);
     }
 
-    i = getIntProperty("mtime", 0);
-    if (i > 0) {
-        obj->setMTime(std::chrono::seconds(i));
+    int mtime = getIntProperty("mtime", 0);
+    if (mtime > 0) {
+        obj->setMTime(std::chrono::seconds(mtime));
     }
 
     duk_get_prop_string(ctx, -1, "parent");
@@ -450,39 +498,42 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             obj->setClass(pcd->getClass());
     }
 
-    b = getBoolProperty("restricted");
-    if (b >= 0)
-        obj->setRestricted(b);
+    int restricted = getBoolProperty("restricted");
+    if (restricted >= 0)
+        obj->setRestricted(restricted);
 
-    duk_get_prop_string(ctx, -1, "meta");
+    duk_get_prop_string(ctx, -1, "metaData");
     if (!duk_is_null_or_undefined(ctx, -1) && duk_is_object(ctx, -1)) {
         duk_to_object(ctx, -1);
-        // only metadata enumerated in mt_keys is allowed
-        for (auto&& [sym, upnp] : mt_keys) {
-            val = getProperty(upnp);
-            if (!val.empty()) {
-                if (sym == M_TRACKNUMBER) {
-                    int j = stoiString(val, 0);
-                    if (j > 0) {
-                        obj->setMetadata(sym, val);
-                        std::static_pointer_cast<CdsItem>(obj)->setTrackNumber(j);
-                    } else
-                        std::static_pointer_cast<CdsItem>(obj)->setTrackNumber(0);
-                } else if (sym == M_PARTNUMBER) {
-                    int j = stoiString(val, 0);
-                    if (j > 0) {
-                        obj->setMetadata(sym, val);
-                        std::static_pointer_cast<CdsItem>(obj)->setPartNumber(j);
-                    } else
-                        std::static_pointer_cast<CdsItem>(obj)->setPartNumber(0);
-                } else {
-                    val = sc->convert(val);
-                    obj->setMetadata(sym, val);
+        auto item = std::static_pointer_cast<CdsItem>(obj);
+        auto keys = getPropertyNames();
+        for (auto&& sym : keys) {
+            auto arrayVal = getArrayProperty(sym);
+            for (auto&& val : arrayVal) {
+                if (!val.empty()) {
+                    if (sym == MetadataHandler::getMetaFieldName(M_TRACKNUMBER)) {
+                        int j = stoiString(val, 0);
+                        if (j > 0) {
+                            obj->addMetaData(sym, val);
+                            item->setTrackNumber(j);
+                        } else
+                            item->setTrackNumber(0);
+                    } else if (sym == MetadataHandler::getMetaFieldName(M_PARTNUMBER)) {
+                        int j = stoiString(val, 0);
+                        if (j > 0) {
+                            obj->addMetaData(sym, val);
+                            item->setPartNumber(j);
+                        } else
+                            item->setPartNumber(0);
+                    } else {
+                        val = sc->convert(val);
+                        obj->addMetaData(sym, val);
+                    }
                 }
             }
         }
     }
-    duk_pop(ctx);
+    duk_pop(ctx); // metaData
 
     // stuff that has not been exported to js
     if (pcd) {
@@ -490,9 +541,9 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         obj->setResources(pcd->getResources());
         obj->setAuxData(pcd->getAuxData());
     } else {
-        i = getIntProperty("flags", -1);
-        if (i >= 0)
-            obj->setFlags(i);
+        int flags = getIntProperty("flags", -1);
+        if (flags >= 0)
+            obj->setFlags(flags);
 
         duk_get_prop_string(ctx, -1, "res");
         if (!duk_is_null_or_undefined(ctx, -1) && duk_is_object(ctx, -1)) {
@@ -502,9 +553,9 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             int resCount = 0;
             for (auto&& sym : keys) {
                 if (sym.find("handlerType") != std::string::npos) {
-                    i = getIntProperty(sym, -1);
-                    if (i >= 0) {
-                        obj->addResource(std::make_shared<CdsResource>(i));
+                    int resNr = getIntProperty(sym, -1);
+                    if (resNr >= 0) {
+                        obj->addResource(std::make_shared<CdsResource>(resNr));
                     }
                 }
             }
@@ -557,10 +608,10 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
     // CdsItem
     if (obj->isItem()) {
         auto item = std::static_pointer_cast<CdsItem>(obj);
-        std::shared_ptr<CdsItem> pcd_item;
+        std::shared_ptr<CdsItem> pcdItem;
 
         if (pcd)
-            pcd_item = std::static_pointer_cast<CdsItem>(pcd);
+            pcdItem = std::static_pointer_cast<CdsItem>(pcd);
 
         val = getProperty("mimetype");
         if (!val.empty()) {
@@ -568,7 +619,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             item->setMimeType(val);
         } else {
             if (pcd)
-                item->setMimeType(pcd_item->getMimeType());
+                item->setMimeType(pcdItem->getMimeType());
         }
 
         val = getProperty("serviceID");
@@ -577,18 +628,19 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             item->setServiceID(val);
         }
 
-        /// \todo check what this is doing here, wasn't it already handled
+        /// copy value from extra description property
         /// in the mt_keys loop?
         val = getProperty("description");
         if (!val.empty()) {
             val = sc->convert(val);
-            item->setMetadata(M_DESCRIPTION, val);
-        } else {
-            if (pcd)
-                item->setMetadata(M_DESCRIPTION, pcd_item->getMetadata(M_DESCRIPTION));
+            item->removeMetaData(M_DESCRIPTION);
+            item->addMetaData(M_DESCRIPTION, val);
+        } else if (pcd && item->getMetaData(M_DESCRIPTION).empty()) {
+            item->addMetaData(M_DESCRIPTION, pcdItem->getMetaData(M_DESCRIPTION));
         }
         if (this->whoami() == S_PLAYLIST) {
             item->setTrackNumber(getIntProperty("playlistOrder", 0));
+            item->setPartNumber(0);
         }
 
         // location must not be touched by character conversion!
@@ -616,7 +668,10 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
                 auto resource = std::make_shared<CdsResource>(CH_DEFAULT);
                 resource->addAttribute(R_PROTOCOLINFO, protocolInfo);
 
-                item->addResource(move(resource));
+                item->addResource(resource);
+            } else {
+                auto resource = item->getResource(CH_DEFAULT);
+                resource->addAttribute(R_PROTOCOLINFO, protocolInfo);
             }
         }
     }
@@ -624,13 +679,17 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
     // CdsDirectory
     if (obj->isContainer()) {
         auto cont = std::static_pointer_cast<CdsContainer>(obj);
-        i = getIntProperty("updateID", -1);
-        if (i >= 0)
-            cont->setUpdateID(i);
 
-        b = getBoolProperty("searchable");
-        if (b >= 0)
-            cont->setSearchable(b);
+        if (this->whoami() == S_PLAYLIST && this->getConfig()->getBoolOption(CFG_IMPORT_SCRIPTING_PLAYLIST_SCRIPT_LINK_OBJECTS) && cont->getRefID() > 0) {
+            cont->setFlag(OBJECT_FLAG_PLAYLIST_REF);
+        }
+        id = getIntProperty("updateID", -1);
+        if (id >= 0)
+            cont->setUpdateID(id);
+
+        int searchable = getBoolProperty("searchable");
+        if (searchable >= 0)
+            cont->setSearchable(searchable);
     }
 
     return obj;
@@ -639,21 +698,20 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
 void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
 {
     std::string val;
-    int i;
 
     duk_push_object(ctx);
 
     // CdsObject
     setIntProperty("objectType", obj->getObjectType());
 
-    i = obj->getID();
+    int id = obj->getID();
 
-    if (i != INVALID_OBJECT_ID)
-        setIntProperty("id", i);
+    if (id != INVALID_OBJECT_ID)
+        setIntProperty("id", id);
 
-    i = obj->getParentID();
-    if (i != INVALID_OBJECT_ID)
-        setIntProperty("parentID", i);
+    id = obj->getParentID();
+    if (id != INVALID_OBJECT_ID)
+        setIntProperty("parentID", id);
 
     val = obj->getTitle();
     if (!val.empty())
@@ -673,8 +731,8 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
     setIntProperty("flags", obj->getFlags());
 
     // TODO: boolean type
-    i = obj->isRestricted();
-    setIntProperty("restricted", i);
+    int restricted = obj->isRestricted();
+    setIntProperty("restricted", restricted);
 
     if (obj->getFlag(OBJECT_FLAG_OGG_THEORA))
         setIntProperty("theora", 1);
@@ -689,22 +747,48 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
 #endif
         setIntProperty("onlineservice", 0);
 
-    // setting metadata
+    // setting legacy metadata
+
+    auto item = std::static_pointer_cast<CdsItem>(obj);
+    auto metaGroups = obj->getMetaGroups();
     {
         duk_push_object(ctx);
         // stack: js meta_js
 
-        auto meta = obj->getMetadata();
-        for (auto&& [key, val] : meta) {
-            setProperty(key, val);
+        for (auto&& [key, attr] : metaGroups) {
+            setProperty(key, fmt::format("{}", fmt::join(attr, entrySeparator)));
         }
+        if (item && item->getTrackNumber() > 0)
+            setProperty(MetadataHandler::getMetaFieldName(M_TRACKNUMBER), fmt::to_string(item->getTrackNumber()));
 
-        if (std::static_pointer_cast<CdsItem>(obj)->getTrackNumber() > 0)
-            setProperty(MetadataHandler::getMetaFieldName(M_TRACKNUMBER), fmt::to_string(std::static_pointer_cast<CdsItem>(obj)->getTrackNumber()));
+        if (item && item->getPartNumber() > 0)
+            setProperty(MetadataHandler::getMetaFieldName(M_PARTNUMBER), fmt::to_string(item->getPartNumber()));
 
         duk_put_prop_string(ctx, -2, "meta");
         // stack: js
     }
+    // setting metadata
+    {
+        duk_push_object(ctx);
+        // stack: js meta_js
+        if (item && item->getTrackNumber() > 0) {
+            metaGroups[MetadataHandler::getMetaFieldName(M_TRACKNUMBER)] = { fmt::to_string(item->getTrackNumber()) };
+        }
+        if (item && item->getPartNumber() > 0) {
+            metaGroups[MetadataHandler::getMetaFieldName(M_PARTNUMBER)] = { fmt::to_string(item->getPartNumber()) };
+        }
+        for (auto&& [key, array] : metaGroups) {
+            auto dukArray = duk_push_array(ctx);
+            for (duk_uarridx_t i = 0; i < array.size(); i++) {
+                duk_push_string(ctx, array[i].c_str());
+                duk_put_prop_index(ctx, dukArray, i);
+            }
+            duk_put_prop_string(ctx, -2, key.c_str());
+        }
+
+        duk_put_prop_string(ctx, -2, "metaData");
+        // stack: js
+    }
 
     // setting auxdata
     {
@@ -719,8 +803,8 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
             aux[ATRAILERS_AUXDATA_POST_DATE] = tmp;
 #endif
 
-        for (auto&& [key, val] : aux) {
-            setProperty(key, val);
+        for (auto&& [key, attr] : aux) {
+            setProperty(key, attr);
         }
 
         duk_put_prop_string(ctx, -2, "aux");
@@ -737,16 +821,16 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
             for (auto&& res : obj->getResources()) {
                 setProperty(fmt::format("{}:handlerType", resCount), fmt::to_string(res->getHandlerType()));
                 auto attributes = res->getAttributes();
-                for (auto&& [key, val] : attributes) {
-                    setProperty(resCount == 0 ? key : fmt::format("{}-{}", resCount, key), val);
+                for (auto&& [key, attr] : attributes) {
+                    setProperty(resCount == 0 ? key : fmt::format("{}-{}", resCount, key), attr);
                 }
                 auto parameters = res->getParameters();
-                for (auto&& [key, val] : parameters) {
-                    setProperty(fmt::format("{}#{}", resCount, key), val);
+                for (auto&& [key, param] : parameters) {
+                    setProperty(fmt::format("{}#{}", resCount, key), param);
                 }
                 auto options = res->getOptions();
-                for (auto&& [key, val] : options) {
-                    setProperty(fmt::format("{}%{}", resCount, key), val);
+                for (auto&& [key, opt] : options) {
+                    setProperty(fmt::format("{}%{}", resCount, key), opt);
                 }
                 resCount++;
             }
@@ -757,8 +841,7 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
     }
 
     // CdsItem
-    if (obj->isItem()) {
-        auto item = std::static_pointer_cast<CdsItem>(obj);
+    if (obj->isItem() && item) {
         val = item->getMimeType();
         if (!val.empty())
             setProperty("mimetype", val);
@@ -772,11 +855,10 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
     if (obj->isContainer()) {
         auto cont = std::static_pointer_cast<CdsContainer>(obj);
         // TODO: boolean type, hide updateID
-        i = cont->getUpdateID();
-        setIntProperty("updateID", i);
+        setIntProperty("updateID", cont->getUpdateID());
 
-        i = cont->isSearchable();
-        setIntProperty("searchable", i);
+        int searchable = cont->isSearchable();
+        setIntProperty("searchable", searchable);
     }
 }
 
@@ -797,7 +879,7 @@ std::string Script::convertToCharset(const std::string& str, charset_convert_t c
     throw_std_runtime_error("Illegal charset given to convertToCharset(): {}", chr);
 }
 
-std::shared_ptr<CdsObject> Script::getProcessedObject()
+std::shared_ptr<CdsObject> Script::getProcessedObject() const
 {
     return processed;
 }
