@@ -4,7 +4,7 @@
 
     script_names.h - this file is part of Gerbera.
 
-    Copyright (C) 2020-2021 Gerbera Contributors
+    Copyright (C) 2020-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -50,7 +50,7 @@ static constexpr auto res_names = std::array<std::pair<resource_attributes_t, co
     std::pair(R_VIDEOCODEC, "R_VIDEOCODEC"),
 };
 
-static constexpr auto mt_names = std::array<std::pair<metadata_fields_t, const char*>, M_MAX> {
+static constexpr auto mt_names = std::array<std::pair<metadata_fields_t, std::string_view>, M_MAX> {
     std::pair(M_TITLE, "M_TITLE"),
     std::pair(M_ARTIST, "M_ARTIST"),
     std::pair(M_ALBUM, "M_ALBUM"),
@@ -64,6 +64,7 @@ static constexpr auto mt_names = std::array<std::pair<metadata_fields_t, const c
     std::pair(M_PARTNUMBER, "M_PARTNUMBER"),
     std::pair(M_ALBUMARTURI, "M_ALBUMARTURI"),
     std::pair(M_REGION, "M_REGION"),
+    std::pair(M_CREATOR, "M_CREATOR"),
     std::pair(M_AUTHOR, "M_AUTHOR"),
     std::pair(M_DIRECTOR, "M_DIRECTOR"),
     std::pair(M_PUBLISHER, "M_PUBLISHER"),
@@ -74,6 +75,7 @@ static constexpr auto mt_names = std::array<std::pair<metadata_fields_t, const c
     std::pair(M_COMPOSER, "M_COMPOSER"),
     std::pair(M_CONDUCTOR, "M_CONDUCTOR"),
     std::pair(M_ORCHESTRA, "M_ORCHESTRA"),
+    std::pair(M_CONTENT_CLASS, "M_CONTENT_CLASS"),
 };
 
 static constexpr auto ot_names = std::array {
@@ -91,6 +93,10 @@ static constexpr auto upnp_classes = std::array {
     std::pair(UPNP_CLASS_MUSIC_ORCHESTRA, "UPNP_CLASS_CONTAINER_MUSIC_ORCHESTRA"),
     std::pair(UPNP_CLASS_CONTAINER, "UPNP_CLASS_CONTAINER"),
     std::pair(UPNP_CLASS_ITEM, "UPNP_CLASS_ITEM"),
+    std::pair(UPNP_CLASS_AUDIO_ITEM, "UPNP_CLASS_AUDIO_ITEM"),
+    std::pair(UPNP_CLASS_VIDEO_ITEM, "UPNP_CLASS_VIDEO_ITEM"),
+    std::pair(UPNP_CLASS_IMAGE_ITEM, "UPNP_CLASS_IMAGE_ITEM"),
+    std::pair(UPNP_CLASS_PLAYLIST_ITEM, "UPNP_CLASS_PLAYLIST_ITEM"),
     std::pair(UPNP_CLASS_MUSIC_TRACK, "UPNP_CLASS_ITEM_MUSIC_TRACK"),
     std::pair(UPNP_CLASS_VIDEO_ITEM, "UPNP_CLASS_CONTAINER_ITEM_VIDEO"),
     std::pair(UPNP_CLASS_IMAGE_ITEM, "UPNP_CLASS_CONTAINER_ITEM_IMAGE"),
