@@ -1,11 +1,11 @@
 /*GRB*
 
     Gerbera - https://gerbera.io/
-    
+
     context.cc - this file is part of Gerbera.
-    
-    Copyright (C) 2021 Gerbera Contributors
-    
+
+    Copyright (C) 2021-2022 Gerbera Contributors
+
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -30,14 +30,12 @@ Context::Context(std::shared_ptr<Config> config,
     std::shared_ptr<Mime> mime,
     std::shared_ptr<Database> database,
     std::shared_ptr<Server> server,
-    std::shared_ptr<web::SessionManager> session_manager)
+    std::shared_ptr<Web::SessionManager> sessionManager)
     : config(std::move(config))
     , clients(std::move(clients))
     , mime(std::move(mime))
     , database(std::move(database))
     , server(std::move(server))
-    , session_manager(std::move(session_manager))
+    , session_manager(std::move(sessionManager))
 {
 }
-
-Context::~Context() = default;
