@@ -32,18 +32,16 @@
 #ifndef __STORAGE_H__
 #define __STORAGE_H__
 
-#include <deque>
-#include <filesystem>
 #include <map>
-#include <memory>
-#include <string>
 #include <unordered_set>
 #include <vector>
-namespace fs = std::filesystem;
+
+#include "util/grb_fs.h"
 
 // forward declaration
 class AutoscanDirectory;
 class AutoscanList;
+class CdsContainer;
 class CdsObject;
 class Config;
 class ConfigValue;
@@ -66,28 +64,20 @@ protected:
     int startingIndex {};
     int requestedCount {};
     std::string sortCrit;
+    bool showDynamicContainers { true };
 
     // output parameters
     int totalMatches {};
 
 public:
-    BrowseParam(std::shared_ptr<CdsObject> object, unsigned int flags)
+    BrowseParam(const std::shared_ptr<CdsObject>& object, unsigned int flags)
         : flags(flags)
-        , object(std::move(object))
+        , object(object)
     {
     }
 
-    unsigned int getFlags() const { return flags; }
     unsigned int getFlag(unsigned int mask) const { return flags & mask; }
-    void setFlags(unsigned int flags) { this->flags = flags; }
     void setFlag(unsigned int mask) { flags |= mask; }
-    void changeFlag(unsigned int mask, bool value)
-    {
-        if (value)
-            setFlag(mask);
-        else
-            clearFlag(mask);
-    }
     void clearFlag(unsigned int mask) { flags &= !mask; }
 
     std::shared_ptr<CdsObject> getObject() const { return object; }
@@ -112,6 +102,12 @@ public:
         this->sortCrit = sortCrit;
     }
 
+    void setDynamicContainers(bool showDynamicContainers)
+    {
+        this->showDynamicContainers = showDynamicContainers;
+    }
+
+    bool getDynamicContainers() const { return showDynamicContainers; }
     int getStartingIndex() const { return startingIndex; }
     int getRequestedCount() const { return requestedCount; }
     int getTotalMatches() const { return totalMatches; }
@@ -130,19 +126,21 @@ protected:
     std::string sortCrit;
     int startingIndex;
     int requestedCount;
+    bool searchableContainers;
 
 public:
     SearchParam(std::string containerID, std::string searchCriteria, std::string sortCriteria, int startingIndex,
-        int requestedCount)
+        int requestedCount, bool searchableContainers)
         : containerID(std::move(containerID))
         , searchCrit(std::move(searchCriteria))
         , sortCrit(std::move(sortCriteria))
         , startingIndex(startingIndex)
         , requestedCount(requestedCount)
+        , searchableContainers(searchableContainers)
     {
     }
-    const std::string& getContainerId() const { return containerID; }
     const std::string& searchCriteria() const { return searchCrit; }
+    bool getSearchableContainers() const { return searchableContainers; }
     int getStartingIndex() const { return startingIndex; }
     int getRequestedCount() const { return requestedCount; }
     const std::string& getSortCriteria() const { return sortCrit; }
@@ -150,17 +148,14 @@ public:
 
 class Database {
 public:
-    explicit Database(std::shared_ptr<Config> config)
-        : config(std::move(config))
-    {
-    }
+    explicit Database(std::shared_ptr<Config> config);
     virtual ~Database() = default;
     virtual void init() = 0;
 
     /// \brief shutdown the Database with its possible threads
     virtual void shutdown() = 0;
 
-    virtual void addObject(std::shared_ptr<CdsObject> object, int* changedContainer) = 0;
+    virtual void addObject(const std::shared_ptr<CdsObject>& object, int* changedContainer) = 0;
 
     /// \brief Adds a virtual container chain specified by path.
     /// \param path container path separated by '/'. Slashes in container
@@ -178,9 +173,7 @@ public:
     /// the object ID of the container that is last in the path. The
     /// updateID will hold the objectID of the container that was changed,
     /// in case new containers were created during the operation.
-    virtual void addContainerChain(std::string path, const std::string& lastClass, int lastRefID, int* containerID,
-        std::deque<int>& updateID, const std::map<std::string, std::string>& lastMetadata)
-        = 0;
+    virtual bool addContainer(int parentContainerId, std::string virtualPath, const std::shared_ptr<CdsContainer>& cont, int* containerID) = 0;
 
     /// \brief Builds the container path. Fetches the path of the
     /// parent and adds the title
@@ -191,12 +184,13 @@ public:
 
     virtual void updateObject(const std::shared_ptr<CdsObject>& object, int* changedContainer) = 0;
 
-    virtual std::vector<std::shared_ptr<CdsObject>> browse(const std::unique_ptr<BrowseParam>& param) = 0;
-    virtual std::vector<std::shared_ptr<CdsObject>> search(const std::unique_ptr<SearchParam>& param, int* numMatches) = 0;
+    virtual std::vector<std::shared_ptr<CdsObject>> browse(BrowseParam& param) = 0;
+    virtual std::vector<std::shared_ptr<CdsObject>> search(const SearchParam& param, int* numMatches) = 0;
+    virtual std::vector<std::shared_ptr<CdsObject>> findObjectByContentClass(const std::string& contentClass) = 0;
 
     virtual std::vector<std::string> getMimeTypes() = 0;
 
-    //virtual std::vector<std::shared_ptr<CdsObject>> selectObjects(const std::unique_ptr<SelectParam>& param) = 0;
+    // virtual std::vector<std::shared_ptr<CdsObject>> selectObjects(const std::unique_ptr<SelectParam>& param) = 0;
 
     /// \brief Loads a given (pc directory) object, identified by the given path
     /// from the database
@@ -222,12 +216,12 @@ public:
     /* utility methods */
     virtual std::shared_ptr<CdsObject> loadObject(int objectID) = 0;
     virtual int getChildCount(int contId, bool containers = true, bool items = true, bool hideFsRoot = false) = 0;
+    virtual std::map<int, int> getChildCounts(const std::vector<int>& contId, bool containers = true, bool items = true, bool hideFsRoot = false) = 0;
 
-    class ChangedContainers {
-    public:
+    struct ChangedContainers {
         // Signed because IDs start at -1.
-        std::vector<int32_t> upnp;
-        std::vector<int32_t> ui;
+        std::vector<std::int32_t> upnp;
+        std::vector<std::int32_t> ui;
     };
 
     /// \brief Removes the object identified by the objectID from the database.
@@ -271,7 +265,7 @@ public:
 
     /* autoscan methods */
     virtual std::shared_ptr<AutoscanList> getAutoscanList(ScanMode scanode) = 0;
-    virtual void updateAutoscanList(ScanMode scanmode, std::shared_ptr<AutoscanList> list) = 0;
+    virtual void updateAutoscanList(ScanMode scanmode, const std::shared_ptr<AutoscanList>& list) = 0;
 
     /* config methods */
     virtual std::vector<ConfigValue> getConfigValues() = 0;
@@ -284,9 +278,9 @@ public:
     /// \return nullptr if the given id is no autoscan start point,
     /// or the matching AutoscanDirectory
     virtual std::shared_ptr<AutoscanDirectory> getAutoscanDirectory(int objectID) = 0;
-    virtual void addAutoscanDirectory(std::shared_ptr<AutoscanDirectory> adir) = 0;
-    virtual void updateAutoscanDirectory(std::shared_ptr<AutoscanDirectory> adir) = 0;
-    virtual void removeAutoscanDirectory(std::shared_ptr<AutoscanDirectory> adir) = 0;
+    virtual void addAutoscanDirectory(const std::shared_ptr<AutoscanDirectory>& adir) = 0;
+    virtual void updateAutoscanDirectory(const std::shared_ptr<AutoscanDirectory>& adir) = 0;
+    virtual void removeAutoscanDirectory(const std::shared_ptr<AutoscanDirectory>& adir) = 0;
     virtual void checkOverlappingAutoscans(const std::shared_ptr<AutoscanDirectory>& adir) = 0;
 
     virtual std::vector<int> getPathIDs(int objectID) = 0;
@@ -299,18 +293,10 @@ public:
     /// \return objectID of the container given by path
     virtual int ensurePathExistence(const fs::path& path, int* changedContainer) = 0;
 
-    /// \brief clears the given flag in all objects in the DB
-    virtual void clearFlagInDB(int flag) = 0;
-
-    virtual std::string getFsRootName() = 0;
-
     virtual void threadCleanup() = 0;
     virtual bool threadCleanupRequired() const = 0;
 
 protected:
-    /* helper for addContainerChain */
-    static void stripAndUnescapeVirtualContainerFromPath(std::string path, std::string& first, std::string& last);
-
     static std::shared_ptr<Database> createInstance(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<Timer>& timer);
     friend class Server;
 
