@@ -15,9 +15,7 @@ CREATE TABLE `mt_cds_object` (
   `dc_title` varchar(255) default NULL,
   `location` blob,
   `location_hash` int(11) unsigned default NULL,
-  `metadata` blob,
   `auxdata` blob,
-  `resources` blob,
   `update_id` int(11) NOT NULL default '0',
   `mime_type` varchar(40) default NULL,
   `flags` int(11) unsigned NOT NULL default '1',
@@ -26,6 +24,7 @@ CREATE TABLE `mt_cds_object` (
   `service_id` varchar(255) default NULL,
   `bookmark_pos` int(11) unsigned NOT NULL default '0',
   `last_modified` bigint(20) unsigned default NULL,
+  `last_updated` bigint(20) unsigned default '0',
   PRIMARY KEY  (`id`),
   KEY `cds_object_ref_id` (`ref_id`),
   KEY `cds_object_parent_id` (`parent_id`,`object_type`,`dc_title`),
@@ -36,16 +35,21 @@ CREATE TABLE `mt_cds_object` (
   CONSTRAINT `mt_cds_object_ibfk_1` FOREIGN KEY (`ref_id`) REFERENCES `mt_cds_object` (`id`) ON DELETE CASCADE ON UPDATE CASCADE,
   CONSTRAINT `mt_cds_object_ibfk_2` FOREIGN KEY (`parent_id`) REFERENCES `mt_cds_object` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
 ) ENGINE=MyISAM CHARSET=utf8;
-INSERT INTO `mt_cds_object` VALUES (-1,NULL,-1,0,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0,NULL,9,NULL,NULL,NULL,0,NULL);
-INSERT INTO `mt_cds_object` VALUES (0,NULL,-1,1,'object.container','Root',NULL,NULL,NULL,NULL,NULL,0,NULL,9,NULL,NULL,NULL,0,NULL);
+INSERT INTO `mt_cds_object` (
+    `id`, `parent_id`, `object_type`, `flags`
+) VALUES (-1,-1,0,9);
+INSERT INTO `mt_cds_object` (
+    `id`, `parent_id`, `object_type`, `upnp_class`, `dc_title`, `flags`
+) VALUES (0,-1,1,'object.container','Root',9);
 UPDATE `mt_cds_object` SET `id`='0' WHERE `id`='1';
-INSERT INTO `mt_cds_object` VALUES (1,NULL,0,1,'object.container','PC Directory',NULL,NULL,NULL,NULL,NULL,0,NULL,9,NULL,NULL,NULL,0,NULL);
+INSERT INTO `mt_cds_object` (
+    `id`,  `parent_id`, `object_type`, `upnp_class`, `dc_title`, `flags`
+) VALUES (1,0,1,'object.container','PC Directory',9);
 CREATE TABLE `mt_internal_setting` (
   `key` varchar(40) NOT NULL,
   `value` varchar(255) NOT NULL,
   PRIMARY KEY  (`key`)
 ) ENGINE=MyISAM CHARSET=utf8;
-INSERT INTO `mt_internal_setting` VALUES ('db_version','10');
 CREATE TABLE `mt_autoscan` (
   `id` int(11) NOT NULL auto_increment,
   `obj_id` int(11) default NULL,
@@ -78,7 +82,16 @@ CREATE TABLE `grb_config_value` (
   `item_value` varchar(255) NOT NULL,
   `status` varchar(20) NOT NULL)
   ENGINE=MyISAM CHARSET=utf8;
-CREATE INDEX grb_config_value_item ON grb_config_value(item);
+CREATE TABLE `grb_cds_resource` (
+    `item_id` int(11) NOT NULL,
+    `res_id` int(11) NOT NULL,
+    `handlerType` int(11) NOT NULL,
+    `options` text default NULL,
+    `parameters` text default NULL,
+    PRIMARY KEY (`item_id`, `res_id`),
+    CONSTRAINT `grb_cds_resource_fk` FOREIGN KEY (`item_id`) REFERENCES `mt_cds_object` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
+) ENGINE=MyISAM CHARSET=utf8;
+INSERT INTO `mt_internal_setting` VALUES('resource_attribute', '');
 /*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
 /*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
 /*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
