@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     mysql_database.h - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -38,13 +38,12 @@
 #include "database/sql_database.h"
 #include <mutex>
 #include <mysql.h>
-#include <string>
 #include <vector>
 
 /// \brief The Database class for using MySQL
 class MySQLDatabase : public SQLDatabase, public std::enable_shared_from_this<SQLDatabase> {
 public:
-    explicit MySQLDatabase(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime);
+    explicit MySQLDatabase(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime);
     ~MySQLDatabase() override;
 
     MySQLDatabase(const MySQLDatabase&) = delete;
@@ -63,15 +62,7 @@ private:
     void shutdownDriver() override;
     std::shared_ptr<Database> getSelf() override;
 
-    std::string quote(std::string_view str) const override { return quote(std::string(str)); }
     std::string quote(const std::string& value) const override;
-    std::string quote(int val) const override { return fmt::to_string(val); }
-    std::string quote(unsigned int val) const override { return fmt::to_string(val); }
-    std::string quote(long val) const override { return fmt::to_string(val); }
-    std::string quote(unsigned long val) const override { return fmt::to_string(val); }
-    std::string quote(bool val) const override { return fmt::to_string(val ? '1' : '0'); }
-    std::string quote(char val) const override { return quote(fmt::to_string(val)); }
-    std::string quote(long long val) const override { return fmt::to_string(val); }
 
     std::shared_ptr<SQLResult> select(const std::string& query) override;
     int exec(const std::string& query, bool getLastInsertId = false) override;
@@ -84,29 +75,24 @@ private:
     bool threadCleanupRequired() const override { return true; }
 
     pthread_key_t mysql_init_key {};
+    const int mysql_init_val = 1;
 };
 
 /// \brief The Database class for using MySQL with transactions
 class MySQLDatabaseWithTransactions : public SqlWithTransactions, public MySQLDatabase {
 public:
-    MySQLDatabaseWithTransactions(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime)
-        : SqlWithTransactions(config)
-        , MySQLDatabase(std::move(config), std::move(mime))
-    {
-    }
-    void beginTransaction(const std::string_view& tName) override;
-    void rollback(const std::string_view& tName) override;
-    void commit(const std::string_view& tName) override;
+    MySQLDatabaseWithTransactions(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime);
+
+    void beginTransaction(std::string_view tName) override;
+    void rollback(std::string_view tName) override;
+    void commit(std::string_view tName) override;
 
     std::shared_ptr<SQLResult> select(const std::string& query) override;
 };
 
 class MysqlResult : public SQLResult {
 public:
-    explicit MysqlResult(MYSQL_RES* mysql_res)
-        : mysql_res(mysql_res)
-    {
-    }
+    explicit MysqlResult(MYSQL_RES* mysqlRes);
     ~MysqlResult() override;
 
     MysqlResult(const MysqlResult&) = delete;
@@ -115,8 +101,8 @@ public:
 private:
     int nullRead {};
     std::unique_ptr<SQLRow> nextRow() override;
-    unsigned long long getNumRows() const override { return mysql_num_rows(mysql_res); }
-    MYSQL_RES* mysql_res;
+    unsigned long long getNumRows() const override { return mysql_num_rows(mysqlRes); }
+    MYSQL_RES* mysqlRes;
 
     friend class MysqlRow;
     friend class MySQLDatabase;
@@ -124,14 +110,12 @@ private:
 
 class MysqlRow : public SQLRow {
 public:
-    explicit MysqlRow(MYSQL_ROW mysql_row);
+    explicit MysqlRow(MYSQL_ROW mysqlRow);
 
 private:
-    char* col_c_str(int index) const override { return mysql_row[index]; }
+    char* col_c_str(int index) const override;
 
-    MYSQL_ROW mysql_row;
-
-    friend std::unique_ptr<SQLRow> MysqlResult::nextRow();
+    MYSQL_ROW mysqlRow;
 };
 
 #endif // __mysql_database_H__
