@@ -3,7 +3,7 @@
 
   search_handler.cc - this file is part of Gerbera.
 
-  Copyright (C) 2018-2021 Gerbera Contributors
+  Copyright (C) 2018-2022 Gerbera Contributors
 
   Gerbera is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 2
@@ -27,8 +27,8 @@
 #include <algorithm>
 #include <stack>
 
-#include "config/config_manager.h"
 #include "database/sql_database.h"
+#include "metadata/metadata_handler.h"
 #include "util/tools.h"
 
 static const std::unordered_map<std::string_view, TokenType> tokenTypes {
@@ -53,9 +53,14 @@ static const std::unordered_map<std::string_view, TokenType> tokenTypes {
     { "or", TokenType::OR }
 };
 
+SearchLexer::SearchLexer(std::string input)
+    : input(std::move(input))
+{
+}
+
 std::unique_ptr<SearchToken> SearchLexer::nextToken()
 {
-    for (; currentPos < input.length();) {
+    while (currentPos < input.length()) {
         char ch = input[currentPos];
 
         switch (ch) {
@@ -120,7 +125,7 @@ std::string SearchLexer::getQuotedValue(const std::string& input)
 {
     std::string token;
     bool escaping = false;
-    for (; currentPos < input.length();) {
+    while (currentPos < input.length()) {
         auto ch = input[currentPos];
         if (ch == '"' && !escaping) {
             break;
@@ -140,7 +145,7 @@ std::string SearchLexer::getQuotedValue(const std::string& input)
 std::string SearchLexer::nextStringToken(const std::string& input)
 {
     auto startPos = currentPos;
-    for (; currentPos < input.length();) {
+    while (currentPos < input.length()) {
         auto ch = input[currentPos];
         if (std::isalnum(ch) || ch == ':' || ch == '@' || ch == '.' || ch == '_')
             currentPos++;
@@ -161,50 +166,55 @@ std::unique_ptr<SearchToken> SearchLexer::makeToken(std::string tokenStr)
     return std::make_unique<SearchToken>(TokenType::PROPERTY, std::move(tokenStr));
 }
 
+SearchParser::SearchParser(const SQLEmitter& sqlEmitter, const std::string& searchCriteria)
+    : lexer(std::make_unique<SearchLexer>(searchCriteria))
+    , sqlEmitter(sqlEmitter)
+{
+}
+
 void SearchParser::getNextToken()
 {
     currentToken = lexer->nextToken();
 }
 
-std::shared_ptr<ASTNode> SearchParser::parse()
+std::unique_ptr<ASTNode> SearchParser::parse()
 {
     getNextToken();
     if (currentToken->getType() == TokenType::ASTERISK)
-        return std::make_shared<ASTAsterisk>(sqlEmitter, currentToken->getValue());
+        return std::make_unique<ASTAsterisk>(sqlEmitter, currentToken->getValue());
 
     return parseSearchExpression();
 }
 
-std::shared_ptr<ASTNode> SearchParser::parseSearchExpression()
+std::unique_ptr<ASTNode> SearchParser::parseSearchExpression()
 {
-    std::stack<std::shared_ptr<ASTNode>> nodeStack;
+    std::stack<std::unique_ptr<ASTNode>> nodeStack;
     std::stack<TokenType> operatorStack;
-    std::shared_ptr<ASTNode> root;
-    std::shared_ptr<ASTNode> expressionNode;
+    std::unique_ptr<ASTNode> root;
     TokenType currentOperator = TokenType::INVALID;
     while (currentToken) {
         if (currentToken->getType() == TokenType::PROPERTY) {
-            expressionNode = parseRelationshipExpression();
+            auto expressionNode = parseRelationshipExpression();
             if (currentOperator == TokenType::AND) {
                 if (!nodeStack.top())
                     throw_std_runtime_error("Cannot construct ASTAndOperator without lhs");
                 if (!expressionNode)
                     throw_std_runtime_error("Cannot construct ASTAndOperator without rhs");
-                std::shared_ptr<ASTNode> lhs(nodeStack.top());
+                auto lhs = std::move(nodeStack.top());
                 nodeStack.pop();
-                nodeStack.push(std::make_shared<ASTAndOperator>(sqlEmitter, lhs, expressionNode));
+                nodeStack.push(std::make_unique<ASTAndOperator>(sqlEmitter, std::move(lhs), std::move(expressionNode)));
                 operatorStack.pop();
             } else if (currentOperator == TokenType::OR) {
                 if (!nodeStack.top())
                     throw_std_runtime_error("Cannot construct ASTOrOperator without lhs");
                 if (!expressionNode)
                     throw_std_runtime_error("Cannot construct ASTOrOperator without rhs");
-                std::shared_ptr<ASTNode> lhs(nodeStack.top());
+                auto lhs = std::move(nodeStack.top());
                 nodeStack.pop();
-                nodeStack.push(std::make_shared<ASTOrOperator>(sqlEmitter, lhs, expressionNode));
+                nodeStack.push(std::make_unique<ASTOrOperator>(sqlEmitter, std::move(lhs), std::move(expressionNode)));
                 operatorStack.pop();
             } else {
-                nodeStack.push(expressionNode);
+                nodeStack.push(std::move(expressionNode));
             }
             currentOperator = TokenType::INVALID;
             getNextToken();
@@ -219,18 +229,18 @@ std::shared_ptr<ASTNode> SearchParser::parseSearchExpression()
     }
 
     while (!nodeStack.empty()) {
-        root = nodeStack.top();
+        root = std::move(nodeStack.top());
         nodeStack.pop();
         if (!operatorStack.empty()) {
             currentOperator = operatorStack.top();
             operatorStack.pop();
             if (!nodeStack.empty()) {
-                std::shared_ptr<ASTNode> lhs = nodeStack.top();
+                auto lhs = std::move(nodeStack.top());
                 nodeStack.pop();
                 if (currentOperator == TokenType::AND)
-                    root = std::make_shared<ASTAndOperator>(sqlEmitter, lhs, root);
+                    root = std::make_unique<ASTAndOperator>(sqlEmitter, std::move(lhs), std::move(root));
                 else
-                    root = std::make_shared<ASTOrOperator>(sqlEmitter, lhs, root);
+                    root = std::make_unique<ASTOrOperator>(sqlEmitter, std::move(lhs), std::move(root));
             } else
                 throw_std_runtime_error("Cannot construct ASTOrOperator/ASTAndOperator without rhs");
         }
@@ -238,14 +248,12 @@ std::shared_ptr<ASTNode> SearchParser::parseSearchExpression()
     return root;
 }
 
-std::shared_ptr<ASTNode> SearchParser::parseParenthesis()
+std::unique_ptr<ASTNode> SearchParser::parseParenthesis()
 {
     if (currentToken->getType() != TokenType::LPAREN)
         throw_std_runtime_error("Failed to parse search criteria - expecting a ')'");
 
-    std::shared_ptr<ASTNode> currentNode;
-    std::shared_ptr<ASTNode> lhsNode;
-    std::shared_ptr<ASTNode> rhsNode;
+    std::unique_ptr<ASTNode> currentNode;
     getNextToken();
     while (currentToken && currentToken->getType() != TokenType::RPAREN) {
         // just call parseSearchExpression() at this point?
@@ -254,18 +262,15 @@ std::shared_ptr<ASTNode> SearchParser::parseParenthesis()
             getNextToken();
         } else if (currentToken->getType() == TokenType::AND || currentToken->getType() == TokenType::OR) {
             auto tokenType = currentToken->getType();
-            lhsNode = currentNode;
+            auto lhsNode = std::move(currentNode);
 
             getNextToken();
-            if (currentToken->getType() == TokenType::LPAREN)
-                rhsNode = parseParenthesis();
-            else
-                rhsNode = parseRelationshipExpression();
+            auto rhsNode = (currentToken->getType() == TokenType::LPAREN) ? parseParenthesis() : parseRelationshipExpression();
 
             if (tokenType == TokenType::AND)
-                currentNode = std::make_shared<ASTAndOperator>(sqlEmitter, lhsNode, rhsNode);
+                currentNode = std::make_unique<ASTAndOperator>(sqlEmitter, std::move(lhsNode), std::move(rhsNode));
             else if (tokenType == TokenType::OR)
-                currentNode = std::make_shared<ASTOrOperator>(sqlEmitter, lhsNode, rhsNode);
+                currentNode = std::make_unique<ASTOrOperator>(sqlEmitter, std::move(lhsNode), std::move(rhsNode));
             else
                 throw_std_runtime_error("Failed to parse search criteria - expected and/or");
 
@@ -278,57 +283,59 @@ std::shared_ptr<ASTNode> SearchParser::parseParenthesis()
     if (!currentNode)
         throw_std_runtime_error("Failed to parse search criteria - bad expression between parenthesis");
 
-    return std::make_shared<ASTParenthesis>(sqlEmitter, currentNode);
+    return std::make_unique<ASTParenthesis>(sqlEmitter, std::move(currentNode));
 }
 
-std::shared_ptr<ASTNode> SearchParser::parseRelationshipExpression()
+std::unique_ptr<ASTNode> SearchParser::parseRelationshipExpression()
 {
     if (currentToken->getType() != TokenType::PROPERTY)
         throw_std_runtime_error("Failed to parse search criteria - expecting a property name");
 
-    auto relationshipExpr = std::shared_ptr<ASTNode>(nullptr);
-    auto property = std::make_shared<ASTProperty>(sqlEmitter, currentToken->getValue());
+    auto property = std::make_unique<ASTProperty>(sqlEmitter, currentToken->getValue());
 
     getNextToken();
     if (currentToken->getType() == TokenType::COMPAREOP) {
-        auto operatr = std::make_shared<ASTCompareOperator>(sqlEmitter, currentToken->getValue());
+        auto operatr = std::make_unique<ASTCompareOperator>(sqlEmitter, currentToken->getValue());
         getNextToken();
         auto quotedString = parseQuotedString();
-        relationshipExpr = std::make_shared<ASTCompareExpression>(sqlEmitter, property, operatr, quotedString);
-    } else if (currentToken->getType() == TokenType::STRINGOP) {
-        auto operatr = std::make_shared<ASTStringOperator>(sqlEmitter, currentToken->getValue());
-        getNextToken();
-        auto quotedString = parseQuotedString();
-        relationshipExpr = std::make_shared<ASTStringExpression>(sqlEmitter, property, operatr, quotedString);
-    } else if (currentToken->getType() == TokenType::EXISTS) {
-        auto operatr = std::make_shared<ASTExistsOperator>(sqlEmitter, currentToken->getValue());
-        getNextToken();
-        auto booleanValue = std::make_shared<ASTBoolean>(sqlEmitter, currentToken->getValue());
-        relationshipExpr = std::make_shared<ASTExistsExpression>(sqlEmitter, property, operatr, booleanValue);
-    } else
-        throw_std_runtime_error("Failed to parse search criteria - expecting a comparison, exists, or string operator");
+        return std::make_unique<ASTCompareExpression>(sqlEmitter, std::move(property), std::move(operatr), std::move(quotedString));
+    }
 
-    return relationshipExpr;
+    if (currentToken->getType() == TokenType::STRINGOP) {
+        auto operatr = std::make_unique<ASTStringOperator>(sqlEmitter, currentToken->getValue());
+        getNextToken();
+        auto quotedString = parseQuotedString();
+        return std::make_unique<ASTStringExpression>(sqlEmitter, std::move(property), std::move(operatr), std::move(quotedString));
+    }
+
+    if (currentToken->getType() == TokenType::EXISTS) {
+        auto operatr = std::make_unique<ASTExistsOperator>(sqlEmitter, currentToken->getValue());
+        getNextToken();
+        auto booleanValue = std::make_unique<ASTBoolean>(sqlEmitter, currentToken->getValue());
+        return std::make_unique<ASTExistsExpression>(sqlEmitter, std::move(property), std::move(operatr), std::move(booleanValue));
+    }
+
+    throw_std_runtime_error("Failed to parse search criteria - expecting a comparison, exists, or string operator");
 }
 
-std::shared_ptr<ASTQuotedString> SearchParser::parseQuotedString()
+std::unique_ptr<ASTQuotedString> SearchParser::parseQuotedString()
 {
     if (currentToken->getType() != TokenType::DQUOTE)
         throw_std_runtime_error("Failed to parse search criteria - expecting a double-quote");
-    auto openQuote = std::make_shared<ASTDQuote>(sqlEmitter, currentToken->getValue());
+    auto openQuote = std::make_unique<ASTDQuote>(sqlEmitter, currentToken->getValue());
     getNextToken();
 
     if (currentToken->getType() != TokenType::ESCAPEDSTRING)
         throw_std_runtime_error("Failed to parse search criteria - expecting an escaped string value");
 
-    auto escapedString = std::make_shared<ASTEscapedString>(sqlEmitter, currentToken->getValue());
+    auto escapedString = std::make_unique<ASTEscapedString>(sqlEmitter, currentToken->getValue());
     getNextToken();
 
     if (currentToken->getType() != TokenType::DQUOTE)
         throw_std_runtime_error("Failed to parse search criteria - expecting a double-quote");
-    auto closeQuote = std::make_shared<ASTDQuote>(sqlEmitter, currentToken->getValue());
+    auto closeQuote = std::make_unique<ASTDQuote>(sqlEmitter, currentToken->getValue());
 
-    return std::make_shared<ASTQuotedString>(sqlEmitter, openQuote, escapedString, closeQuote);
+    return std::make_unique<ASTQuotedString>(sqlEmitter, std::move(openQuote), std::move(escapedString), std::move(closeQuote));
 }
 
 std::string ASTNode::emitSQL() const
@@ -336,41 +343,92 @@ std::string ASTNode::emitSQL() const
     return sqlEmitter.emitSQL(this);
 }
 
+ASTAsterisk::ASTAsterisk(const SQLEmitter& sqlEmitter, std::string value)
+    : ASTNode(sqlEmitter)
+    , value(std::move(value))
+{
+}
+
 std::string ASTAsterisk::emit() const
 {
     return sqlEmitter.emit(this);
 }
 
+ASTProperty::ASTProperty(const SQLEmitter& sqlEmitter, std::string value)
+    : ASTNode(sqlEmitter)
+    , value(std::move(value))
+{
+}
+
 std::string ASTProperty::emit() const
 {
     return value;
 }
 
+ASTBoolean::ASTBoolean(const SQLEmitter& sqlEmitter, std::string value)
+    : ASTNode(sqlEmitter)
+    , value(std::move(value))
+{
+}
+
 std::string ASTBoolean::emit() const
 {
     return value;
 }
 
+ASTParenthesis::ASTParenthesis(const SQLEmitter& sqlEmitter, std::unique_ptr<ASTNode> node)
+    : ASTNode(sqlEmitter)
+    , bracketedNode(std::move(node))
+{
+}
+
 std::string ASTParenthesis::emit() const
 {
     return sqlEmitter.emit(this, bracketedNode->emit());
 }
 
+ASTDQuote::ASTDQuote(const SQLEmitter& sqlEmitter, std::string value)
+    : ASTNode(sqlEmitter)
+    , value(std::move(value))
+{
+}
+
 std::string ASTDQuote::emit() const
 {
     return sqlEmitter.emit(this);
 }
 
+ASTEscapedString::ASTEscapedString(const SQLEmitter& sqlEmitter, std::string value)
+    : ASTNode(sqlEmitter)
+    , value(std::move(value))
+{
+}
+
 std::string ASTEscapedString::emit() const
 {
     return value;
 }
 
+ASTQuotedString::ASTQuotedString(const SQLEmitter& sqlEmitter, std::unique_ptr<ASTDQuote> openQuote,
+    std::unique_ptr<ASTEscapedString> escapedString, std::unique_ptr<ASTDQuote> closeQuote)
+    : ASTNode(sqlEmitter)
+    , openQuote(std::move(openQuote))
+    , escapedString(std::move(escapedString))
+    , closeQuote(std::move(closeQuote))
+{
+}
+
 std::string ASTQuotedString::emit() const
 {
     return openQuote->emit() + escapedString->emit() + closeQuote->emit();
 }
 
+ASTCompareOperator::ASTCompareOperator(const SQLEmitter& sqlEmitter, std::string value)
+    : ASTNode(sqlEmitter)
+    , value(std::move(value))
+{
+}
+
 std::string ASTCompareOperator::emit() const
 {
     log_error("Emitting for ASTCompareOperator");
@@ -382,11 +440,26 @@ std::string ASTCompareOperator::emit(const std::string& property, const std::str
     return sqlEmitter.emit(this, property, value);
 }
 
+ASTCompareExpression::ASTCompareExpression(const SQLEmitter& sqlEmitter, std::unique_ptr<ASTProperty> lhs,
+    std::unique_ptr<ASTCompareOperator> operatr, std::unique_ptr<ASTQuotedString> rhs)
+    : ASTNode(sqlEmitter)
+    , lhs(std::move(lhs))
+    , operatr(std::move(operatr))
+    , rhs(std::move(rhs))
+{
+}
+
 std::string ASTCompareExpression::emit() const
 {
     return operatr->emit(lhs->emit(), rhs->emit());
 }
 
+ASTStringOperator::ASTStringOperator(const SQLEmitter& sqlEmitter, std::string value)
+    : ASTNode(sqlEmitter)
+    , value(std::move(value))
+{
+}
+
 std::string ASTStringOperator::emit() const
 {
     log_error("Emitting for ASTStringOperator");
@@ -398,11 +471,26 @@ std::string ASTStringOperator::emit(const std::string& property, const std::stri
     return sqlEmitter.emit(this, property, value);
 }
 
+ASTStringExpression::ASTStringExpression(const SQLEmitter& sqlEmitter, std::unique_ptr<ASTProperty> lhs,
+    std::unique_ptr<ASTStringOperator> operatr, std::unique_ptr<ASTQuotedString> rhs)
+    : ASTNode(sqlEmitter)
+    , lhs(std::move(lhs))
+    , operatr(std::move(operatr))
+    , rhs(std::move(rhs))
+{
+}
+
 std::string ASTStringExpression::emit() const
 {
     return operatr->emit(lhs->emit(), rhs->emit());
 }
 
+ASTExistsOperator::ASTExistsOperator(const SQLEmitter& sqlEmitter, std::string value)
+    : ASTNode(sqlEmitter)
+    , value(std::move(value))
+{
+}
+
 std::string ASTExistsOperator::emit() const
 {
     log_error("Emitting for ASTExistsOperator");
@@ -414,21 +502,50 @@ std::string ASTExistsOperator::emit(const std::string& property, const std::stri
     return sqlEmitter.emit(this, property, value);
 }
 
+ASTExistsExpression::ASTExistsExpression(const SQLEmitter& sqlEmitter, std::unique_ptr<ASTProperty> lhs,
+    std::unique_ptr<ASTExistsOperator> operatr, std::unique_ptr<ASTBoolean> rhs)
+    : ASTNode(sqlEmitter)
+    , lhs(std::move(lhs))
+    , operatr(std::move(operatr))
+    , rhs(std::move(rhs))
+{
+}
+
 std::string ASTExistsExpression::emit() const
 {
     return operatr->emit(lhs->emit(), rhs->emit());
 }
 
+ASTAndOperator::ASTAndOperator(const SQLEmitter& sqlEmitter, std::unique_ptr<ASTNode> lhs, std::unique_ptr<ASTNode> rhs)
+    : ASTNode(sqlEmitter)
+    , lhs(std::move(lhs))
+    , rhs(std::move(rhs))
+{
+}
 std::string ASTAndOperator::emit() const
 {
     return sqlEmitter.emit(this, lhs->emit(), rhs->emit());
 }
 
+ASTOrOperator::ASTOrOperator(const SQLEmitter& sqlEmitter, std::unique_ptr<ASTNode> lhs, std::unique_ptr<ASTNode> rhs)
+    : ASTNode(sqlEmitter)
+    , lhs(std::move(lhs))
+    , rhs(std::move(rhs))
+{
+}
+
 std::string ASTOrOperator::emit() const
 {
     return sqlEmitter.emit(this, lhs->emit(), rhs->emit());
 }
 
+DefaultSQLEmitter::DefaultSQLEmitter(std::shared_ptr<ColumnMapper> colMapper, std::shared_ptr<ColumnMapper> metaMapper, std::shared_ptr<ColumnMapper> resMapper)
+    : colMapper(std::move(colMapper))
+    , metaMapper(std::move(metaMapper))
+    , resMapper(std::move(resMapper))
+{
+}
+
 std::string DefaultSQLEmitter::emitSQL(const ASTNode* node) const
 {
     std::string predicates = node->emit();
@@ -449,15 +566,15 @@ std::string DefaultSQLEmitter::emit(const ASTParenthesis* node, const std::strin
 //    2: property statement lower case
 //    3: value
 static const std::map<std::string, std::string> logicOperator {
-    { "contains", "({2} LIKE LOWER('%{3}%') AND {0} IS NOT NULL)" }, // lower
-    { "doesnotcontain", "({2} NOT LIKE LOWER('%{3}%') AND {0} IS NOT NULL)" }, // lower
-    { "startswith", "({2} LIKE LOWER('{3}%') AND {0} IS NOT NULL)" }, // lower
+    { "contains", "({2} LIKE LOWER('%{3}%'))" }, // lower
+    { "doesnotcontain", "({2} NOT LIKE LOWER('%{3}%'))" }, // lower
+    { "startswith", "({2} LIKE LOWER('{3}%'))" }, // lower
     { "derivedfrom", "(LOWER({0}) LIKE LOWER('{3}%'))" },
     //{ "derivedfrom", "{0} LIKE LOWER('{3}%')" },
-    { "exists", "({1} IS {3} AND {0} IS NOT NULL)" },
+    { "exists", "({1} IS {3})" },
     { "@exists", "({1} IS {3})" },
     { "newer", "({1} {3})" },
-    { "compare", "({2}LOWER('{3}') AND {0} IS NOT NULL)" }, // lower
+    { "compare", "({2}LOWER('{3}'))" }, // lower
     { "@compare", "({2}LOWER('{3}'))" }, // lower
 };
 
@@ -485,9 +602,9 @@ std::string DefaultSQLEmitter::emit(const ASTCompareOperator* node, const std::s
     auto operatr = node->getValue();
     auto [prpUpper, prpLower] = getPropertyStatement(property);
 
-    if ((operatr == ">" || operatr == ">=") && value.substr(0, 5) == "@last") {
-        auto dateVal = to_seconds(std::chrono::system_clock::now()).count() - (24 * 60 * 60 * stoiString(value.substr(5)));
-        return fmt::format(logicOperator.at("newer"), "", fmt::format("{} {}", prpUpper, operatr), fmt::format("{} {}", prpLower, operatr), dateVal);
+    if ((operatr == ">" || operatr == ">=") && startswith(value, "@last")) {
+        auto dateVal = currentTime() - std::chrono::hours(24 * stoiString(value.substr(5)));
+        return fmt::format(logicOperator.at("newer"), "", fmt::format("{} {}", prpUpper, operatr), fmt::format("{} {}", prpLower, operatr), dateVal.count());
     }
 
     if (operatr != "=")
@@ -536,14 +653,24 @@ std::string DefaultSQLEmitter::emit(const ASTOrOperator* node, const std::string
     return fmt::format("{} OR {}", lhs, rhs);
 }
 
-std::string SortParser::parse()
+SortParser::SortParser(std::shared_ptr<ColumnMapper> colMapper, std::shared_ptr<ColumnMapper> metaMapper, std::string sortCriteria)
+    : colMapper(std::move(colMapper))
+    , metaMapper(std::move(metaMapper))
+    , sortCrit(std::move(sortCriteria))
+{
+}
+
+std::string SortParser::parse(std::string& addColumns, std::string& addJoin)
 {
     if (sortCrit.empty()) {
         return {};
     }
     std::vector<std::string> sort;
+    std::vector<std::string> colBuf;
+    std::vector<std::string> joinBuf;
+    size_t cnt = 0;
     for (auto&& seg : splitString(sortCrit, ',')) {
-        seg = trimString(seg);
+        trimStringInPlace(seg);
         bool desc = (seg[0] == '-');
         if (seg[0] == '-' || seg[0] == '+') {
             seg = seg.substr(1);
@@ -554,8 +681,34 @@ std::string SortParser::parse()
         if (!sortSql.empty()) {
             sort.push_back(fmt::format("{} {}", sortSql, (desc ? "DESC" : "ASC")));
         } else {
-            log_warning("Unknown sort key '{}' in '{}'", seg, sortCrit);
+            for (auto&& metaId : MetadataIterator()) {
+                auto&& metaName = MetadataHandler::getMetaFieldName(metaId);
+                if (metaName == seg) {
+                    sortSql = metaName;
+                }
+            }
+            if (!sortSql.empty()) {
+                log_debug("Sort by meta data '{}'", sortSql);
+                auto metaAlias = fmt::format("meta_prop{}", cnt);
+                colBuf.push_back(fmt::format("{}.{}", metaMapper->quote(metaAlias), metaMapper->mapQuoted(META_VALUE, true)));
+                joinBuf.push_back(fmt::format("INNER JOIN {0} {1} ON {2} = {1}.{3} AND {1}.{4} = '{5}'",
+                    metaMapper->getTableName(), metaMapper->quote(metaAlias),
+                    colMapper->mapQuoted(UPNP_SEARCH_ID),
+                    metaMapper->mapQuoted(UPNP_SEARCH_ID, true),
+                    metaMapper->mapQuoted(META_NAME, true),
+                    sortSql));
+
+                sort.push_back(fmt::format("{}.{} {}", metaMapper->quote(metaAlias), metaMapper->mapQuoted(META_VALUE, true), (desc ? "DESC" : "ASC")));
+                cnt++;
+            } else {
+                log_warning("Unknown sort key '{}' in '{}'", seg, sortCrit);
+            }
         }
     }
+    if (!colBuf.empty()) {
+        colBuf.emplace(colBuf.begin(), ""); // result starts with ,
+    }
+    addColumns = fmt::format("{}", fmt::join(colBuf, ", "));
+    addJoin = fmt::format("{}", fmt::join(joinBuf, " "));
     return fmt::format("{}", fmt::join(sort, ", "));
 }
