@@ -3,7 +3,7 @@
 
   sql_format.h - this file is part of Gerbera.
 
-  Copyright (C) 2021 Gerbera Contributors
+  Copyright (C) 2021-2022 Gerbera Contributors
 
   Gerbera is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 2
@@ -26,10 +26,9 @@
 #define __SQL_FORMAT_H__
 
 #include <fmt/format.h>
-#include <string_view>
 
 struct SQLIdentifier {
-    constexpr SQLIdentifier(const std::string_view& name, char quote_begin, char quote_end)
+    constexpr SQLIdentifier(std::string_view name, char quote_begin, char quote_end)
         : name(name)
         , quote_begin(quote_begin)
         , quote_end(quote_end)
@@ -49,4 +48,23 @@ struct fmt::formatter<SQLIdentifier> : formatter<std::string_view> {
     }
 };
 
+struct ColumnUpdate {
+    ColumnUpdate(const SQLIdentifier& column, std::string value)
+        : column(column)
+        , value(std::move(value))
+    {
+    }
+    SQLIdentifier column;
+    std::string value;
+};
+
+template <>
+struct fmt::formatter<ColumnUpdate> : formatter<std::string_view> {
+    template <typename FormatContext>
+    auto format(const ColumnUpdate& a, FormatContext& ctx) -> decltype(ctx.out())
+    {
+        return format_to(ctx.out(), "{} = {}", a.column, a.value);
+    }
+};
+
 #endif
