@@ -38,18 +38,18 @@
 #define DB_BACKUP_FORMAT "{}.backup"
 
 #define SQLITE3_SET_VERSION "INSERT INTO \"mt_internal_setting\" VALUES('db_version', '{}')"
-#define SQLITE3_UPDATE_VERSION "UPDATE \"mt_internal_setting\" SET \"value\"='{}' WHERE \"key\"='db_version' AND \"value\"='{}'"
-#define SQLITE3_ADD_RESOURCE_ATTR "ALTER TABLE \"grb_cds_resource\" ADD COLUMN \"{}\" varchar(255) default NULL"
+static constexpr auto sqlite3UpdateVersion = std::string_view(R"(UPDATE "mt_internal_setting" SET "value"='{}' WHERE "key"='db_version' AND "value"='{}')");
+static constexpr auto sqlite3AddResourceAttr = std::string_view(R"(ALTER TABLE "grb_cds_resource" ADD COLUMN "{}" varchar(255) default NULL)");
 
-Sqlite3Database::Sqlite3Database(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime, std::shared_ptr<Timer> timer)
-    : SQLDatabase(std::move(config), std::move(mime))
+Sqlite3Database::Sqlite3Database(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, std::shared_ptr<Timer> timer)
+    : SQLDatabase(config, mime)
     , timer(std::move(timer))
 {
     table_quote_begin = '"';
     table_quote_end = '"';
 
     // if sqlite3.sql or sqlite3-upgrade.xml is changed hashies have to be updated, index 0 is used for create script
-    hashies = { 3147846384, 778996897, 3362507034, 853149842, 4035419264, 3497064885, 974692115, 119767663, 3167732653, 2427825904, 3305506356, 43189396, 2767540493 };
+    hashies = { 3035716215, 778996897, 3362507034, 853149842, 4035419264, 3497064885, 974692115, 119767663, 3167732653, 2427825904, 3305506356, 43189396, 2767540493, 2512852146, 1273710965 };
 }
 
 void Sqlite3Database::prepare()
@@ -65,15 +65,18 @@ void Sqlite3Database::init()
     dbInitDone = false;
     SQLDatabase::init();
 
-    std::string dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
-    log_debug("SQLite path: {}", dbFilePath);
+    fs::path dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
+    log_debug("SQLite path: {}", dbFilePath.c_str());
 
     // check for db-file
     if (access(dbFilePath.c_str(), R_OK | W_OK) != 0 && errno != ENOENT)
         throw DatabaseException("", fmt::format("Error while accessing sqlite database file ({}): {}", dbFilePath.c_str(), std::strerror(errno)));
 
     taskQueueOpen = true;
-    threadRunner = std::make_unique<StdThreadRunner>("SQLiteThread", Sqlite3Database::staticThreadProc, this, config);
+    threadRunner = std::make_unique<StdThreadRunner>(
+        "SQLiteThread", [](void* arg) {
+            auto inst = static_cast<Sqlite3Database*>(arg);
+            inst->threadProc(); }, this, config);
 
     if (!threadRunner->isAlive()) {
         throw DatabaseException("", fmt::format("Could not start sqlite thread: {}", std::strerror(errno)));
@@ -89,11 +92,11 @@ void Sqlite3Database::init()
         prepare();
     } catch (const std::runtime_error& e) {
         shutdown();
-        throw_std_runtime_error("Sqlite3Database.init: could not open '{}' exclusively", dbFilePath);
+        throw_std_runtime_error("Sqlite3Database.init: could not open '{}' exclusively", dbFilePath.c_str());
     }
 
     std::string dbVersion;
-    std::string dbFilePathbackup = fmt::format(DB_BACKUP_FORMAT, dbFilePath);
+    fs::path dbFilePathbackup = fmt::format(DB_BACKUP_FORMAT, dbFilePath.c_str());
     try {
         dbVersion = getInternalSetting("db_version");
     } catch (const std::runtime_error& e) {
@@ -111,7 +114,7 @@ void Sqlite3Database::init()
                     btask->waitForTask();
                     prepare();
                     dbVersion = getInternalSetting("db_version");
-                } catch (const std::runtime_error& e) {
+                } catch (const std::runtime_error& err) {
                 }
             }
         } else {
@@ -142,7 +145,7 @@ void Sqlite3Database::init()
     }
 
     try {
-        upgradeDatabase(std::move(dbVersion), hashies, CFG_SERVER_STORAGE_SQLITE_UPGRADE_FILE, SQLITE3_UPDATE_VERSION, SQLITE3_ADD_RESOURCE_ATTR);
+        upgradeDatabase(std::stoul(dbVersion), hashies, CFG_SERVER_STORAGE_SQLITE_UPGRADE_FILE, sqlite3UpdateVersion, sqlite3AddResourceAttr);
         if (config->getBoolOption(CFG_SERVER_STORAGE_SQLITE_BACKUP_ENABLED) && timer) {
             // do a backup now
             auto btask = std::make_shared<SLBackupTask>(config, false);
@@ -189,7 +192,13 @@ std::string Sqlite3Database::getError(const std::string& query, const std::strin
     return fmt::format("SQLITE3: ({}, : {}) {}\nQuery: {}\nerror: {}", sqlite3_errcode(db), sqlite3_extended_errcode(db), sqlite3_errmsg(db), query.empty() ? "unknown" : query, error.empty() ? "unknown" : error);
 }
 
-void Sqlite3DatabaseWithTransactions::beginTransaction(const std::string_view& tName)
+Sqlite3DatabaseWithTransactions::Sqlite3DatabaseWithTransactions(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<Timer>& timer)
+    : SqlWithTransactions(config)
+    , Sqlite3Database(config, mime, timer)
+{
+}
+
+void Sqlite3DatabaseWithTransactions::beginTransaction(std::string_view tName)
 {
     if (use_transaction) {
         log_debug("BEGIN TRANSACTION {} {}", tName, inTransaction);
@@ -201,7 +210,7 @@ void Sqlite3DatabaseWithTransactions::beginTransaction(const std::string_view& t
     }
 }
 
-void Sqlite3DatabaseWithTransactions::rollback(const std::string_view& tName)
+void Sqlite3DatabaseWithTransactions::rollback(std::string_view tName)
 {
     if (use_transaction && inTransaction) {
         log_debug("ROLLBACK {} {}", tName, inTransaction);
@@ -210,7 +219,7 @@ void Sqlite3DatabaseWithTransactions::rollback(const std::string_view& tName)
     }
 }
 
-void Sqlite3DatabaseWithTransactions::commit(const std::string_view& tName)
+void Sqlite3DatabaseWithTransactions::commit(std::string_view tName)
 {
     if (use_transaction && inTransaction) {
         log_debug("COMMIT {} {}", tName, inTransaction);
@@ -255,75 +264,67 @@ int Sqlite3Database::exec(const std::string& query, bool getLastInsertId)
     }
 }
 
-void* Sqlite3Database::staticThreadProc(void* arg)
-{
-    log_debug("Sqlite3Database::staticThreadProc - running thread");
-    auto inst = static_cast<Sqlite3Database*>(arg);
-    try {
-        inst->threadProc();
-        log_debug("Sqlite3Database::staticThreadProc - exiting thread");
-    } catch (const std::runtime_error& e) {
-        log_error("Sqlite3Database::staticThreadProc - aborting thread");
-    }
-    return nullptr;
-}
-
 void Sqlite3Database::threadProc()
 {
-    sqlite3* db;
+    log_debug("Running thread");
+    try {
+        sqlite3* db;
 
-    std::string dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
+        std::string dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
 
-    int res = sqlite3_open(dbFilePath.c_str(), &db);
-    if (res != SQLITE_OK) {
-        startupError = fmt::format("Sqlite3Database.init: could not open '{}'", dbFilePath);
-        return;
-    }
+        int res = sqlite3_open(dbFilePath.c_str(), &db);
+        if (res != SQLITE_OK) {
+            startupError = fmt::format("Sqlite3Database.init: could not open '{}'", dbFilePath);
+            return;
+        }
 
-    StdThreadRunner::waitFor("Sqlite3Database", [this] { return threadRunner != nullptr; });
-    auto lock = threadRunner->uniqueLockS("threadProc");
-    // tell init() that we are ready
-    threadRunner->setReady();
+        StdThreadRunner::waitFor("Sqlite3Database", [this] { return threadRunner != nullptr; });
+        auto lock = threadRunner->uniqueLockS("threadProc");
+        // tell init() that we are ready
+        threadRunner->setReady();
 
-    while (!shutdownFlag) {
-        while (!taskQueue.empty()) {
-            auto task = taskQueue.front();
-            taskQueue.pop();
+        while (!shutdownFlag) {
+            while (!taskQueue.empty()) {
+                auto task = std::move(taskQueue.front());
+                taskQueue.pop();
 
-            lock.unlock();
-            try {
-                task->run(&db, this);
-                if (task->didContamination())
-                    dirty = true;
-                else if (task->didDecontamination())
-                    dirty = false;
-                task->sendSignal();
-            } catch (const std::runtime_error& e) {
-                task->sendSignal(e.what());
+                lock.unlock();
+                try {
+                    task->run(db, this);
+                    if (task->didContamination())
+                        dirty = true;
+                    else if (task->didDecontamination())
+                        dirty = false;
+                    task->sendSignal();
+                } catch (const std::runtime_error& e) {
+                    task->sendSignal(e.what());
+                }
+                lock.lock();
             }
-            lock.lock();
+
+            /* if nothing to do, sleep until awakened */
+            threadRunner->wait(lock);
+        }
+        log_debug("Exiting");
+
+        taskQueueOpen = false;
+        while (!taskQueue.empty()) {
+            auto task = std::move(taskQueue.front());
+            taskQueue.pop();
+            task->sendSignal("Sorry, sqlite3 thread is shutting down");
         }
 
-        /* if nothing to do, sleep until awakened */
-        threadRunner->wait(lock);
-    }
-    log_debug("Sqlite3Database::threadProc - exiting");
-
-    taskQueueOpen = false;
-    while (!taskQueue.empty()) {
-        auto task = taskQueue.front();
-        taskQueue.pop();
-        task->sendSignal("Sorry, sqlite3 thread is shutting down");
-    }
-
-    if (db) {
-        log_debug("Sqlite3Database::staticThreadProc - closing database");
-        if (sqlite3_close(db) == SQLITE_OK) {
-            log_debug("Sqlite3Database::staticThreadProc - closed database");
-        } else {
-            log_error("Sqlite3Database::staticThreadProc - closing database failed");
+        if (db) {
+            log_debug("closing database");
+            if (sqlite3_close(db) == SQLITE_OK) {
+                log_debug("Closed database");
+            } else {
+                log_error("Closing database failed");
+            }
+            db = nullptr;
         }
-        db = nullptr;
+    } catch (const std::runtime_error& e) {
+        log_error("Aborting thread");
     }
 }
 
@@ -377,7 +378,7 @@ bool SLTask::is_running() const
 void SLTask::sendSignal()
 {
     if (is_running()) { // we check before we lock first, because there is no need to lock then
-        std::lock_guard<decltype(mutex)> lock(mutex);
+        std::scoped_lock<decltype(mutex)> lock(mutex);
         running = false;
         cond.notify_one();
     }
@@ -399,26 +400,32 @@ void SLTask::waitForTask()
     }
 
     if (!getError().empty()) {
-        log_debug("{}", getError().c_str());
+        log_debug("{}", getError());
         throw_std_runtime_error(getError());
     }
 }
 
 /* SLInitTask */
-void SLInitTask::run(sqlite3** db, Sqlite3Database* sl)
+SLInitTask::SLInitTask(std::shared_ptr<Config> config, unsigned int hashie)
+    : config(std::move(config))
+    , hashie(hashie)
+{
+}
+
+void SLInitTask::run(sqlite3*& db, Sqlite3Database* sl)
 {
     log_debug("Running: init");
     std::string dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
 
-    sqlite3_close(*db);
+    sqlite3_close(db);
 
-    int res = sqlite3_open(dbFilePath.c_str(), db);
+    int res = sqlite3_open(dbFilePath.c_str(), &db);
     if (res != SQLITE_OK)
         throw DatabaseException("", "SQLite: Failed to create new database");
 
-    auto sqlFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_INIT_SQL_FILE);
+    auto sqlFilePath = fs::path(config->getOption(CFG_SERVER_STORAGE_SQLITE_INIT_SQL_FILE));
     log_debug("Loading initialisation SQL from: {}", sqlFilePath.c_str());
-    auto sql = readTextFile(sqlFilePath);
+    auto sql = GrbFile(std::move(sqlFilePath)).readTextFile();
     auto&& myHash = stringHash(sql);
 
     if (myHash == hashie) {
@@ -426,7 +433,7 @@ void SLInitTask::run(sqlite3** db, Sqlite3Database* sl)
 
         char* err = nullptr;
         int ret = sqlite3_exec(
-            *db,
+            db,
             sql.c_str(),
             nullptr,
             nullptr,
@@ -437,7 +444,7 @@ void SLInitTask::run(sqlite3** db, Sqlite3Database* sl)
             sqlite3_free(err);
         }
         if (ret != SQLITE_OK) {
-            throw DatabaseException("", sl->getError(sql, error, *db, ret));
+            throw DatabaseException("", sl->getError(sql, error, db, ret));
         }
         contamination = true;
     } else {
@@ -446,14 +453,19 @@ void SLInitTask::run(sqlite3** db, Sqlite3Database* sl)
 }
 
 /* SLSelectTask */
-void SLSelectTask::run(sqlite3** db, Sqlite3Database* sl)
+SLSelectTask::SLSelectTask(const std::string& query)
+    : query(query.c_str())
+{
+}
+
+void SLSelectTask::run(sqlite3*& db, Sqlite3Database* sl)
 {
     log_debug("Running: {}", query);
     pres = std::make_shared<Sqlite3Result>();
 
     char* err = nullptr;
     int ret = sqlite3_get_table(
-        *db,
+        db,
         query,
         &pres->table,
         &pres->nrow,
@@ -466,7 +478,7 @@ void SLSelectTask::run(sqlite3** db, Sqlite3Database* sl)
         sqlite3_free(err);
     }
     if (ret != SQLITE_OK) {
-        throw DatabaseException("", sl->getError(query, error, *db, ret));
+        throw DatabaseException("", sl->getError(query, error, db, ret));
     }
 
     pres->row = pres->table;
@@ -481,12 +493,12 @@ SLExecTask::SLExecTask(const std::string& query, bool getLastInsertId)
 {
 }
 
-void SLExecTask::run(sqlite3** db, Sqlite3Database* sl)
+void SLExecTask::run(sqlite3*& db, Sqlite3Database* sl)
 {
     log_debug("Running: {}", query);
     char* err;
     int ret = sqlite3_exec(
-        *db,
+        db,
         query,
         nullptr,
         nullptr,
@@ -497,10 +509,10 @@ void SLExecTask::run(sqlite3** db, Sqlite3Database* sl)
         sqlite3_free(err);
     }
     if (ret != SQLITE_OK) {
-        throw DatabaseException("", sl->getError(query, error, *db, ret));
+        throw DatabaseException("", sl->getError(query, error, db, ret));
     }
     if (getLastInsertIdFlag)
-        lastInsertId = sqlite3_last_insert_rowid(*db);
+        lastInsertId = sqlite3_last_insert_rowid(db);
     contamination = true;
 }
 
@@ -511,16 +523,16 @@ SLBackupTask::SLBackupTask(std::shared_ptr<Config> config, bool restore)
 {
 }
 
-void SLBackupTask::run(sqlite3** db, Sqlite3Database* sl)
+void SLBackupTask::run(sqlite3*& db, Sqlite3Database* sl)
 {
     log_debug("Running: backup");
-    std::string dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
+    fs::path dbFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE);
 
     if (!restore) {
         try {
             fs::copy(
                 dbFilePath,
-                fmt::format(DB_BACKUP_FORMAT, dbFilePath),
+                fmt::format(DB_BACKUP_FORMAT, dbFilePath.c_str()),
                 fs::copy_options::overwrite_existing);
             log_debug("sqlite3 backup successful");
             decontamination = true;
@@ -529,16 +541,16 @@ void SLBackupTask::run(sqlite3** db, Sqlite3Database* sl)
         }
     } else {
         log_info("trying to restore sqlite3 database from backup...");
-        sqlite3_close(*db);
+        sqlite3_close(db);
         try {
             fs::copy(
-                fmt::format(DB_BACKUP_FORMAT, dbFilePath),
+                fmt::format(DB_BACKUP_FORMAT, dbFilePath.c_str()),
                 dbFilePath,
                 fs::copy_options::overwrite_existing);
         } catch (const std::runtime_error& e) {
             throw DatabaseException(fmt::format("Error while restoring sqlite3 backup: {}", e.what()), fmt::format("Error while restoring sqlite3 backup: {}", e.what()));
         }
-        int res = sqlite3_open(dbFilePath.c_str(), db);
+        int res = sqlite3_open(dbFilePath.c_str(), &db);
         if (res != SQLITE_OK) {
             throw DatabaseException("", "error while restoring sqlite3 backup: could not reopen sqlite3 database after restore");
         }
@@ -546,6 +558,18 @@ void SLBackupTask::run(sqlite3** db, Sqlite3Database* sl)
     }
 }
 
+/* Sqlite3Row */
+
+Sqlite3Row::Sqlite3Row(char** row)
+    : row(row)
+{
+}
+
+char* Sqlite3Row::col_c_str(int index) const
+{
+    return row[index];
+}
+
 /* Sqlite3Result */
 
 Sqlite3Result::~Sqlite3Result()
@@ -570,7 +594,7 @@ std::unique_ptr<SQLRow> Sqlite3Result::nextRow()
 
 /* Sqlite3BackupTimerSubscriber */
 
-void Sqlite3Database::timerNotify(std::shared_ptr<Timer::Parameter> param)
+void Sqlite3Database::timerNotify(const std::shared_ptr<Timer::Parameter>& param)
 {
     auto btask = std::make_shared<SLBackupTask>(config, false);
     this->addTask(btask, true);
