@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     sqlite3_database.h - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -51,7 +51,7 @@ public:
 
     /// \brief run the sqlite3 task
     /// \param sl The instance of Sqlite3Database to do the queries with.
-    virtual void run(sqlite3** db, Sqlite3Database* sl) = 0;
+    virtual void run(sqlite3*& db, Sqlite3Database* sl) = 0;
 
     /// \brief returns true if the task is not completed
     /// \return true if the task is not completed yet, false if the task is finished and the results are ready.
@@ -84,7 +84,7 @@ protected:
     bool decontamination {};
 
     std::condition_variable cond;
-    std::mutex mutex;
+    mutable std::mutex mutex;
 
     std::string error;
 };
@@ -93,12 +93,8 @@ protected:
 class SLInitTask : public SLTask {
 public:
     /// \brief Constructor for the sqlite3 init task
-    explicit SLInitTask(std::shared_ptr<Config> config, unsigned int hashie)
-        : config(std::move(config))
-        , hashie(hashie)
-    {
-    }
-    void run(sqlite3** db, Sqlite3Database* sl) override;
+    explicit SLInitTask(std::shared_ptr<Config> config, unsigned int hashie);
+    void run(sqlite3*& db, Sqlite3Database* sl) override;
 
     std::string_view taskType() const override { return "InitTask"; }
 
@@ -112,12 +108,9 @@ class SLSelectTask : public SLTask {
 public:
     /// \brief Constructor for the sqlite3 select task
     /// \param query The SQL query string
-    explicit SLSelectTask(const std::string& query)
-        : query(query.c_str())
-    {
-    }
-    void run(sqlite3** db, Sqlite3Database* sl) override;
-    [[nodiscard]] std::shared_ptr<SQLResult> getResult() const { return std::static_pointer_cast<SQLResult>(pres); }
+    explicit SLSelectTask(const std::string& query);
+    void run(sqlite3*& db, Sqlite3Database* sl) override;
+    [[nodiscard]] std::shared_ptr<Sqlite3Result> getResult() const { return pres; }
 
     std::string_view taskType() const override { return "SelectTask"; }
 
@@ -134,7 +127,7 @@ public:
     /// \brief Constructor for the sqlite3 exec task
     /// \param query The SQL query string
     SLExecTask(const std::string& query, bool getLastInsertId);
-    void run(sqlite3** db, Sqlite3Database* sl) override;
+    void run(sqlite3*& db, Sqlite3Database* sl) override;
     int getLastInsertId() const { return lastInsertId; }
 
     std::string_view taskType() const override { return "ExecTask"; }
@@ -152,7 +145,7 @@ class SLBackupTask : public SLTask {
 public:
     /// \brief Constructor for the sqlite3 backup task
     SLBackupTask(std::shared_ptr<Config> config, bool restore);
-    void run(sqlite3** db, Sqlite3Database* sl) override;
+    void run(sqlite3*& db, Sqlite3Database* sl) override;
 
     std::string_view taskType() const override { return "BackupTask"; }
 
@@ -164,8 +157,8 @@ protected:
 /// \brief The Database class for using SQLite3
 class Sqlite3Database : public Timer::Subscriber, public SQLDatabase, public std::enable_shared_from_this<SQLDatabase> {
 public:
-    void timerNotify(std::shared_ptr<Timer::Parameter> param) override;
-    Sqlite3Database(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime, std::shared_ptr<Timer> timer);
+    void timerNotify(const std::shared_ptr<Timer::Parameter>& param) override;
+    Sqlite3Database(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, std::shared_ptr<Timer> timer);
 
 protected:
     void _exec(const std::string& query) override;
@@ -176,15 +169,7 @@ private:
     void shutdownDriver() override;
     std::shared_ptr<Database> getSelf() override;
 
-    std::string quote(std::string_view str) const override { return quote(std::string(str)); }
     std::string quote(const std::string& value) const override;
-    std::string quote(int val) const override { return fmt::to_string(val); }
-    std::string quote(unsigned int val) const override { return fmt::to_string(val); }
-    std::string quote(long val) const override { return fmt::to_string(val); }
-    std::string quote(unsigned long val) const override { return fmt::to_string(val); }
-    std::string quote(bool val) const override { return val ? "1" : "0"; }
-    std::string quote(char val) const override { return quote(std::string(1, val)); }
-    std::string quote(long long val) const override { return fmt::to_string(val); }
 
     std::shared_ptr<SQLResult> select(const std::string& query) override;
     int exec(const std::string& query, bool getLastInsertId = false) override;
@@ -196,7 +181,6 @@ private:
     std::string getError(const std::string& query, const std::string& error, sqlite3* db, int errorCode);
 
     std::unique_ptr<StdThreadRunner> threadRunner;
-    static void* staticThreadProc(void* arg);
     void threadProc();
 
     void addTask(const std::shared_ptr<SLTask>& task, bool onlyIfDirty = false);
@@ -221,20 +205,16 @@ private:
     friend class SLSelectTask;
     friend class SLExecTask;
     friend class SLInitTask;
-    friend class Sqlite3BackupTimerSubscriber;
 };
 
 /// \brief The Database class for using SQLite3 with transactions
 class Sqlite3DatabaseWithTransactions : public SqlWithTransactions, public Sqlite3Database {
 public:
-    Sqlite3DatabaseWithTransactions(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime, std::shared_ptr<Timer> timer)
-        : SqlWithTransactions(config)
-        , Sqlite3Database(std::move(config), std::move(mime), std::move(timer))
-    {
-    }
-    void beginTransaction(const std::string_view& tName) override;
-    void rollback(const std::string_view& tName) override;
-    void commit(const std::string_view& tName) override;
+    Sqlite3DatabaseWithTransactions(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<Timer>& timer);
+
+    void beginTransaction(std::string_view tName) override;
+    void rollback(std::string_view tName) override;
+    void commit(std::string_view tName) override;
 };
 
 /// \brief Represents a result of a sqlite3 select
@@ -266,13 +246,10 @@ private:
 /// \brief Represents a row of a result of a sqlite3 select
 class Sqlite3Row : public SQLRow {
 public:
-    explicit Sqlite3Row(char** row)
-        : row(row)
-    {
-    }
+    explicit Sqlite3Row(char** row);
 
 private:
-    char* col_c_str(int index) const override { return row[index]; }
+    char* col_c_str(int index) const override;
     char** row;
 };
 
