@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     buffered_io_handler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -31,16 +31,14 @@
 
 #include "buffered_io_handler.h" // API
 
-#include <cassert>
-
 #include "util/tools.h"
 
 class Config;
 
-BufferedIOHandler::BufferedIOHandler(std::shared_ptr<Config> config, std::unique_ptr<IOHandler>& underlyingHandler, size_t bufSize, size_t maxChunkSize, size_t initialFillSize)
-    : IOHandlerBufferHelper(std::move(config), bufSize, initialFillSize)
+BufferedIOHandler::BufferedIOHandler(const std::shared_ptr<Config>& config, std::unique_ptr<IOHandler> underlyingHandler, std::size_t bufSize, std::size_t maxChunkSize, std::size_t initialFillSize)
+    : IOHandlerBufferHelper(config, bufSize, initialFillSize)
 {
-    if (underlyingHandler == nullptr)
+    if (!underlyingHandler)
         throw_std_runtime_error("underlyingHandler must not be nullptr");
     if (maxChunkSize == 0)
         throw_std_runtime_error("maxChunkSize must be greater than 0");
@@ -48,7 +46,7 @@ BufferedIOHandler::BufferedIOHandler(std::shared_ptr<Config> config, std::unique
     this->maxChunkSize = maxChunkSize;
 
     // test it first!
-    //seekEnabled = true;
+    // seekEnabled = true;
 }
 
 void BufferedIOHandler::open(enum UpnpOpenFileMode mode)
@@ -68,22 +66,22 @@ void BufferedIOHandler::close()
 void BufferedIOHandler::threadProc()
 {
     int readBytes = 0;
-    size_t maxWrite;
+    std::size_t maxWrite;
+    StdThreadRunner::waitFor("BufferedIOHandler", [this] { return threadRunner != nullptr; });
 
 #ifdef TOMBDEBUG
-    std::chrono::milliseconds last_log;
-    bool first_log = true;
+    std::chrono::milliseconds lastLog;
+    bool firstLog = true;
 #endif
 
     auto lock = threadRunner->uniqueLock();
     do {
-
 #ifdef TOMBDEBUG
-        if (first_log || getDeltaMillis(last_log) > std::chrono::seconds(1)) {
-            if (first_log)
-                first_log = false;
-            last_log = currentTimeMS();
-            float percentFillLevel = 0;
+        if (firstLog || getDeltaMillis(lastLog) > std::chrono::milliseconds(100)) {
+            if (firstLog)
+                firstLog = false;
+            lastLog = currentTimeMS();
+            [[maybe_unused]] float percentFillLevel = 0;
             if (!empty) {
                 auto currentFillSize = int(b - a);
                 if (currentFillSize <= 0)
@@ -146,7 +144,7 @@ void BufferedIOHandler::threadProc()
             threadRunner->wait(lock);
         } else {
             lock.unlock();
-            size_t chunkSize = (maxChunkSize > maxWrite ? maxWrite : maxChunkSize);
+            std::size_t chunkSize = (maxChunkSize > maxWrite ? maxWrite : maxChunkSize);
             readBytes = underlyingHandler->read(buffer + b, chunkSize);
             lock.lock();
             if (readBytes > 0) {
@@ -162,7 +160,7 @@ void BufferedIOHandler::threadProc()
                     auto currentFillSize = int(b - a);
                     if (currentFillSize <= 0)
                         currentFillSize += bufSize;
-                    if (size_t(currentFillSize) >= initialFillSize) {
+                    if (std::size_t(currentFillSize) >= initialFillSize) {
                         log_debug("buffer: initial fillsize reached");
                         waitForInitialFillSize = false;
                         threadRunner->notify();
