@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     io_handler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -31,8 +31,6 @@
 
 #include "io_handler.h" // API
 
-#include <unistd.h>
-
 /// \fn static UpnpWebFileHandle web_open(const char *filename,
 ///                                       enum UpnpOpenFileMode mode)
 /// \brief Opens a file for the web server.
@@ -48,7 +46,7 @@ void IOHandler::open(enum UpnpOpenFileMode mode)
 }
 
 /// \fn static int web_read (UpnpWebFileHandle f, char *buf,
-///                          size_t length)
+///                          std::size_t length)
 /// \brief Reads a previously opened file sequentially.
 /// \param f Handle of the file.
 /// \param buf  This buffer will be filled by fread.
@@ -60,13 +58,13 @@ void IOHandler::open(enum UpnpOpenFileMode mode)
 ///
 /// \retval 0   EOF encountered.
 /// \retval -1  Error.
-size_t IOHandler::read(char* buf, size_t length)
+std::size_t IOHandler::read(char* buf, std::size_t length)
 {
     return -1;
 }
 
 /// \fn static int web_write (UpnpWebFileHandle f,char *buf,
-///                           size_t length)
+///                           std::size_t length)
 /// \brief Writes to a previously opened file sequentially.
 /// \param f Handle of the file.
 /// \param buf This buffer will be filled by fwrite.
@@ -81,7 +79,7 @@ size_t IOHandler::read(char* buf, size_t length)
 /// \retval Actual number of bytes written.
 ///
 /// \warning Currently this function is not supported.
-size_t IOHandler::write(char* buf, size_t length)
+std::size_t IOHandler::write(char* buf, std::size_t length)
 {
     return 0;
 }
