@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     io_handler_buffer_helper.h - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -51,7 +51,7 @@ public:
     /// \param initialFillSize the number of bytes which have to be in the buffer
     /// before the first read at the very beginning or after a seek returns;
     /// 0 disables the delay
-    IOHandlerBufferHelper(std::shared_ptr<Config> config, size_t bufSize, size_t initialFillSize);
+    IOHandlerBufferHelper(std::shared_ptr<Config> config, std::size_t bufSize, std::size_t initialFillSize);
     ~IOHandlerBufferHelper() noexcept override;
 
     IOHandlerBufferHelper(const IOHandlerBufferHelper&) = delete;
@@ -59,14 +59,14 @@ public:
 
     // inherited from IOHandler
     void open(enum UpnpOpenFileMode mode) override;
-    size_t read(char* buf, size_t length) override;
+    std::size_t read(char* buf, std::size_t length) override;
     void seek(off_t offset, int whence) override;
     void close() override;
 
 protected:
     std::shared_ptr<Config> config;
-    size_t bufSize;
-    size_t initialFillSize;
+    std::size_t bufSize;
+    std::size_t initialFillSize;
     char* buffer {};
     bool isOpen {};
     bool eof {};
@@ -77,8 +77,8 @@ protected:
 
     // buffer stuff..
     bool empty { true };
-    size_t a {};
-    size_t b {};
+    std::size_t a {};
+    std::size_t b {};
     off_t posRead {};
 
     // seek stuff...
@@ -90,7 +90,6 @@ protected:
     // thread stuff..
     void startBufferThread();
     void stopBufferThread();
-    static void* staticThreadProc(void* arg);
     virtual void threadProc() = 0;
 
     std::unique_ptr<StdThreadRunner> threadRunner;
