@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     process_io_handler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -32,27 +32,26 @@
 #include "process_io_handler.h" // API
 
 #include <csignal>
+#include <utility>
 
 #include <fcntl.h>
 #include <sys/select.h>
-#include <sys/stat.h>
 
 #include "content/content_manager.h"
-#include "util/process.h"
 
 // after MAX_TIMEOUTS we will tell libupnp to check the socket,
 // this will make sure that we do not block the read and allow libupnp to
 // call our close() callback
 
-#define MAX_TIMEOUTS 2 // maximum allowe consecutive timeouts
+#define MAX_TIMEOUTS 2 // maximum allowed consecutive timeouts
 
-ProcListItem::ProcListItem(std::shared_ptr<Executor>&& exec, bool abortOnDeath)
+ProcListItem::ProcListItem(std::shared_ptr<Executor> exec, bool abortOnDeath)
     : executor(std::move(exec))
     , abort(abortOnDeath)
 {
 }
 
-std::shared_ptr<Executor> ProcListItem::getExecutor()
+std::shared_ptr<Executor> ProcListItem::getExecutor() const
 {
     return executor;
 }
@@ -105,50 +104,39 @@ void ProcessIOHandler::unregisterAll()
 ProcessIOHandler::ProcessIOHandler(std::shared_ptr<ContentManager> content,
     fs::path filename,
     std::shared_ptr<Executor> mainProc,
-    std::vector<std::shared_ptr<ProcListItem>> procList,
+    std::vector<std::unique_ptr<ProcListItem>> procList,
     bool ignoreSeek)
     : content(std::move(content))
     , procList(std::move(procList))
     , mainProc(std::move(mainProc))
-    , filename(std::move(filename))
+    , path(std::move(filename))
     , ignoreSeek(ignoreSeek)
 {
     if (this->mainProc && (!this->mainProc->isAlive() || abort())) {
         killAll();
         throw_std_runtime_error("process terminated early");
     }
-    /*
-    if (mkfifo(filename.c_str(), O_RDWR) == -1)
-    {
-        log_error("Failed to create fifo: {}", std::strerror(errno));
-        killAll();
-        if (main_proc)
-            main_proc->kill();
-
-        throw_std_runtime_error("Could not create reader fifo");
-    }
-*/
     registerAll();
 }
 
 void ProcessIOHandler::open(enum UpnpOpenFileMode mode)
 {
-    if ((mainProc) && ((!mainProc->isAlive() || abort()))) {
+    if (mainProc && (!mainProc->isAlive() || abort())) {
         killAll();
         throw_std_runtime_error("process terminated early");
     }
 
     if (mode == UPNP_READ)
 #ifdef __linux__
-        fd = ::open(filename.c_str(), O_RDONLY | O_NONBLOCK | O_CLOEXEC);
+        fd = ::open(path.c_str(), O_RDONLY | O_NONBLOCK | O_CLOEXEC);
 #else
-        fd = ::open(filename.c_str(), O_RDONLY | O_NONBLOCK);
+        fd = ::open(path.c_str(), O_RDONLY | O_NONBLOCK);
 #endif
     else if (mode == UPNP_WRITE)
 #ifdef __linux__
-        fd = ::open(filename.c_str(), O_WRONLY | O_NONBLOCK | O_CLOEXEC);
+        fd = ::open(path.c_str(), O_WRONLY | O_NONBLOCK | O_CLOEXEC);
 #else
-        fd = ::open(filename.c_str(), O_WRONLY | O_NONBLOCK);
+        fd = ::open(path.c_str(), O_WRONLY | O_NONBLOCK);
 #endif
     else
         fd = -1;
@@ -161,45 +149,40 @@ void ProcessIOHandler::open(enum UpnpOpenFileMode mode)
         killAll();
         if (mainProc)
             mainProc->kill();
-        fs::remove(filename);
-        throw_std_runtime_error("open: failed to open: {}", filename.c_str());
+        fs::remove(path);
+        throw_std_runtime_error("open: failed to open: {}", path.c_str());
     }
 }
 
-size_t ProcessIOHandler::read(char* buf, size_t length)
+std::size_t ProcessIOHandler::read(char* buf, std::size_t length)
 {
     fd_set readSet;
-    struct timespec timeout;
-    ssize_t bytes_read = 0;
-    size_t num_bytes = 0;
-    char* p_buffer = buf;
-    int exit_status = EXIT_SUCCESS;
-    int ret = 0;
-    int timeout_count = 0;
+    struct timespec timeout = { FIFO_READ_TIMEOUT, 0 };
+    ssize_t bytesRead;
+    std::size_t numBytes = 0;
+    char* pBuffer = buf;
+    int exitStatus = EXIT_SUCCESS;
+    int ret;
+    int timeoutCount = 0;
 
     while (true) {
         FD_ZERO(&readSet);
         FD_SET(fd, &readSet);
 
-        timeout.tv_sec = FIFO_READ_TIMEOUT;
-        timeout.tv_nsec = 0;
-
         ret = pselect(fd + 1, &readSet, nullptr, nullptr, &timeout, nullptr);
-        if (ret == -1) {
-            if (errno == EINTR)
-                continue;
-        }
+        if ((ret == -1) && (errno == EINTR))
+            continue;
 
         // timeout
         if (ret == 0) {
             if (mainProc) {
-                bool main_ok = mainProc->isAlive();
-                if (!main_ok || abort()) {
-                    if (!main_ok) {
-                        exit_status = mainProc->getStatus();
-                        log_debug("process exited with status {}", exit_status);
+                bool mainOk = mainProc->isAlive();
+                if (!mainOk || abort()) {
+                    if (!mainOk) {
+                        exitStatus = mainProc->getStatus();
+                        log_debug("process exited with status {}", exitStatus);
                         killAll();
-                        return (exit_status == EXIT_SUCCESS) ? 0 : -1;
+                        return (exitStatus == EXIT_SUCCESS) ? 0 : -1;
                     }
                     mainProc->kill();
                     killAll();
@@ -210,35 +193,35 @@ size_t ProcessIOHandler::read(char* buf, size_t length)
                 return 0;
             }
 
-            timeout_count++;
-            if (timeout_count > MAX_TIMEOUTS) {
+            timeoutCount++;
+            if (timeoutCount > MAX_TIMEOUTS) {
                 log_debug("max timeouts, checking socket!");
                 return CHECK_SOCKET;
             }
         }
 
         if (FD_ISSET(fd, &readSet)) {
-            timeout_count = 0;
-            bytes_read = ::read(fd, p_buffer, length);
-            if (bytes_read == 0)
+            timeoutCount = 0;
+            bytesRead = ::read(fd, pBuffer, length);
+            if (bytesRead == 0)
                 break;
 
-            if (bytes_read < 0) {
+            if (bytesRead < 0) {
                 log_debug("aborting read!!!");
                 return -1;
             }
 
-            num_bytes = num_bytes + bytes_read;
-            length = length - bytes_read;
+            numBytes = numBytes + bytesRead;
+            length = length - bytesRead;
 
             if (length == 0)
                 break;
 
-            p_buffer = buf + num_bytes;
+            pBuffer = buf + numBytes;
         }
     }
 
-    if (num_bytes == 0) {
+    if (numBytes == 0) {
         // not sure what we return here since no way of knowing about feof
         // actually that will depend on the ret code of the process
         ret = -1;
@@ -255,43 +238,37 @@ size_t ProcessIOHandler::read(char* buf, size_t length)
         return ret;
     }
 
-    return num_bytes;
+    return numBytes;
 }
 
-size_t ProcessIOHandler::write(char* buf, size_t length)
+std::size_t ProcessIOHandler::write(char* buf, std::size_t length)
 {
     fd_set writeSet;
-    struct timespec timeout;
-    ssize_t bytes_written = 0;
-    size_t num_bytes = 0;
-    char* p_buffer = buf;
-    int exit_status = EXIT_SUCCESS;
-    int ret = 0;
+    struct timespec timeout = { FIFO_WRITE_TIMEOUT, 0 };
+    ssize_t bytesWritten;
+    std::size_t numBytes = 0;
+    char* pBuffer = buf;
+    int exitStatus = EXIT_SUCCESS;
+    int ret;
 
     while (true) {
         FD_ZERO(&writeSet);
         FD_SET(fd, &writeSet);
 
-        timeout.tv_sec = FIFO_WRITE_TIMEOUT;
-        timeout.tv_nsec = 0;
-
         ret = pselect(fd + 1, nullptr, &writeSet, nullptr, &timeout, nullptr);
-        if (ret == -1) {
-            if (errno == EINTR) {
-                continue;
-            }
-        }
+        if ((ret == -1) && (errno == EINTR))
+            continue;
 
         // timeout
         if (ret == 0) {
             if (mainProc) {
-                bool main_ok = mainProc->isAlive();
-                if (!main_ok || abort()) {
-                    if (!main_ok) {
-                        exit_status = mainProc->getStatus();
-                        log_debug("process exited with status {}", exit_status);
+                bool mainOk = mainProc->isAlive();
+                if (!mainOk || abort()) {
+                    if (!mainOk) {
+                        exitStatus = mainProc->getStatus();
+                        log_debug("process exited with status {}", exitStatus);
                         killAll();
-                        return (exit_status == EXIT_SUCCESS) ? 0 : -1;
+                        return (exitStatus == EXIT_SUCCESS) ? 0 : -1;
                     }
 
                     mainProc->kill();
@@ -305,25 +282,25 @@ size_t ProcessIOHandler::write(char* buf, size_t length)
         }
 
         if (FD_ISSET(fd, &writeSet)) {
-            bytes_written = ::write(fd, p_buffer, length);
-            if (bytes_written == 0)
+            bytesWritten = ::write(fd, pBuffer, length);
+            if (bytesWritten == 0)
                 break;
 
-            if (bytes_written < 0) {
+            if (bytesWritten < 0) {
                 log_debug("aborting write!!!");
                 return -1;
             }
 
-            num_bytes = num_bytes + bytes_written;
-            length = length - bytes_written;
+            numBytes = numBytes + bytesWritten;
+            length = length - bytesWritten;
             if (length == 0)
                 break;
 
-            p_buffer = buf + num_bytes;
+            pBuffer = buf + numBytes;
         }
     }
 
-    if (num_bytes == 0) {
+    if (numBytes == 0) {
         // not sure what we return here since no way of knowing about feof
         // actually that will depend on the ret code of the process
         ret = -1;
@@ -343,7 +320,7 @@ size_t ProcessIOHandler::write(char* buf, size_t length)
         return ret;
     }
 
-    return num_bytes;
+    return numBytes;
 }
 
 void ProcessIOHandler::seek(off_t offset, int whence)
@@ -355,30 +332,27 @@ void ProcessIOHandler::seek(off_t offset, int whence)
 
 void ProcessIOHandler::close()
 {
-    bool ret;
+}
 
-    log_debug("terminating process, closing {}", this->filename.c_str());
+ProcessIOHandler::~ProcessIOHandler()
+{
+    log_debug("Destroying ProcessIOHandler: terminating process, closing {}", this->path.c_str());
     unregisterAll();
 
+    bool killed;
     if (mainProc) {
-        ret = mainProc->kill();
-    } else
-        ret = true;
+        killed = mainProc->kill();
+    } else {
+        killed = true;
+    }
 
     killAll();
 
     ::close(fd);
 
-    fs::remove(filename);
+    fs::remove(path);
 
-    if (!ret)
-        throw_std_runtime_error("failed to kill process");
-}
-
-ProcessIOHandler::~ProcessIOHandler()
-{
-    try {
-        close();
-    } catch (const std::runtime_error& ex) {
+    if (!killed) {
+        log_warning("~ProcessIOHandler: Failed to kill process");
     }
 }
