@@ -35,9 +35,7 @@
 /// running "doxygen doxygen.conf" from the mediatomb/doc/ directory.
 
 #include <csignal>
-#include <cstdio>
-#include <cstdlib>
-#include <filesystem>
+#include <fmt/core.h>
 #include <mutex>
 #include <spdlog/sinks/basic_file_sink.h>
 
@@ -50,15 +48,15 @@
 #include <iso/limits_iso.h>
 #endif
 
-// those are needed for -P pidfile, -u user and -d daemonize options
+// those are needed for -u user and -d daemonize options
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
-#include <fcntl.h>
 #include <grp.h>
 #include <pwd.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/wait.h>
 #include <unistd.h>
 
 #include "common.h"
@@ -68,22 +66,25 @@
 #include "contrib/cxxopts.hpp"
 #include "server.h"
 
-static struct {
-    int shutdown_flag = 0;
-    int restart_flag = 0;
-    pthread_t main_thread_id;
+static constexpr auto gitBranch = std::string_view(GIT_BRANCH);
+static constexpr auto gitCommitHash = std::string_view(GIT_COMMIT_HASH);
 
-    std::mutex mutex;
+static struct {
+    int shutdownFlag = 0;
+    int restartFlag = 0;
+    pthread_t mainThreadId;
+
+    mutable std::mutex mutex;
     std::unique_lock<std::mutex> lock { mutex };
     std::condition_variable cond;
 } _ctx;
 
 static void printCopyright()
 {
-    printf("\nGerbera UPnP Server %s\n"
-           "Copyright 2016-2021 Gerbera Contributors.\n"
-           "Licence GPLv2: GNU GPL version 2.\n"
-           "This is free software: you are free to change and redistribute it.\n\n",
+    fmt::print("\nGerbera UPnP Server {}\n"
+               "Copyright 2016-2021 Gerbera Contributors.\n"
+               "Licence GPLv2: GNU GPL version 2.\n"
+               "This is free software: you are free to change and redistribute it.\n\n",
         GERBERA_VERSION);
 }
 
@@ -96,26 +97,37 @@ static void logCopyright()
 
 static void signalHandler(int signum)
 {
-    if (_ctx.main_thread_id != pthread_self()) {
+    if (_ctx.mainThreadId != pthread_self()) {
+        return;
+    }
+
+    log_debug("Got a SIG: {}", signum);
+
+    if (signum == SIGCHLD) {
+        log_debug("Got a SIGCHLD!");
+        int savedErrno = errno;
+        while (waitpid(pid_t(-1), nullptr, WNOHANG) > 0) { }
+        errno = savedErrno;
         return;
     }
 
     if (signum == SIGSEGV) {
         log_error("This should never happen {}:{}, killing Gerbera!", errno, std::strerror(errno));
-        exit(EXIT_FAILURE);
+        std::exit(EXIT_FAILURE);
     }
+
     if ((signum == SIGINT) || (signum == SIGTERM)) {
-        _ctx.shutdown_flag++;
-        if (_ctx.shutdown_flag == 1) {
+        _ctx.shutdownFlag++;
+        if (_ctx.shutdownFlag == 1) {
             log_info("Gerbera shutting down. Please wait...");
-        } else if (_ctx.shutdown_flag == 2) {
+        } else if (_ctx.shutdownFlag == 2) {
             log_info("Gerbera still shutting down, signal again to kill.");
-        } else if (_ctx.shutdown_flag > 2) {
+        } else if (_ctx.shutdownFlag > 2) {
             log_error("Clean shutdown failed, killing Gerbera!");
-            exit(EXIT_FAILURE);
+            std::exit(EXIT_FAILURE);
         }
     } else if (signum == SIGHUP) {
-        _ctx.restart_flag = 1;
+        _ctx.restartFlag = 1;
     }
 
     _ctx.cond.notify_one();
@@ -123,11 +135,11 @@ static void signalHandler(int signum)
 
 static void installSignalHandler()
 {
-    _ctx.main_thread_id = pthread_self();
+    _ctx.mainThreadId = pthread_self();
 
     struct sigaction action = {};
     action.sa_handler = signalHandler;
-    action.sa_flags = 0;
+    action.sa_flags = SA_NOCLDSTOP;
     sigfillset(&action.sa_mask);
     if (sigaction(SIGSEGV, &action, nullptr) < 0) {
         log_error("Could not register SIGSEGV handler!");
@@ -148,6 +160,10 @@ static void installSignalHandler()
     if (sigaction(SIGPIPE, &action, nullptr) < 0) {
         log_error("Could not register SIGPIPE handler!");
     }
+
+    if (sigaction(SIGCHLD, &action, nullptr) < 0) {
+        log_error("Could not register SIGCHLD handler!");
+    }
 }
 
 int main(int argc, char** argv, char** envp)
@@ -158,65 +174,72 @@ int main(int argc, char** argv, char** envp)
         ("D,debug", "Enable debugging", cxxopts::value<bool>()->default_value("false")) //
         ("d,daemon", "Daemonize after startup", cxxopts::value<bool>()->default_value("false")) //
         ("u,user", "Drop privs to user", cxxopts::value<std::string>()) //
-        ("P,pidfile", "Write a pidfile to the specified location, e.g. /run/gerbera.pid", cxxopts::value<std::string>()) //
+        ("P,pidfile", "Write a pidfile to the specified location, e.g. /run/gerbera.pid", cxxopts::value<fs::path>()) //
         ("e,interface", "Interface to bind with", cxxopts::value<std::string>()) //
         ("p,port", "Port to bind with, must be >=49152", cxxopts::value<in_port_t>()) //
         ("i,ip", "IP to bind with", cxxopts::value<std::string>()) //
-        ("c,config", "Path to config file", cxxopts::value<std::string>()) //
-        ("m,home", "Search this directory for a .gerbera folder containing a config file", cxxopts::value<std::string>()) //
-        ("f,cfgdir", "Override name of config folder (.config/gerbera) by default. -h must also be set.", cxxopts::value<std::string>()) //
-        ("l,logfile", "Set log location", cxxopts::value<std::string>()) //
+        ("c,config", "Path to config file", cxxopts::value<fs::path>()) //
+        ("m,home", "Search this directory for a .config/gerbera folder containing a config file", cxxopts::value<fs::path>()) //
+        ("f,cfgdir", "Override name of config folder (.config/gerbera) in home folder.", cxxopts::value<fs::path>()) //
+        ("l,logfile", "Set log location", cxxopts::value<fs::path>()) //
         ("compile-info", "Print compile info and exit") //
         ("v,version", "Print version info and exit") //
         ("h,help", "Print this help and exit") //
         ("create-config", "Print a default config.xml file and exit") //
-        ("add-file", "Scan a file into the DB on startup, can be specified multiple times", cxxopts::value<std::vector<std::string>>(), "FILE") //
+        ("add-file", "Scan a file into the DB on startup, can be specified multiple times", cxxopts::value<std::vector<fs::path>>(), "FILE") //
         ;
 
     try {
         cxxopts::ParseResult opts = options.parse(argc, argv);
 
         if (opts.count("help") > 0) {
-            std::cout << options.help({ "", "Group" }) << std::endl;
-            exit(EXIT_SUCCESS);
+            fmt::print("{}\n", options.help({ "", "Group" }));
+            std::exit(EXIT_SUCCESS);
         }
 
         if (opts.count("version") > 0) {
             printCopyright();
-            exit(EXIT_SUCCESS);
+            std::exit(EXIT_SUCCESS);
         }
 
         if (opts.count("compile-info") > 0) {
             printCopyright();
-            std::cout << "Compile info" << std::endl
-                      << "-------------" << std::endl
-                      << COMPILE_INFO << std::endl
-                      << std::endl;
-            if (strlen(GIT_BRANCH) > 0) {
-                std::cout << "Git info:" << std::endl
-                          << "-------------" << std::endl
-                          << "Git Branch: " << GIT_BRANCH << std::endl;
+            fmt::print(
+                "Compile info\n"
+                "-------------\n"
+                "{}\n\n",
+                COMPILE_INFO);
+            if (!gitBranch.empty()) {
+                fmt::print(
+                    "Git info:\n"
+                    "-------------\n"
+                    "Git Branch: {}\n",
+                    gitBranch);
             }
-            if (strlen(GIT_COMMIT_HASH) > 0) {
-                std::cout << "Git Commit: " << GIT_COMMIT_HASH << std::endl;
+            if (!gitCommitHash.empty()) {
+                fmt::print("Git Commit: {}\n", gitCommitHash);
             }
 
-            exit(EXIT_SUCCESS);
+            std::exit(EXIT_SUCCESS);
         }
 
         bool debug = opts["debug"].as<bool>();
         if (debug) {
             spdlog::set_level(spdlog::level::debug);
-            spdlog::set_pattern("%Y-%m-%d %X.%e %6l: [%s:%#] %!(): %v");
+            spdlog::set_pattern("%Y-%m-%d %X.%e %^%6l%$: [%s:%#] %!(): %v");
         } else {
             spdlog::set_level(spdlog::level::info);
-            spdlog::set_pattern("%Y-%m-%d %X %6l: %v");
+            spdlog::set_pattern("%Y-%m-%d %X %^%6l%$: %v");
         }
 
-        std::optional<std::string> logfile;
+        std::optional<fs::path> logfile;
         if (opts.count("logfile") > 0) {
-            auto file_logger = spdlog::basic_logger_mt("basic_logger", opts["logfile"].as<std::string>());
-            spdlog::set_default_logger(file_logger);
+            logfile = opts["logfile"].as<fs::path>();
+            if (!fs::directory_entry(logfile->parent_path()).exists()) {
+                log_warning("Log dir {} missing", logfile->parent_path().c_str());
+            }
+            auto fileLogger = spdlog::basic_logger_mt("basic_logger", *logfile);
+            spdlog::set_default_logger(fileLogger);
             spdlog::flush_on(spdlog::level::trace);
         }
 
@@ -225,9 +248,12 @@ int main(int argc, char** argv, char** envp)
             logCopyright();
         }
 
-        std::optional<std::string> home;
+        std::optional<fs::path> home;
         if (opts.count("home") > 0) {
-            home = opts["home"].as<std::string>();
+            home = opts["home"].as<fs::path>();
+            if (!fs::directory_entry(*home).exists()) {
+                log_warning("Home dir {} missing", home->c_str());
+            }
         }
 
         // are we requested to drop privs?
@@ -236,40 +262,40 @@ int main(int argc, char** argv, char** envp)
             user = opts["user"].as<std::string>();
 
             // get actual euid/egid of process
-            uid_t actual_euid = geteuid();
+            uid_t actualEuid = geteuid();
 
             // get user info of requested user from passwd
-            auto user_id = getpwnam(user->c_str());
-            if (!user_id) {
+            auto userId = getpwnam(user->c_str());
+            if (!userId) {
                 log_error("Invalid user requested.");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
 
             // set home according to /etc/passwd entry
             if (!home.has_value()) {
-                home = user_id->pw_dir;
+                home = userId->pw_dir;
             }
 
             // we need to be euid root to become requested user/group
-            if (actual_euid != 0) {
+            if (actualEuid != 0) {
                 log_error("Need to be root to change user.");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
 
             // set all uids, gids and add. groups
-// mac os x does this differently, setgid and setuid are basically doing the same
+// macOS does this differently, setgid and setuid are basically doing the same
 // as setresuid and setresgid on linux: setting all of real{u,g}id, effective{u,g}id and saved-set{u,g}id
 // Solaroid systems are likewise missing setresgid and setresuid
 #if defined(__APPLE__) || defined(SOLARIS) || defined(__CYGWIN__) || defined(__HAIKU__)
             // set group-ids, then add. groups, last user-ids, all need to succeed
-            if (0 != setgid(user_id->pw_gid) || 0 != initgroups(user_id->pw_name, user_id->pw_gid) || 0 != setuid(user_id->pw_uid)) {
+            if (0 != setgid(userId->pw_gid) || 0 != initgroups(userId->pw_name, userId->pw_gid) || 0 != setuid(userId->pw_uid)) {
 #else
-            if (0 != setresgid(user_id->pw_gid, user_id->pw_gid, user_id->pw_gid) || 0 != initgroups(user_id->pw_name, user_id->pw_gid) || 0 != setresuid(user_id->pw_uid, user_id->pw_uid, user_id->pw_uid)) {
+            if (0 != setresgid(userId->pw_gid, userId->pw_gid, userId->pw_gid) || 0 != initgroups(userId->pw_name, userId->pw_gid) || 0 != setresuid(userId->pw_uid, userId->pw_uid, userId->pw_uid)) {
 #endif
                 log_error("Unable to change user.");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
-            log_info("Dropped to User: {}", user->c_str());
+            log_info("Dropped to User: {}", *user);
         }
 
         // are we requested to daemonize?
@@ -281,29 +307,29 @@ int main(int argc, char** argv, char** envp)
             pid = fork();
             if (pid < 0) {
                 log_error("Unable to fork.");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
 
             // terminate parent
             if (pid > 0)
-                exit(EXIT_SUCCESS);
+                std::exit(EXIT_SUCCESS);
 
             // become session leader
             if (setsid() < 0) {
                 log_error("Unable to setsid.");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
 
             // second fork
             pid = fork();
             if (pid < 0) {
                 log_error("Unable to fork.");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
 
             // terminate parent
             if (pid > 0)
-                exit(EXIT_SUCCESS);
+                std::exit(EXIT_SUCCESS);
 
             // set new file permissions
             umask(0);
@@ -311,7 +337,7 @@ int main(int argc, char** argv, char** envp)
             // change dir to /
             if (chdir("/")) {
                 log_error("Unable to chdir to root dir.");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
             // close open filedescriptors belonging to a tty
             for (auto fd = int(sysconf(_SC_OPEN_MAX)); fd >= 0; fd--) {
@@ -322,14 +348,19 @@ int main(int argc, char** argv, char** envp)
         }
 
         // are we requested to write a pidfile ?
-        std::optional<std::string> pidfile;
+        std::optional<fs::path> pidfile;
         if (opts.count("pidfile") > 0) {
-            pidfile = opts["pidfile"].as<std::string>();
+            pidfile = opts["pidfile"].as<fs::path>();
+            if (!fs::directory_entry(pidfile->parent_path()).exists()) {
+                log_warning("pidfile parent dir {} missing", pidfile->parent_path().c_str());
+            }
 
             // x will make it fail if file exists
-            auto pidf = ::fopen(pidfile->c_str(), "wx");
+            GrbFile pidFile(pidfile.value());
+            auto pidf = pidFile.open("wx", false);
             if (!pidf) {
-                log_error("Pidfile {} exists. It may be that gerbera is already", pidfile->c_str());
+                log_error("fopen {} failed: {}", pidfile->c_str(), std::strerror(errno));
+                log_error("Pidfile already exists or is not writable. It may be that gerbera is already");
                 log_error("running or the file is a leftover from an unclean shutdown.");
                 log_error("In that case, remove the file before starting gerbera.");
                 std::exit(EXIT_FAILURE);
@@ -350,17 +381,19 @@ int main(int argc, char** argv, char** envp)
                 std::exit(EXIT_FAILURE);
             }
             log_debug("Wrote pidfile {}.", pidfile->c_str());
-            ::fclose(pidf);
         }
 
-        std::optional<std::string> config_file;
+        std::optional<fs::path> configFile;
         if (opts.count("config") > 0) {
-            config_file = opts["config"].as<std::string>();
+            configFile = opts["config"].as<fs::path>();
         }
 
-        std::optional<std::string> confdir;
+        std::optional<fs::path> confdir;
         if (opts.count("cfgdir") > 0) {
-            confdir = opts["cfgdir"].as<std::string>();
+            confdir = opts["cfgdir"].as<fs::path>();
+            if (!fs::directory_entry(*confdir).exists()) {
+                log_warning("confdir {} missing", confdir->c_str());
+            }
         }
 
         if (!confdir.has_value()) {
@@ -368,7 +401,7 @@ int main(int argc, char** argv, char** envp)
         }
 
         // If home is not given by the user, get it from the environment
-        if (!config_file.has_value() && !home.has_value()) {
+        if (!configFile.has_value() && !home.has_value()) {
             // Check XDG first
             const char* h = std::getenv("XDG_CONFIG_HOME");
             if (h) {
@@ -383,7 +416,7 @@ int main(int argc, char** argv, char** envp)
 
             if (!home.has_value()) {
                 log_error("Could not determine users home directory");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
             log_debug("Home detected as: {}", home->c_str());
         }
@@ -416,8 +449,8 @@ int main(int argc, char** argv, char** envp)
                 confdir = "";
             }
             std::string generated = configGenerator.generate(home.value_or(""), confdir.value_or(""), dataDir.value_or(""), magic.value_or(""));
-            std::cout << generated.c_str() << std::endl;
-            exit(EXIT_SUCCESS);
+            fmt::print("{}\n", generated);
+            std::exit(EXIT_SUCCESS);
         }
 
         std::optional<in_port_t> portnum;
@@ -440,35 +473,34 @@ int main(int argc, char** argv, char** envp)
         std::shared_ptr<ConfigManager> configManager;
         try {
             configManager = std::make_shared<ConfigManager>(
-                config_file.value_or(""), home.value_or(""), confdir.value_or(""),
+                configFile.value_or(""), home.value_or(""), confdir.value_or(""),
                 dataDir.value_or(""), magic.value_or(""),
                 ip.value_or(""), interface.value_or(""), portnum.value_or(0),
                 debug);
             configManager->load(home.value_or(""));
             portnum = in_port_t(configManager->getIntOption(CFG_SERVER_PORT));
         } catch (const ConfigParseException& ce) {
-            log_error("Error parsing config file '{}': {}", (*config_file).c_str(), ce.what());
-            exit(EXIT_FAILURE);
+            log_error("Error parsing config file '{}': {}", configFile.value_or("").c_str(), ce.what());
+            std::exit(EXIT_FAILURE);
         } catch (const std::runtime_error& e) {
             log_error("{}", e.what());
-            exit(EXIT_FAILURE);
+            std::exit(EXIT_FAILURE);
         }
 
-        sigset_t mask_set;
-        sigfillset(&mask_set);
-        pthread_sigmask(SIG_SETMASK, &mask_set, nullptr);
+        sigset_t maskSet;
+        sigfillset(&maskSet);
+        pthread_sigmask(SIG_SETMASK, &maskSet, nullptr);
 
         installSignalHandler();
 
-        std::shared_ptr<Server> server;
+        auto server = std::make_shared<Server>(configManager);
+
         try {
-            auto config = std::static_pointer_cast<Config>(configManager);
-            server = std::make_shared<Server>(config);
             server->init();
             server->run();
         } catch (const UpnpException& ue) {
-            sigemptyset(&mask_set);
-            pthread_sigmask(SIG_SETMASK, &mask_set, nullptr);
+            sigemptyset(&maskSet);
+            pthread_sigmask(SIG_SETMASK, &maskSet, nullptr);
 
             if (ue.getErrorCode() == UPNP_E_SOCKET_BIND) {
                 log_error("LibUPnP could not bind to socket");
@@ -476,6 +508,9 @@ int main(int argc, char** argv, char** envp)
             } else if (ue.getErrorCode() == UPNP_E_SOCKET_ERROR) {
                 log_error("LibUPnP Socket error");
                 log_error("Please check if your network interface was configured for multicast!");
+            } else if (ue.getErrorCode() == UPNP_E_SUCCESS) {
+                /* This means we died, not libupnp explicitly, likely because they gave us the wrong port */
+                log_error(ue.what());
             } else {
 #ifdef UPNP_HAVE_TOOLS
                 log_error("Failed to start LibUPnP: {} error code: {}", UpnpGetErrorMessage(ue.getErrorCode()), ue.getErrorCode());
@@ -487,20 +522,20 @@ int main(int argc, char** argv, char** envp)
             try {
                 if (server)
                     server->shutdown();
-                server = nullptr;
-                configManager = nullptr;
+                server.reset();
+                configManager.reset();
             } catch (const std::runtime_error& e) {
                 log_error("{}", e.what());
             }
 
-            exit(EXIT_FAILURE);
+            std::exit(EXIT_FAILURE);
         } catch (const std::runtime_error& e) {
             log_error("{}", e.what());
-            exit(EXIT_FAILURE);
+            std::exit(EXIT_FAILURE);
         }
 
         if (opts.count("add-file") > 0) {
-            auto files = opts["add-file"].as<std::vector<std::string>>();
+            auto files = opts["add-file"].as<std::vector<fs::path>>();
             for (auto&& f : files) {
                 try {
                     std::error_code ec;
@@ -519,55 +554,54 @@ int main(int argc, char** argv, char** envp)
                     }
                 } catch (const std::runtime_error& e) {
                     log_error("{}", e.what());
-                    exit(EXIT_FAILURE);
+                    std::exit(EXIT_FAILURE);
                 }
             }
         }
 
-        sigemptyset(&mask_set);
-        pthread_sigmask(SIG_SETMASK, &mask_set, nullptr);
+        sigemptyset(&maskSet);
+        pthread_sigmask(SIG_SETMASK, &maskSet, nullptr);
 
         // wait until signalled to terminate
-        while (!_ctx.shutdown_flag) {
+        while (!_ctx.shutdownFlag) {
             _ctx.cond.wait(_ctx.lock);
 
-            if (_ctx.restart_flag != 0) {
+            if (_ctx.restartFlag != 0) {
                 log_info("Restarting Gerbera!");
                 try {
                     server->shutdown();
-                    server = nullptr;
-                    configManager = nullptr;
+                    server.reset();
+                    configManager.reset();
 
                     try {
                         configManager = std::make_shared<ConfigManager>(
-                            config_file.value_or(""), home.value_or(""), confdir.value_or(""),
+                            configFile.value_or(""), home.value_or(""), confdir.value_or(""),
                             dataDir.value_or(""), magic.value_or(""),
                             ip.value_or(""), interface.value_or(""), portnum.value_or(-1),
                             debug);
                     } catch (const ConfigParseException& ce) {
-                        log_error("Error parsing config file '{}': {}", (*config_file).c_str(), ce.what());
+                        log_error("Error parsing config file '{}': {}", configFile.value_or("").c_str(), ce.what());
                         log_error("Could not restart Gerbera");
                         // at this point upnp shutdown has already been called
-                        // so it is safe to exit
-                        exit(EXIT_FAILURE);
+                        // therefore it is safe to exit
+                        std::exit(EXIT_FAILURE);
                     } catch (const std::runtime_error& e) {
                         log_error("Error reloading configuration: {}",
                             e.what());
-                        exit(EXIT_FAILURE);
+                        std::exit(EXIT_FAILURE);
                     }
 
                     ///  \todo fix this for SIGHUP
-                    auto config = std::static_pointer_cast<Config>(configManager);
-                    server = std::make_shared<Server>(config);
+                    server = std::make_shared<Server>(configManager);
                     server->init();
                     server->run();
 
-                    _ctx.restart_flag = 0;
+                    _ctx.restartFlag = 0;
                 } catch (const std::runtime_error& e) {
-                    _ctx.restart_flag = 0;
-                    _ctx.shutdown_flag = 1;
-                    sigemptyset(&mask_set);
-                    pthread_sigmask(SIG_SETMASK, &mask_set, nullptr);
+                    _ctx.restartFlag = 0;
+                    _ctx.shutdownFlag = 1;
+                    sigemptyset(&maskSet);
+                    pthread_sigmask(SIG_SETMASK, &maskSet, nullptr);
                     log_error("Could not restart Gerbera");
                 }
             }
@@ -577,10 +611,10 @@ int main(int argc, char** argv, char** envp)
         int ret = EXIT_SUCCESS;
         try {
             server->shutdown();
-            server = nullptr;
-            configManager = nullptr;
-        } catch (const UpnpException& upnp_e) {
-            log_error("main: upnp error {}", upnp_e.getErrorCode());
+            server.reset();
+            configManager.reset();
+        } catch (const UpnpException& upnpE) {
+            log_error("main: upnp error {}", upnpE.getErrorCode());
             ret = EXIT_FAILURE;
         } catch (const std::runtime_error& e) {
             log_error("main: error {}", e.what());
@@ -588,8 +622,8 @@ int main(int argc, char** argv, char** envp)
         }
 
         // remove pidfile if one was written
-        if (opts.count("pidfile") > 0) {
-            if (0 == remove(pidfile->c_str())) {
+        if (pidfile) {
+            if (fs::remove(*pidfile)) {
                 log_debug("Pidfile {} removed.", pidfile->c_str());
             } else {
                 log_info("Could not remove pidfile {}", pidfile->c_str());
@@ -597,9 +631,9 @@ int main(int argc, char** argv, char** envp)
         }
 
         log_info("Gerbera exiting. Have a nice day.");
-        exit(ret);
+        std::exit(ret);
     } catch (const cxxopts::OptionException& e) {
-        std::cerr << "Failed to parse arguments: " << e.what() << std::endl;
-        exit(EXIT_FAILURE);
+        fmt::print(stderr, "Failed to parse arguments: {}\n", e.what());
+        std::exit(EXIT_FAILURE);
     }
 }
