@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     libexif_handler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -35,23 +35,22 @@
 #include <iohandler/file_io_handler.h>
 
 #include "cds_objects.h"
-#include "config/config_manager.h"
 #include "iohandler/mem_io_handler.h"
 #include "util/string_converter.h"
 #include "util/tools.h"
 
 /// \brief Sets resolution for a given resource index, item must be a JPEG image
-static void setJpegResolutionResource(const std::shared_ptr<CdsItem>& item, size_t res_num)
+static void setJpegResolutionResource(const std::shared_ptr<CdsItem>& item, std::size_t resNum)
 {
     try {
-        auto fio_h = std::unique_ptr<IOHandler>(std::make_unique<FileIOHandler>(item->getLocation()));
-        fio_h->open(UPNP_READ);
-        std::string resolution = get_jpeg_resolution(fio_h);
+        auto fioH = std::make_unique<FileIOHandler>(item->getLocation());
+        fioH->open(UPNP_READ);
+        const std::string resolution = get_jpeg_resolution(std::move(fioH));
 
-        if (res_num >= item->getResourceCount())
+        if (resNum >= item->getResourceCount())
             throw_std_runtime_error("Invalid resource index");
 
-        item->getResource(res_num)->addAttribute(R_RESOLUTION, resolution);
+        item->getResource(resNum)->addAttribute(R_RESOLUTION, resolution);
     } catch (const std::runtime_error& e) {
         log_error("Exception! {}", e.what());
     }
@@ -168,17 +167,18 @@ static int getTagFromString(const std::string& tag)
     auto result = getValueOrDefault(exifTagMap, tag, -1);
 
     if (result == -1)
-        log_warning("Ignoring unknown libexif tag: {}", tag.c_str());
+        log_warning("Ignoring unknown libexif tag: {}", tag);
     return result;
 }
 
-void LibExifHandler::process_ifd(ExifContent* content, const std::shared_ptr<CdsItem>& item, const std::unique_ptr<StringConverter>& sc, const std::vector<std::string>& auxtags)
+void LibExifHandler::process_ifd(const ExifContent* content, const std::shared_ptr<CdsItem>& item,
+    const std::unique_ptr<StringConverter>& sc, const std::vector<std::string>& auxtags, const std::map<std::string, std::string>& metatags)
 {
     constexpr auto BUFLEN = 4096;
     std::array<char, BUFLEN> exif_entry_buffer;
 #define exif_egv(arg) exif_entry_get_value(arg, exif_entry_buffer.data(), BUFLEN)
 
-    for (size_t i = 0; i < content->count; i++) {
+    for (std::size_t i = 0; i < content->count; i++) {
         ExifEntry* e = content->entries[i];
 
         // log_debug("Processing entry: {}", i);
@@ -191,7 +191,7 @@ void LibExifHandler::process_ifd(ExifContent* content, const std::shared_ptr<Cds
                 // convert date to ISO 8601 as required in the UPnP spec
                 // from YYYY:MM:DD to YYYY-MM-DD
                 if (value.length() >= 11) {
-                    item->setMetadata(M_DATE, fmt::format("{}-{}-{}", value.substr(0, 4), value.substr(5, 2), value.substr(8, 2)));
+                    item->addMetaData(M_DATE, fmt::format("{}-{}-{}", value.substr(0, 4), value.substr(5, 2), value.substr(8, 2)));
                 }
             }
             break;
@@ -199,7 +199,7 @@ void LibExifHandler::process_ifd(ExifContent* content, const std::shared_ptr<Cds
         case EXIF_TAG_USER_COMMENT: {
             auto value = trimString(exif_egv(e));
             if (!value.empty()) {
-                item->setMetadata(M_DESCRIPTION, sc->convert(value));
+                item->addMetaData(M_DESCRIPTION, sc->convert(value));
             }
             break;
         }
@@ -221,16 +221,26 @@ void LibExifHandler::process_ifd(ExifContent* content, const std::shared_ptr<Cds
             break;
         }
 
+        // if there are any metadata tags that the user wants - add them
+        for (auto&& [tag, key] : metatags) {
+            if (tag.empty() || e->tag != getTagFromString(tag))
+                continue;
+
+            auto value = trimString(exif_egv(e));
+            if (!value.empty()) {
+                item->addMetaData(key, sc->convert(value));
+                log_debug("Adding tag '{}' as '{}' with value '{}'", tag, key, value);
+            }
+        }
         // if there are any auxilary tags that the user wants - add them
         for (auto&& aux : auxtags) {
-            if (!aux.empty()) {
-                if (e->tag == getTagFromString(aux)) {
-                    auto value = trimString(exif_egv(e));
-                    if (!value.empty()) {
-                        item->setAuxData(aux, sc->convert(value));
-                        // log_debug("Adding tag: {} with value {}", aux, value);
-                    }
-                }
+            if (aux.empty() || e->tag != getTagFromString(aux))
+                continue;
+
+            auto value = trimString(exif_egv(e));
+            if (!value.empty()) {
+                item->setAuxData(aux, sc->convert(value));
+                // log_debug("Adding tag: {} with value {}", aux, value);
             }
         }
     }
@@ -251,10 +261,11 @@ void LibExifHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
         return;
     }
 
-    std::vector<std::string> aux = config->getArrayOption(CFG_IMPORT_LIBOPTS_EXIF_AUXDATA_TAGS_LIST);
+    auto aux = config->getArrayOption(CFG_IMPORT_LIBOPTS_EXIF_AUXDATA_TAGS_LIST);
+    auto meta = config->getDictionaryOption(CFG_IMPORT_LIBOPTS_EXIF_METADATA_TAGS_LIST);
     for (auto&& i : ed->ifd) {
         if (i)
-            process_ifd(i, item, sc, aux);
+            process_ifd(i, item, sc, aux, meta);
     }
 
     // we got the image resolution so we can add our resource
@@ -266,16 +277,16 @@ void LibExifHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 
     if (ed->size) {
         try {
-            auto io_h = std::unique_ptr<IOHandler>(std::make_unique<MemIOHandler>(ed->data, ed->size));
-            io_h->open(UPNP_READ);
-            auto&& th_resolution = get_jpeg_resolution(io_h);
-            log_debug("RESOLUTION: {}", th_resolution.c_str());
+            auto ioH = std::make_unique<MemIOHandler>(ed->data, ed->size);
+            ioH->open(UPNP_READ);
+            const std::string thResolution = get_jpeg_resolution(std::move(ioH));
+            log_debug("RESOLUTION: {}", thResolution);
 
             auto resource = std::make_shared<CdsResource>(CH_LIBEXIF);
             resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(item->getMimeType()));
-            resource->addAttribute(R_RESOLUTION, th_resolution);
+            resource->addAttribute(R_RESOLUTION, thResolution);
             resource->addParameter(RESOURCE_CONTENT_TYPE, EXIF_THUMBNAIL);
-            item->addResource(move(resource));
+            item->addResource(resource);
         } catch (const std::runtime_error& e) {
             log_error("Something bad happened! {}", e.what());
         }
@@ -302,8 +313,8 @@ std::unique_ptr<IOHandler> LibExifHandler::serveContent(const std::shared_ptr<Cd
     if (!(ed->size))
         throw_std_runtime_error("Resource {} has no exif thumbnail", resNum);
 
-    auto h = std::make_unique<MemIOHandler>(ed->data, ed->size);
+    auto ioHandler = std::make_unique<MemIOHandler>(ed->data, ed->size);
     exif_data_unref(ed);
-    return std::move(h);
+    return ioHandler;
 }
 #endif // HAVE_LIBEXIF
