@@ -4,7 +4,7 @@
 
     metacontent_handler.cc - this file is part of Gerbera.
 
-    Copyright (C) 2020-2021 Gerbera Contributors
+    Copyright (C) 2020-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -44,9 +44,10 @@ ContentPathSetup::ContentPathSetup(std::shared_ptr<Config> config, config_option
 {
 }
 
-std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<CdsObject>& obj, const std::string& setting, fs::path folder)
+std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<CdsObject>& obj, const std::string& setting, fs::path folder) const
 {
-    auto tweak = allTweaks->get(obj->getLocation());
+    auto objLocation = obj->getLocation();
+    auto tweak = allTweaks->get(objLocation);
     auto files = !tweak || !tweak->hasSetting(setting) ? this->names : std::vector<std::string> { tweak->getSetting(setting) };
     auto isCaseSensitive = tweak && tweak->hasCaseSensitive() ? tweak->getCaseSensitive() : this->caseSensitive;
 
@@ -54,33 +55,32 @@ std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<Cds
 
     if (!files.empty()) {
         if (folder.empty()) {
-            folder = (obj->isContainer()) ? obj->getLocation() : obj->getLocation().parent_path();
+            folder = (obj->isContainer()) ? objLocation : objLocation.parent_path();
         }
         log_debug("Folder name: {}", folder.c_str());
 
         if (isCaseSensitive) {
             for (auto&& name : files) {
-                auto found = folder / expandName(name, obj);
+                auto contentFile = folder / expandName(name, obj);
                 std::error_code ec;
-                bool exists = isRegularFile(found, ec); // no error throwing, please
-                if (!exists)
+                if (!isRegularFile(contentFile, ec) || contentFile == objLocation) // no error throwing, please
                     continue;
 
-                log_debug("{}: found", found.c_str());
-                result.push_back(std::move(found));
+                log_debug("{}: found", contentFile.c_str());
+                result.push_back(std::move(contentFile));
             }
         } else {
             std::map<std::string, fs::path> fileNames;
             std::error_code ec;
             for (auto&& p : fs::directory_iterator(folder, ec))
-                if (isRegularFile(p, ec))
+                if (isRegularFile(p, ec) && p.path() != objLocation)
                     fileNames[toLower(p.path().filename().string())] = p;
 
             for (auto&& name : files) {
                 auto fileName = toLower(expandName(name, obj));
                 for (auto&& [f, s] : fileNames) {
                     if (f == fileName) {
-                        log_debug("{}: found", f.c_str());
+                        log_debug("{}: found", f);
                         result.push_back(s);
                     }
                 }
@@ -88,44 +88,44 @@ std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<Cds
         }
         if (!patterns.empty()) {
             for (auto&& [dir, ext] : patterns) {
-                auto found = fs::path(expandName(dir, obj));
+                auto contentPath = fs::path(expandName(dir, obj));
                 auto extn = fs::path(expandName(ext, obj));
                 auto stem = isCaseSensitive ? extn.stem().string() : toLower(extn.stem().string());
                 if (extn.has_extension()) {
                     extn = isCaseSensitive ? extn.extension().string() : toLower(extn.extension().string());
                 } else {
-                    extn = isCaseSensitive ? fmt::format(".{}", ext) : toLower(fmt::format(".{}", ext));
-                    stem = "";
+                    extn = fmt::format(".{}", isCaseSensitive ? ext : toLower(ext));
+                    stem.clear();
                 }
                 std::error_code ec;
-                if (found.is_relative()) {
-                    found = folder / found;
+                if (contentPath.is_relative()) {
+                    contentPath = fs::weakly_canonical(folder / contentPath);
                 }
-                if (!fs::is_directory(found)) {
-                    log_debug("{}: not a directory", found.string());
+                if (!fs::is_directory(contentPath)) {
+                    log_debug("{}: not a directory", contentPath.string());
                     continue;
                 }
-                for (auto&& p : fs::directory_iterator(found, ec)) {
-                    if (isRegularFile(p, ec) && ((isCaseSensitive && p.path().extension() == extn) || (!isCaseSensitive && toLower(p.path().extension().string()) == extn))) {
+                for (auto&& contentFile : fs::directory_iterator(contentPath, ec)) {
+                    if (isRegularFile(contentFile, ec) && ((isCaseSensitive && contentFile.path().extension() == extn) || (!isCaseSensitive && toLower(contentFile.path().extension().string()) == extn)) && contentFile.path() != objLocation) {
                         if (!stem.empty()) {
                             replaceAllString(stem, "*", ".*");
                             replaceAllString(stem, ".", "?");
-                            std::regex re(fmt::format("^{}$", stem));
+                            auto re = std::regex(fmt::format("^{}$", stem));
                             std::cmatch m;
-                            if (std::regex_match(p.path().stem().string().c_str(), m, re)) {
-                                log_debug("{}: found", p.path().string());
-                                result.push_back(p.path());
+                            if (std::regex_match(contentFile.path().stem().string().c_str(), m, re)) {
+                                log_debug("{}: found", contentFile.path().string());
+                                result.push_back(contentFile.path());
                             }
                         } else {
-                            log_debug("{}: found", p.path().string());
-                            result.push_back(p.path());
+                            log_debug("{}: found", contentFile.path().string());
+                            result.push_back(contentFile.path());
                         }
                     }
                 }
             }
         }
     }
-    if (result.empty())
+    if (result.empty()) // required to detect no match
         result.emplace_back();
     return result;
 }
@@ -136,6 +136,7 @@ static constexpr auto metaTags = std::array {
     std::pair("%artist%", M_ARTIST),
     std::pair("%genre%", M_GENRE),
     std::pair("%title%", M_TITLE),
+    std::pair("%composer%", M_COMPOSER),
 };
 
 std::string ContentPathSetup::expandName(std::string_view name, const std::shared_ptr<CdsObject>& obj)
@@ -143,18 +144,18 @@ std::string ContentPathSetup::expandName(std::string_view name, const std::share
     std::string copy(name);
 
     for (auto&& [key, val] : metaTags)
-        replaceString(copy, key, obj->getMetadata(val));
+        replaceString(copy, key, obj->getMetaData(val));
 
     if (obj->isItem()) {
         fs::path location = obj->getLocation();
-        replaceString(copy, "%filename%", location.stem().string().c_str());
+        replaceString(copy, "%filename%", location.stem().string());
     }
     if (obj->isContainer()) {
         auto title = obj->getTitle();
         if (!title.empty())
             replaceString(copy, "%filename%", title);
         fs::path location = obj->getLocation();
-        replaceString(copy, "%filename%", location.filename().string().c_str());
+        replaceString(copy, "%filename%", location.filename().string());
     }
     return copy;
 }
@@ -186,7 +187,7 @@ void FanArtHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
             resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(mimeType));
             resource->addAttribute(R_RESOURCE_FILE, path.string());
             resource->addParameter(RESOURCE_CONTENT_TYPE, ID3_ALBUM_ART);
-            obj->addResource(move(resource));
+            obj->addResource(resource);
         }
     }
 }
@@ -237,7 +238,7 @@ void ContainerArtHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
             resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(mimeType));
             resource->addAttribute(R_RESOURCE_FILE, path.string());
             resource->addParameter(RESOURCE_CONTENT_TYPE, ID3_ALBUM_ART);
-            obj->addResource(move(resource));
+            obj->addResource(resource);
         }
     }
 }
@@ -274,6 +275,7 @@ SubtitleHandler::SubtitleHandler(const std::shared_ptr<Context>& context)
 void SubtitleHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto pathList = setup->getContentPath(obj, SETTING_SUBTITLE);
+    auto objFilename = obj->getLocation().filename().string() + ".";
 
     if (pathList.empty() || pathList[0].empty())
         obj->removeResource(CH_SUBTITLE);
@@ -292,10 +294,16 @@ void SubtitleHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 
             resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(mimeType));
             resource->addAttribute(R_RESOURCE_FILE, path.string());
-            resource->addAttribute(R_LANGUAGE, path.stem().string()); // assume file name is related to some language
+            resource->addAttribute(R_TYPE, type);
+            auto lang = path.stem().string();
+            if (startswith(lang, objFilename)) {
+                replaceAllString(lang, objFilename, ""); // remove starting part with filename
+            }
+            if (!lang.empty())
+                resource->addAttribute(R_LANGUAGE, lang); // assume file name is related to some language
             resource->addParameter(RESOURCE_CONTENT_TYPE, VIDEO_SUB);
             resource->addParameter("type", type);
-            obj->addResource(move(resource));
+            obj->addResource(resource);
         }
     }
 }
@@ -334,13 +342,13 @@ void ResourceHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
         obj->removeResource(CH_RESOURCE);
 
     for (auto&& path : pathList) {
-        log_debug("Running resource handler check on {} -> {}", obj->getLocation().string().c_str(), path.string().c_str());
+        log_debug("Running resource handler check on {} -> {}", obj->getLocation().string(), path.string());
 
         if (!path.empty() && toLower(path.string()) == toLower(obj->getLocation().string())) {
             auto resource = std::make_shared<CdsResource>(CH_RESOURCE);
             resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo("res"));
             resource->addAttribute(R_RESOURCE_FILE, path.string());
-            obj->addResource(move(resource));
+            obj->addResource(resource);
         }
     }
 }
@@ -351,11 +359,11 @@ std::unique_ptr<IOHandler> ResourceHandler::serveContent(const std::shared_ptr<C
     if (path.empty()) {
         path = setup->getContentPath(obj, SETTING_RESOURCE)[0];
     }
-    log_debug("Resource: Opening name: {}", path.c_str());
+    log_debug("Resource: Opening name: {}", path.string());
     struct stat statbuf;
     int ret = stat(path.c_str(), &statbuf);
     if (ret != 0) {
-        log_warning("File does not exist: {} ({})", path.c_str(), std::strerror(errno));
+        log_warning("File does not exist: {} ({})", path.string(), std::strerror(errno));
         return nullptr;
     }
     return std::make_unique<FileIOHandler>(path);
