@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     metadata_handler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -31,10 +31,9 @@
 
 #include "metadata_handler.h" // API
 
-#include <filesystem>
-
 #include "cds_objects.h"
 #include "config/config_manager.h"
+#include "content/scripting/script_names.h"
 #include "util/tools.h"
 
 #ifdef HAVE_EXIV2
@@ -57,6 +56,7 @@
 #include "metadata/matroska_handler.h"
 #endif
 
+#include "ffmpeg_thumbnailer_handler.h"
 #include "metadata/metacontent_handler.h"
 
 MetadataHandler::MetadataHandler(const std::shared_ptr<Context>& context)
@@ -65,7 +65,7 @@ MetadataHandler::MetadataHandler(const std::shared_ptr<Context>& context)
 {
 }
 
-void MetadataHandler::setMetadata(const std::shared_ptr<Context>& context, const std::shared_ptr<CdsItem>& item, const fs::directory_entry& dirEnt)
+void MetadataHandler::extractMetaData(const std::shared_ptr<Context>& context, const std::shared_ptr<CdsItem>& item, const fs::directory_entry& dirEnt)
 {
     std::error_code ec;
     if (!isRegularFile(dirEnt, ec))
@@ -78,59 +78,68 @@ void MetadataHandler::setMetadata(const std::shared_ptr<Context>& context, const
     resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(mimetype));
     resource->addAttribute(R_SIZE, fmt::to_string(filesize));
 
-    item->addResource(move(resource));
+    item->addResource(resource);
+    item->clearMetaData();
 
     auto mappings = context->getConfig()->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
-    std::string content_type = getValueOrDefault(mappings, mimetype);
+    std::string contentType = getValueOrDefault(mappings, mimetype);
+    auto itemCls = item->getClass();
 
-    if ((content_type == CONTENT_TYPE_OGG) && (isTheora(item->getLocation()))) {
+    if ((contentType == CONTENT_TYPE_OGG) && (isTheora(item->getLocation()))) {
         item->setFlag(OBJECT_FLAG_OGG_THEORA);
     }
 
 #ifdef HAVE_TAGLIB
-    if ((content_type == CONTENT_TYPE_MP3) || ((content_type == CONTENT_TYPE_OGG) && (!item->getFlag(OBJECT_FLAG_OGG_THEORA))) || (content_type == CONTENT_TYPE_WMA) || (content_type == CONTENT_TYPE_WAVPACK) || (content_type == CONTENT_TYPE_FLAC) || (content_type == CONTENT_TYPE_PCM) || (content_type == CONTENT_TYPE_AIFF) || (content_type == CONTENT_TYPE_APE) || (content_type == CONTENT_TYPE_MP4)) {
+    if ((contentType == CONTENT_TYPE_MP3) || ((contentType == CONTENT_TYPE_OGG) && (!item->getFlag(OBJECT_FLAG_OGG_THEORA))) || (contentType == CONTENT_TYPE_WMA) || (contentType == CONTENT_TYPE_WAVPACK) || (contentType == CONTENT_TYPE_FLAC) || (contentType == CONTENT_TYPE_PCM) || (contentType == CONTENT_TYPE_AIFF) || (contentType == CONTENT_TYPE_APE) || (contentType == CONTENT_TYPE_MP4)) {
         TagLibHandler(context).fillMetadata(item);
     }
 #endif // HAVE_TAGLIB
 
 #ifdef HAVE_EXIV2
-    if (content_type == CONTENT_TYPE_JPG) {
+    if (contentType == CONTENT_TYPE_JPG) {
         Exiv2Handler(context).fillMetadata(item);
     }
 #endif
 
 #ifdef HAVE_LIBEXIF
-    if (content_type == CONTENT_TYPE_JPG) {
+    if (contentType == CONTENT_TYPE_JPG) {
         LibExifHandler(context).fillMetadata(item);
     }
 #endif // HAVE_LIBEXIF
 
 #ifdef HAVE_MATROSKA
-    if (content_type == CONTENT_TYPE_MKV) {
+    if (contentType == CONTENT_TYPE_MKV) {
         MatroskaHandler(context).fillMetadata(item);
     }
 #endif
 
 #ifdef HAVE_FFMPEG
-    if (content_type != CONTENT_TYPE_PLAYLIST && ((content_type == CONTENT_TYPE_OGG && item->getFlag(OBJECT_FLAG_OGG_THEORA)) || startswith(item->getMimeType(), "video") || startswith(item->getMimeType(), "audio"))) {
+    if (contentType != CONTENT_TYPE_PLAYLIST && (itemCls == UPNP_CLASS_MUSIC_TRACK || itemCls == UPNP_CLASS_VIDEO_ITEM)) {
         FfmpegHandler(context).fillMetadata(item);
     }
 #else
-    if (content_type == CONTENT_TYPE_AVI) {
-        std::string fourcc = getAVIFourCC(dirEnt.path().string());
+    if (contentType == CONTENT_TYPE_AVI) {
+        std::string fourcc = getAVIFourCC(dirEnt.path());
         if (!fourcc.empty()) {
-            item->getResource(0)->addOption(RESOURCE_OPTION_FOURCC,
-                fourcc);
+            item->getResource(0)->addOption(RESOURCE_OPTION_FOURCC, fourcc);
         }
     }
 #endif // HAVE_FFMPEG
 
+#ifdef HAVE_FFMPEGTHUMBNAILER
+    // Thumbnails for videos
+    if (itemCls == UPNP_CLASS_VIDEO_ITEM)
+        FfmpegThumbnailerHandler(context, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_VIDEO_ENABLED).fillMetadata(item);
+    else if (itemCls == UPNP_CLASS_IMAGE_ITEM)
+        FfmpegThumbnailerHandler(context, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_ENABLED).fillMetadata(item);
+#endif
+
     // Fanart for audio and video
-    if (startswith(mimetype, "video") || startswith(mimetype, "audio"))
+    if (itemCls == UPNP_CLASS_MUSIC_TRACK || itemCls == UPNP_CLASS_VIDEO_ITEM)
         FanArtHandler(context).fillMetadata(item);
 
     // Subtitles for videos
-    if (startswith(mimetype, "video"))
+    if (itemCls == UPNP_CLASS_VIDEO_ITEM)
         SubtitleHandler(context).fillMetadata(item);
 
     ResourceHandler(context).fillMetadata(item);
@@ -171,9 +180,9 @@ std::unique_ptr<MetadataHandler> MetadataHandler::createHandler(const std::share
     case CH_MATROSKA:
         return std::make_unique<MatroskaHandler>(context);
 #endif
-#if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
+#ifdef HAVE_FFMPEGTHUMBNAILER
     case CH_FFTH:
-        return std::make_unique<FfmpegHandler>(context);
+        return std::make_unique<FfmpegThumbnailerHandler>(context, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED);
 #endif
     case CH_FANART:
         return std::make_unique<FanArtHandler>(context);
@@ -192,7 +201,7 @@ std::string MetadataHandler::getMimeType() const
     return MIMETYPE_DEFAULT;
 }
 
-static constexpr std::array ch_keys = {
+static constexpr std::array chKeys = {
     std::pair(CH_DEFAULT, "Default"),
 #ifdef HAVE_LIBEXIF
     std::pair(CH_LIBEXIF, "LibExif"),
@@ -203,7 +212,7 @@ static constexpr std::array ch_keys = {
     std::pair(CH_TRANSCODE, "Transcode"),
     std::pair(CH_EXTURL, "Exturl"),
     std::pair(CH_MP4, "MP4"),
-#if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
+#ifdef HAVE_FFMPEGTHUMBNAILER
     std::pair(CH_FFTH, "FFmpegThumbnailer"),
 #endif
     std::pair(CH_FLAC, "Flac"),
@@ -218,18 +227,28 @@ static constexpr std::array ch_keys = {
 
 int MetadataHandler::remapContentHandler(const std::string& contHandler)
 {
-    auto ch_entry = std::find_if(ch_keys.begin(), ch_keys.end(), [contHandler](auto&& entry) { return contHandler == entry.second; });
-    if (ch_entry != ch_keys.end()) {
-        return ch_entry->first;
+    auto chEntry = std::find_if(chKeys.begin(), chKeys.end(), [contHandler](auto&& entry) { return contHandler == entry.second; });
+    if (chEntry != chKeys.end()) {
+        return chEntry->first;
     }
     return -1;
 }
 
 std::string MetadataHandler::mapContentHandler2String(int ch)
 {
-    auto ch_entry = std::find_if(ch_keys.begin(), ch_keys.end(), [ch](auto&& entry) { return ch == entry.first; });
-    if (ch_entry != ch_keys.end()) {
-        return ch_entry->second;
+    auto chEntry = std::find_if(chKeys.begin(), chKeys.end(), [ch](auto&& entry) { return ch == entry.first; });
+    if (chEntry != chKeys.end()) {
+        return chEntry->second;
     }
     return "Unknown";
 }
+
+metadata_fields_t MetadataHandler::remapMetaDataField(std::string_view fieldName)
+{
+    for (auto&& [f, s] : mt_names) {
+        if (s == fieldName) {
+            return f;
+        }
+    }
+    return M_MAX;
+}
