@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     taglib_handler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -32,20 +32,23 @@
 #ifdef HAVE_TAGLIB
 #include "taglib_handler.h" // API
 
-#include <taglib/aifffile.h>
-#include <taglib/apefile.h>
-#include <taglib/asffile.h>
-#include <taglib/attachedpictureframe.h>
-#include <taglib/flacfile.h>
-#include <taglib/id3v2tag.h>
-#include <taglib/mp4file.h>
-#include <taglib/mpegfile.h>
-#include <taglib/textidentificationframe.h>
-#include <taglib/tfilestream.h>
-#include <taglib/tiostream.h>
-#include <taglib/tpropertymap.h>
-#include <taglib/vorbisfile.h>
-#include <taglib/wavpackfile.h>
+#include <aifffile.h>
+#include <apefile.h>
+#include <asffile.h>
+#include <attachedpictureframe.h>
+#include <flacfile.h>
+#include <id3v2tag.h>
+#include <mp4file.h>
+#include <mpegfile.h>
+#include <oggflacfile.h>
+#include <opusfile.h>
+#include <speexfile.h>
+#include <textidentificationframe.h>
+#include <tfilestream.h>
+#include <tiostream.h>
+#include <tpropertymap.h>
+#include <vorbisfile.h>
+#include <wavpackfile.h>
 
 #include "cds_objects.h"
 #include "config/config_manager.h"
@@ -58,113 +61,115 @@ TagLibHandler::TagLibHandler(const std::shared_ptr<Context>& context)
 {
     entrySeparator = this->config->getOption(CFG_IMPORT_LIBOPTS_ENTRY_SEP);
     legacyEntrySeparator = this->config->getOption(CFG_IMPORT_LIBOPTS_ENTRY_LEGACY_SEP);
+    trimStringInPlace(legacyEntrySeparator);
+    if (legacyEntrySeparator.empty())
+        legacyEntrySeparator = "\n";
+    specialPropertyMap = this->config->getDictionaryOption(CFG_IMPORT_LIBOPTS_ID3_METADATA_TAGS_LIST);
 }
 
 void TagLibHandler::addField(metadata_fields_t field, const TagLib::File& file, const TagLib::Tag* tag, const std::shared_ptr<CdsItem>& item) const
 {
-    if (!tag)
-        return;
-
-    if (tag->isEmpty())
+    if (!tag || tag->isEmpty())
         return;
 
     auto sc = StringConverter::i2i(config); // sure is sure
 
-    TagLib::String val;
-    TagLib::StringList list;
-    std::string value;
-    unsigned int i;
-    bool checkLegacy = true;
+    std::vector<std::string> value;
+
+    auto propertyMap = std::map<metadata_fields_t, std::string> {
+        { M_ARTIST, "ARTIST" },
+        { M_ALBUMARTIST, "ALBUMARTIST" },
+        { M_COMPOSER, "COMPOSER" },
+        { M_CONDUCTOR, "CONDUCTOR" },
+        { M_GENRE, "GENRE" },
+        { M_ORCHESTRA, "ORCHESTRA" },
+    };
 
     switch (field) {
     case M_TITLE:
-        val = tag->title();
-        checkLegacy = false;
-        break;
-    case M_ARTIST:
-        val = tag->artist();
+        value.push_back(tag->title().to8Bit(true));
         break;
     case M_ALBUM:
-        val = tag->album();
-        checkLegacy = false;
+        value.push_back(tag->album().to8Bit(true));
         break;
     case M_DATE:
-    case M_UPNP_DATE:
-        i = tag->year();
+    case M_UPNP_DATE: {
+        unsigned int i = tag->year();
         if (i == 0)
             return;
-        value = fmt::format("{}-01-01", i);
-        break;
-    case M_GENRE:
-        val = tag->genre();
-        checkLegacy = false;
+        value.push_back(fmt::format("{}-01-01", i));
         break;
+    }
     case M_DESCRIPTION:
-        val = tag->comment();
-        checkLegacy = false;
+        value.push_back(tag->comment().to8Bit(true));
         break;
-    case M_TRACKNUMBER:
-        i = tag->track();
-        if (i == 0)
+    case M_TRACKNUMBER: {
+        std::uint32_t i = tag->track();
+        if (i == 0 || i > std::uint32_t(std::numeric_limits<int>::max()))
             return;
-        value = fmt::to_string(i);
-        item->setTrackNumber(int(i));
+        value.push_back(fmt::to_string(i));
+        item->setTrackNumber(i);
         break;
-    case M_PARTNUMBER:
-        list = file.properties()["DISCNUMBER"];
+    }
+    case M_PARTNUMBER: {
+        auto list = file.properties()["DISCNUMBER"];
         if (!list.isEmpty()) {
-            value = list[0].toCString(true);
-            item->setPartNumber(stoiString(value));
+            value.push_back(list[0].to8Bit(true));
         } else {
-            list = file.properties()["TPOS"];
-            if (list.isEmpty())
+            auto list2 = file.properties()["TPOS"];
+            if (list2.isEmpty())
                 return;
-            value = list[0].toCString(true);
-            item->setPartNumber(stoiString(value));
+            value.push_back(list2[0].to8Bit(true));
         }
+        item->setPartNumber(stoiString(value[0]));
         break;
-    case M_ALBUMARTIST:
+    }
+    default: {
+        auto it = propertyMap.find(field);
+        if (it == propertyMap.end())
+            return;
         // we have to use file.properties() instead of tag->properties()
         // because the latter returns incomplete properties
         // https://mail.kde.org/pipermail/taglib-devel/2015-May/002729.html
-        list = file.properties()["ALBUMARTIST"];
+        auto list = file.properties()[it->second];
         if (list.isEmpty())
             return;
-        val = list.toString(entrySeparator);
-        break;
-    case M_COMPOSER:
-        list = file.properties()["COMPOSER"];
-        if (list.isEmpty())
-            return;
-        val = list.toString(entrySeparator);
-        break;
-    case M_CONDUCTOR:
-        list = file.properties()["CONDUCTOR"];
-        if (list.isEmpty())
-            return;
-        val = list.toString(entrySeparator);
-        break;
-    case M_ORCHESTRA:
-        list = file.properties()["ORCHESTRA"];
-        if (list.isEmpty())
-            return;
-        val = list.toString(entrySeparator);
-        break;
-    default:
-        return;
+        for (auto&& entry : list) {
+            for (auto&& val : entry.split(legacyEntrySeparator))
+                value.push_back(val.to8Bit(true));
+        }
     }
-
-    if ((field != M_DATE) && (field != M_CREATION_DATE) && (field != M_TRACKNUMBER) && (field != M_PARTNUMBER)) {
-        if (!legacyEntrySeparator.empty() && checkLegacy)
-            val = val.split(legacyEntrySeparator).toString(entrySeparator);
-        value = val.toCString(true);
     }
 
-    value = trimString(value);
-
     if (!value.empty()) {
-        item->setMetadata(field, sc->convert(value));
-        //        log_debug("Setting metadata on item: {}, {}", field, sc->convert(value).c_str());
+        for (auto&& entry : value) {
+            trimStringInPlace(entry);
+            if (!entry.empty())
+                item->addMetaData(field, sc->convert(entry));
+        }
+        // [log_debug("Setting metadata on item: {} = {}", field, sc->convert(value).c_str());]
+    }
+}
+
+void TagLibHandler::addSpecialFields(const TagLib::File& file, const TagLib::Tag* tag, const std::shared_ptr<CdsItem>& item) const
+{
+    if (!tag || tag->isEmpty())
+        return;
+
+    auto sc = StringConverter::i2i(config); // sure is sure
+
+    for (auto&& [key, meta] : specialPropertyMap) {
+        auto list = file.properties()[key];
+        if (list.isEmpty())
+            return;
+        for (auto&& val : list) {
+            for (auto&& entrySeg : val.split(legacyEntrySeparator)) {
+                std::string entry = entrySeg.to8Bit(true);
+                trimStringInPlace(entry);
+                if (!entry.empty())
+                    item->addMetaData(meta, sc->convert(entry));
+            }
+        }
     }
 }
 
@@ -174,8 +179,10 @@ void TagLibHandler::populateGenericTags(const std::shared_ptr<CdsItem>& item, co
         return;
 
     const TagLib::Tag* tag = file.tag();
-    for (auto&& key : mt_keys)
-        addField(key.first, file, tag, item);
+    for (auto&& [field, key] : mt_keys)
+        addField(field, file, tag, item);
+
+    addSpecialFields(file, tag, item);
 
     const TagLib::AudioProperties* audioProps = file.audioProperties();
     if (!audioProps)
@@ -207,8 +214,8 @@ void TagLibHandler::populateGenericTags(const std::shared_ptr<CdsItem>& item, co
 
 void TagLibHandler::populateAuxTags(const std::shared_ptr<CdsItem>& item, const TagLib::PropertyMap& propertyMap, const std::unique_ptr<StringConverter>& sc) const
 {
-    auto aux_tags_list = config->getArrayOption(CFG_IMPORT_LIBOPTS_ID3_AUXDATA_TAGS_LIST);
-    for (auto&& desiredTag : aux_tags_list) {
+    auto auxTagsList = config->getArrayOption(CFG_IMPORT_LIBOPTS_ID3_AUXDATA_TAGS_LIST);
+    for (auto&& desiredTag : auxTagsList) {
         if (desiredTag.empty()) {
             continue;
         }
@@ -221,7 +228,7 @@ void TagLibHandler::populateAuxTags(const std::shared_ptr<CdsItem>& item, const
             auto val = property.toString(entrySeparator);
             if (!legacyEntrySeparator.empty())
                 val = val.split(legacyEntrySeparator).toString(entrySeparator);
-            std::string value(val.toCString(true));
+            std::string value(val.to8Bit(true));
             value = sc->convert(value);
             log_debug("Adding auxdata: {} with value {}", desiredTag.c_str(), value.c_str());
             item->setAuxData(desiredTag, value);
@@ -238,60 +245,60 @@ void TagLibHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
         return;
 
     auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
-    std::string content_type = getValueOrDefault(mappings, item->getMimeType());
+    std::string contentType = getValueOrDefault(mappings, item->getMimeType());
 
     auto fs = TagLib::FileStream(item->getLocation().c_str(), true); // true = Read only
 
-    if (content_type == CONTENT_TYPE_MP3) {
-        extractMP3(&fs, item);
-    } else if (content_type == CONTENT_TYPE_FLAC) {
-        extractFLAC(&fs, item);
-    } else if (content_type == CONTENT_TYPE_MP4) {
-        extractMP4(&fs, item);
-    } else if (content_type == CONTENT_TYPE_OGG) {
-        extractOgg(&fs, item);
-    } else if (content_type == CONTENT_TYPE_APE) {
-        extractAPE(&fs, item);
-    } else if (content_type == CONTENT_TYPE_WMA) {
-        extractASF(&fs, item);
-    } else if (content_type == CONTENT_TYPE_WAVPACK) {
-        extractWavPack(&fs, item);
-    } else if (content_type == CONTENT_TYPE_AIFF) {
-        extractAiff(&fs, item);
+    if (contentType == CONTENT_TYPE_MP3) {
+        extractMP3(fs, item);
+    } else if (contentType == CONTENT_TYPE_FLAC) {
+        extractFLAC(fs, item);
+    } else if (contentType == CONTENT_TYPE_MP4) {
+        extractMP4(fs, item);
+    } else if (contentType == CONTENT_TYPE_OGG) {
+        extractOgg(fs, item);
+    } else if (contentType == CONTENT_TYPE_APE) {
+        extractAPE(fs, item);
+    } else if (contentType == CONTENT_TYPE_WMA) {
+        extractASF(fs, item);
+    } else if (contentType == CONTENT_TYPE_WAVPACK) {
+        extractWavPack(fs, item);
+    } else if (contentType == CONTENT_TYPE_AIFF) {
+        extractAiff(fs, item);
     } else {
-        log_warning("TagLibHandler {}: Does not handle the {} content type", item->getLocation().c_str(), content_type.c_str());
+        log_warning("TagLibHandler {}: Does not handle the {} content type", item->getLocation().c_str(), contentType.c_str());
     }
     log_debug("TagLib handler done.");
 }
 
-bool TagLibHandler::isValidArtworkContentType(std::string_view art_mimetype)
+bool TagLibHandler::isValidArtworkContentType(std::string_view artMimetype)
 {
     // saw that simply "PNG" was used with some mp3's, so mimetype setting
     // was probably invalid
-    return art_mimetype.find('/') != std::string_view::npos;
+    return artMimetype.find('/') != std::string_view::npos;
 }
 
 std::string TagLibHandler::getContentTypeFromByteVector(const TagLib::ByteVector& data) const
 {
 #ifdef HAVE_MAGIC
-    auto art_mimetype = mime->bufferToMimeType(data.data(), data.size());
-    return art_mimetype.empty() ? MIMETYPE_DEFAULT : art_mimetype;
+    auto artMimetype = mime->bufferToMimeType(data.data(), data.size());
+    return artMimetype.empty() ? MIMETYPE_DEFAULT : artMimetype;
 #else
     return MIMETYPE_DEFAULT;
 #endif
 }
 
-void TagLibHandler::addArtworkResource(const std::shared_ptr<CdsItem>& item, const std::string& art_mimetype)
+void TagLibHandler::addArtworkResource(const std::shared_ptr<CdsItem>& item, const std::string& artMimetype)
 {
     // if we could not determine the mimetype, then there is no
     // point to add the resource - it's probably garbage
-    log_debug("Found artwork of type {} in file {}", art_mimetype.c_str(), item->getLocation().c_str());
+    log_debug("Found artwork of type {} in file {}", artMimetype.c_str(), item->getLocation().c_str());
 
-    if (art_mimetype != MIMETYPE_DEFAULT) {
+    if (artMimetype != MIMETYPE_DEFAULT) {
         auto resource = std::make_shared<CdsResource>(CH_ID3);
-        resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(art_mimetype));
+        resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(artMimetype));
         resource->addParameter(RESOURCE_CONTENT_TYPE, ID3_ALBUM_ART);
-        item->addResource(move(resource));
+        item->addResource(resource);
     }
 }
 
@@ -306,11 +313,11 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(const std::shared_ptr<Cds
         return nullptr;
 
     auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
-    std::string content_type = getValueOrDefault(mappings, item->getMimeType());
+    std::string contentType = getValueOrDefault(mappings, item->getMimeType());
 
     auto roStream = TagLib::FileStream(item->getLocation().c_str(), true); // Open read only
 
-    if (content_type == CONTENT_TYPE_MP3) {
+    if (contentType == CONTENT_TYPE_MP3) {
         // stream album art from MP3 file
         auto f = TagLib::MPEG::File(&roStream, TagLib::ID3v2::FrameFactory::instance());
 
@@ -331,7 +338,7 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(const std::shared_ptr<Cds
 
         return std::make_unique<MemIOHandler>(art->picture().data(), art->picture().size());
     }
-    if (content_type == CONTENT_TYPE_FLAC) {
+    if (contentType == CONTENT_TYPE_FLAC) {
         // stream album art from FLAC file
         auto f = TagLib::FLAC::File(&roStream, TagLib::ID3v2::FrameFactory::instance());
 
@@ -341,12 +348,12 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(const std::shared_ptr<Cds
         if (f.pictureList().isEmpty())
             throw_std_runtime_error("flac resource has no picture information");
 
-        TagLib::FLAC::Picture* pic = f.pictureList().front();
+        const TagLib::FLAC::Picture* pic = f.pictureList().front();
         const TagLib::ByteVector& data = pic->data();
 
         return std::make_unique<MemIOHandler>(data.data(), data.size());
     }
-    if (content_type == CONTENT_TYPE_MP4) {
+    if (contentType == CONTENT_TYPE_MP4) {
         // stream album art from MP4 file
         auto f = TagLib::MP4::File(&roStream);
 
@@ -375,7 +382,7 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(const std::shared_ptr<Cds
 
         return std::make_unique<MemIOHandler>(data.data(), data.size());
     }
-    if (content_type == CONTENT_TYPE_WMA) {
+    if (contentType == CONTENT_TYPE_WMA) {
         // stream album art from WMA file
         auto f = TagLib::ASF::File(&roStream);
 
@@ -398,16 +405,16 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(const std::shared_ptr<Cds
 
         return std::make_unique<MemIOHandler>(data.data(), data.size());
     }
-    if (content_type == CONTENT_TYPE_OGG) {
+    if (contentType == CONTENT_TYPE_OGG) {
         // stream album art from Ogg/Vorbis file
-        auto f = TagLib::Ogg::Vorbis::File(&roStream);
+        auto f = getOggFile(roStream);
 
-        if (!f.isValid() || !f.tag())
-            throw_std_runtime_error("Could not open vorbis file: {}", item->getLocation().c_str());
+        if (!f || !f->isValid() || !f->tag())
+            throw_std_runtime_error("Could not open OGG file: {}", item->getLocation().c_str());
 
-        const TagLib::List<TagLib::FLAC::Picture*> picList = f.tag()->pictureList();
+        const TagLib::List<TagLib::FLAC::Picture*> picList = reinterpret_cast<TagLib::Ogg::XiphComment*>(f->tag())->pictureList();
         if (picList.isEmpty())
-            throw_std_runtime_error("vorbis file has no picture information");
+            throw_std_runtime_error("OGG file has no picture information");
 
         const TagLib::FLAC::Picture* pic = picList.front();
         const TagLib::ByteVector& data = pic->data();
@@ -415,12 +422,12 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(const std::shared_ptr<Cds
         return std::make_unique<MemIOHandler>(data.data(), data.size());
     }
 
-    throw_std_runtime_error("Unsupported content_type: {}", content_type.c_str());
+    throw_std_runtime_error("Unsupported content_type: {}", contentType.c_str());
 }
 
-void TagLibHandler::extractMP3(TagLib::IOStream* roStream, const std::shared_ptr<CdsItem>& item) const
+void TagLibHandler::extractMP3(TagLib::IOStream& roStream, const std::shared_ptr<CdsItem>& item) const
 {
-    auto mp3 = TagLib::MPEG::File(roStream, TagLib::ID3v2::FrameFactory::instance());
+    auto mp3 = TagLib::MPEG::File(&roStream, TagLib::ID3v2::FrameFactory::instance());
     if (!mp3.isValid()) {
         log_info("TagLibHandler {}: does not appear to be a valid mp3 file", item->getLocation().c_str());
         return;
@@ -438,8 +445,8 @@ void TagLibHandler::extractMP3(TagLib::IOStream* roStream, const std::shared_ptr
     // http://id3.org/id3v2.4.0-frames "4.2.6. User defined text information frame"
     bool hasTXXXFrames = frameListMap.contains("TXXX");
 
-    std::vector<std::string> aux_tags_list = config->getArrayOption(CFG_IMPORT_LIBOPTS_ID3_AUXDATA_TAGS_LIST);
-    for (auto&& desiredFrame : aux_tags_list) {
+    std::vector<std::string> auxTagsList = config->getArrayOption(CFG_IMPORT_LIBOPTS_ID3_AUXDATA_TAGS_LIST);
+    for (auto&& desiredFrame : auxTagsList) {
         if (desiredFrame.empty()) {
             continue;
         }
@@ -449,23 +456,26 @@ void TagLibHandler::extractMP3(TagLib::IOStream* roStream, const std::shared_ptr
             if (frameList.isEmpty())
                 continue;
 
-            std::string value;
+            std::vector<std::string> content;
             for (auto&& frame : frameList) {
                 auto textFrame = dynamic_cast<const TagLib::ID3v2::TextIdentificationFrame*>(frame);
                 if (!textFrame)
                     continue;
-                auto frameContents = textFrame->fieldList().toString(entrySeparator);
-                if (!value.empty())
-                    value += entrySeparator;
-                if (!legacyEntrySeparator.empty())
-                    frameContents = frameContents.split(legacyEntrySeparator).toString(entrySeparator);
-                value += sc->convert(frameContents.toCString(true));
+                for (auto&& field : textFrame->fieldList()) {
+                    if (legacyEntrySeparator.empty())
+                        content.push_back(sc->convert(field.to8Bit(true)));
+                    else
+                        for (auto&& val : field.split(legacyEntrySeparator))
+                            content.push_back(sc->convert(val.to8Bit(true)));
+                }
+            }
+            if (!content.empty()) {
+                log_debug("Adding auxdata: {} with value '{}'", desiredFrame, fmt::to_string(fmt::join(content, entrySeparator)));
+                item->setAuxData(desiredFrame, fmt::format("{}", fmt::join(content, entrySeparator)));
             }
-            log_debug("Adding auxdata: {} with value {}", desiredFrame.c_str(), value.c_str());
-            item->setAuxData(desiredFrame, value);
         } else if (hasTXXXFrames && startswith(desiredFrame, "TXXX:")) {
             auto&& frameList = frameListMap["TXXX"];
-            //log_debug("TXXX Frame list has {} elements", frameList.size());
+            // log_debug("TXXX Frame list has {} elements", frameList.size());
 
             std::string desiredSubTag = desiredFrame.substr(5);
             if (desiredSubTag.empty())
@@ -475,28 +485,27 @@ void TagLibHandler::extractMP3(TagLib::IOStream* roStream, const std::shared_ptr
                 const auto textFrame = dynamic_cast<const TagLib::ID3v2::TextIdentificationFrame*>(frame);
                 if (!textFrame)
                     continue;
-                std::string content;
+                std::vector<std::string> content;
                 std::string subTag;
                 for (auto&& field : textFrame->fieldList()) {
                     if (subTag.empty()) {
                         // first element is subTag name
-                        subTag = field.toCString(true);
+                        subTag = sc->convert(field.to8Bit(true));
+                    } else if (legacyEntrySeparator.empty()) {
+                        content.push_back(sc->convert(field.to8Bit(true)));
                     } else {
-                        content = fmt::format("{}{}{}", content, field.toCString(true), entrySeparator);
+                        for (auto&& val : field.split(legacyEntrySeparator))
+                            content.push_back(sc->convert(val.to8Bit(true)));
                     }
                 }
+                log_debug("TXXX Tag: {}", subTag);
 
-                // remove entrySeparator at the end again
-                if (content.length() > entrySeparator.length())
-                    content = content.substr(0, content.length() - entrySeparator.length());
-                // log_debug("TXXX Tag: {}", subTag.c_str());
+                if (desiredSubTag == subTag && !content.empty()) {
+                    if (content[0] == subTag)
+                        content.erase(content.begin()); // Avoid leading tag for options unknown to taglib
 
-                if (desiredSubTag == subTag) {
-                    if (content.substr(0, subTag.length()) == subTag)
-                        content = content.substr(subTag.length() + 1); // Avoid leading tag for options unknown to taglib
-
-                    log_debug("Adding auxdata: '{}' with value '{}'", desiredFrame, content);
-                    item->setAuxData(desiredFrame, content);
+                    log_debug("Adding auxdata: '{}' with value '{}'", desiredFrame, fmt::to_string(fmt::join(content, entrySeparator)));
+                    item->setAuxData(desiredFrame, fmt::format("{}", fmt::join(content, entrySeparator)));
                     break;
                 }
             }
@@ -511,52 +520,74 @@ void TagLibHandler::extractMP3(TagLib::IOStream* roStream, const std::shared_ptr
         }
 
         auto pic = art->picture();
-        std::string art_mimetype = sc->convert(art->mimeType().toCString(true));
-        if (!isValidArtworkContentType(art_mimetype)) {
-            art_mimetype = getContentTypeFromByteVector(pic);
+        std::string artMimetype = sc->convert(art->mimeType().to8Bit(true));
+        if (!isValidArtworkContentType(artMimetype)) {
+            artMimetype = getContentTypeFromByteVector(pic);
         }
 
-        addArtworkResource(item, art_mimetype);
+        addArtworkResource(item, artMimetype);
     }
 }
 
-void TagLibHandler::extractOgg(TagLib::IOStream* roStream, const std::shared_ptr<CdsItem>& item) const
+std::unique_ptr<TagLib::File> TagLibHandler::getOggFile(TagLib::IOStream& ioStream)
 {
-    auto vorbis = TagLib::Ogg::Vorbis::File(roStream);
+    if (TagLib::Ogg::Vorbis::File::isSupported(&ioStream)) {
+        return std::make_unique<TagLib::Ogg::Vorbis::File>(&ioStream);
+    }
 
-    if (!vorbis.isValid()) {
+    if (TagLib::Ogg::Opus::File::isSupported(&ioStream)) {
+        return std::make_unique<TagLib::Ogg::Opus::File>(&ioStream);
+    }
+
+    if (TagLib::Ogg::Speex::File::isSupported(&ioStream)) {
+        return std::make_unique<TagLib::Ogg::Speex::File>(&ioStream);
+    }
+
+    if (TagLib::Ogg::FLAC::File::isSupported(&ioStream)) {
+        return std::make_unique<TagLib::Ogg::FLAC::File>(&ioStream);
+    }
+
+    log_warning("Could not match supported Taglib OGG File for {}", ioStream.name());
+    return nullptr;
+}
+
+void TagLibHandler::extractOgg(TagLib::IOStream& roStream, const std::shared_ptr<CdsItem>& item) const
+{
+    auto oggFile = getOggFile(roStream);
+
+    if (!oggFile || !oggFile->isValid()) {
         log_info("TagLibHandler {}: does not appear to be a valid ogg file", item->getLocation().c_str());
         return;
     }
-    populateGenericTags(item, vorbis);
+    populateGenericTags(item, *oggFile);
 
-    if (!vorbis.tag())
+    if (!oggFile->tag())
         return;
 
     auto sc = StringConverter::i2i(config);
-    auto propertyMap = vorbis.properties();
+    auto propertyMap = oggFile->properties();
     populateAuxTags(item, propertyMap, sc);
 
     // Vorbis uses the FLAC binary picture structure...
     // https://wiki.xiph.org/VorbisComment#Cover_art
     // The unofficial COVERART field is not supported.
-    const TagLib::List<TagLib::FLAC::Picture*> picList = vorbis.tag()->pictureList();
+    const TagLib::List<TagLib::FLAC::Picture*> picList = reinterpret_cast<TagLib::Ogg::XiphComment*>(oggFile->tag())->pictureList();
     if (picList.isEmpty())
         return;
 
     const TagLib::FLAC::Picture* pic = picList.front();
     const TagLib::ByteVector& data = pic->data();
 
-    std::string art_mimetype = sc->convert(pic->mimeType().toCString(true));
-    if (!isValidArtworkContentType(art_mimetype)) {
-        art_mimetype = getContentTypeFromByteVector(data);
+    std::string artMimetype = sc->convert(pic->mimeType().to8Bit(true));
+    if (!isValidArtworkContentType(artMimetype)) {
+        artMimetype = getContentTypeFromByteVector(data);
     }
-    addArtworkResource(item, art_mimetype);
+    addArtworkResource(item, artMimetype);
 }
 
-void TagLibHandler::extractASF(TagLib::IOStream* roStream, const std::shared_ptr<CdsItem>& item) const
+void TagLibHandler::extractASF(TagLib::IOStream& roStream, const std::shared_ptr<CdsItem>& item) const
 {
-    auto asf = TagLib::ASF::File(roStream);
+    auto asf = TagLib::ASF::File(&roStream);
 
     if (!asf.isValid()) {
         log_info("TagLibHandler {}: does not appear to be a valid asf/wma file", item->getLocation().c_str());
@@ -585,17 +616,17 @@ void TagLibHandler::extractASF(TagLib::IOStream* roStream, const std::shared_ptr
         if (!wmpic.isValid())
             return;
 
-        std::string art_mimetype = sc->convert(wmpic.mimeType().toCString(true));
-        if (!isValidArtworkContentType(art_mimetype)) {
-            art_mimetype = getContentTypeFromByteVector(wmpic.picture());
+        std::string artMimetype = sc->convert(wmpic.mimeType().to8Bit(true));
+        if (!isValidArtworkContentType(artMimetype)) {
+            artMimetype = getContentTypeFromByteVector(wmpic.picture());
         }
-        addArtworkResource(item, art_mimetype);
+        addArtworkResource(item, artMimetype);
     }
 }
 
-void TagLibHandler::extractFLAC(TagLib::IOStream* roStream, const std::shared_ptr<CdsItem>& item) const
+void TagLibHandler::extractFLAC(TagLib::IOStream& roStream, const std::shared_ptr<CdsItem>& item) const
 {
-    auto flac = TagLib::FLAC::File(roStream, TagLib::ID3v2::FrameFactory::instance());
+    auto flac = TagLib::FLAC::File(&roStream, TagLib::ID3v2::FrameFactory::instance());
 
     if (!flac.isValid()) {
         log_info("TagLibHandler {}: does not appear to be a valid flac file", item->getLocation().c_str());
@@ -621,16 +652,16 @@ void TagLibHandler::extractFLAC(TagLib::IOStream* roStream, const std::shared_pt
     const TagLib::FLAC::Picture* pic = flac.pictureList().front();
     const TagLib::ByteVector& data = pic->data();
 
-    std::string art_mimetype = sc->convert(pic->mimeType().toCString(true));
-    if (!isValidArtworkContentType(art_mimetype)) {
-        art_mimetype = getContentTypeFromByteVector(data);
+    std::string artMimetype = sc->convert(pic->mimeType().to8Bit(true));
+    if (!isValidArtworkContentType(artMimetype)) {
+        artMimetype = getContentTypeFromByteVector(data);
     }
-    addArtworkResource(item, art_mimetype);
+    addArtworkResource(item, artMimetype);
 }
 
-void TagLibHandler::extractAPE(TagLib::IOStream* roStream, const std::shared_ptr<CdsItem>& item) const
+void TagLibHandler::extractAPE(TagLib::IOStream& roStream, const std::shared_ptr<CdsItem>& item) const
 {
-    auto ape = TagLib::APE::File(roStream);
+    auto ape = TagLib::APE::File(&roStream);
 
     if (!ape.isValid()) {
         log_info("TagLibHandler {}: does not appear to be a valid APE file", item->getLocation().c_str());
@@ -650,9 +681,9 @@ void TagLibHandler::extractAPE(TagLib::IOStream* roStream, const std::shared_ptr
     }
 }
 
-void TagLibHandler::extractWavPack(TagLib::IOStream* roStream, const std::shared_ptr<CdsItem>& item) const
+void TagLibHandler::extractWavPack(TagLib::IOStream& roStream, const std::shared_ptr<CdsItem>& item) const
 {
-    auto wavpack = TagLib::WavPack::File(roStream);
+    auto wavpack = TagLib::WavPack::File(&roStream);
 
     if (!wavpack.isValid()) {
         log_info("TagLibHandler {}: does not appear to be a valid WavPack file", item->getLocation().c_str());
@@ -672,9 +703,9 @@ void TagLibHandler::extractWavPack(TagLib::IOStream* roStream, const std::shared
     }
 }
 
-void TagLibHandler::extractMP4(TagLib::IOStream* roStream, const std::shared_ptr<CdsItem>& item) const
+void TagLibHandler::extractMP4(TagLib::IOStream& roStream, const std::shared_ptr<CdsItem>& item) const
 {
-    auto mp4 = TagLib::MP4::File(roStream);
+    auto mp4 = TagLib::MP4::File(&roStream);
 
     if (!mp4.isValid()) {
         log_info("TagLibHandler {}: does not appear to be a valid mp4 file", item->getLocation().c_str());
@@ -684,7 +715,7 @@ void TagLibHandler::extractMP4(TagLib::IOStream* roStream, const std::shared_ptr
     populateGenericTags(item, mp4);
 
     if (!mp4.hasMP4Tag()) {
-        log_info("TagLibHandler {}: mp4 file has no tag information", item->getLocation().c_str());
+        log_debug("TagLibHandler {}: mp4 file has no tag information", item->getLocation().c_str());
         return;
     }
 
@@ -708,10 +739,10 @@ void TagLibHandler::extractMP4(TagLib::IOStream* roStream, const std::shared_ptr
             return;
         }
 
-        auto& coverArt = coverArtList.front();
-        auto art_mimetype = getContentTypeFromByteVector(coverArt.data());
-        if (!art_mimetype.empty()) {
-            addArtworkResource(item, art_mimetype);
+        const auto& coverArt = coverArtList.front();
+        auto artMimetype = getContentTypeFromByteVector(coverArt.data());
+        if (!artMimetype.empty()) {
+            addArtworkResource(item, artMimetype);
         }
     } else {
         log_debug("TagLibHandler {}: mp4 file has no 'covr' item",
@@ -719,9 +750,9 @@ void TagLibHandler::extractMP4(TagLib::IOStream* roStream, const std::shared_ptr
     }
 }
 
-void TagLibHandler::extractAiff(TagLib::IOStream* roStream, const std::shared_ptr<CdsItem>& item) const
+void TagLibHandler::extractAiff(TagLib::IOStream& roStream, const std::shared_ptr<CdsItem>& item) const
 {
-    auto aiff = TagLib::RIFF::AIFF::File(roStream);
+    auto aiff = TagLib::RIFF::AIFF::File(&roStream);
 
     if (!aiff.isValid()) {
         log_info("TagLibHandler {}: does not appear to be a valid AIFF file", item->getLocation().c_str());
