@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     request_handler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -31,13 +31,12 @@
 
 #include "request_handler.h" // API
 
-#include <numeric>
-#include <vector>
-
 #include "content/content_manager.h"
 #include "database/database.h"
 #include "util/tools.h"
 
+#include <fmt/core.h>
+
 RequestHandler::RequestHandler(std::shared_ptr<ContentManager> content)
     : content(std::move(content))
     , context(this->content->getContext())
@@ -48,53 +47,46 @@ RequestHandler::RequestHandler(std::shared_ptr<ContentManager> content)
 {
 }
 
-void RequestHandler::splitUrl(const char* url, char separator, std::string& path, std::string& parameters)
+std::pair<std::string_view, std::string_view> RequestHandler::splitUrl(std::string_view url, char separator)
 {
-    const auto url_s = std::string { url };
-    const auto i1 = size_t { [=]() {
-        if (separator == '/')
-            return url_s.rfind(separator);
-        if (separator == '?')
-            return url_s.find(separator);
+    std::size_t splitPos;
+    switch (separator) {
+    case '/':
+        splitPos = url.rfind('/');
+        break;
+    case '?':
+        splitPos = url.find('?');
+        break;
+    default:
         throw_std_runtime_error("Forbidden separator: {}", separator);
-    }() };
-
-    if (i1 == std::string::npos) {
-        path = url_s;
-        parameters.clear();
-    } else {
-        parameters = url_s.substr(i1 + 1);
-        path = url_s.substr(0, i1);
     }
+
+    if (splitPos == std::string_view::npos)
+        return { url, std::string_view() };
+
+    return { url.substr(0, splitPos), url.substr(splitPos + 1) };
 }
 
-std::string RequestHandler::joinUrl(const std::vector<std::string>& components, bool addToEnd, const std::string& separator)
+std::string RequestHandler::joinUrl(const std::vector<std::string>& components, bool addToEnd, std::string_view separator)
 {
-    return !components.empty()
-        ? (std::accumulate(std::next(components.begin()), components.end(), separator + components[0], [=](auto&& a, auto&& b) { return a + separator + b; }) + (addToEnd ? separator : ""))
-        : "/";
+    if (components.empty())
+        return std::string(separator);
+    return fmt::format("{}{}{}", separator, fmt::join(components, separator), (addToEnd ? separator : ""));
 }
 
-std::map<std::string, std::string> RequestHandler::parseParameters(const char* filename, const char* baseLink)
+std::map<std::string, std::string> RequestHandler::parseParameters(std::string_view filename, std::string_view baseLink)
 {
-    std::map<std::string, std::string> params;
-
-    const auto parameters = std::string(filename + strlen(baseLink));
-    dictDecodeSimple(parameters, &params);
-    log_debug("filename: {} -> parameters: {}", filename, parameters.c_str());
-
-    return params;
+    const auto parameters = filename.substr(baseLink.size());
+    return pathToMap(parameters);
 }
 
-std::shared_ptr<CdsObject> RequestHandler::getObjectById(std::map<std::string, std::string> params)
+std::shared_ptr<CdsObject> RequestHandler::loadObject(const std::map<std::string, std::string>& params) const
 {
     auto it = params.find("object_id");
     if (it == params.end()) {
-        //log_error("object_id not found in url");
-        throw_std_runtime_error("getInfo: object_id not found");
+        throw_std_runtime_error("loadObject: object_id not found");
     }
 
-    int objectID = std::stoi(it->second);
-    //log_debug("load objectID: {}", objectID);
+    int objectID = stoiString(it->second);
     return database->loadObject(objectID);
 }
