@@ -33,7 +33,6 @@
 
 #ifdef HAVE_CURL
 #include <curl/curl.h>
-#include <iostream>
 #endif
 
 #include <upnpconfig.h>
@@ -41,7 +40,6 @@
 #include <upnptools.h>
 #endif
 
-#include <chrono>
 #include <thread>
 
 #include "config/config_manager.h"
@@ -49,7 +47,6 @@
 #include "database/database.h"
 #include "device_description_handler.h"
 #include "file_request_handler.h"
-#include "serve_request_handler.h"
 #include "util/mime.h"
 #include "util/upnp_clients.h"
 #include "web/pages.h"
@@ -84,14 +81,12 @@ void Server::init()
     timer->run();
     database = Database::createInstance(config, mime, timer);
     config->updateConfigFromDatabase(database);
-    session_manager = std::make_shared<web::SessionManager>(config, timer);
+    session_manager = std::make_shared<Web::SessionManager>(config, timer);
     context = std::make_shared<Context>(config, clients, mime, database, self, session_manager);
 
     content = std::make_shared<ContentManager>(context, self, timer);
 }
 
-Server::~Server() { log_debug("Server destroyed"); }
-
 void Server::run()
 {
     log_debug("Starting...");
@@ -114,27 +109,32 @@ void Server::run()
         iface = ipToInterface(ip);
 
     if (!ip.empty() && iface.empty())
-        throw_std_runtime_error("Could not find IP: {}", ip.c_str());
+        throw_std_runtime_error("Could not find IP: {}", ip);
 
     // check webroot directory
-    std::string web_root = config->getOption(CFG_SERVER_WEBROOT);
-    if (web_root.empty()) {
-        throw_std_runtime_error("Invalid web server root directory {}", web_root);
+    std::string webRoot = config->getOption(CFG_SERVER_WEBROOT);
+    if (webRoot.empty()) {
+        throw_std_runtime_error("Invalid web server root directory {}", webRoot);
     }
 
-    auto ret = startupInterface(iface, in_port_t(config->getIntOption(CFG_SERVER_PORT)));
+    auto configPort = in_port_t(config->getIntOption(CFG_SERVER_PORT));
+    auto ret = startupInterface(iface, configPort);
     if (ret != UPNP_E_SUCCESS) {
-        throw UpnpException(ret, fmt::format("run: UpnpInit failed {} {}", iface, port));
+        throw UpnpException(ret, fmt::format("UpnpInit failed {} {}", iface, port));
     }
 
-    ret = UpnpSetWebServerRootDir(web_root.c_str());
+    if (configPort > 0 && port != configPort) {
+        throw UpnpException(ret, fmt::format("LibUPnP failed to bind to request port! Bound to {}, requested: {}", port, configPort));
+    }
+
+    ret = UpnpSetWebServerRootDir(webRoot.c_str());
     if (ret != UPNP_E_SUCCESS) {
-        throw UpnpException(ret, fmt::format("run: UpnpSetWebServerRootDir failed {}", web_root));
+        throw UpnpException(ret, fmt::format("UpnpSetWebServerRootDir failed {}", webRoot));
     }
 
-    log_debug("webroot: {}", web_root.c_str());
+    log_debug("webroot: {}", webRoot);
 
-    log_debug("Setting virtual dir to: {}", virtual_directory.c_str());
+    log_debug("Setting virtual dir to: {}", virtual_directory);
     ret = UpnpAddVirtualDir(virtual_directory.c_str(), this, nullptr);
     if (ret != UPNP_E_SUCCESS) {
         throw UpnpException(ret, fmt::format("run: UpnpAddVirtualDir failed {}", virtual_directory));
@@ -156,15 +156,15 @@ void Server::run()
     std::ostringstream buf;
     desc->print(buf, "", 0);
     std::string deviceDescription = buf.str();
-    //log_debug("Device Description: {}", deviceDescription.c_str());
+    // log_debug("Device Description: {}", deviceDescription.c_str());
 
     log_debug("Registering with UPnP...");
     ret = UpnpRegisterRootDevice2(
         UPNPREG_BUF_DESC,
         deviceDescription.c_str(),
-        size_t(deviceDescription.length()) + 1,
+        deviceDescription.length() + 1,
         true,
-        handleUpnpRootDeviceEventCallback,
+        [](auto eventType, auto event, auto cookie) { return static_cast<Server*>(cookie)->handleUpnpRootDeviceEvent(eventType, event); },
         this,
         &rootDeviceHandle);
     if (ret != UPNP_E_SUCCESS) {
@@ -172,7 +172,7 @@ void Server::run()
     }
 
     ret = UpnpRegisterClient(
-        handleUpnpClientEventCallback,
+        [](auto eventType, auto event, auto cookie) { return static_cast<Server*>(cookie)->handleUpnpClientEvent(eventType, event); },
         this,
         &clientHandle);
     if (ret != UPNP_E_SUCCESS) {
@@ -180,32 +180,54 @@ void Server::run()
     }
 
     log_debug("Creating ContentDirectoryService");
-    cds = std::make_unique<ContentDirectoryService>(context, xmlbuilder.get(), rootDeviceHandle,
+    cds = std::make_unique<ContentDirectoryService>(context, xmlbuilder, rootDeviceHandle,
         config->getIntOption(CFG_SERVER_UPNP_TITLE_AND_DESC_STRING_LIMIT));
 
     log_debug("Creating ConnectionManagerService");
-    cmgr = std::make_unique<ConnectionManagerService>(context, xmlbuilder.get(), rootDeviceHandle);
+    cmgr = std::make_unique<ConnectionManagerService>(context, xmlbuilder, rootDeviceHandle);
 
     log_debug("Creating MRRegistrarService");
-    mrreg = std::make_unique<MRRegistrarService>(context, xmlbuilder.get(), rootDeviceHandle);
+    mrreg = std::make_unique<MRRegistrarService>(context, xmlbuilder, rootDeviceHandle);
 
     // The advertisement will be sent by LibUPnP every (A/2)-30 seconds, and will have a cache-control max-age of A where A is
     // the value configured here. Ex: A value of 62 will result in an SSDP advertisement being sent every second.
-    log_debug("Sending UPnP Alive advertisements every {} seconds", (aliveAdvertisementInterval / 2) - 30);
+    log_info("Will send UPnP Alive advertisements every {} seconds", (aliveAdvertisementInterval / 2) - 30);
     ret = UpnpSendAdvertisement(rootDeviceHandle, aliveAdvertisementInterval);
     if (ret != UPNP_E_SUCCESS) {
         throw UpnpException(ret, fmt::format("run: UpnpSendAdvertisement {} failed", aliveAdvertisementInterval));
     }
 
+    UpnpSetHostValidateCallback(
+        [](auto host, auto cookie) -> int {
+            auto hostStr = std::string(host);
+            auto ip = std::string(UpnpGetServerIpAddress());
+            auto ip6 = std::string(UpnpGetServerIp6Address());
+            auto ip6gla = std::string(UpnpGetServerUlaGuaIp6Address());
+
+            if (hostStr.find(ip) != std::string::npos || hostStr.find(ip6) != std::string::npos || hostStr.find(ip6gla) != std::string::npos) {
+                return UPNP_E_SUCCESS;
+            }
+
+            auto virtualURL = static_cast<Server*>(cookie)->getVirtualUrl();
+            if (!virtualURL.empty() && virtualURL.find(host) != std::string::npos) {
+                return UPNP_E_SUCCESS;
+            }
+            log_warning("Rejected attempt to load host '{}' as it does not match configured virtualURL: '{}'. "
+                        "See https://docs.gerbera.io/en/stable/config-server.html#virtualurl",
+                host, static_cast<Server*>(cookie)->config->getOption(CFG_VIRTUAL_URL));
+            return UPNP_E_BAD_HTTPMSG;
+        },
+        this);
+
     std::string url = config->getOption(CFG_VIRTUAL_URL);
     if (url.empty()) {
         url = renderWebUri(ip, port);
     }
-    if (url.find("http") != 0) { // url does not start with http
+    if (!startswith(url, "http")) { // url does not start with http
         url = fmt::format("http://{}", url);
     }
     writeBookmark(url);
-    log_info("The Web UI can be reached by following this link: {}/", url);
+    log_info("The Web UI can be reached by following this link: {}", url);
 }
 
 int Server::startupInterface(const std::string& iface, in_port_t inPort)
@@ -215,19 +237,21 @@ int Server::startupInterface(const std::string& iface, in_port_t inPort)
     const char* ifName = iface.empty() ? nullptr : iface.c_str();
 
     int ret = UPNP_E_INIT_FAILED;
-    for (size_t attempt = 0; ret != UPNP_E_SUCCESS; attempt++) {
+    for (std::size_t attempt = 0; attempt < 4; attempt++) {
         ret = UpnpInit2(ifName, inPort);
-        if (ret != UPNP_E_SUCCESS) {
-            if (attempt > 3) {
-                throw UpnpException(ret, fmt::format("run: UpnpInit failed with {} {}", ifName, inPort));
-            }
+        if (ret == UPNP_E_SUCCESS)
+            break;
+
 #ifdef UPNP_HAVE_TOOLS
-            log_warning("UPnP Init {}:{} failed: {} ({}). Retrying in {} seconds...", ifName, inPort, UpnpGetErrorMessage(ret), ret, attempt + 1);
+        log_warning("UPnP Init {}:{} failed: {} ({}). Retrying in {} seconds...", ifName, inPort, UpnpGetErrorMessage(ret), ret, attempt + 1);
 #else
-            log_warning("UPnP Init {}:{} failed: ({}). Retrying in {} seconds...", ifName, inPort, ret, attempt + 1);
+        log_warning("UPnP Init {}:{} failed: ({}). Retrying in {} seconds...", ifName, inPort, ret, attempt + 1);
 #endif
-            std::this_thread::sleep_for(std::chrono::seconds(attempt + 1));
-        }
+        std::this_thread::sleep_for(std::chrono::seconds(attempt + 1));
+    }
+
+    if (ret != UPNP_E_SUCCESS) {
+        throw UpnpException(ret, fmt::format("run: UpnpInit failed with {} {}", ifName, inPort));
     }
 
     port = UpnpGetServerPort();
@@ -267,16 +291,16 @@ void Server::writeBookmark(const std::string& addr)
 
     fs::path path = config->getOption(CFG_SERVER_BOOKMARK_FILE);
     log_debug("Writing bookmark file to: {}", path.c_str());
-    writeTextFile(path, data);
+    GrbFile(std::move(path)).writeTextFile(data);
 }
 
 void Server::emptyBookmark()
 {
-    const std::string data = "<html><body><h1>Gerbera Media Server is not running.</h1><p>Please start it and try again.</p></body></html>";
+    const std::string_view data = "<html><body><h1>Gerbera Media Server is not running.</h1><p>Please start it and try again.</p></body></html>";
 
     fs::path path = config->getOption(CFG_SERVER_BOOKMARK_FILE);
     log_debug("Clearing bookmark file at: {}", path.c_str());
-    writeTextFile(path, data);
+    GrbFile(std::move(path)).writeTextFile(data);
 }
 
 std::string Server::getVirtualUrl() const
@@ -335,15 +359,12 @@ void Server::shutdown()
     timer->shutdown();
     timer = nullptr;
 
+    context = nullptr;
+
     mime = nullptr;
     clients = nullptr;
 }
 
-int Server::handleUpnpRootDeviceEventCallback(Upnp_EventType eventType, const void* event, void* cookie)
-{
-    return static_cast<Server*>(cookie)->handleUpnpRootDeviceEvent(eventType, event);
-}
-
 int Server::handleUpnpRootDeviceEvent(Upnp_EventType eventType, const void* event)
 {
     int ret = UPNP_E_SUCCESS; // general purpose return code
@@ -361,11 +382,11 @@ int Server::handleUpnpRootDeviceEvent(Upnp_EventType eventType, const void* even
     case UPNP_CONTROL_ACTION_REQUEST:
         log_debug("UPNP_CONTROL_ACTION_REQUEST");
         try {
-            auto request = std::make_unique<ActionRequest>(context, static_cast<UpnpActionRequest*>(const_cast<void*>(event)));
+            auto request = ActionRequest(context, static_cast<UpnpActionRequest*>(const_cast<void*>(event)));
             routeActionRequest(request);
-            request->update();
-        } catch (const UpnpException& upnp_e) {
-            ret = upnp_e.getErrorCode();
+            request.update();
+        } catch (const UpnpException& upnpE) {
+            ret = upnpE.getErrorCode();
             UpnpActionRequest_set_ErrCode(static_cast<UpnpActionRequest*>(const_cast<void*>(event)), ret);
         } catch (const std::runtime_error& e) {
             log_info("Exception: {}", e.what());
@@ -377,9 +398,9 @@ int Server::handleUpnpRootDeviceEvent(Upnp_EventType eventType, const void* even
         try {
             auto request = std::make_unique<SubscriptionRequest>(static_cast<UpnpSubscriptionRequest*>(const_cast<void*>(event)));
             routeSubscriptionRequest(request);
-        } catch (const UpnpException& upnp_e) {
-            log_warning("Subscription exception: {}", upnp_e.what());
-            ret = upnp_e.getErrorCode();
+        } catch (const UpnpException& upnpE) {
+            log_warning("Subscription exception: {}", upnpE.what());
+            ret = upnpE.getErrorCode();
         }
         break;
 
@@ -394,11 +415,6 @@ int Server::handleUpnpRootDeviceEvent(Upnp_EventType eventType, const void* even
     return ret;
 }
 
-int Server::handleUpnpClientEventCallback(Upnp_EventType eventType, const void* event, void* cookie)
-{
-    return static_cast<Server*>(cookie)->handleUpnpClientEvent(eventType, event);
-}
-
 int Server::handleUpnpClientEvent(Upnp_EventType eventType, const void* event)
 {
     // check parameters
@@ -410,10 +426,10 @@ int Server::handleUpnpClientEvent(Upnp_EventType eventType, const void* event)
     switch (eventType) {
     case UPNP_DISCOVERY_ADVERTISEMENT_ALIVE:
     case UPNP_DISCOVERY_SEARCH_RESULT: {
-        auto d_event = reinterpret_cast<const UpnpDiscovery*>(event);
-        const char* userAgent = UpnpDiscovery_get_Os_cstr(d_event);
-        const struct sockaddr_storage* destAddr = UpnpDiscovery_get_DestAddr(d_event);
-        const char* location = UpnpDiscovery_get_Location_cstr(d_event);
+        auto dEvent = static_cast<const UpnpDiscovery*>(event);
+        const char* userAgent = UpnpDiscovery_get_Os_cstr(dEvent);
+        const struct sockaddr_storage* destAddr = UpnpDiscovery_get_DestAddr(dEvent);
+        const char* location = UpnpDiscovery_get_Location_cstr(dEvent);
 
         clients->addClientByDiscovery(destAddr, userAgent, location);
         break;
@@ -425,26 +441,26 @@ int Server::handleUpnpClientEvent(Upnp_EventType eventType, const void* event)
     return 0;
 }
 
-void Server::routeActionRequest(const std::unique_ptr<ActionRequest>& request) const
+void Server::routeActionRequest(ActionRequest& request)
 {
     log_debug("start");
 
     // make sure the request is for our device
-    if (request->getUDN() != serverUDN) {
+    if (request.getUDN() != serverUDN) {
         // not for us
         throw UpnpException(UPNP_E_BAD_REQUEST, "routeActionRequest: request not for this device");
     }
 
     // we need to match the serviceID to one of our services
-    if (request->getServiceID() == UPNP_DESC_CM_SERVICE_ID) {
+    if (request.getServiceID() == UPNP_DESC_CM_SERVICE_ID) {
         // this call is for the lifetime stats service
         // log_debug("request for connection manager service");
         cmgr->processActionRequest(request);
-    } else if (request->getServiceID() == UPNP_DESC_CDS_SERVICE_ID) {
+    } else if (request.getServiceID() == UPNP_DESC_CDS_SERVICE_ID) {
         // this call is for the toaster control service
-        //log_debug("routeActionRequest: request for content directory service");
+        // log_debug("routeActionRequest: request for content directory service");
         cds->processActionRequest(request);
-    } else if (request->getServiceID() == UPNP_DESC_MRREG_SERVICE_ID) {
+    } else if (request.getServiceID() == UPNP_DESC_MRREG_SERVICE_ID) {
         mrreg->processActionRequest(request);
     } else {
         // cp is asking for a nonexistent service, or for a service
@@ -458,19 +474,18 @@ void Server::routeSubscriptionRequest(const std::unique_ptr<SubscriptionRequest>
     // make sure that the request is for our device
     if (request->getUDN() != serverUDN) {
         // not for us
-        log_debug("routeSubscriptionRequest: request not for this device: {} vs {}",
-            request->getUDN().c_str(), serverUDN.c_str());
+        log_debug("routeSubscriptionRequest: request not for this device: {} vs {}", request->getUDN(), serverUDN);
         throw UpnpException(UPNP_E_BAD_REQUEST, "routeActionRequest: request not for this device");
     }
 
     // we need to match the serviceID to one of our services
     if (request->getServiceID() == UPNP_DESC_CDS_SERVICE_ID) {
         // this call is for the content directory service
-        //log_debug("routeSubscriptionRequest: request for content directory service");
+        // log_debug("routeSubscriptionRequest: request for content directory service");
         cds->processSubscriptionRequest(request);
     } else if (request->getServiceID() == UPNP_DESC_CM_SERVICE_ID) {
         // this call is for the connection manager service
-        //log_debug("routeSubscriptionRequest: request for connection manager service");
+        // log_debug("routeSubscriptionRequest: request for connection manager service");
         cmgr->processSubscriptionRequest(request);
     } else if (request->getServiceID() == UPNP_DESC_MRREG_SERVICE_ID) {
         mrreg->processSubscriptionRequest(request);
@@ -497,29 +512,18 @@ std::unique_ptr<RequestHandler> Server::createRequestHandler(const char* filenam
     }
 
     if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_UI_HANDLER))) {
-        std::string parameters;
-        std::string path;
-        RequestHandler::splitUrl(filename, URL_UI_PARAM_SEPARATOR, path, parameters);
+        auto&& [path, parameters] = RequestHandler::splitUrl(filename, URL_UI_PARAM_SEPARATOR);
 
-        std::map<std::string, std::string> params;
-        dictDecode(parameters, &params);
+        auto params = dictDecode(parameters);
 
         auto it = params.find(URL_REQUEST_TYPE);
-        std::string r_type = it != params.end() && !it->second.empty() ? it->second : "index";
+        std::string rType = it != params.end() && !it->second.empty() ? it->second : "index";
 
-        return web::createWebRequestHandler(context, content, xmlbuilder, r_type);
+        return Web::createWebRequestHandler(context, content, xmlbuilder, rType);
     }
 
     if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, DEVICE_DESCRIPTION_PATH))) {
-        return std::make_unique<DeviceDescriptionHandler>(content, xmlbuilder.get());
-    }
-
-    if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_SERVE_HANDLER))) {
-        if (config->getOption(CFG_SERVER_SERVEDIR).empty()) {
-            throw_std_runtime_error("Serving directories is not enabled in configuration");
-        }
-
-        return std::make_unique<ServeRequestHandler>(content);
+        return std::make_unique<DeviceDescriptionHandler>(content, xmlbuilder);
     }
 
 #if defined(HAVE_CURL)
@@ -559,9 +563,8 @@ int Server::registerVirtualDirCallbacks()
             auto reqHandler = static_cast<const Server*>(cookie)->createRequestHandler(filename);
             std::string link = urlUnescape(filename);
             auto ioHandler = reqHandler->open(startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_UI_HANDLER)) ? filename : link.c_str(), mode);
-            auto ioPtr = UpnpWebFileHandle(ioHandler.release());
-            //log_debug("{} open({})", ioPtr, filename);
-            return ioPtr;
+            ioHandler->open(mode);
+            return ioHandler.release();
         } catch (const ServerShutdownException& se) {
             return nullptr;
         } catch (const SubtitlesNotFoundException& sex) {
@@ -576,8 +579,8 @@ int Server::registerVirtualDirCallbacks()
         return ret;
 
     log_debug("Setting UpnpVirtualDir ReadCallback");
-    ret = UpnpVirtualDir_set_ReadCallback([](UpnpWebFileHandle f, char* buf, size_t length, const void* cookie, const void* requestCookie) -> int {
-        //log_debug("{} read({})", f, length);
+    ret = UpnpVirtualDir_set_ReadCallback([](UpnpWebFileHandle f, char* buf, std::size_t length, const void* cookie, const void* requestCookie) -> int {
+        // log_debug("{} read({})", f, length);
         if (static_cast<const Server*>(cookie)->getShutdownStatus())
             return -1;
 
@@ -588,8 +591,8 @@ int Server::registerVirtualDirCallbacks()
         return ret;
 
     log_debug("Setting UpnpVirtualDir WriteCallback");
-    ret = UpnpVirtualDir_set_WriteCallback([](UpnpWebFileHandle f, char* buf, size_t length, const void* cookie, const void* requestCookie) -> int {
-        //log_debug("{} write({})", f, length);
+    ret = UpnpVirtualDir_set_WriteCallback([](UpnpWebFileHandle f, char* buf, std::size_t length, const void* cookie, const void* requestCookie) -> int {
+        // log_debug("{} write({})", f, length);
         return 0;
     });
     if (ret != UPNP_E_SUCCESS)
@@ -597,7 +600,7 @@ int Server::registerVirtualDirCallbacks()
 
     log_debug("Setting UpnpVirtualDir SeekCallback");
     ret = UpnpVirtualDir_set_SeekCallback([](UpnpWebFileHandle f, off_t offset, int whence, const void* cookie, const void* requestCookie) -> int {
-        //log_debug("{} seek({}, {})", f, offset, whence);
+        // log_debug("{} seek({}, {})", f, offset, whence);
         try {
             auto handler = static_cast<IOHandler*>(f);
             handler->seek(offset, whence);
@@ -612,17 +615,17 @@ int Server::registerVirtualDirCallbacks()
 
     log_debug("Setting UpnpVirtualDir CloseCallback");
     ret = UpnpVirtualDir_set_CloseCallback([](UpnpWebFileHandle f, const void* cookie, const void* requestCookie) -> int {
-        //log_debug("{} close()", f);
-        int ret_close = 0;
+        // log_debug("{} close()", f);
+        int retClose = 0;
         auto handler = std::unique_ptr<IOHandler>(static_cast<IOHandler*>(f));
         try {
             handler->close();
         } catch (const std::runtime_error& e) {
             log_error("Exception during close: {}", e.what());
-            ret_close = -1;
+            retClose = -1;
         }
 
-        return ret_close;
+        return retClose;
     });
 
     return ret;
