@@ -1,11 +1,11 @@
 /*GRB*
 
     Gerbera - https://gerbera.io/
-    
-    context.h - this file is part of Gerbera.
-    
-    Copyright (C) 2021 Gerbera Contributors
-    
+
+    transcode_handler.cc - this file is part of Gerbera.
+
+    Copyright (C) 2021-2022 Gerbera Contributors
+
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -28,8 +28,8 @@
 #include "content/content_manager.h"
 #include "context.h"
 
-TranscodeHandler::TranscodeHandler(std::shared_ptr<ContentManager> content)
+TranscodeHandler::TranscodeHandler(const std::shared_ptr<ContentManager>& content)
     : config(content->getContext()->getConfig())
-    , content(std::move(content))
+    , content(content)
 {
 }
