@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     upnp_cm.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -38,68 +38,68 @@
 #include "util/tools.h"
 
 ConnectionManagerService::ConnectionManagerService(const std::shared_ptr<Context>& context,
-    UpnpXMLBuilder* xmlBuilder, UpnpDevice_Handle deviceHandle)
+    std::shared_ptr<UpnpXMLBuilder> xmlBuilder, UpnpDevice_Handle deviceHandle)
     : config(context->getConfig())
     , database(context->getDatabase())
-    , xmlBuilder(xmlBuilder)
+    , xmlBuilder(std::move(xmlBuilder))
     , deviceHandle(deviceHandle)
 {
 }
 
-void ConnectionManagerService::doGetCurrentConnectionIDs(const std::unique_ptr<ActionRequest>& request)
+void ConnectionManagerService::doGetCurrentConnectionIDs(ActionRequest& request)
 {
     log_debug("start");
 
-    auto response = UpnpXMLBuilder::createResponse(request->getActionName(), UPNP_DESC_CM_SERVICE_TYPE);
+    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CM_SERVICE_TYPE);
     auto root = response->document_element();
     root.append_child("ConnectionID").append_child(pugi::node_pcdata).set_value("0");
 
-    request->setResponse(std::move(response));
-    request->setErrorCode(UPNP_E_SUCCESS);
+    request.setResponse(std::move(response));
+    request.setErrorCode(UPNP_E_SUCCESS);
 
     log_debug("end");
 }
 
-void ConnectionManagerService::doGetCurrentConnectionInfo(const std::unique_ptr<ActionRequest>& request)
+void ConnectionManagerService::doGetCurrentConnectionInfo(ActionRequest& request)
 {
     log_debug("start");
 
-    request->setErrorCode(UPNP_E_NOT_EXIST);
+    request.setErrorCode(UPNP_E_NOT_EXIST);
 
     log_debug("doGetCurrentConnectionInfo: end");
 }
 
-void ConnectionManagerService::doGetProtocolInfo(const std::unique_ptr<ActionRequest>& request)
+void ConnectionManagerService::doGetProtocolInfo(ActionRequest& request)
 {
     log_debug("start");
 
-    auto response = UpnpXMLBuilder::createResponse(request->getActionName(), UPNP_DESC_CM_SERVICE_TYPE);
-    auto CSV = mimeTypesToCsv(database->getMimeTypes());
+    auto response = UpnpXMLBuilder::createResponse(request.getActionName(), UPNP_DESC_CM_SERVICE_TYPE);
+    auto csv = mimeTypesToCsv(database->getMimeTypes());
     auto root = response->document_element();
 
-    root.append_child("Source").append_child(pugi::node_pcdata).set_value(CSV.c_str());
+    root.append_child("Source").append_child(pugi::node_pcdata).set_value(csv.c_str());
     root.append_child("Sink").append_child(pugi::node_pcdata).set_value("");
 
-    request->setResponse(std::move(response));
-    request->setErrorCode(UPNP_E_SUCCESS);
+    request.setResponse(std::move(response));
+    request.setErrorCode(UPNP_E_SUCCESS);
 
     log_debug("end");
 }
 
-void ConnectionManagerService::processActionRequest(const std::unique_ptr<ActionRequest>& request)
+void ConnectionManagerService::processActionRequest(ActionRequest& request)
 {
     log_debug("start");
 
-    if (request->getActionName() == "GetCurrentConnectionIDs") {
+    if (request.getActionName() == "GetCurrentConnectionIDs") {
         doGetCurrentConnectionIDs(request);
-    } else if (request->getActionName() == "GetCurrentConnectionInfo") {
+    } else if (request.getActionName() == "GetCurrentConnectionInfo") {
         doGetCurrentConnectionInfo(request);
-    } else if (request->getActionName() == "GetProtocolInfo") {
+    } else if (request.getActionName() == "GetProtocolInfo") {
         doGetProtocolInfo(request);
     } else {
         // invalid or unsupported action
-        log_debug("unrecognized action {}", request->getActionName().c_str());
-        request->setErrorCode(UPNP_E_INVALID_ACTION);
+        log_debug("unrecognized action {}", request.getActionName().c_str());
+        request.setErrorCode(UPNP_E_INVALID_ACTION);
         //        throw UpnpException(UPNP_E_INVALID_ACTION, "unrecognized action");
     }
 
@@ -108,13 +108,13 @@ void ConnectionManagerService::processActionRequest(const std::unique_ptr<Action
 
 void ConnectionManagerService::processSubscriptionRequest(const std::unique_ptr<SubscriptionRequest>& request)
 {
-    auto CSV = mimeTypesToCsv(database->getMimeTypes());
+    auto csv = mimeTypesToCsv(database->getMimeTypes());
     auto propset = UpnpXMLBuilder::createEventPropertySet();
     auto property = propset->document_element().first_child();
 
     property.append_child("CurrentConnectionIDs").append_child(pugi::node_pcdata).set_value("0");
     property.append_child("SinkProtocolInfo").append_child(pugi::node_pcdata).set_value("");
-    property.append_child("SourceProtocolInfo").append_child(pugi::node_pcdata).set_value(CSV.c_str());
+    property.append_child("SourceProtocolInfo").append_child(pugi::node_pcdata).set_value(csv.c_str());
 
     std::ostringstream buf;
     propset->print(buf, "", 0);
@@ -139,11 +139,11 @@ void ConnectionManagerService::processSubscriptionRequest(const std::unique_ptr<
 #endif
 }
 
-void ConnectionManagerService::sendSubscriptionUpdate(const std::string& sourceProtocol_CSV)
+void ConnectionManagerService::sendSubscriptionUpdate(const std::string& sourceProtocolCsv)
 {
     auto propset = UpnpXMLBuilder::createEventPropertySet();
     auto property = propset->document_element().first_child();
-    property.append_child("SourceProtocolInfo").append_child(pugi::node_pcdata).set_value(sourceProtocol_CSV.c_str());
+    property.append_child("SourceProtocolInfo").append_child(pugi::node_pcdata).set_value(sourceProtocolCsv.c_str());
 
     std::ostringstream buf;
     propset->print(buf, "", 0);
