@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     url_request_handler.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -36,7 +36,6 @@
 #include "config/config_manager.h"
 #include "content/content_manager.h"
 #include "database/database.h"
-#include "iohandler/buffered_io_handler.h"
 #include "iohandler/curl_io_handler.h"
 #include "transcoding/transcode_dispatcher.h"
 #include "util/url.h"
@@ -45,33 +44,27 @@
 #include "content/onlineservice/online_service_helper.h"
 #endif
 
-URLRequestHandler::URLRequestHandler(std::shared_ptr<ContentManager> content)
-    : RequestHandler(std::move(content))
-{
-}
-
 void URLRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
 {
     log_debug("start");
 
     auto params = parseParameters(filename, LINK_URL_REQUEST_HANDLER);
-    auto obj = getObjectById(params);
+    auto obj = loadObject(params);
     if (!obj->isExternalItem()) {
         throw_std_runtime_error("getInfo: object is not an external url item");
     }
 
     auto item = std::static_pointer_cast<CdsItemExternalURL>(obj);
 
-    std::string tr_profile = getValueOrDefault(params, URL_PARAM_TRANSCODE_PROFILE_NAME);
+    std::string trProfile = getValueOrDefault(params, URL_PARAM_TRANSCODE_PROFILE_NAME);
 
-    std::string header;
     std::string mimeType;
 
-    if (!tr_profile.empty()) {
+    if (!trProfile.empty()) {
         auto tp = config->getTranscodingProfileListOption(CFG_TRANSCODING_PROFILE_LIST)
-                      ->getByName(tr_profile);
+                      ->getByName(trProfile);
         if (!tp)
-            throw_std_runtime_error("Transcoding requested but no profile matching the name {} found", tr_profile.c_str());
+            throw_std_runtime_error("Transcoding requested but no profile matching the name {} found", trProfile);
 
         mimeType = tp->getTargetMimeType();
         UpnpFileInfo_set_FileLength(info, -1);
@@ -81,12 +74,11 @@ void URLRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
 #else
         std::string url = item->getLocation();
 #endif
-        log_debug("Online content url: {}", url.c_str());
+        log_debug("Online content url: {}", url);
         try {
             auto st = URL::getInfo(url);
-            UpnpFileInfo_set_FileLength(info, st->getSize());
-            header = "Accept-Ranges: bytes";
-            log_debug("URL used for request: {}", st->getURL().c_str());
+            UpnpFileInfo_set_FileLength(info, st.getSize());
+            log_debug("URL used for request: {}", st.getURL());
         } catch (const std::runtime_error& ex) {
             log_warning("{}", ex.what());
             UpnpFileInfo_set_FileLength(info, -1);
@@ -99,12 +91,6 @@ void URLRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
     UpnpFileInfo_set_LastModified(info, 0);
     UpnpFileInfo_set_IsDirectory(info, 0);
 
-    // FIX EXTRA HEADERS
-    //    if (!header.empty()) {
-    //        UpnpFileInfo_set_ExtraHeaders(info,
-    //            ixmlCloneDOMString(header.c_str()));
-    //    }
-
 #ifdef USING_NPUPNP
     info->content_type = std::move(mimeType);
 #else
@@ -125,7 +111,7 @@ std::unique_ptr<IOHandler> URLRequestHandler::open(const char* filename, enum Up
         throw_std_runtime_error("UPNP_WRITE unsupported");
 
     auto params = parseParameters(filename, LINK_URL_REQUEST_HANDLER);
-    auto obj = getObjectById(params);
+    auto obj = loadObject(params);
     if (!obj->isExternalItem()) {
         throw_std_runtime_error("object is not an external url item");
     }
@@ -136,28 +122,28 @@ std::unique_ptr<IOHandler> URLRequestHandler::open(const char* filename, enum Up
 #else
     std::string url = item->getLocation();
 #endif
-    log_debug("Online content url: {}", url.c_str());
+    log_debug("Online content url: {}", url);
 
-    std::string tr_profile = getValueOrDefault(params, URL_PARAM_TRANSCODE_PROFILE_NAME);
-    if (!tr_profile.empty()) {
+    std::string trProfile = getValueOrDefault(params, URL_PARAM_TRANSCODE_PROFILE_NAME);
+    if (!trProfile.empty()) {
         auto tp = config->getTranscodingProfileListOption(CFG_TRANSCODING_PROFILE_LIST)
-                      ->getByName(tr_profile);
+                      ->getByName(trProfile);
         if (!tp)
-            throw_std_runtime_error("Transcoding of file {} but no profile matching the name {} found", url.c_str(), tr_profile.c_str());
+            throw_std_runtime_error("Transcoding of file {} but no profile matching the name {} found", url, trProfile);
 
-        auto tr_d = std::make_unique<TranscodeDispatcher>(content);
-        auto io_handler = tr_d->serveContent(tp, url, item, "");
-        io_handler->open(mode);
+        auto trD = std::make_unique<TranscodeDispatcher>(content);
+        auto ioHandler = trD->serveContent(tp, url, item, "");
+        ioHandler->open(mode);
 
         log_debug("end");
-        return io_handler;
+        return ioHandler;
     }
 
     ///\todo make curl io handler configurable for url request handler
-    auto io_handler = std::make_unique<CurlIOHandler>(config, url, nullptr, 1024 * 1024, 0);
-    io_handler->open(mode);
+    auto ioHandler = std::make_unique<CurlIOHandler>(config, url, nullptr, 1024 * 1024, 0);
+    ioHandler->open(mode);
     content->triggerPlayHook(obj);
-    return std::move(io_handler);
+    return ioHandler;
 }
 
 #endif // HAVE_CURL
