@@ -1,11 +1,11 @@
 /*GRB*
 
     Gerbera - https://gerbera.io/
-    
-    mime.h - this file is part of Gerbera.
-    
-    Copyright (C) 2021 Gerbera Contributors
-    
+
+    mime.cc - this file is part of Gerbera.
+
+    Copyright (C) 2021-2022 Gerbera Contributors
+
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -33,6 +33,7 @@ Mime::Mime(const std::shared_ptr<Config>& config)
     , ignore_unknown_extensions(config->getBoolOption(CFG_IMPORT_MAPPINGS_IGNORE_UNKNOWN_EXTENSIONS))
     , extension_mimetype_map(config->getDictionaryOption(CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST))
     , mimetype_upnpclass_map(config->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST))
+    , ignoredExtensions(config->getArrayOption(CFG_IMPORT_MAPPINGS_IGNORED_EXTENSIONS))
 {
     if (ignore_unknown_extensions && (extension_mimetype_map.empty())) {
         log_warning("Ignore unknown extensions set, but no mappings specified");
@@ -80,10 +81,9 @@ std::string Mime::fileToMimeType(const fs::path& path, const std::string& defval
     return mimeType;
 }
 
-std::string Mime::bufferToMimeType(const void* buffer, size_t length)
+std::string Mime::bufferToMimeType(const void* buffer, std::size_t length)
 {
-    const char* mimeType = magic_buffer(magicCookie, buffer, length);
-    return mimeType;
+    return magic_buffer(magicCookie, buffer, length);
 }
 #endif
 
@@ -96,6 +96,9 @@ std::string Mime::getMimeType(const fs::path& path, const std::string& defval)
     if (!extension_map_case_sensitive)
         extension = toLower(extension);
 
+    if (std::find(ignoredExtensions.begin(), ignoredExtensions.end(), extension) != ignoredExtensions.end()) {
+        return {};
+    }
     std::string mimeType = getValueOrDefault(extension_mimetype_map, extension, "");
     if (mimeType.empty() && !ignore_unknown_extensions) {
 #ifdef HAVE_MAGIC
@@ -110,13 +113,5 @@ std::string Mime::getMimeType(const fs::path& path, const std::string& defval)
 
 std::string Mime::mimeTypeToUpnpClass(const std::string& mimeType)
 {
-    auto it = mimetype_upnpclass_map.find(mimeType);
-    if (it != mimetype_upnpclass_map.end())
-        return it->second;
-
-    // try to match foo
-    std::vector<std::string> parts = splitString(mimeType, '/');
-    if (parts.size() != 2)
-        return {};
-    return getValueOrDefault(mimetype_upnpclass_map, parts[0] + "/*");
+    return getPropertyMapValue(mimetype_upnpclass_map, mimeType);
 }
