@@ -1,11 +1,11 @@
 /*GRB*
 
     Gerbera - https://gerbera.io/
-    
+
     mime.h - this file is part of Gerbera.
-    
-    Copyright (C) 2021 Gerbera Contributors
-    
+
+    Copyright (C) 2021-2022 Gerbera Contributors
+
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -26,11 +26,9 @@
 #ifndef __MIME_H__
 #define __MIME_H__
 
-#include <filesystem>
 #include <map>
-#include <memory>
-#include <string>
-namespace fs = std::filesystem;
+
+#include "util/grb_fs.h"
 
 #ifdef HAVE_MAGIC
 // for older versions of filemagic
@@ -52,9 +50,7 @@ public:
     Mime& operator=(const Mime&) = delete;
 
     /// \brief Extracts mimetype from a buffer using filemagic
-    std::string bufferToMimeType(const void* buffer, size_t length);
-#else
-    virtual ~Mime() = default;
+    std::string bufferToMimeType(const void* buffer, std::size_t length);
 #endif // HAVE_MAGIC
 
     std::string mimeTypeToUpnpClass(const std::string& mimeType);
@@ -66,6 +62,7 @@ private:
 
     std::map<std::string, std::string> extension_mimetype_map;
     std::map<std::string, std::string> mimetype_upnpclass_map;
+    std::vector<std::string> ignoredExtensions;
 
 #ifdef HAVE_MAGIC
     magic_t magicCookie;
