@@ -1,34 +1,34 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     mt_inotify.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
 /*
-    The original version of the next_events function was taken from the 
+    The original version of the next_events function was taken from the
     inotify-tools package, http://inotify-tools.sf.net/
     The original author is Rohan McGovern  <rohan@mcgovern.id.au>
     inotify tools are licensed under GNU GPL Version 2
@@ -40,8 +40,6 @@
 #include "mt_inotify.h"
 
 #include <array>
-#include <cassert>
-#include <cerrno>
 #include <sys/inotify.h>
 #include <sys/ioctl.h>
 #include <sys/select.h>
@@ -53,7 +51,6 @@
 #include "tools.h"
 
 #define MAX_EVENTS 4096
-#define MAX_STRLEN 4096
 
 Inotify::Inotify()
 #ifdef __linux__
@@ -85,14 +82,14 @@ Inotify::~Inotify()
 bool Inotify::supported()
 {
 #ifdef __linux__
-    int test_fd = inotify_init1(IN_CLOEXEC);
+    int testFd = inotify_init1(IN_CLOEXEC);
 #else
-    int test_fd = inotify_init();
+    int testFd = inotify_init();
 #endif
-    if (test_fd < 0)
+    if (testFd < 0)
         return false;
 
-    close(test_fd);
+    close(testFd);
     return true;
 }
 
@@ -122,23 +119,20 @@ struct inotify_event* Inotify::nextEvent()
 {
     static std::array<inotify_event, MAX_EVENTS> event;
     static struct inotify_event* ret;
-    static int first_byte = 0;
+    static int firstByte = 0;
     static ssize_t bytes;
 
-    int fd_max;
-
     // first_byte is index into event buffer
-    if (first_byte != 0
-        && first_byte <= int(bytes - sizeof(struct inotify_event))) {
-
-        ret = reinterpret_cast<struct inotify_event*>(reinterpret_cast<char*>(&event[0]) + first_byte);
-        first_byte += sizeof(struct inotify_event) + ret->len;
+    if (firstByte != 0
+        && firstByte <= int(bytes - sizeof(struct inotify_event))) {
+        ret = reinterpret_cast<struct inotify_event*>(reinterpret_cast<char*>(&event[0]) + firstByte);
+        firstByte += sizeof(struct inotify_event) + ret->len;
 
         // if the pointer to the next event exactly hits end of bytes read,
         // that's good.  next time we're called, we'll read.
-        if (first_byte == bytes) {
-            first_byte = 0;
-        } else if (first_byte > bytes) {
+        if (firstByte == bytes) {
+            firstByte = 0;
+        } else if (firstByte > bytes) {
             // oh... no.  this can't be happening.  An incomplete event.
             // Copy what we currently have into first element, call self to
             // read remainder.
@@ -149,33 +143,32 @@ struct inotify_event* Inotify::nextEvent()
 
             // how much of the event do we have?
             bytes = reinterpret_cast<char*>(&event[0]) + bytes - reinterpret_cast<char*>(ret);
-            memcpy(&event[0], ret, bytes);
+            std::memcpy(&event[0], ret, bytes);
             return nextEvent();
         }
         return ret;
     }
 
-    if (first_byte == 0) {
+    if (firstByte == 0) {
         bytes = 0;
     }
 
-    static ssize_t this_bytes;
-    static unsigned int bytes_to_read;
+    static unsigned int bytesToRead;
     static int rc;
-    static fd_set read_fds;
+    static fd_set readFds;
 
-    FD_ZERO(&read_fds);
+    FD_ZERO(&readFds);
 
-    FD_SET(inotify_fd, &read_fds);
+    FD_SET(inotify_fd, &readFds);
 
-    fd_max = inotify_fd;
+    auto fdMax = inotify_fd;
 
-    FD_SET(stop_fd_read, &read_fds);
+    FD_SET(stop_fd_read, &readFds);
 
-    if (stop_fd_read > fd_max)
-        fd_max = stop_fd_read;
+    if (stop_fd_read > fdMax)
+        fdMax = stop_fd_read;
 
-    rc = select(fd_max + 1, &read_fds,
+    rc = select(fdMax + 1, &readFds,
         nullptr, nullptr, nullptr);
     if (rc < 0) {
         return nullptr;
@@ -185,42 +178,42 @@ struct inotify_event* Inotify::nextEvent()
         return nullptr;
     }
 
-    if (FD_ISSET(stop_fd_read, &read_fds)) {
+    if (FD_ISSET(stop_fd_read, &readFds)) {
         char buf;
         if (read(stop_fd_read, &buf, 1) == -1) {
             log_error("Inotify: could not read stop: {}", std::strerror(errno));
         }
     }
 
-    if (FD_ISSET(inotify_fd, &read_fds)) {
-
+    if (FD_ISSET(inotify_fd, &readFds)) {
+        static ssize_t thisBytes;
         // wait until we have enough bytes to read
         do {
-            rc = ioctl(inotify_fd, FIONREAD, &bytes_to_read);
-        } while (!rc && bytes_to_read < sizeof(struct inotify_event));
+            rc = ioctl(inotify_fd, FIONREAD, &bytesToRead);
+        } while (!rc && bytesToRead < sizeof(struct inotify_event));
 
         if (rc == -1) {
             return nullptr;
         }
 
-        this_bytes = read(inotify_fd, &event[0] + bytes,
+        thisBytes = read(inotify_fd, &event[0] + bytes,
             sizeof(struct inotify_event) * MAX_EVENTS - bytes);
-        if (this_bytes < 0) {
+        if (thisBytes < 0) {
             return nullptr;
         }
-        if (this_bytes == 0) {
+        if (thisBytes == 0) {
             log_error("Inotify reported end-of-file.  Possibly too many "
                       "events occurred at once.\n");
             return nullptr;
         }
-        bytes += this_bytes;
+        bytes += thisBytes;
 
         ret = &event[0];
-        first_byte = int(sizeof(struct inotify_event) + ret->len);
-        assert(first_byte <= bytes);
+        firstByte = int(sizeof(struct inotify_event) + ret->len);
+        assert(firstByte <= bytes);
 
-        if (first_byte == bytes) {
-            first_byte = 0;
+        if (firstByte == bytes) {
+            firstByte = 0;
         }
 
         return ret;
@@ -237,4 +230,4 @@ void Inotify::stop() const
     }
 }
 
-#endif //HAVE_INOTIFY
+#endif // HAVE_INOTIFY
