@@ -41,7 +41,11 @@ void ThreadExecutor::startThread()
     int ret = pthread_create(
         &thread,
         nullptr,
-        ThreadExecutor::staticThreadProc,
+        [](void* arg) -> void* {
+            auto inst = static_cast<ThreadExecutor*>(arg);
+            inst->threadProc();
+            pthread_exit(nullptr);
+        },
         this);
 
     if (ret != 0) {
@@ -68,10 +72,3 @@ bool ThreadExecutor::kill()
     }
     return true;
 }
-
-void* ThreadExecutor::staticThreadProc(void* arg)
-{
-    auto inst = static_cast<ThreadExecutor*>(arg);
-    inst->threadProc();
-    pthread_exit(nullptr);
-}
