@@ -1,11 +1,11 @@
 /*GRB*
 
     Gerbera - https://gerbera.io/
-    
+
     upnp_clients.h - this file is part of Gerbera.
-    
-    Copyright (C) 2020-2021 Gerbera Contributors
-    
+
+    Copyright (C) 2020-2022 Gerbera Contributors
+
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -49,6 +49,7 @@ enum class ClientType {
     SamsungBDP,
     SamsungSeriesCDE,
     SamsungBDJ5500,
+    IRadio,
     StandardUPnP
 };
 
@@ -56,23 +57,24 @@ enum class ClientType {
 enum class ClientMatchType {
     None,
     UserAgent, // received via UpnpActionRequest, UpnpFileInfo and UpnpDiscovery (all might be slitely different)
-    //FriendlyName,
-    //ModelName,
+    // FriendlyName,
+    // ModelName,
     IP, // use client's network address
 };
 
 struct ClientInfo {
-    std::string name; // used for logging/debugging proposes only
-    ClientType type;
-    QuirkFlags flags;
+    std::string name { "Unknown" }; // used for logging/debugging proposes only
+    ClientType type { ClientType::Unknown };
+    QuirkFlags flags { QUIRK_FLAG_NONE };
 
     // to match the client
-    ClientMatchType matchType;
+    ClientMatchType matchType { ClientMatchType::None };
     std::string match;
+    int captionInfoCount { 1 };
 };
 
 struct ClientCacheEntry {
-    ClientCacheEntry(struct sockaddr_storage addr, std::string userAgent, std::chrono::seconds last, std::chrono::seconds age, const struct ClientInfo* pInfo)
+    ClientCacheEntry(const struct sockaddr_storage& addr, std::string userAgent, std::chrono::seconds last, std::chrono::seconds age, const struct ClientInfo* pInfo)
         : addr(addr)
         , userAgent(std::move(userAgent))
         , last(last)
@@ -94,22 +96,22 @@ public:
     void refresh(const std::shared_ptr<Config>& config);
 
     // always return something, 'Unknown' if we do not know better
-    void getInfo(const struct sockaddr_storage* addr, const std::string& userAgent, const ClientInfo** ppInfo);
+    const ClientInfo* getInfo(const struct sockaddr_storage* addr, const std::string& userAgent);
 
     void addClientByDiscovery(const struct sockaddr_storage* addr, const std::string& userAgent, const std::string& descLocation);
     const std::vector<ClientCacheEntry>& getClientList() const { return cache; }
 
 private:
-    bool getInfoByAddr(const struct sockaddr_storage* addr, const ClientInfo** ppInfo);
-    bool getInfoByType(const std::string& match, ClientMatchType type, const ClientInfo** ppInfo);
+    const ClientInfo* getInfoByAddr(const struct sockaddr_storage* addr) const;
+    const ClientInfo* getInfoByType(const std::string& match, ClientMatchType type) const;
 
-    bool getInfoByCache(const struct sockaddr_storage* addr, const ClientInfo** ppInfo);
-    void updateCache(const struct sockaddr_storage* addr, std::string userAgent, const ClientInfo* pInfo);
+    const ClientInfo* getInfoByCache(const struct sockaddr_storage* addr) const;
+    void updateCache(const struct sockaddr_storage* addr, const std::string& userAgent, const ClientInfo* pInfo);
 
     static std::unique_ptr<pugi::xml_document> downloadDescription(const std::string& location);
 
-    std::mutex mutex;
-    using AutoLock = std::lock_guard<std::mutex>;
+    mutable std::mutex mutex;
+    using AutoLock = std::scoped_lock<std::mutex>;
     std::vector<ClientCacheEntry> cache;
 
     std::vector<ClientInfo> clientInfo;
