@@ -1,11 +1,11 @@
 /*GRB*
 
     Gerbera - https://gerbera.io/
-    
+
     upnp_clients.cc - this file is part of Gerbera.
-    
-    Copyright (C) 2020-2021 Gerbera Contributors
-    
+
+    Copyright (C) 2020-2022 Gerbera Contributors
+
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -34,19 +34,14 @@
 
 #include <fmt/chrono.h>
 
-web::clients::clients(std::shared_ptr<ContentManager> content)
-    : WebRequestHandler(std::move(content))
-{
-}
-
-static std::string seconds_to_string(const std::chrono::seconds& t)
+static std::string secondsToString(const std::chrono::seconds& t)
 {
     return fmt::format("{:%a %b %d %H:%M:%S %Y}", fmt::localtime(t.count()));
 }
 
-void web::clients::process()
+void Web::Clients::process()
 {
-    check_request();
+    checkRequest();
     auto root = xmlDoc->document_element();
 
     auto clients = root.append_child("clients");
@@ -59,8 +54,8 @@ void web::clients::process()
         item.append_attribute("ip") = ip.c_str();
         auto hostName = getHostName(reinterpret_cast<const struct sockaddr*>(&obj.addr));
         item.append_attribute("host") = hostName.c_str();
-        item.append_attribute("time") = seconds_to_string(obj.age).c_str();
-        item.append_attribute("last") = seconds_to_string(obj.last).c_str();
+        item.append_attribute("time") = secondsToString(obj.age).c_str();
+        item.append_attribute("last") = secondsToString(obj.last).c_str();
         item.append_attribute("userAgent") = obj.userAgent.c_str();
         item.append_attribute("name") = obj.pInfo->name.c_str();
         item.append_attribute("match") = obj.pInfo->match.c_str();
