@@ -4,7 +4,7 @@
 
     config_load.cc - this file is part of Gerbera.
 
-    Copyright (C) 2020-2021 Gerbera Contributors
+    Copyright (C) 2020-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -38,11 +38,10 @@
 #include "database/database.h"
 #include "metadata/metadata_handler.h"
 #include "transcoding/transcoding.h"
-#include "upnp_xml.h"
 #include "util/upnp_clients.h"
 
-web::configLoad::configLoad(std::shared_ptr<ContentManager> content)
-    : WebRequestHandler(std::move(content))
+Web::ConfigLoad::ConfigLoad(const std::shared_ptr<ContentManager>& content)
+    : WebRequestHandler(content)
 {
     try {
         if (this->database) {
@@ -55,7 +54,7 @@ web::configLoad::configLoad(std::shared_ptr<ContentManager> content)
     }
 }
 
-void web::configLoad::addTypeMeta(pugi::xml_node& meta, const std::shared_ptr<ConfigSetup>& cs)
+void Web::ConfigLoad::addTypeMeta(pugi::xml_node& meta, const std::shared_ptr<ConfigSetup>& cs)
 {
     auto info = meta.append_child("item");
     info.append_attribute("item") = cs->getUniquePath().c_str();
@@ -65,13 +64,13 @@ void web::configLoad::addTypeMeta(pugi::xml_node& meta, const std::shared_ptr<Co
     info.append_attribute("help") = cs->getHelp();
 }
 
-void web::configLoad::createItem(pugi::xml_node& item, const std::string& name, config_option_t id, config_option_t aid, const std::shared_ptr<ConfigSetup>& cs)
+void Web::ConfigLoad::createItem(pugi::xml_node& item, const std::string& name, config_option_t id, config_option_t aid, const std::shared_ptr<ConfigSetup>& cs)
 {
-    allItems[name] = &item;
+    allItems[name] = fmt::format("{}[{}]", item.path(), allItems.size() + 1);
     item.append_attribute("item") = name.c_str();
     item.append_attribute("id") = fmt::format("{:03d}", id).c_str();
     item.append_attribute("aid") = fmt::format("{:03d}", aid).c_str();
-    if (std::any_of(dbEntries.begin(), dbEntries.end(), [&](auto&& s) { return s.item == name; })) {
+    if (std::any_of(dbEntries.begin(), dbEntries.end(), [=](auto&& s) { return s.item == name; })) {
         item.append_attribute("status") = "unchanged";
         item.append_attribute("source") = "database";
     } else {
@@ -83,36 +82,37 @@ void web::configLoad::createItem(pugi::xml_node& item, const std::string& name,
 }
 
 template <typename T>
-void web::configLoad::setValue(pugi::xml_node& item, const T& value)
+void Web::ConfigLoad::setValue(pugi::xml_node& item, const T& value)
 {
     static_assert(fmt::has_formatter<T, fmt::format_context>::value, "T must be formattable");
     item.append_attribute("value") = fmt::to_string(value).c_str();
 }
 
 template <>
-void web::configLoad::setValue(pugi::xml_node& item, const std::string& value)
+void Web::ConfigLoad::setValue(pugi::xml_node& item, const std::string& value)
 {
     item.append_attribute("value") = value.c_str();
 }
 
 template <>
-void web::configLoad::setValue(pugi::xml_node& item, const std::string_view& value)
+void Web::ConfigLoad::setValue(pugi::xml_node& item, const std::string_view& value)
 {
     item.append_attribute("value") = value.data();
 }
 
 template <>
-void web::configLoad::setValue(pugi::xml_node& item, const fs::path& value)
+void Web::ConfigLoad::setValue(pugi::xml_node& item, const fs::path& value)
 {
     item.append_attribute("value") = value.c_str();
 }
 
 /// \brief: process config_load request
-void web::configLoad::process()
+void Web::ConfigLoad::process()
 {
-    check_request();
+    checkRequest();
     auto root = xmlDoc->document_element();
     auto values = root.append_child("values");
+    std::string action = param("action");
 
     // set handling of json properties
     xml2JsonHints->setArrayName(values, "item");
@@ -124,13 +124,6 @@ void web::configLoad::process()
 
     log_debug("Sending Config to web!");
 
-    // generate meta info for ui
-    auto meta = root.append_child("types");
-    xml2JsonHints->setArrayName(meta, "item");
-    for (auto&& cs : ConfigDefinition::getOptionList()) {
-        addTypeMeta(meta, cs);
-    }
-
     // write database status
     {
         auto item = values.append_child("item");
@@ -161,6 +154,16 @@ void web::configLoad::process()
         setValue(item, database->getTotalFiles(true, "image"));
     }
 
+    if (action == "status")
+        return;
+
+    // generate meta info for ui
+    auto meta = root.append_child("types");
+    xml2JsonHints->setArrayName(meta, "item");
+    for (auto&& cs : ConfigDefinition::getOptionList()) {
+        addTypeMeta(meta, cs);
+    }
+
     // write all values with simple type (string, int, bool)
     for (auto&& option : ConfigOptionIterator()) {
         try {
@@ -176,10 +179,9 @@ void web::configLoad::process()
     }
 
     // write client configuration
-    std::shared_ptr<ConfigSetup> cs;
-    cs = ConfigDefinition::findConfigSetup(CFG_CLIENTS_LIST);
+    auto cs = ConfigDefinition::findConfigSetup(CFG_CLIENTS_LIST);
     auto clientConfig = cs->getValue()->getClientConfigListOption();
-    for (size_t i = 0; i < clientConfig->size(); i++) {
+    for (std::size_t i = 0; i < clientConfig->size(); i++) {
         auto client = clientConfig->get(i);
 
         auto item = values.append_child("item");
@@ -193,6 +195,10 @@ void web::configLoad::process()
         item = values.append_child("item");
         createItem(item, cs->getItemPath(i, ATTR_CLIENTS_CLIENT_USERAGENT), cs->option, ATTR_CLIENTS_CLIENT_USERAGENT, cs);
         setValue(item, client->getUserAgent());
+
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(i, ATTR_CLIENTS_UPNP_CAPTION_COUNT), cs->option, ATTR_CLIENTS_UPNP_CAPTION_COUNT, cs);
+        setValue(item, client->getCaptionInfoCount());
     }
     if (clientConfig->size() == 0) {
         auto item = values.append_child("item");
@@ -208,7 +214,7 @@ void web::configLoad::process()
     // write import tweaks
     cs = ConfigDefinition::findConfigSetup(CFG_IMPORT_DIRECTORIES_LIST);
     auto directoryConfig = cs->getValue()->getDirectoryTweakOption();
-    for (size_t i = 0; i < directoryConfig->size(); i++) {
+    for (std::size_t i = 0; i < directoryConfig->size(); i++) {
         auto dir = directoryConfig->get(i);
 
         auto item = values.append_child("item");
@@ -255,7 +261,7 @@ void web::configLoad::process()
     // write dynamic content
     cs = ConfigDefinition::findConfigSetup(CFG_SERVER_DYNAMIC_CONTENT_LIST);
     auto dynContent = cs->getValue()->getDynamicContentListOption();
-    for (size_t i = 0; i < dynContent->size(); i++) {
+    for (std::size_t i = 0; i < dynContent->size(); i++) {
         auto cont = dynContent->get(i);
 
         auto item = values.append_child("item");
@@ -309,7 +315,7 @@ void web::configLoad::process()
             item = values.append_child("item");
             createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_MIMETYPE_PROF_MAP, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_TRANSCODE, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_USING), cs->option, ATTR_TRANSCODING_MIMETYPE_PROF_MAP_USING, cs);
             setValue(item, name->getName());
-            profiles[name->getName()] = pr;
+            profiles.emplace(name->getName(), pr);
 
             pr++;
         }
@@ -340,7 +346,7 @@ void web::configLoad::process()
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_RES), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_RES);
-        setValue(item, entry->getAttributes()[MetadataHandler::getResAttrName(R_RESOLUTION)]);
+        setValue(item, entry->getAttribute(MetadataHandler::getResAttrName(R_RESOLUTION)));
 
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL);
@@ -396,11 +402,11 @@ void web::configLoad::process()
             createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC, ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_MODE), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_MODE);
             setValue(item, TranscodingProfile::mapFourCcMode(fourCCMode));
 
-            const auto fourCCList = entry->getAVIFourCCList();
+            const auto& fourCCList = entry->getAVIFourCCList();
             if (!fourCCList.empty()) {
                 item = values.append_child("item");
                 createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC, ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC);
-                setValue(item, std::accumulate(next(fourCCList.begin()), fourCCList.end(), fourCCList[0], [](auto&& a, auto&& b) { return fmt::format("{}, {}", a.c_str(), b.c_str()); }));
+                setValue(item, std::accumulate(next(fourCCList.begin()), fourCCList.end(), fourCCList[0], [](auto&& a, auto&& b) { return fmt::format("{}, {}", a, b); }));
             }
         }
         pr++;
@@ -409,7 +415,7 @@ void web::configLoad::process()
     // write autoscan configuration
     for (auto&& ascs : ConfigDefinition::getConfigSetupList<ConfigAutoscanSetup>()) {
         auto autoscan = ascs->getValue()->getAutoscanListOption();
-        for (size_t i = 0; i < autoscan->size(); i++) {
+        for (std::size_t i = 0; i < autoscan->size(); i++) {
             auto&& entry = autoscan->get(i);
             auto&& adir = content->getAutoscanDirectory(entry->getLocation());
             auto item = values.append_child("item");
@@ -490,8 +496,8 @@ void web::configLoad::process()
     // write content of all arrays
     for (auto&& acs : ConfigDefinition::getConfigSetupList<ConfigArraySetup>()) {
         auto array = acs->getValue()->getArrayOption(true);
-        for (size_t i = 0; i < array.size(); i++) {
-            auto entry = array[i];
+        for (std::size_t i = 0; i < array.size(); i++) {
+            auto&& entry = array[i];
             auto item = values.append_child("item");
             createItem(item, acs->getItemPath(i), acs->option, acs->attrOption != CFG_MAX ? acs->attrOption : acs->nodeOption, acs);
             setValue(item, entry);
@@ -502,9 +508,9 @@ void web::configLoad::process()
     for (auto&& entry : dbEntries) {
         auto exItem = allItems.find(entry.item);
         if (exItem != allItems.end()) {
-            auto item = exItem->second;
-            item->attribute("source") = "database";
-            item->attribute("status") = entry.status.c_str();
+            auto item = root.select_node(exItem->second.c_str()).node();
+            item.attribute("source") = "database";
+            item.attribute("status") = entry.status.c_str();
         } else {
             auto cs = ConfigDefinition::findConfigSetupByPath(entry.item, true);
             auto acs = ConfigDefinition::findConfigSetupByPath(entry.item, true, cs);
