@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     edit_load.cc - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -31,7 +31,6 @@
 
 #include "pages.h" // API
 
-#include <cstdio>
 #include <fmt/chrono.h>
 
 #include "cds_objects.h"
@@ -41,23 +40,22 @@
 #include "upnp_xml.h"
 #include "util/tools.h"
 
-web::edit_load::edit_load(std::shared_ptr<ContentManager> content, std::shared_ptr<UpnpXMLBuilder> xmlBuilder)
-    : WebRequestHandler(std::move(content))
+Web::EditLoad::EditLoad(const std::shared_ptr<ContentManager>& content, std::shared_ptr<UpnpXMLBuilder> xmlBuilder)
+    : WebRequestHandler(content)
     , xmlBuilder(std::move(xmlBuilder))
 {
 }
 
 /// \brief: process request 'edit_load' to list contents of a folder
-void web::edit_load::process()
+void Web::EditLoad::process()
 {
-    check_request();
+    checkRequest();
 
     std::string objID = param("object_id");
-    int objectID;
     if (objID.empty())
         throw_std_runtime_error("invalid object id");
 
-    objectID = std::stoi(objID);
+    auto objectID = std::stoi(objID);
     auto obj = database->loadObject(objectID);
 
     // set handling of json properties
@@ -104,7 +102,7 @@ void web::edit_load::process()
     xml2JsonHints->setArrayName(metaData, "metadata");
     xml2JsonHints->setFieldType("metavalue", "string");
 
-    for (auto&& [key, val] : obj->getMetadata()) {
+    for (auto&& [key, val] : obj->getMetaData()) {
         auto metaEntry = metaData.append_child("metadata");
         metaEntry.append_attribute("metaname") = key.c_str();
         metaEntry.append_attribute("metavalue") = val.c_str();
@@ -162,21 +160,21 @@ void web::edit_load::process()
         // write resource parameters
         for (auto&& [key, val] : resItem->getParameters()) {
             auto resEntry = resources.append_child("resources");
-            resEntry.append_attribute("resname") = fmt::format(".{}", key.c_str()).c_str();
+            resEntry.append_attribute("resname") = fmt::format(".{}", key).c_str();
             resEntry.append_attribute("resvalue") = val.c_str();
             resEntry.append_attribute("editable") = false;
         }
         // write resource attributes
         for (auto&& [key, val] : resItem->getAttributes()) {
             auto resEntry = resources.append_child("resources");
-            resEntry.append_attribute("resname") = fmt::format(" {}", key.c_str()).c_str();
+            resEntry.append_attribute("resname") = fmt::format(" {}", key).c_str();
             resEntry.append_attribute("resvalue") = val.c_str();
             resEntry.append_attribute("editable") = false;
         }
         // write resource options
         for (auto&& [key, val] : resItem->getOptions()) {
             auto resEntry = resources.append_child("resources");
-            resEntry.append_attribute("resname") = fmt::format("-{}", key.c_str()).c_str();
+            resEntry.append_attribute("resname") = fmt::format("-{}", key).c_str();
             resEntry.append_attribute("resvalue") = val.c_str();
             resEntry.append_attribute("editable") = false;
         }
@@ -185,7 +183,7 @@ void web::edit_load::process()
     // write item meta info
     if (obj->isItem()) {
         auto description = item.append_child("description");
-        description.append_attribute("value") = objItem->getMetadata(M_DESCRIPTION).c_str();
+        description.append_attribute("value") = objItem->getMetaData(M_DESCRIPTION).c_str();
         description.append_attribute("editable") = true;
 
         auto location = item.append_child("location");
@@ -205,7 +203,7 @@ void web::edit_load::process()
 
         if (obj->isExternalItem()) {
             auto protocol = item.append_child("protocol");
-            protocol.append_attribute("value") = getProtocol(objItem->getResource(0)->getAttribute(R_PROTOCOLINFO)).c_str();
+            protocol.append_attribute("value") = getProtocol(objItem->getResource(0)->getAttribute(R_PROTOCOLINFO)).data();
             protocol.append_attribute("editable") = true;
         }
     }
