@@ -1,29 +1,29 @@
 /*MT*
-    
+
     MediaTomb - http://www.mediatomb.cc/
-    
+
     session_manager.h - this file is part of MediaTomb.
-    
+
     Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                        Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
-    
+
     Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
-    
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
-    
+
     MediaTomb is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     version 2 along with MediaTomb; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-    
+
     $Id$
 */
 
@@ -41,7 +41,7 @@
 // forward declaration
 class Config;
 
-namespace web {
+namespace Web {
 
 /// \brief One UI session.
 ///
@@ -60,11 +60,11 @@ public:
     explicit Session(std::chrono::seconds timeout);
 
     void put(const std::string& key, std::string value);
-    std::string get(const std::string& key);
+    std::string get(const std::string& key) const;
 
     /// \brief Returns the time of last access to the session.
     /// \return std::chrono::seconds
-    std::chrono::seconds getLastAccessTime() { return last_access; }
+    std::chrono::seconds getLastAccessTime() const { return last_access; }
 
     std::chrono::seconds getTimeout() const { return timeout; }
 
@@ -98,26 +98,26 @@ protected:
 
     void containerChangedUI(const std::vector<int>& objectIDs);
 
-    std::recursive_mutex rmutex;
-    using AutoLockR = std::lock_guard<decltype(rmutex)>;
+    mutable std::recursive_mutex rmutex;
+    using AutoLockR = std::scoped_lock<decltype(rmutex)>;
     std::map<std::string, std::string> dict;
 
     /// \brief True if the ui update id hash became to big and
     /// the UI shall update every container
-    bool updateAll;
+    bool updateAll {};
 
-    std::shared_ptr<std::unordered_set<int>> uiUpdateIDs;
+    std::unordered_set<int> uiUpdateIDs;
 
     /// \brief maximum time the session can be idle (starting from last_access)
     std::chrono::seconds timeout;
 
     /// \brief time of last access to the session, returned by getLastAccessTime()
-    std::chrono::seconds last_access;
+    std::chrono::seconds last_access {};
 
     /// \brief arbitrary but unique string representing the ID of the session (returned by getID())
     std::string sessionID;
 
-    bool loggedIn;
+    bool loggedIn {};
 
     friend class SessionManager;
 };
@@ -127,8 +127,8 @@ class SessionManager : public Timer::Subscriber {
 protected:
     std::shared_ptr<Timer> timer;
 
-    std::mutex mutex;
-    using AutoLock = std::lock_guard<decltype(mutex)>;
+    mutable std::mutex mutex;
+    using AutoLock = std::scoped_lock<decltype(mutex)>;
 
     /// \brief This array is holding available sessions.
     std::vector<std::shared_ptr<Session>> sessions;
@@ -136,15 +136,11 @@ protected:
     std::map<std::string, std::string> accounts;
 
     void checkTimer();
-    bool timerAdded;
+    bool timerAdded {};
 
 public:
     /// \brief Constructor, initializes the array.
     SessionManager(const std::shared_ptr<Config>& config, std::shared_ptr<Timer> timer);
-    ~SessionManager() override { log_debug("SessionManager destroyed"); }
-
-    SessionManager(const SessionManager&) = delete;
-    SessionManager& operator=(const SessionManager&) = delete;
 
     /// \brief Creates a Session with a given timeout.
     /// \param timeout Session timeout in milliseconds.
@@ -158,7 +154,7 @@ public:
     /// \brief Removes a session
     void removeSession(const std::string& sessionID);
 
-    std::string getUserPassword(const std::string& user);
+    std::string getUserPassword(const std::string& user) const;
 
     /// \brief Is called whenever a container changed in a way,
     /// so that it needs to be redrawn in the tree of the UI.
@@ -168,9 +164,9 @@ public:
 
     void containerChangedUI(const std::vector<int>& objectIDs);
 
-    void timerNotify([[maybe_unused]] std::shared_ptr<Timer::Parameter> parameter) override;
+    void timerNotify([[maybe_unused]] const std::shared_ptr<Timer::Parameter>& parameter) override;
 };
 
-} // namespace web
+} // namespace Web
 
 #endif //  __SESSION_MANAGER_H__
