@@ -5,22 +5,26 @@
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
 #include <memory>
+
 namespace fs = std::filesystem;
 
-using namespace ::testing;
+using ::testing::HasSubstr;
+
+static constexpr auto gitBranch = std::string_view(GIT_BRANCH);
+static constexpr auto gitCommitHash = std::string_view(GIT_COMMIT_HASH);
 
 class ServerTest : public ::testing::Test {
 public:
-    ServerTest() {};
-    virtual ~ServerTest() {};
+    ServerTest() = default;
+    ~ServerTest() override = default;
 
-    virtual void SetUp()
+    void SetUp() override
     {
     }
 
-    virtual void TearDown() {};
+    void TearDown() override { }
 
-    std::string exec(const char* cmd)
+    static std::string exec(const char* cmd)
     {
         std::array<char, 128> buffer;
         std::string result;
@@ -28,13 +32,13 @@ public:
         if (!pipe)
             throw_std_runtime_error("popen() failed");
         while (!feof(pipe.get())) {
-            if (fgets(buffer.data(), 128, pipe.get()) != nullptr)
+            if (fgets(buffer.data(), 128, pipe.get()))
                 result += buffer.data();
         }
         return result;
     }
 
-    std::string mockText(std::string mockFile)
+    static std::string mockText(const std::string& mockFile)
     {
         std::ifstream t(mockFile);
         std::string str((std::istreambuf_iterator<char>(t)), std::istreambuf_iterator<char>());
@@ -48,7 +52,7 @@ TEST_F(ServerTest, ServerOutputsHelpInformation)
     fs::path cmd = fs::path(CMAKE_BINARY_DIR) / "gerbera --help 2>&1";
     std::string output = exec(cmd.c_str());
 
-    ASSERT_THAT(output.c_str(), HasSubstr(expectedOutput.c_str()));
+    ASSERT_THAT(output.c_str(), HasSubstr(expectedOutput));
 }
 
 TEST_F(ServerTest, ServerOutputsCompileInformationIncludingGit)
@@ -57,14 +61,14 @@ TEST_F(ServerTest, ServerOutputsCompileInformationIncludingGit)
     std::string output = exec(cmd.c_str());
 
     ASSERT_THAT(output, HasSubstr("Compile info\n-------------\nWITH_"));
-    if (strlen(GIT_BRANCH) > 0) {
+    if constexpr (!gitBranch.empty()) {
         ASSERT_THAT(output, HasSubstr("Git info:\n-------------\n"));
         ASSERT_THAT(output, HasSubstr("Git Branch: "));
     } else {
         ASSERT_THAT(output, Not(HasSubstr("Git info:\n-------------\n")));
         ASSERT_THAT(output, Not(HasSubstr("Git Branch: ")));
     }
-    if (strlen(GIT_COMMIT_HASH) > 0) {
+    if constexpr (!gitCommitHash.empty()) {
         ASSERT_THAT(output, HasSubstr("Git Commit: "));
     } else {
         ASSERT_THAT(output, Not(HasSubstr("Git Commit: ")));
@@ -75,7 +79,7 @@ TEST_F(ServerTest, GeneratesFullConfigFromServerCommand)
 {
     // simple check to ensure complete generation from server
     // rely on ConfigGeneratorTest for validation.
-    std::string topOutput = "<config version=\"2\" xmlns=\"http://mediatomb.cc/config/2\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://mediatomb.cc/config/2 http://mediatomb.cc/config/2.xsd\">";
+    std::string topOutput = R"(<config version="2" xmlns="http://mediatomb.cc/config/2" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://mediatomb.cc/config/2 http://mediatomb.cc/config/2.xsd">)";
     std::string bottomOutput = "</profile>\n    </profiles>\n  </transcoding>\n</config>";
 
     fs::path cmd = fs::path(CMAKE_BINARY_DIR) / "gerbera --create-config 2>&1";
