@@ -9,15 +9,16 @@
 #include "../mock/config_mock.h"
 #include "../mock/database_mock.h"
 
-using namespace ::testing;
+using ::testing::Return;
+using ::testing::_;
 
 class UpnpXmlTest : public ::testing::Test {
 
 public:
-    UpnpXmlTest() {};
-    virtual ~UpnpXmlTest() {};
+    UpnpXmlTest() = default;
+    ~UpnpXmlTest() override = default;
 
-    virtual void SetUp()
+    void SetUp() override
     {
         config = std::make_shared<ConfigMock>();
 
@@ -29,10 +30,10 @@ public:
         subject = new UpnpXMLBuilder(context, virtualDir, presentationURl);
     }
 
-    virtual void TearDown()
+    void TearDown() override
     {
         delete subject;
-    };
+    }
 
     UpnpXMLBuilder* subject;
     std::shared_ptr<ConfigMock> config;
@@ -43,19 +44,19 @@ public:
 TEST_F(UpnpXmlTest, RenderObjectContainer)
 {
     // arrange
-    pugi::xml_document didl_lite;
-    auto root = didl_lite.append_child("DIDL-Lite");
+    pugi::xml_document didlLite;
+    auto root = didlLite.append_child("DIDL-Lite");
     auto obj = std::make_shared<CdsContainer>();
     obj->setID(1);
     obj->setParentID(2);
     obj->setRestricted(false);
     obj->setTitle("Title");
     obj->setClass(UPNP_CLASS_MUSIC_ALBUM);
-    obj->setMetadata(M_ALBUMARTIST, "Creator");
-    obj->setMetadata(M_COMPOSER, "Composer");
-    obj->setMetadata(M_CONDUCTOR, "Conductor");
-    obj->setMetadata(M_ORCHESTRA, "Orchestra");
-    obj->setMetadata(M_UPNP_DATE, "2001-01-01");
+    obj->addMetaData(M_ALBUMARTIST, "Creator");
+    obj->addMetaData(M_COMPOSER, "Composer");
+    obj->addMetaData(M_CONDUCTOR, "Conductor");
+    obj->addMetaData(M_ORCHESTRA, "Orchestra");
+    obj->addMetaData(M_UPNP_DATE, "2001-01-01");
 
     // albumArtURI
     auto resource = std::make_shared<CdsResource>(CH_CONTAINERART);
@@ -77,34 +78,34 @@ TEST_F(UpnpXmlTest, RenderObjectContainer)
     expectedXml << "<upnp:conductor>Conductor</upnp:conductor>\n";
     expectedXml << "<upnp:date>2001-01-01</upnp:date>\n";
     expectedXml << "<upnp:orchestra>Orchestra</upnp:orchestra>\n";
-    expectedXml << "<upnp:albumArtURI>http://server/content/media/object_id/1/res_id/0/rct/aa/rh/11</upnp:albumArtURI>\n";
+    expectedXml << "<upnp:albumArtURI>http://server/content/media/object_id/1/res_id/0/rct/aa</upnp:albumArtURI>\n";
     expectedXml << "</container>\n";
     expectedXml << "</DIDL-Lite>\n";
 
     // act
-    subject->renderObject(obj, std::string::npos, &root);
+    subject->renderObject(obj, std::string::npos, root);
 
     // assert
     std::ostringstream buf;
-    didl_lite.print(buf, "", 0);
-    std::string didl_lite_xml = buf.str();
-    EXPECT_STREQ(didl_lite_xml.c_str(), expectedXml.str().c_str());
+    didlLite.print(buf, "", 0);
+    std::string didlLiteXml = buf.str();
+    EXPECT_STREQ(didlLiteXml.c_str(), expectedXml.str().c_str());
 }
 
 TEST_F(UpnpXmlTest, RenderObjectItem)
 {
     // arrange
-    pugi::xml_document didl_lite;
-    auto root = didl_lite.append_child("DIDL-Lite");
+    pugi::xml_document didlLite;
+    auto root = didlLite.append_child("DIDL-Lite");
     auto obj = std::make_shared<CdsItem>();
     obj->setID(1);
     obj->setParentID(2);
     obj->setRestricted(false);
     obj->setTitle("Title");
     obj->setClass(UPNP_CLASS_MUSIC_TRACK);
-    obj->setMetadata(M_DESCRIPTION, "Description");
-    obj->setMetadata(M_TRACKNUMBER, "10");
-    obj->setMetadata(M_ALBUM, "Album");
+    obj->addMetaData(M_DESCRIPTION, "Description");
+    obj->addMetaData(M_ALBUM, "Album");
+    obj->addMetaData(M_TRACKNUMBER, "10");
 
     std::ostringstream expectedXml;
     expectedXml << "<DIDL-Lite>\n";
@@ -117,33 +118,36 @@ TEST_F(UpnpXmlTest, RenderObjectItem)
     expectedXml << "</item>\n";
     expectedXml << "</DIDL-Lite>\n";
 
+    EXPECT_CALL(*config, getOption(CFG_IMPORT_LIBOPTS_ENTRY_SEP))
+        .WillRepeatedly(Return(" / "));
+    log_warning(CFG_IMPORT_LIBOPTS_ENTRY_SEP);
     EXPECT_CALL(*config, getTranscodingProfileListOption(_))
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, &root);
+    subject->renderObject(obj, std::string::npos, root);
 
     // assert
     std::ostringstream buf;
-    didl_lite.print(buf, "", 0);
-    std::string didl_lite_xml = buf.str();
-    EXPECT_STREQ(didl_lite_xml.c_str(), expectedXml.str().c_str());
+    didlLite.print(buf, "", 0);
+    std::string didlLiteXml = buf.str();
+    EXPECT_STREQ(didlLiteXml.c_str(), expectedXml.str().c_str());
 }
 
 TEST_F(UpnpXmlTest, RenderObjectItemWithResources)
 {
     // arrange
-    pugi::xml_document didl_lite;
-    auto root = didl_lite.append_child("DIDL-Lite");
+    pugi::xml_document didlLite;
+    auto root = didlLite.append_child("DIDL-Lite");
     auto obj = std::make_shared<CdsItem>();
     obj->setID(42);
     obj->setParentID(2);
     obj->setRestricted(false);
     obj->setTitle("Title");
     obj->setClass(UPNP_CLASS_MUSIC_TRACK);
-    obj->setMetadata(M_DESCRIPTION, "Description");
-    obj->setMetadata(M_TRACKNUMBER, "7");
-    obj->setMetadata(M_ALBUM, "Album");
+    obj->addMetaData(M_DESCRIPTION, "Description");
+    obj->addMetaData(M_ALBUM, "Album");
+    obj->addMetaData(M_TRACKNUMBER, "7");
 
     auto resource = std::make_shared<CdsResource>(CH_DEFAULT);
     resource->addAttribute(R_PROTOCOLINFO, "http-get:*:audio/mpeg:*");
@@ -176,28 +180,31 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithResources)
     expectedXml << "<dc:description>Description</dc:description>\n";
     expectedXml << "<upnp:album>Album</upnp:album>\n";
     expectedXml << "<upnp:originalTrackNumber>7</upnp:originalTrackNumber>\n";
-    expectedXml << "<res bitrate=\"16044\" duration=\"123456\" nrAudioChannels=\"2\" protocolInfo=\"http-get:*:audio/mpeg:DLNA.ORG_OP=01;DLNA.ORG_CI=0\" size=\"4711\">http://server/content/media/object_id/42/res_id/0</res>\n";
-    expectedXml << "<res protocolInfo=\"http-get:*:srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0\" resFile=\"/home/resource/subtitle.srt\">http://server/content/media/object_id/42/res_id/1/rct/vs/type/srt</res>\n";
     expectedXml << "<upnp:albumArtURI xmlns:dlna=\"urn:schemas-dlna-org:metadata-1-0\" dlna:profileID=\"JPEG_TN\">http://server/content/media/object_id/42/res_id/2/rct/aa</upnp:albumArtURI>\n";
+    expectedXml << "<sec:CaptionInfoEx protocolInfo=\"http-get:*:srt:*\" sec:type=\"srt\">http://server/content/media/object_id/42/res_id/1/rct/vs/type/srt/ext/file.subtitle.srt</sec:CaptionInfoEx>\n";
+    expectedXml << "<res bitrate=\"16044\" duration=\"123456\" nrAudioChannels=\"2\" protocolInfo=\"http-get:*:audio/mpeg:DLNA.ORG_PN=MP3;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=01700000000000000000000000000000\" size=\"4711\">http://server/content/media/object_id/42/res_id/0/ext/file.mp3</res>\n";
+    expectedXml << "<res protocolInfo=\"http-get:*:srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\">http://server/content/media/object_id/42/res_id/1/rct/vs/type/srt/ext/file.subtitle.srt</res>\n";
     expectedXml << "</item>\n";
     expectedXml << "</DIDL-Lite>\n";
 
+    EXPECT_CALL(*config, getOption(CFG_IMPORT_LIBOPTS_ENTRY_SEP))
+        .WillRepeatedly(Return(" / "));
     EXPECT_CALL(*config, getTranscodingProfileListOption(_))
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, &root);
+    subject->renderObject(obj, std::string::npos, root);
 
     // assert
     std::ostringstream buf;
-    didl_lite.print(buf, "", 0);
-    std::string didl_lite_xml = buf.str();
-    EXPECT_STREQ(didl_lite_xml.c_str(), expectedXml.str().c_str());
+    didlLite.print(buf, "", 0);
+    std::string didlLiteXml = buf.str();
+    EXPECT_STREQ(didlLiteXml.c_str(), expectedXml.str().c_str());
 }
 
 TEST_F(UpnpXmlTest, CreatesEventPropertySet)
 {
-    auto result = subject->createEventPropertySet();
+    auto result = UpnpXMLBuilder::createEventPropertySet();
     auto root = result->document_element();
 
     EXPECT_NE(root, nullptr);
@@ -211,7 +218,7 @@ TEST_F(UpnpXmlTest, CreateResponse)
     std::string actionName = "action";
     std::string serviceType = "urn:schemas-upnp-org:service:ContentDirectory:1";
 
-    auto result = subject->createResponse(actionName, serviceType);
+    auto result = UpnpXMLBuilder::createResponse(actionName, serviceType);
     EXPECT_NE(result, nullptr);
 
     auto root = result->document_element();
@@ -226,7 +233,7 @@ TEST_F(UpnpXmlTest, FirstResourceRendersPureWhenExternalUrl)
 
     auto item = std::static_pointer_cast<CdsItem>(obj);
 
-    std::string result = subject->getFirstResourcePath(item);
+    std::string result = UpnpXMLBuilder::getFirstResourcePath(item);
 
     EXPECT_NE(result, "");
     EXPECT_STREQ(result.c_str(), "http://localhost/external/url");
@@ -242,7 +249,7 @@ TEST_F(UpnpXmlTest, FirstResourceAddsLocalResourceIdToExternalUrlWhenOnlineWithP
 
     auto item = std::static_pointer_cast<CdsItem>(obj);
 
-    std::string result = subject->getFirstResourcePath(item);
+    std::string result = UpnpXMLBuilder::getFirstResourcePath(item);
 
     EXPECT_NE(result, "");
     EXPECT_STREQ(result.c_str(), "content/online/object_id/12345/res_id/0");
@@ -256,7 +263,7 @@ TEST_F(UpnpXmlTest, FirstResourceAddsLocalResourceIdToItem)
 
     auto item = std::static_pointer_cast<CdsItem>(obj);
 
-    std::string result = subject->getFirstResourcePath(item);
+    std::string result = UpnpXMLBuilder::getFirstResourcePath(item);
 
     EXPECT_NE(result, "");
     EXPECT_STREQ(result.c_str(), "content/media/object_id/12345/res_id/0");
