@@ -4,7 +4,7 @@ Gerbera - https://gerbera.io/
 
     mysql_config_fake.h - this file is part of Gerbera.
 
-    Copyright (C) 2020-2021 Gerbera Contributors
+    Copyright (C) 2020-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -27,7 +27,8 @@ Gerbera - https://gerbera.io/
 class MySQLConfigFake : public Config {
 public:
     fs::path getConfigFilename() const override { return {}; }
-    std::string getOption(config_option_t option) const override {
+    std::string getOption(config_option_t option) const override
+    {
         if (option == CFG_SERVER_STORAGE_MYSQL_HOST) {
             return "hydra.home";
         }
@@ -43,12 +44,12 @@ public:
         if (option == CFG_SERVER_STORAGE_MYSQL_UPGRADE_FILE) {
             return "mysql-upgrade.xml";
         }
-//        if (option == CFG_SERVER_STORAGE_MYSQL_DATABASE) {
-//            return "gerbera";
-//        }
+        //        if (option == CFG_SERVER_STORAGE_MYSQL_DATABASE) {
+        //            return "gerbera";
+        //        }
         return {};
     }
-    void addOption(config_option_t option, std::shared_ptr<ConfigOption> optionValue) override { }
+    void addOption(config_option_t option, const std::shared_ptr<ConfigOption>& optionValue) override { }
     int getIntOption(config_option_t option) const override { return 0; }
     bool getBoolOption(config_option_t option) const override { return false; }
     std::map<std::string, std::string> getDictionaryOption(config_option_t option) const override { return {}; }
@@ -56,7 +57,7 @@ public:
     std::shared_ptr<AutoscanList> getAutoscanListOption(config_option_t option) const override { return nullptr; }
     std::shared_ptr<ClientConfigList> getClientConfigListOption(config_option_t option) const override { return nullptr; }
     std::shared_ptr<DirectoryConfigList> getDirectoryTweakOption(config_option_t option) const override { return nullptr; }
-    void updateConfigFromDatabase(std::shared_ptr<Database> database) override {}
+    void updateConfigFromDatabase(const std::shared_ptr<Database>& database) override { }
     std::string getOrigValue(const std::string& item) const override { return {}; }
     void setOrigValue(const std::string& item, const std::string& value) override { }
     void setOrigValue(const std::string& item, bool value) override { }
@@ -64,7 +65,6 @@ public:
     bool hasOrigValue(const std::string& item) const override { return false; }
     std::shared_ptr<TranscodingProfileList> getTranscodingProfileListOption(config_option_t option) const override { return nullptr; }
     std::shared_ptr<DynamicContentList> getDynamicContentListOption(config_option_t option) const override { return nullptr; }
-    fs::path getDataDir() const override { return "/usr/local/share/gerbera"; }
 };
 
 #endif //GERBERA_MYSQL_CONFIG_FAKE_H
