@@ -5,8 +5,6 @@
 #include <gtest/gtest.h>
 #include <memory>
 
-#include "cds_objects.h"
-#include "config/config_manager.h"
 #include "content/onlineservice/online_service.h"
 #include "metadata/metadata_handler.h"
 #include "util/string_converter.h"
@@ -15,8 +13,6 @@
 #include "mock/duk_helper.h"
 #include "mock/script_test_fixture.h"
 
-using namespace ::testing;
-
 class ImportScriptTest : public ScriptTestFixture {
 public:
     ImportScriptTest()
@@ -58,7 +54,8 @@ static duk_ret_t addContainerTree(duk_context* ctx)
         { "/Audio/Artists/Artist/All - full name", "45" },
         { "/Audio/Artists/Artist/Album", "46" },
         { "/Audio/Albums/Album", "47" },
-        { "/Audio/Genres/Genre", "48" },
+        { "/Audio/Genres/Genre", "481" },
+        { "/Audio/Genres/Genre2", "482" },
         { "/Audio/Composers/Composer", "49" },
         { "/Audio/Year/2018", "50" },
         { "/Video/All Video", "60" },
@@ -92,16 +89,16 @@ static duk_ret_t addCdsObject(duk_context* ctx)
 {
     std::vector<std::string> keys {
         "title",
-        "meta['dc:title']",
-        "meta['upnp:artist']",
-        "meta['upnp:album']",
-        "meta['dc:date']",
-        "meta['upnp:date']",
-        "meta['upnp:genre']",
-        "meta['dc:description']",
-        "meta['upnp:composer']",
-        "meta['upnp:conductor']",
-        "meta['upnp:orchestra']"
+        "metaData['dc:title']",
+        "metaData['upnp:artist']",
+        "metaData['upnp:album']",
+        "metaData['dc:date']",
+        "metaData['upnp:date']",
+        "metaData['upnp:genre']",
+        "metaData['dc:description']",
+        "metaData['upnp:composer']",
+        "metaData['upnp:conductor']",
+        "metaData['upnp:orchestra']",
     };
     addCdsObjectParams params = ScriptTestFixture::addCdsObject(ctx, keys);
     return ImportScriptTest::commonScriptMock->addCdsObject(params.objectValues, params.containerChain, params.objectType);
@@ -135,14 +132,14 @@ static duk_function_list_entry js_global_functions[] = {
 };
 
 template <typename Map>
-bool map_compare(Map const& lhs, Map const& rhs)
+bool mapCompare(Map const& lhs, Map const& rhs)
 {
     return lhs.size() == rhs.size() && std::equal(lhs.begin(), lhs.end(), rhs.begin());
 }
 MATCHER_P(IsIdenticalMap, control, "Map to be identical")
 {
     {
-        return (map_compare(arg, control));
+        return (mapCompare(arg, control));
     }
 }
 
@@ -163,24 +160,26 @@ TEST_F(ImportScriptTest, AddsAudioItemToVariousCdsContainerChains)
     std::string date = "2018-01-01";
     std::string year = "2018";
     std::string genre = "Genre";
+    std::string genre2 = "Genre2";
     std::string desc = "Description";
     std::string id = "2";
     std::string location = "/home/gerbera/audio.mp3";
     std::string channels = "2";
-    int online_service = 0;
+    int onlineService = 0;
     int theora = 0;
     std::map<std::string, std::string> aux;
 
-    std::map<std::string, std::string> meta {
-        { "dc:title", title },
-        { "upnp:artist", artist },
-        { "upnp:album", album },
+    std::vector<std::pair<std::string, std::string>> meta {
         { "dc:date", date },
-        { "upnp:date", year },
-        { "upnp:genre", genre },
         { "dc:description", desc },
+        { "dc:title", title },
+        { "upnp:album", album },
+        { "upnp:artist", artist },
         { "upnp:composer", composer },
         { "upnp:conductor", conductor },
+        { "upnp:date", year },
+        { "upnp:genre", genre },
+        { "upnp:genre", genre2 },
         { "upnp:orchestra", orchestra },
     };
 
@@ -190,17 +189,17 @@ TEST_F(ImportScriptTest, AddsAudioItemToVariousCdsContainerChains)
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
     std::map<std::string, std::string> asAudioAllAudio {
+        { "metaData['dc:date']", date },
+        { "metaData['dc:description']", desc },
+        { "metaData['dc:title']", title },
+        { "metaData['upnp:album']", album },
+        { "metaData['upnp:artist']", artist },
+        { "metaData['upnp:composer']", composer },
+        { "metaData['upnp:conductor']", conductor },
+        { "metaData['upnp:date']", year },
+        { "metaData['upnp:genre']", fmt::format("{},{}", genre, genre2) },
+        { "metaData['upnp:orchestra']", orchestra },
         { "title", title },
-        { "meta['dc:title']", title },
-        { "meta['upnp:artist']", artist },
-        { "meta['upnp:album']", album },
-        { "meta['dc:date']", date },
-        { "meta['upnp:date']", year },
-        { "meta['upnp:genre']", genre },
-        { "meta['dc:description']", desc },
-        { "meta['upnp:composer']", composer },
-        { "meta['upnp:conductor']", conductor },
-        { "meta['upnp:orchestra']", orchestra },
     };
 
     std::map<std::string, std::string> asAudioAllFullName;
@@ -232,7 +231,9 @@ TEST_F(ImportScriptTest, AddsAudioItemToVariousCdsContainerChains)
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "47", UNDEFINED)).WillOnce(Return(0));
 
     EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("Audio", "Genres", "Genre"))).WillOnce(Return(1));
-    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "48", UNDEFINED)).WillOnce(Return(0));
+    EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("Audio", "Genres", "Genre2"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "481", UNDEFINED)).WillOnce(Return(0));
+    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "482", UNDEFINED)).WillOnce(Return(0));
 
     EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("Audio", "Composers", "Composer"))).WillOnce(Return(1));
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "49", UNDEFINED)).WillOnce(Return(0));
@@ -241,7 +242,7 @@ TEST_F(ImportScriptTest, AddsAudioItemToVariousCdsContainerChains)
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "50", UNDEFINED)).WillOnce(Return(0));
 
     addGlobalFunctions(ctx, js_global_functions);
-    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, online_service);
+    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, onlineService);
     executeScript(ctx);
 }
 
@@ -251,10 +252,10 @@ TEST_F(ImportScriptTest, AddsVideoItemToCdsContainerChainWithDirs)
     std::string mimetype = "video/mpeg";
     std::string id = "2";
     std::string location = "/home/gerbera/video.mp4";
-    auto online_service = int(OS_None);
+    auto onlineService = int(OS_None);
     int theora = 0;
     std::map<std::string, std::string> aux;
-    std::map<std::string, std::string> meta;
+    std::vector<std::pair<std::string, std::string>> meta;
     std::map<std::string, std::string> res;
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
@@ -276,7 +277,7 @@ TEST_F(ImportScriptTest, AddsVideoItemToCdsContainerChainWithDirs)
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asVideoAllVideo), "61", UNDEFINED)).WillOnce(Return(0));
 
     addGlobalFunctions(ctx, js_global_functions);
-    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, online_service);
+    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, onlineService);
     executeScript(ctx);
 }
 
@@ -288,11 +289,11 @@ TEST_F(ImportScriptTest, AddsAppleTrailerVideoItemToCdsContainerChains)
     std::string genre = "Genre";
     std::string id = "2";
     std::string location = "/home/gerbera/video.mp4";
-    auto online_service = int(OS_ATrailers);
+    auto onlineService = int(OS_ATrailers);
     int theora = 0;
     std::map<std::string, std::string> res;
 
-    std::map<std::string, std::string> meta {
+    std::vector<std::pair<std::string, std::string>> meta {
         { "dc:date", date },
         { "upnp:genre", genre },
     };
@@ -304,8 +305,8 @@ TEST_F(ImportScriptTest, AddsAppleTrailerVideoItemToCdsContainerChains)
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
     std::map<std::string, std::string> asVideoAllVideo {
         { "title", title },
-        { "meta['dc:date']", date },
-        { "meta['upnp:genre']", genre },
+        { "metaData['dc:date']", date },
+        { "metaData['upnp:genre']", genre },
     };
 
     // Expecting the common script calls
@@ -326,7 +327,7 @@ TEST_F(ImportScriptTest, AddsAppleTrailerVideoItemToCdsContainerChains)
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asVideoAllVideo), "83", UNDEFINED)).WillOnce(Return(0));
 
     addGlobalFunctions(ctx, js_global_functions);
-    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, online_service);
+    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, onlineService);
     executeScript(ctx);
 }
 
@@ -337,10 +338,10 @@ TEST_F(ImportScriptTest, AddsImageItemToCdsContainerChains)
     std::string date = "2018-01-01";
     std::string id = "2";
     std::string location = "/home/gerbera/image.jpg";
-    auto online_service = int(OS_ATrailers);
+    auto onlineService = int(OS_ATrailers);
     int theora = 0;
 
-    std::map<std::string, std::string> meta {
+    std::vector<std::pair<std::string, std::string>> meta {
         { "dc:date", date },
     };
 
@@ -350,7 +351,7 @@ TEST_F(ImportScriptTest, AddsImageItemToCdsContainerChains)
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
     std::map<std::string, std::string> asImagePhotos {
         { "title", title },
-        { "meta['dc:date']", date },
+        { "metaData['dc:date']", date },
     };
 
     // Expecting the common script calls
@@ -373,7 +374,7 @@ TEST_F(ImportScriptTest, AddsImageItemToCdsContainerChains)
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asImagePhotos), "73", UNDEFINED)).WillOnce(Return(0));
 
     addGlobalFunctions(ctx, js_global_functions);
-    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, online_service);
+    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, onlineService);
     executeScript(ctx);
 }
 
@@ -383,10 +384,10 @@ TEST_F(ImportScriptTest, AddsOggTheoraVideoItemToCdsContainerChainWithDirs)
     std::string mimetype = "application/ogg";
     std::string id = "2";
     std::string location = "/home/gerbera/video.ogg";
-    auto online_service = int(OS_None);
+    auto onlineService = int(OS_None);
     int theora = 1;
     std::map<std::string, std::string> aux;
-    std::map<std::string, std::string> meta;
+    std::vector<std::pair<std::string, std::string>> meta;
     std::map<std::string, std::string> res;
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
@@ -408,7 +409,7 @@ TEST_F(ImportScriptTest, AddsOggTheoraVideoItemToCdsContainerChainWithDirs)
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asVideoAllVideo), "61", UNDEFINED)).WillOnce(Return(0));
 
     addGlobalFunctions(ctx, js_global_functions);
-    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, online_service);
+    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, onlineService);
     executeScript(ctx);
 }
 
@@ -428,11 +429,11 @@ TEST_F(ImportScriptTest, AddsOggTheoraAudioItemToVariousCdsContainerChains)
     std::string id = "2";
     std::string location = "/home/gerbera/audio.mp3";
     std::string channels = "2";
-    int online_service = 0;
+    int onlineService = 0;
     int theora = 0;
     std::map<std::string, std::string> aux;
 
-    std::map<std::string, std::string> meta {
+    std::vector<std::pair<std::string, std::string>> meta {
         { "dc:title", title },
         { "upnp:artist", artist },
         { "upnp:album", album },
@@ -451,17 +452,17 @@ TEST_F(ImportScriptTest, AddsOggTheoraAudioItemToVariousCdsContainerChains)
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
     std::map<std::string, std::string> asAudioAllAudio {
+        { "metaData['dc:date']", date },
+        { "metaData['dc:description']", desc },
+        { "metaData['dc:title']", title },
+        { "metaData['upnp:album']", album },
+        { "metaData['upnp:artist']", artist },
+        { "metaData['upnp:composer']", composer },
+        { "metaData['upnp:conductor']", conductor },
+        { "metaData['upnp:date']", year },
+        { "metaData['upnp:genre']", genre },
+        { "metaData['upnp:orchestra']", orchestra },
         { "title", title },
-        { "meta['dc:title']", title },
-        { "meta['upnp:artist']", artist },
-        { "meta['upnp:album']", album },
-        { "meta['dc:date']", date },
-        { "meta['upnp:date']", year },
-        { "meta['upnp:genre']", genre },
-        { "meta['dc:description']", desc },
-        { "meta['upnp:composer']", composer },
-        { "meta['upnp:conductor']", conductor },
-        { "meta['upnp:orchestra']", orchestra },
     };
 
     std::map<std::string, std::string> asAudioAllFullName;
@@ -493,7 +494,7 @@ TEST_F(ImportScriptTest, AddsOggTheoraAudioItemToVariousCdsContainerChains)
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "47", UNDEFINED)).WillOnce(Return(0));
 
     EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("Audio", "Genres", "Genre"))).WillOnce(Return(1));
-    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "48", UNDEFINED)).WillOnce(Return(0));
+    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "481", UNDEFINED)).WillOnce(Return(0));
 
     EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("Audio", "Composers", "Composer"))).WillOnce(Return(1));
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "49", UNDEFINED)).WillOnce(Return(0));
@@ -502,7 +503,7 @@ TEST_F(ImportScriptTest, AddsOggTheoraAudioItemToVariousCdsContainerChains)
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudio), "50", UNDEFINED)).WillOnce(Return(0));
 
     addGlobalFunctions(ctx, js_global_functions);
-    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, online_service);
+    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, onlineService);
     executeScript(ctx);
 }
 
