@@ -5,8 +5,6 @@
 #include <gtest/gtest.h>
 #include <memory>
 
-#include "cds_objects.h"
-#include "config/config_manager.h"
 #include "content/onlineservice/online_service.h"
 #include "metadata/metadata_handler.h"
 #include "util/string_converter.h"
@@ -15,8 +13,6 @@
 #include "mock/duk_helper.h"
 #include "mock/script_test_fixture.h"
 
-using namespace ::testing;
-
 class ImportStructuredScriptTest : public ScriptTestFixture {
 public:
     ImportStructuredScriptTest()
@@ -60,8 +56,10 @@ static duk_ret_t addContainerTree(duk_context* ctx)
         { "/-Artist-/-ABCD-/-all-/Artist", "46" },
         { "/-Artist-/-ABCD-/A/Artist/-all-", "47" },
         { "/-Artist-/-ABCD-/A/Artist/Album (2018)", "48" },
-        { "/-Genre-/Genre/--all--", "49" },
-        { "/-Genre-/Genre/-A-/Album - Artist", "50" },
+        { "/-Genre-/Genre/--all--", "491" },
+        { "/-Genre-/Genre2/--all--", "492" },
+        { "/-Genre-/Genre/-A-/Album - Artist", "501" },
+        { "/-Genre-/Genre2/-A-/Album - Artist", "502" },
         { "/-Track-/-ABCD-/A", "51" },
         { "/-Track-/--all--", "52" },
         { "/-Year-/2010 - 2019/-all-", "53" },
@@ -88,13 +86,13 @@ static duk_ret_t addCdsObject(duk_context* ctx)
 {
     std::vector<std::string> keys = {
         "title",
-        "meta['dc:title']",
-        "meta['upnp:artist']",
-        "meta['upnp:album']",
-        "meta['dc:date']",
-        "meta['upnp:date']",
-        "meta['upnp:genre']",
-        "meta['dc:description']"
+        "metaData['dc:title']",
+        "metaData['upnp:artist']",
+        "metaData['upnp:album']",
+        "metaData['dc:date']",
+        "metaData['upnp:date']",
+        "metaData['upnp:genre']",
+        "metaData['dc:description']"
     };
     addCdsObjectParams params = ScriptTestFixture::addCdsObject(ctx, keys);
     return ImportStructuredScriptTest::commonScriptMock->addCdsObject(params.objectValues, params.containerChain, params.objectType);
@@ -135,14 +133,14 @@ static duk_function_list_entry js_global_functions[] = {
 };
 
 template <typename Map>
-bool map_compare(Map const& lhs, Map const& rhs)
+bool mapCompare(Map const& lhs, Map const& rhs)
 {
     return lhs.size() == rhs.size() && std::equal(lhs.begin(), lhs.end(), rhs.begin());
 }
 MATCHER_P(IsIdenticalMap, control, "Map to be identical")
 {
     {
-        return (map_compare(arg, control));
+        return (mapCompare(arg, control));
     }
 }
 
@@ -160,34 +158,36 @@ TEST_F(ImportStructuredScriptTest, AddsAudioItemWithABCBoxFormat)
     std::string date = "2018-01-01";
     std::string year = "2018";
     std::string genre = "Genre";
+    std::string genre2 = "Genre2";
     std::string desc = "Description";
     std::string id = "2";
     std::string location = "/home/gerbera/audio.mp3";
-    int online_service = 0;
+    int onlineService = 0;
     int theora = 0;
     std::map<std::string, std::string> aux;
     std::map<std::string, std::string> res;
 
-    std::map<std::string, std::string> meta {
+    std::vector<std::pair<std::string, std::string>> meta {
         { "dc:title", title },
         { "upnp:artist", artist },
         { "upnp:album", album },
         { "dc:date", date },
         { "upnp:date", year },
         { "upnp:genre", genre },
+        { "upnp:genre", genre2 },
         { "dc:description", desc },
     };
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
     std::map<std::string, std::string> asAudioAllAudio {
         { "title", title },
-        { "meta['dc:title']", title },
-        { "meta['upnp:artist']", artist },
-        { "meta['upnp:album']", album },
-        { "meta['dc:date']", date },
-        { "meta['upnp:date']", year },
-        { "meta['upnp:genre']", genre },
-        { "meta['dc:description']", desc },
+        { "metaData['dc:title']", title },
+        { "metaData['upnp:artist']", artist },
+        { "metaData['upnp:album']", album },
+        { "metaData['dc:date']", date },
+        { "metaData['upnp:date']", year },
+        { "metaData['upnp:genre']", fmt::format("{},{}", genre, genre2) },
+        { "metaData['dc:description']", desc },
     };
 
     std::map<std::string, std::string> asAudioAllFullName;
@@ -238,11 +238,15 @@ TEST_F(ImportStructuredScriptTest, AddsAudioItemWithABCBoxFormat)
 
     // GENRE //
     EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("-Genre-", "Genre", "--all--"))).WillOnce(Return(1));
-    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudioTitleArtist), "49", UNDEFINED)).WillOnce(Return(0));
+    EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("-Genre-", "Genre2", "--all--"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudioTitleArtist), "491", UNDEFINED)).WillOnce(Return(0));
+    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudioTitleArtist), "492", UNDEFINED)).WillOnce(Return(0));
 
     EXPECT_CALL(*commonScriptMock, abcBox(Eq("Artist"), Eq(26), Eq("-"))).WillOnce(Return(1));
     EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("-Genre-", "Genre", "-A-", "Album - Artist"))).WillOnce(Return(1));
-    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudioTitleArtist), "50", UNDEFINED)).WillOnce(Return(0));
+    EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("-Genre-", "Genre2", "-A-", "Album - Artist"))).WillOnce(Return(1));
+    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudioTitleArtist), "501", UNDEFINED)).WillOnce(Return(0));
+    EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asAudioAllAudioTitleArtist), "502", UNDEFINED)).WillOnce(Return(0));
 
     // TRACKS //
     EXPECT_CALL(*commonScriptMock, abcBox(Eq("Audio Title"), Eq(6), Eq("-"))).WillOnce(Return(1));
@@ -264,7 +268,7 @@ TEST_F(ImportStructuredScriptTest, AddsAudioItemWithABCBoxFormat)
 
     addGlobalFunctions(ctx, js_global_functions, { { "/import/scripting/virtual-layout/attribute::audio-layout", audioLayout }, { "/import/scripting/virtual-layout/structured-layout/attribute::genre-box", "26" } });
 
-    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, online_service);
+    dukMockItem(ctx, mimetype, id, theora, title, meta, aux, res, location, onlineService);
     executeScript(ctx);
 }
 
