@@ -6,15 +6,12 @@
 #include <memory>
 
 #include "cds_objects.h"
-#include "config/config_manager.h"
 #include "util/string_converter.h"
 
 #include "mock/common_script_mock.h"
 #include "mock/duk_helper.h"
 #include "mock/script_test_fixture.h"
 
-using namespace ::testing;
-
 // Extends ScriptTestFixture to allow
 // for unique testing of the Internal URL Playlist
 // processing
@@ -23,9 +20,6 @@ public:
     // As Duktape requires static methods, so must the mock expectations be
     static std::unique_ptr<CommonScriptMock> commonScriptMock;
 
-    // Used to iterate through `readln` content
-    static int readLineCnt;
-
     InternalUrlPLSPlaylistTest()
     {
         commonScriptMock = std::make_unique<::testing::NiceMock<CommonScriptMock>>();
@@ -39,7 +33,6 @@ public:
 };
 
 std::unique_ptr<CommonScriptMock> InternalUrlPLSPlaylistTest::commonScriptMock;
-int InternalUrlPLSPlaylistTest::readLineCnt = 0;
 
 static duk_ret_t getPlaylistType(duk_context* ctx)
 {
@@ -81,19 +74,7 @@ static duk_ret_t getLastPath(duk_context* ctx)
 // Uses the `CommonScriptMock` to track expectations
 static duk_ret_t readln(duk_context* ctx)
 {
-    std::vector<std::string> lines {
-        "[playlist]",
-        "\n",
-        "File1=/home/gerbera/example.mp3",
-        "Title1=Song from Playlist Title",
-        "Length1=120",
-        "\n",
-        "NumberOfEntries=1",
-        "Version=2",
-        "-EOF-" // used to stop processing
-    };
-
-    std::string line = lines.at(InternalUrlPLSPlaylistTest::readLineCnt);
+    std::string line = InternalUrlPLSPlaylistTest::lines.at(InternalUrlPLSPlaylistTest::readLineCnt);
 
     duk_push_string(ctx, line.c_str());
     InternalUrlPLSPlaylistTest::readLineCnt++;
@@ -165,14 +146,14 @@ static duk_function_list_entry js_global_functions[] = {
 };
 
 template <typename Map>
-bool map_compare(Map const& lhs, Map const& rhs)
+bool mapCompare(Map const& lhs, Map const& rhs)
 {
     return lhs.size() == rhs.size() && std::equal(lhs.begin(), lhs.end(), rhs.begin());
 }
 MATCHER_P(IsIdenticalMap, control, "Map to be identical")
 {
     {
-        return (map_compare(arg, control));
+        return (mapCompare(arg, control));
     }
 }
 
@@ -181,8 +162,9 @@ TEST_F(InternalUrlPLSPlaylistTest, CreatesDukContextWithPlaylistScript)
     EXPECT_NE(ctx, nullptr);
 }
 
-TEST_F(InternalUrlPLSPlaylistTest, AddsCdsObjectFromM3UPlaylistWithInternalUrlPlaylistAndDirChains)
+TEST_F(InternalUrlPLSPlaylistTest, AddsCdsObjectFromPlaylistWithInternalUrlPlaylistAndDirChains)
 {
+    ScriptTestFixture::mockPlaylistFile("fixtures/example-internal.pls");
     std::map<std::string, std::string> asPlaylistChain {
         { "objectType", "2" },
         { "location", "/home/gerbera/example.mp3" },
@@ -199,7 +181,7 @@ TEST_F(InternalUrlPLSPlaylistTest, AddsCdsObjectFromM3UPlaylistWithInternalUrlPl
     EXPECT_CALL(*commonScriptMock, getLastPath(Eq("/location/of/playlist.pls"))).WillOnce(Return(1));
     EXPECT_CALL(*commonScriptMock, addContainerTree(ElementsAre("Playlists", "Directories", "of", "Playlist Title"))).WillOnce(Return(1));
     EXPECT_CALL(*commonScriptMock, readln(Eq("[playlist]"))).WillOnce(Return(1));
-    EXPECT_CALL(*commonScriptMock, readln(Eq("\n"))).Times(2).WillRepeatedly(Return(1));
+    EXPECT_CALL(*commonScriptMock, readln(Eq(""))).Times(2).WillRepeatedly(Return(1));
     EXPECT_CALL(*commonScriptMock, readln(Eq("File1=/home/gerbera/example.mp3"))).WillOnce(Return(1));
     EXPECT_CALL(*commonScriptMock, readln(Eq("Title1=Song from Playlist Title"))).WillOnce(Return(1));
     EXPECT_CALL(*commonScriptMock, readln(Eq("Length1=120"))).WillOnce(Return(1));
