@@ -4,7 +4,7 @@
 
     gerbera-items.module.js - this file is part of Gerbera.
 
-    Copyright (C) 2016-2021 Gerbera Contributors
+    Copyright (C) 2016-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -48,17 +48,18 @@ const treeItemSelected = function (data) {
 };
 
 const retrieveGerberaItems = (type, parentId, start, count) => {
+  var requestData = {
+    req_type: type,
+    parent_id: parentId,
+    start: start,
+    count: count,
+    updates: 'check'
+  };
+  requestData[Auth.SID] = Auth.getSessionId();
   return $.ajax({
     url: GerberaApp.clientConfig.api,
     type: 'get',
-    data: {
-      req_type: type,
-      sid: Auth.getSessionId(),
-      parent_id: parentId,
-      start: start,
-      count: count,
-      updates: 'check'
-    }
+    data: requestData
   });
 };
 
@@ -76,11 +77,15 @@ const loadItems = (response) => {
       pager = {
         currentPage: Math.ceil(response.items.start / GerberaApp.viewItems()) + 1,
         pageCount: 10,
+        gridMode: GerberaApp.gridMode(),
         onClick: Items.retrieveItemsForPage,
         onNext: Items.nextPage,
         onPrevious: Items.previousPage,
+        onItemsPerPage: Items.changeItemsPerPage,
+        onModeSelect: Items.changeGridMode,
         totalMatches: response.items.total_matches,
         itemsPerPage: GerberaApp.viewItems(),
+        ippOptions: GerberaApp.itemsPerPage(),
         parentId: response.items.parent_id
       };
     } else if (type === 'fs') {
@@ -130,6 +135,32 @@ const nextPage = (event) => {
   }
 };
 
+const changeItemsPerPage = (pageItem, newValue) => {
+  GerberaApp.setViewItems(newValue);
+  const pageEvent = {
+    data: {
+      pageNumber: 1,
+      itemsPerPage: newValue,
+      gridMode: pageItem.gridMode,
+      parentId: pageItem.parentId
+    }
+  };
+  return retrieveItemsForPage(pageEvent)
+};
+
+const changeGridMode = (pageItem, newValue) => {
+  GerberaApp.setGridMode(newValue);
+  const pageEvent = {
+    data: {
+      pageNumber: pageItem.pageNumber,
+      itemsPerPage: pageItem.itemsPerPage,
+      gridMode: newValue,
+      parentId: pageItem.parentId
+    }
+  };
+  return retrieveItemsForPage(pageEvent)
+};
+
 const previousPage = function (event) {
   const pageItem = event.data;
   const pageNumber = GerberaApp.currentPage() - 1;
@@ -151,15 +182,16 @@ const previousPage = function (event) {
 const editItem = (event) => {
   const item = event.data;
   if (item) {
+    var requestData = {
+      req_type: 'edit_load',
+      object_id: item.id,
+      updates: 'check'
+    };
+    requestData[Auth.SID] = Auth.getSessionId();
     $.ajax({
       url: GerberaApp.clientConfig.api,
       type: 'get',
-      data: {
-        req_type: 'edit_load',
-        sid: Auth.getSessionId(),
-        object_id: item.id,
-        updates: 'check'
-      }
+      data: requestData
     })
       .then((response) => loadEditItem(response))
       .catch((err) => GerberaApp.error(err));
@@ -177,16 +209,17 @@ const deleteItemFromList = (event) => {
 
 const deleteGerberaItem = (item, includeAll) => {
   const deleteAll = includeAll ? 1 : 0;
+  var requestData = {
+    req_type: 'remove',
+    object_id: item.id,
+    all: deleteAll,
+    updates: 'check'
+  };
+  requestData[Auth.SID] = Auth.getSessionId();
   return $.ajax({
     url: GerberaApp.clientConfig.api,
     type: 'get',
-    data: {
-      req_type: 'remove',
-      sid: Auth.getSessionId(),
-      object_id: item.id,
-      all: deleteAll,
-      updates: 'check'
-    }
+    data: requestData
   });
 };
 
@@ -204,21 +237,30 @@ const deleteComplete = (response) => {
 const downloadItem = (event) => {
   const item = event.data;
   event.preventDefault();
-  // TODO: content type
-  window.location.href = item.url;
+
+  var link = document.createElement("a");
+  link.download = item.text;
+  link.type = item.mtype;
+  link.href = item.url;
+
+  document.body.appendChild(link);
+  link.click();
+
+  document.body.removeChild(link);
 };
 
 const addFileItem = (event) => {
   const item = event.data;
   if (item) {
+    var requestData = {
+      req_type: 'add',
+      object_id: item.id
+    };
+    requestData[Auth.SID] = Auth.getSessionId();
     $.ajax({
       url: GerberaApp.clientConfig.api,
       type: 'get',
-      data: {
-        req_type: 'add',
-        sid: Auth.getSessionId(),
-        object_id: item.id
-      }
+      data: requestData
     })
       .then((response) => addFileItemComplete(response))
       .catch((err) => GerberaApp.error(err));
@@ -247,9 +289,9 @@ const addObject = () => {
   const item = $('#editModal').editmodal('addObject');
   const addObjectData = {
     req_type: 'add_object',
-    sid: Auth.getSessionId(),
     updates: 'check'
   };
+  addObjectData[Auth.SID] = Auth.getSessionId();
   const requestData = $.extend({}, item, addObjectData);
 
   if (requestData.parent_id && requestData.parent_id >= 0) {
@@ -300,11 +342,19 @@ const transformItems = (items) => {
       id: gItem.id,
       text: gItem.title,
       url: gItem.res,
-      image: ('image' in gItem) ? gItem.image : null
+      mtype: ('mtype' in gItem) ? gItem.mtype : null,
+      upnp_class: ('upnp_class' in gItem) ? gItem.upnp_class : null,
+      image: ('image' in gItem) ? gItem.image : null,
+      part: ('part' in gItem) ? gItem.part : null,
+      track: ('track' in gItem) ? gItem.track : null
     };
 
-    if (GerberaApp.serverConfig.enableThumbnail) {
-      item.img = '/content/media/object_id/' + gItem.id + '/res_id/1/rh/6/ext/file.jpg';
+    if (!GerberaApp.serverConfig.enableNumbering) {
+      item.part = null;
+      item.track = null;
+    }
+    if (!GerberaApp.serverConfig.enableThumbnail) {
+      item.image = null;
     }
     if (GerberaApp.serverConfig.enableVideo) {
       item.video = '/content/media/object_id/' + gItem.id + '/res_id/0/ext/file.mp4';
@@ -332,7 +382,7 @@ const retrieveItemsForPage = (event) => {
   const pageItem = event.data;
   const linkType = (GerberaApp.getType() === 'db') ? 'items' : 'files';
   const start = (pageItem.pageNumber * pageItem.itemsPerPage) - pageItem.itemsPerPage;
-  return retrieveGerberaItems(linkType, pageItem.parentId, start, GerberaApp.viewItems())
+  return retrieveGerberaItems(linkType, pageItem.parentId, start, pageItem.itemsPerPage)
     .then((response) => loadItems(response))
     .then(() => {
       setPage(pageItem.pageNumber)
@@ -344,9 +394,9 @@ const saveItem = () => {
   const item = $('#editModal').editmodal('saveItem');
   const saveData = {
     req_type: 'edit_save',
-    sid: Auth.getSessionId(),
     updates: 'check'
   };
+  saveData[Auth.SID] = Auth.getSessionId();
   const requestData = $.extend({}, item, saveData);
 
   if (requestData.object_id && requestData.object_id > 0) {
@@ -399,6 +449,8 @@ export const Items = {
   saveItem,
   saveItemComplete,
   setPage,
+  changeItemsPerPage,
+  changeGridMode,
   nextPage,
   previousPage,
   transformItems,
