@@ -4,7 +4,7 @@
 
     jquery.gerbera.editor.js - this file is part of Gerbera.
 
-    Copyright (C) 2016-2021 Gerbera Contributors
+    Copyright (C) 2016-2022 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -110,7 +110,7 @@
     modal.find('#hidebutton').hide();
   }
 
-  function appendMetaItem(tbody, name, value) {
+  function appendMetaItem(tbody, name, value, special = null) {
     let row, content, text;
     row = $('<tr></tr>');
     content = $('<td></td>');
@@ -119,9 +119,14 @@
     text.text(name).appendTo(content);
     row.append(content);
     content = $('<td></td>');
-    const nl = '\n';
-    text = $('<span>' + value.replace(RegExp(nl, 'g'), '<br>') + '</span>');
-    text.appendTo(content);
+    if (value !== null) {
+      const nl = '\n';
+      text = $('<span>' + value.replace(RegExp(nl, 'g'), '<br>') + '</span>');
+      text.appendTo(content);
+    }
+    if (special !== null) {
+        special.appendTo(content);
+    }
     row.append(content);
     tbody.append(row);
   }
@@ -195,8 +200,11 @@
             $(`<thead><tr><th>Resource</th><th>${item.resources.resources[i].resvalue}</th></tr></thead>`).appendTo(restable);
             tbody = $('<tbody></tbody>');
             restable.append(tbody);
-          }
-          else {
+          } else if (item.resources.resources[i].resname === 'image') {
+            appendMetaItem(tbody, 'content', null, $('<img width="50px" class="resourceImage" src="' +  item.resources.resources[i].resvalue + '"/>'));
+          } else if (item.resources.resources[i].resname === 'link') {
+            appendMetaItem(tbody, 'content', null, $('<a href=' +  item.resources.resources[i].resvalue + '>Open</span>'));
+          } else {
             appendMetaItem(tbody, item.resources.resources[i].resname, item.resources.resources[i].resvalue);
           }
         }
@@ -263,6 +271,18 @@
         .closest('.form-group').hide();
     }
 
+    if ('last_updated' in item && item['last_updated'].value !== '') {
+      modal.find('#editLut')
+        .val(item['last_updated'].value)
+        .prop('disabled', true)
+        .closest('.form-group').show();
+    } else {
+      modal.find('#editLut')
+        .val('')
+        .prop('disabled', true)
+        .closest('.form-group').hide();
+    }
+
     hideFields([
       modal.find('#editProtocol')
     ]);
@@ -291,6 +311,18 @@
         .closest('.form-group').hide();
     }
 
+    if ('last_updated' in item && item['last_updated'].value !== '') {
+      modal.find('#editLut')
+        .val(item['last_updated'].value)
+        .prop('disabled', true)
+        .closest('.form-group').show();
+    } else {
+      modal.find('#editLut')
+        .val('')
+        .prop('disabled', true)
+        .closest('.form-group').hide();
+    }
+
     hideFields([
       modal.find('#editLocation'),
       modal.find('#editMime'),
